@@ -28,6 +28,7 @@
 #include "../rtgui/mydiagonalcurve.h"
 #include "color.h"
 #include "procparams.h"
+#include "editbuffer.h"
 
 #include "LUT.h"
 
@@ -59,7 +60,7 @@ class CurveFactory {
     static inline double basel (double x, double m1, double m2) {
         if (x==0.0)
             return 0.0;
-        double k = sqrt ((m1-1.0)*(m1-m2)/2) / (1.0-m2);
+        double k = sqrt ((m1-1.0)*(m1-m2)*0.5) / (1.0-m2);
         double l = (m1-m2) / (1.0-m2) + k;
         double lx = xlog(x);
         return m2*x + (1.0-m2)*(2.0 - xexp(k*lx))*xexp(l*lx);
@@ -92,12 +93,14 @@ class CurveFactory {
     }
 	static inline double clower2 (double x, double m, double sr) {
 		//curve for b<0; starts with positive slope and then rolls over toward straight line to x=y=1
-		float x1 = sr/1.5 + 0.00001;
-		float y1 = 1-(1-x1)*m;
+		double x1 = sr/1.5 + 0.00001;
 		if (x>x1 || sr<0.001) 
 			return 1-(1-x)*m;
 		else
+		{
+			double y1 = 1-(1-x1)*m;
 			return y1+m*(x-x1)-(1-m)*SQR(SQR(1-x/x1));
+		}
 	}
     // tone curve base. a: slope (from exp.comp.), b: black point normalized by 65535, 
 	// D: max. x value (can be>1), hr,sr: highlight,shadow recovery
@@ -122,6 +125,26 @@ class CurveFactory {
 				return y+(x-m)*slope;
 		}
     }
+    static inline double simplebasecurve (double x, double b, double sr) { 
+    	// a = 1, D = 1, hr = 0 (unused for a = D = 1)
+        if (b<0) {
+			double m = 0.5;//midpoint
+			double slope = 1.0+b;//slope of straight line between (0,-b) and (1,1)
+			double y = -b+m*slope;//value at midpoint
+			if (x>m) 
+				return y + (x - m)*slope;//value on straight line between (m,y) and (1,1)
+			else 
+				return y*clower2(x/m, slope*m/y, 2.0-sr);
+		} else {
+			double slope = 1.0/(1.0-b);
+			double m = b+(1-b)*0.25;
+			double y = (m-b)*slope;
+			if (x<=m)
+				return b==0 ? x*slope : clower (x/m, slope*m/y, sr) * y;
+			else
+				return y+(x-m)*slope;
+		}
+    }
 	
 
   public:
@@ -170,9 +193,14 @@ class CurveFactory {
 	{
 		if (comp>0.0) {
 			float val = level+(hlrange-65536.0);
+			if(val == 0.0f)	// to avoid division by zero
+				val = 0.000001f;
 			float Y = val*exp_scale/hlrange;
+			Y *= comp;
+			if(Y <= -1.0)	// to avoid log(<=0)
+				Y = -.999999f;
 			float R = hlrange/(val*comp);
-			return log(1.0+Y*comp)*R;
+			return log(1.0+Y)*R;
 		} else {
 			return exp_scale;
 		}
@@ -190,8 +218,11 @@ class CurveFactory {
 						 ToneCurve & customToneCurvebw1, ToneCurve & customToneCurvebw2, int skip);
 		
 	static void curveCL ( bool & clcutili, const std::vector<double>& clcurvePoints, LUTf & clCurve, LUTu & histogramcl, LUTu & outBeforeCLurveHistogram, int skip);
+	static void curveToningCL ( bool & clctoningutili, const std::vector<double>& clcurvePoints, LUTf & clToningCurve, int skip);
+	static void curveToningLL ( bool & llctoningutili, const std::vector<double>& llcurvePoints, LUTf & llToningCurve, int skip);
+	static void denoiseLL ( bool & lldenoiseutili, const std::vector<double>& llcurvePoints, LUTf & Noisecurve,int skip);
 						  
-	static void complexsgnCurve ( bool & autili,  bool & butili, bool & ccutili, bool & clcutili, double saturation, double rstprotection, const std::vector<double>& acurvePoints,
+	static void complexsgnCurve ( float adjustr, bool & autili,  bool & butili, bool & ccutili, bool & clcutili, double saturation, double rstprotection, const std::vector<double>& acurvePoints,
 								 const std::vector<double>& bcurvePoints,const std::vector<double>& cccurvePoints,const std::vector<double>& lccurvePoints, LUTf & aoutCurve, LUTf & boutCurve, LUTf & satCurve, LUTf & lhskCurve, 
 								 LUTu & histogramC, LUTu & histogramLC, LUTu & outBeforeCCurveHistogram,LUTu & outBeforeLCurveHistogram,///for chroma
 								int skip=1);
@@ -260,6 +291,8 @@ class Curve {
     Curve ();
     virtual ~Curve () {};
     void AddPolygons ();
+    int getSize () const; // return the number of control points
+    void getControlPoint(int cpNum, double &x, double &y) const;
     virtual double getVal (double t) const = 0;
     virtual void   getVal (const std::vector<double>& t, std::vector<double>& res) const = 0;
 
@@ -271,10 +304,6 @@ class DiagonalCurve : public Curve {
   protected:
     DiagonalCurveType kind;
 
-    unsigned int minSearch;     // a effacer!!!
-    unsigned int maxSearch;     // a effacer!!!
-    unsigned int searchArray[21];     // a effacer!!!
-
     void spline_cubic_set ();
     void NURBS_set ();
 
@@ -320,6 +349,69 @@ class ToneCurve {
     operator bool (void) const { return lutToneCurve; }
 };
 
+class OpacityCurve {
+  public:
+    LUTf lutOpacityCurve;  // 0xffff range
+
+    virtual ~OpacityCurve() {};
+
+    void Reset();
+    void Set(const Curve *pCurve);
+    void Set(const std::vector<double> &curvePoints, bool &opautili);
+
+    // TODO: transfer this method to the Color class...
+    float blend (float x, float lower, float upper) const {
+        return (upper-lower)*lutOpacityCurve[x*500.f] + lower;
+    }
+    void blend3f (float x, float lower1, float upper1, float &result1, float lower2, float upper2, float &result2, float lower3, float upper3, float &result3) const {
+        float opacity = lutOpacityCurve[x*500.f];
+        result1 = (upper1-lower1)*opacity + lower1;
+        result2 = (upper2-lower2)*opacity + lower2;
+        result3 = (upper3-lower3)*opacity + lower3;
+    }
+
+    operator bool (void) const { return lutOpacityCurve; }
+};
+class NoisCurve {
+  public:
+    LUTf lutNoisCurve;  // 0xffff range
+	float nonzero;
+    virtual ~NoisCurve() {};
+
+    void Reset();
+    void Set(const Curve *pCurve);
+    void Set(const std::vector<double> &curvePoints, bool &lldenoiseutili);
+
+    operator bool (void) const { return lutNoisCurve; }
+};
+
+class ColorGradientCurve {
+  public:
+    LUTf   lut1;    // [0.;1.] range (float values)
+    LUTf   lut2;  // [0.;1.] range (float values)
+    LUTf   lut3;   // [0.;1.] range (float values)
+    double low;
+    double high;
+
+    virtual ~ColorGradientCurve() {};
+
+    void Reset();
+    void SetXYZ(const Curve *pCurve, const double xyz_rgb[3][3], const double rgb_xyz[3][3], float satur, float lumin);
+    void SetXYZ(const std::vector<double> &curvePoints, const double xyz_rgb[3][3], const double rgb_xyz[3][3], float satur, float lumin);
+    void SetRGB(const Curve *pCurve, const double xyz_rgb[3][3], const double rgb_xyz[3][3]);
+    void SetRGB(const std::vector<double> &curvePoints, const double xyz_rgb[3][3], const double rgb_xyz[3][3]);
+
+    /**
+    * @brief Get the value of Red, Green and Blue corresponding to the requested index
+    * @param index value in the [0 ; 1] range
+    * @param r corresponding red value [0 ; 65535] (return value)
+    * @param g corresponding green value [0 ; 65535] (return value)
+    * @param b corresponding blue value [0 ; 65535] (return value)
+    */
+    void getVal(float index, float &r, float &g, float &b) const;
+    operator bool (void) const { return lut1 && lut2 && lut3; }
+};
+
 class ColorAppearance {
   public:
     LUTf lutColCurve;  // 0xffff range
