@@ -48,19 +48,21 @@ public:
     ,ifname(NULL)
     ,meta_data(NULL)
     ,shot_select(0),multi_out(0)
+	,float_raw_image(NULL)
     ,image(NULL)
     ,bright(1.),threshold(0.)
     ,half_size(0),four_color_rgb(0),document_mode(0),highlight(0)
     ,verbose(0)
+    ,use_auto_wb(0),use_camera_wb(0),use_camera_matrix(1)
+    ,output_color(1),output_bps(8),output_tiff(0),med_passes(0),no_auto_bright(0)
     ,RT_whitelevel_from_constant(0)
     ,RT_blacklevel_from_constant(0)
     ,RT_matrix_from_constant(0)
-    ,use_auto_wb(0),use_camera_wb(0),use_camera_matrix(-1)
-    ,output_color(1),output_bps(8),output_tiff(0),med_passes(0),no_auto_bright(0)
 	,getbithuff(this,ifp,zero_after_ff)
 	,ph1_bithuff(this,ifp,order)	
 	,pana_bits(ifp,load_flags)
     {
+        memset(&hbd, 0, sizeof(hbd));
         aber[0]=aber[1]=aber[2]=aber[3]=1;
         gamm[0]=0.45;gamm[1]=4.5;gamm[2]=gamm[3]=gamm[4]=gamm[5]=0;
         user_mul[0]=user_mul[1]=user_mul[2]=user_mul[3]=0;
@@ -74,8 +76,8 @@ protected:
     FILE *ofp;
     short order;
     const char *ifname;
-    char *meta_data, xtrans[6][6];
-    char cdesc[5], desc[512], make[64], model[64], model2[64], artist[64];
+    char *meta_data, xtrans[6][6],xtrans_abs[6][6];
+    char cdesc[5], desc[512], make[64], model[64], model2[64], model3[64], artist[64];
     float flash_used, canon_ev, iso_speed, shutter, aperture, focal_len;
     time_t timestamp;
     unsigned shot_order, kodak_cbpp, filters, exif_cfa, unique_id;
@@ -84,12 +86,13 @@ protected:
     unsigned thumb_length, meta_length, profile_length;
     unsigned thumb_misc, *oprof, fuji_layout, shot_select, multi_out;
     unsigned tiff_nifds, tiff_samples, tiff_bps, tiff_compress;
-    unsigned black, cblack[4], maximum, mix_green, raw_color, zero_is_bad;
+    unsigned black, cblack[4102], maximum, mix_green, raw_color, zero_is_bad;
     unsigned zero_after_ff, is_raw, dng_version, is_foveon, data_error;
     unsigned tile_width, tile_length, gpsdata[32], load_flags;
     ushort raw_height, raw_width, height, width, top_margin, left_margin;
     ushort shrink, iheight, iwidth, fuji_width, thumb_width, thumb_height;
     ushort *raw_image;
+    float * float_raw_image;
     ushort white[8][8], curve[0x10000], cr2_slice[3], sraw_mul[4];
     int mask[8][4], flip, tiff_flip, colors;
     double pixel_aspect;
@@ -103,9 +106,9 @@ protected:
     int output_color, output_bps, output_tiff, med_passes;
     int no_auto_bright;
     unsigned greybox[4] ;
-    int RT_matrix_from_constant;
-    int RT_blacklevel_from_constant;
     int RT_whitelevel_from_constant;
+    int RT_blacklevel_from_constant;
+    int RT_matrix_from_constant;
 
     float cam_mul[4], pre_mul[4], cmatrix[3][4], rgb_cam[3][4];
     
@@ -123,13 +126,17 @@ protected:
 
     struct tiff_ifd {
       int width, height, bps, comp, phint, offset, flip, samples, bytes;
-      int tile_width, tile_length;
+      int tile_width, tile_length, sample_format, predictor;
     } tiff_ifd[10];
 
     struct ph1 {
-      int format, key_off, black, black_off, split_col, tag_21a;
-      float tag_210;
+	  int format, key_off, tag_21a;
+	  int black, split_col, black_col, split_row, black_row;
+	  float tag_210;
     } ph1;
+    struct hbd {
+        off_t levels, unknown1, flatfield;
+    } hbd;
 
     struct jhead {
       int bits, high, wide, clrs, sraw, psv, restart, vpred[6];
@@ -170,6 +177,7 @@ unsigned getint (int type);
 float int_to_float (int i);
 double getreal (int type);
 void read_shorts (ushort *pixel, int count);
+void cubic_spline(const int *x_, const int *y_, const int len);
 void canon_600_fixed_wb (int temp);
 int canon_600_color (int ratio[2], int mar);
 void canon_600_auto_wb();
@@ -214,6 +222,7 @@ void canon_sraw_load_raw();
 void adobe_copy_pixel (unsigned row, unsigned col, ushort **rp);
 void lossless_dng_load_raw();
 void packed_dng_load_raw();
+void deflate_dng_load_raw();
 void pentax_load_raw();
 void nikon_load_raw();
 int nikon_is_compressed();
@@ -230,6 +239,11 @@ int raw (unsigned row, unsigned col);
 void phase_one_flat_field (int is_float, int nc);
 void phase_one_correct();
 void phase_one_load_raw();
+void nikon_yuv_load_raw();
+void kodak_c330_load_raw();
+void kodak_c603_load_raw();
+void samsung3_load_raw();
+void parse_qt (int end);
 
 // ph1_bithuff(int nbits, ushort *huff);
 class ph1_bithuff_t {
@@ -249,6 +263,8 @@ private:
 ph1_bithuff_t ph1_bithuff;
 
 void phase_one_load_raw_c();
+void hasselblad_correct();
+void parse_hasselblad_gain();
 void hasselblad_load_raw();
 void leaf_hdr_load_raw();
 void unpacked_load_raw();
@@ -277,7 +293,7 @@ void minolta_rd175_load_raw();
 void quicktake_100_load_raw();
 void kodak_radc_load_raw();
 void samsung_load_raw();
-
+void samsung2_load_raw();
 void kodak_jpeg_load_raw();
 void lossy_dng_load_raw();
 void kodak_dc120_load_raw();
@@ -333,7 +349,7 @@ void bad_pixels (const char *cfname);
 void subtract (const char *fname);
 void gamma_curve (double pwr, double ts, int mode, int imax);
 void pseudoinverse (double (*in)[3], double (*out)[3], int size);
-void cam_xyz_coeff (double cam_xyz[4][3]);
+void cam_xyz_coeff (float rgb_cam[3][4], double cam_xyz[4][3]);
 void hat_transform (float *temp, float *base, int st, int size, int sc);
 void wavelet_denoise();
 void scale_colors();
