@@ -5,6 +5,7 @@
  *
  *  RawTherapee is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
+ *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  * 
@@ -23,17 +24,17 @@
 #include "rt_math.h"
 #include "colortemp.h"
 
+// "ceil" rounding
 #define SKIPS(a,b) ((a) / (b) + ((a) % (b) > 0))
 
 namespace rtengine {
 
 extern const Settings* settings;
 
-Crop::Crop (ImProcCoordinator* parent)
-    : origCrop(NULL), transCrop(NULL), laboCrop(NULL), labnCrop(NULL),
-      cropImg(NULL), cieCrop(NULL), cbuf_real(NULL), cshmap(NULL),
-      cbuffer(NULL), updating(false), newUpdatePending(false),
-      skip(10),
+Crop::Crop (ImProcCoordinator* parent, EditDataProvider *editDataProvider)
+    : EditBuffer(editDataProvider), origCrop(NULL), laboCrop(NULL), labnCrop(NULL),
+      cropImg(NULL), cbuf_real(NULL), cshmap(NULL), transCrop(NULL), cieCrop(NULL), cbuffer(NULL),
+      updating(false), newUpdatePending(false), skip(10),
       cropx(0), cropy(0), cropw(-1), croph(-1),
       trafx(0), trafy(0), trafw(-1), trafh(-1),
       rqcropx(0), rqcropy(0), rqcropw(-1), rqcroph(-1),
@@ -47,17 +48,18 @@ Crop::Crop (ImProcCoordinator* parent)
 Crop::~Crop () {
 
     MyMutex::MyLock cropLock(cropMutex);
-    MyMutex::MyLock processingLock(parent->mProcessing);
 
     std::vector<Crop*>::iterator i = std::find (parent->crops.begin(), parent->crops.end(), this);
     if (i!=parent->crops.end ())
         parent->crops.erase (i);
+
+    MyMutex::MyLock processingLock(parent->mProcessing);
     freeAll ();
 }
 
 void Crop::destroy () {
     MyMutex::MyLock lock(cropMutex);
-    MyMutex::MyLock processingLock(parent->mProcessing);   /////////         RETESTER MAINTENANT QUE CE VERROU EST AJOUTE!!!
+    MyMutex::MyLock processingLock(parent->mProcessing);
     freeAll();
 }
 
@@ -69,9 +71,46 @@ void Crop::setListener (DetailedCropListener* il) {
     }
 }
 
-void Crop::update (int todo) {
+EditUniqueID Crop::getCurrEditID() {
+    EditSubscriber *subscriber = EditBuffer::dataProvider ? EditBuffer::dataProvider->getCurrSubscriber() : NULL;
+    return subscriber ? subscriber->getEditID() : EUID_None;
+}
+
+/*
+ * Delete the edit image buffer if there's no subscriber anymore.
+ * If allocation has to be done, it is deferred to Crop::update
+ */
+void Crop::setEditSubscriber(EditSubscriber* newSubscriber) {
     MyMutex::MyLock lock(cropMutex);
 
+    // At this point, editCrop.dataProvider->currSubscriber is the old subscriber
+    EditSubscriber *oldSubscriber = EditBuffer::dataProvider ? EditBuffer::dataProvider->getCurrSubscriber() : NULL;
+    if (newSubscriber == NULL || (oldSubscriber != NULL && oldSubscriber->getEditBufferType() != newSubscriber->getEditBufferType())) {
+        if (EditBuffer::imgFloatBuffer!=NULL) {
+            delete EditBuffer::imgFloatBuffer;
+            EditBuffer::imgFloatBuffer = NULL;
+        }
+        if (EditBuffer::LabBuffer!=NULL) {
+            delete EditBuffer::LabBuffer;
+            EditBuffer::LabBuffer = NULL;
+        }
+        if (EditBuffer::singlePlaneBuffer.getW()!=-1) {
+            EditBuffer::singlePlaneBuffer.flushData();
+        }
+    }
+    if (newSubscriber == NULL  && oldSubscriber != NULL && oldSubscriber->getEditingType() == ET_OBJECTS) {
+    	printf("Free object buffers\n");
+        EditBuffer::resize(0, 0); // This will delete the objects buffer
+    }
+    else if (newSubscriber && newSubscriber->getEditingType() == ET_OBJECTS) {
+        EditBuffer::resize(cropw, croph, newSubscriber);
+    }
+    // If oldSubscriber == NULL && newSubscriber != NULL -> the image will be allocated when necessary
+}
+
+void Crop::update (int todo) {
+    MyMutex::MyLock cropLock(cropMutex);
+
     ProcParams& params = parent->params;
 
     // No need to update todo here, since it has already been changed in ImprocCoordinator::updatePreviewImage,
@@ -117,14 +156,31 @@ void Crop::update (int todo) {
         parent->imgsrc->getImage (parent->currWB, tr, origCrop, pp, params.toneCurve, params.icm, params.raw );
         //ColorTemp::CAT02 (origCrop, &params)	;
 
-        //parent->imgsrc->convertColorSpace(origCrop, params.icm);
-
+		Imagefloat *calclum;//for Luminance denoise curve
+		NoisCurve dnNoisCurve;
+		bool lldenoiseutili=false;
+		params.dirpyrDenoise.getCurves(dnNoisCurve, lldenoiseutili);
+		if(lldenoiseutili && skip==1 && params.dirpyrDenoise.enabled)	{//only allocate memory if enabled and skip
+			calclum = new Imagefloat (cropw, croph);//for Luminance denoise curve
+				if(origCrop !=  calclum)
+					origCrop->copyData(calclum);
+		
+			parent->imgsrc->convertColorSpace(calclum, params.icm, parent->currWB, params.raw);//for denoise luminance curve
+		}
         if (todo & M_LINDENOISE) {
-            if (skip==1 && params.dirpyrDenoise.enabled)
-                parent->ipf.RGB_denoise(origCrop, origCrop, parent->imgsrc->isRAW(), /*Roffset,*/ params.dirpyrDenoise, params.defringe, parent->imgsrc->getDirPyrDenoiseExpComp());
+            if (skip==1 && params.dirpyrDenoise.enabled) {
+
+                parent->ipf.RGB_denoise(origCrop, origCrop, calclum, parent->imgsrc->isRAW(), /*Roffset,*/ params.dirpyrDenoise, params.defringe, parent->imgsrc->getDirPyrDenoiseExpComp(), dnNoisCurve,lldenoiseutili);
         }
+		}
+	//	delete calclum;
+
         parent->imgsrc->convertColorSpace(origCrop, params.icm, parent->currWB, params.raw);
-    }
+
+	}
+
+    // has to be called after setCropSizes! Tools prior to this point can't handle the Edit mechanism, but that shouldn't be a problem.
+    createBuffer(cropw, croph);
 
     // transform
     if (needstransform) {
@@ -148,8 +204,11 @@ void Crop::update (int todo) {
         double radius = sqrt (double(SKIPS(parent->fw,skip)*SKIPS(parent->fw,skip)+SKIPS(parent->fh,skip)*SKIPS(parent->fh,skip))) / 2.0;
         double shradius = params.sh.radius;
         if (!params.sh.hq) shradius *= radius / 1800.0;
+        if(!cshmap)
+			cshmap = new SHMap (cropw, croph, true);
         cshmap->update (baseCrop, shradius, parent->ipf.lumimul, params.sh.hq, skip);
-        cshmap->forceStat (parent->shmap->max_f, parent->shmap->min_f, parent->shmap->avg);
+        if(parent->shmap->min_f < 65535.f) // don't call forceStat with wrong values
+            cshmap->forceStat (parent->shmap->max_f, parent->shmap->min_f, parent->shmap->avg);
     }
 
     // shadows & highlights & tone curve & convert to cielab
@@ -165,11 +224,25 @@ void Crop::update (int todo) {
                    parent->imgsrc->getGamma());
         }*/
     double rrm, ggm, bbm;
+    float satLimit = float(params.colorToning.satProtectionThreshold)/100.f*0.7f+0.3f;
+    float satLimitOpacity = 1.f-(float(params.colorToning.saturatedOpacity)/100.f);
+
+    if(params.colorToning.enabled  && params.colorToning.autosat){//for colortoning evaluation of saturation settings
+        float moyS=0.f;
+        float eqty=0.f;
+        parent->ipf.moyeqt (baseCrop, moyS, eqty);//return image : mean saturation and standard dev of saturation
+        //printf("moy=%f ET=%f\n", moyS,eqty);
+        float satp=((moyS+1.5f*eqty)-0.3f)/0.7f;//1.5 sigma ==> 93% pixels with high saturation -0.3 / 0.7 convert to Hombre scale
+        if(satp >= 0.92f) satp=0.92f;//avoid values too high (out of gamut)
+        if(satp <= 0.15f) satp=0.15f;//avoid too low values
+        satLimit= 100.f*satp;
+        satLimitOpacity= 100.f*(moyS-0.85f*eqty);//-0.85 sigma==>20% pixels with low saturation
+    }
 
     if (todo & M_RGBCURVE)
-        parent->ipf.rgbProc (baseCrop, laboCrop, parent->hltonecurve, parent->shtonecurve, parent->tonecurve, cshmap,
-                             params.toneCurve.saturation, parent->rCurve, parent->gCurve, parent->bCurve, parent->customToneCurve1,
-                             parent->customToneCurve2, parent->beforeToneCurveBW, parent->afterToneCurveBW,rrm, ggm, bbm,
+        parent->ipf.rgbProc (baseCrop, laboCrop, this, parent->hltonecurve, parent->shtonecurve, parent->tonecurve, cshmap,
+                             params.toneCurve.saturation, parent->rCurve, parent->gCurve, parent->bCurve, satLimit ,satLimitOpacity, parent->ctColorCurve, parent->ctOpacityCurve, parent->opautili, parent->clToningcurve,parent->cl2Toningcurve,
+                             parent->customToneCurve1, parent->customToneCurve2, parent->beforeToneCurveBW, parent->afterToneCurveBW,rrm, ggm, bbm,
                              parent->bwAutoR, parent->bwAutoG, parent->bwAutoB);
 
     /*xref=000;yref=000;
@@ -195,16 +268,15 @@ void Crop::update (int todo) {
 
 
         //parent->ipf.luminanceCurve (labnCrop, labnCrop, parent->lumacurve);
-        bool utili=true;
-        bool autili=true;
-        bool butili=true;
-        bool ccutili=true;
-        bool clcutili=true;
-        bool cclutili=true;
+        bool utili=parent->utili;
+        bool autili=parent->autili;
+        bool butili=parent->butili;
+        bool ccutili=parent->ccutili;
+        bool clcutili=parent->clcutili;
+        bool cclutili=parent->cclutili;
 
- 
         LUTu dummy;
-        parent->ipf.chromiLuminanceCurve (1,labnCrop, labnCrop, parent->chroma_acurve, parent->chroma_bcurve, parent->satcurve, parent->lhskcurve,  parent->clcurve, parent->lumacurve, utili, autili, butili, ccutili,cclutili, clcutili, dummy, dummy, dummy, dummy);
+        parent->ipf.chromiLuminanceCurve (this, 1,labnCrop, labnCrop, parent->chroma_acurve, parent->chroma_bcurve, parent->satcurve, parent->lhskcurve,  parent->clcurve, parent->lumacurve, utili, autili, butili, ccutili,cclutili, clcutili, dummy, dummy, dummy, dummy);
         parent->ipf.vibrance (labnCrop);
         if((params.colorappearance.enabled && !params.colorappearance.tonecie) ||  (!params.colorappearance.enabled)) parent->ipf.EPDToneMap(labnCrop,5,1);
         //parent->ipf.EPDToneMap(labnCrop, 5, 1);    //Go with much fewer than normal iterates for fast redisplay.
@@ -215,12 +287,17 @@ void Crop::update (int todo) {
             if((params.colorappearance.enabled && !settings->autocielab) ||(!params.colorappearance.enabled) ) {parent->ipf.defringe (labnCrop);}
             parent->ipf.MLsharpen (labnCrop);
             if((params.colorappearance.enabled && !settings->autocielab)  || (!params.colorappearance.enabled)) {
-                    parent->ipf.MLmicrocontrast (labnCrop);
-                    parent->ipf.sharpening (labnCrop, (float**)cbuffer);
-                    parent->ipf.dirpyrequalizer (labnCrop);
-                    }
+                parent->ipf.MLmicrocontrast (labnCrop);
+                parent->ipf.sharpening (labnCrop, (float**)cbuffer);
+            }
         }
-
+     //   if (skip==1) {
+		
+        if((params.colorappearance.enabled && !settings->autocielab)  || (!params.colorappearance.enabled)) {
+            parent->ipf.dirpyrequalizer (labnCrop, skip);
+		//	parent->ipf.Lanczoslab (labnCrop,labnCrop , 1.f/skip);
+		}
+     //   }
         if(params.colorappearance.enabled){
             float fnum = parent->imgsrc->getMetaData()->getFNumber  ();        // F number
             float fiso = parent->imgsrc->getMetaData()->getISOSpeed () ;       // ISO
@@ -243,17 +320,19 @@ void Crop::update (int todo) {
             if(skip==1) execsharp=true;
 
             if (!cieCrop)
-                cieCrop = new CieImage (cropw, croph);
+               { cieCrop = new CieImage (cropw, croph); }
 
             if(settings->ciecamfloat) {
                 float d; // not used after this block
+				skip2=skip;
                 parent->ipf.ciecam_02float (cieCrop, float(adap), begh, endh, 1, 2, labnCrop, &params, parent->customColCurve1, parent->customColCurve2, parent->customColCurve3,
-                                            dummy, dummy, parent->CAMBrightCurveJ, parent->CAMBrightCurveQ, parent->CAMMean, 5, 1,(float**)cbuffer, execsharp, d);
+                                            dummy, dummy, parent->CAMBrightCurveJ, parent->CAMBrightCurveQ, parent->CAMMean, 5, 1, execsharp, d, skip, 1);			
             }
             else {
                 double dd; // not used after this block
+
                 parent->ipf.ciecam_02 (cieCrop,adap, begh, endh, 1, 2, labnCrop, &params, parent->customColCurve1, parent->customColCurve2, parent->customColCurve3,
-                                       dummy, dummy, parent->CAMBrightCurveJ, parent->CAMBrightCurveQ, parent->CAMMean, 5, 1,(float**)cbuffer, execsharp, dd);
+                                       dummy, dummy, parent->CAMBrightCurveJ, parent->CAMBrightCurveQ, parent->CAMMean, 5, 1, execsharp, dd, skip, 1);
             }
         }
         else {
@@ -261,6 +340,10 @@ void Crop::update (int todo) {
             if (cieCrop) delete cieCrop; cieCrop=NULL;
         }
     }
+
+    // all pipette buffer processing should be finished now
+    EditBuffer::setReady();
+
     // switch back to rgb
     parent->ipf.lab2monitorRgb (labnCrop, cropImg);
 
@@ -301,8 +384,13 @@ void Crop::update (int todo) {
     if (cropImageListener) {
         // this in output space held in parallel to allow analysis like shadow/highlight
         Glib::ustring outProfile=params.icm.output;
-        if (params.icm.output=="" || params.icm.output==ColorManagementParams::NoICMString) outProfile="sRGB";
-        Image8 *cropImgtrue = parent->ipf.lab2rgb (labnCrop, 0,0,cropw,croph, outProfile, false);
+        Glib::ustring workProfile=params.icm.working;
+		Image8 *cropImgtrue;
+        if(settings->HistogramWorking)  cropImgtrue = parent->ipf.lab2rgb (labnCrop, 0,0,cropw,croph, workProfile, false);
+		else {
+			if (params.icm.output=="" || params.icm.output==ColorManagementParams::NoICMString) outProfile="sRGB";
+			cropImgtrue = parent->ipf.lab2rgb (labnCrop, 0,0,cropw,croph, outProfile, false);
+			}
 
         int finalW = rqcropw;
         if (cropImg->getWidth()-leftBorder < finalW)
@@ -329,15 +417,17 @@ void Crop::freeAll () {
     if (settings->verbose) printf ("freeallcrop starts %d\n", (int)cropAllocated);
 
     if (cropAllocated) {
-        if (origCrop ) { delete    origCrop;  origCrop=NULL; }
-        if (transCrop) { delete    transCrop; transCrop=NULL; }
-        if (laboCrop ) { delete    laboCrop;  laboCrop=NULL; }
-        if (labnCrop ) { delete    labnCrop;  labnCrop=NULL; }
-        if (cropImg  ) { delete    cropImg;   cropImg=NULL; }
-        if (cieCrop  ) { delete    cieCrop;   cieCrop=NULL; }
-        if (cbuf_real) { delete [] cbuf_real; cbuf_real=NULL; }
-        if (cbuffer  ) { delete [] cbuffer;   cbuffer=NULL; }
-        if (cshmap   ) { delete    cshmap;    cshmap=NULL; }
+        if (origCrop ) { delete    origCrop;    origCrop=NULL; }
+        if (transCrop) { delete    transCrop;   transCrop=NULL; }
+        if (laboCrop ) { delete    laboCrop;    laboCrop=NULL; }
+        if (labnCrop ) { delete    labnCrop;    labnCrop=NULL; }
+        if (cropImg  ) { delete    cropImg;     cropImg=NULL; }
+        if (cieCrop  ) { delete    cieCrop;     cieCrop=NULL; }
+        if (cbuf_real) { delete [] cbuf_real;   cbuf_real=NULL; }
+        if (cbuffer  ) { delete [] cbuffer;     cbuffer=NULL; }
+        if (cshmap   ) { delete    cshmap;      cshmap=NULL; }
+
+        EditBuffer::flush();
     }
     cropAllocated = false;
 }
@@ -410,24 +500,43 @@ if (settings->verbose) printf ("setcropsizes before lock\n");
 
     if (cw!=cropw || ch!=croph || orW!=trafw || orH!=trafh) {
 
-        freeAll ();
-    
         cropw = cw;
         croph = ch;
         trafw = orW;
         trafh = orH;
 
-        origCrop = new Imagefloat (trafw, trafh);
-        //transCrop will be allocated later, if necessary
+        if (!origCrop)
+            origCrop = new Imagefloat;
+        origCrop->allocate(trafw, trafh); // Resizing the buffer (optimization)
+
+        // if transCrop doesn't exist yet, it'll be created where necessary
+        if (transCrop) transCrop->allocate(cropw, croph);
+
+        if (laboCrop) delete laboCrop;  // laboCrop can't be resized
         laboCrop = new LabImage (cropw, croph);
+
+        if (labnCrop) delete labnCrop;  // labnCrop can't be resized
         labnCrop = new LabImage (cropw, croph);
-        cropImg = new Image8 (cropw, croph);
-        //cieCrop is only used in Crop::update, it will be allocated on first use and deleted if not used anymore
+
+        if (!cropImg)
+            cropImg = new Image8;
+        cropImg->allocate(cropw, croph); // Resizing the buffer (optimization)
+
+        //cieCrop is only used in Crop::update, it is destroyed now but will be allocated on first use
+        if (cieCrop) { delete cieCrop; cieCrop=NULL; }
+
+        if (cbuffer  ) delete [] cbuffer;
+        if (cbuf_real) delete [] cbuf_real;
+        if (cshmap   ) { delete    cshmap; cshmap = NULL;}
         cbuffer = new float*[croph];
         cbuf_real= new float[(croph+2)*cropw];
         for (int i=0; i<croph; i++)
             cbuffer[i] = cbuf_real+cropw*i+cropw;
-        cshmap = new SHMap (cropw, croph, true);
+		if(params.sh.enabled) {
+			cshmap = new SHMap (cropw, croph, true);
+		}
+
+        EditBuffer::resize(cropw, croph);
 
         cropAllocated = true;
 
@@ -483,7 +592,6 @@ void Crop::fullUpdate () {
         //parent->changeSinceLast = 0;
         parent->thread->join ();
     }
-    parent->updaterThreadStart.unlock ();
 
     if (parent->plistener)
         parent->plistener->setProgressState (true);
@@ -498,6 +606,7 @@ void Crop::fullUpdate () {
 
     if (parent->plistener)
         parent->plistener->setProgressState (false);
+    parent->updaterThreadStart.unlock ();
 }
 
 }
