@@ -58,6 +58,14 @@ namespace rtengine {
         IIOSA_PLANAR
     } IIOSampleArrangement;
 
+    typedef enum SensorType {
+        ST_NONE,   // use this value if the image is already demosaiced (i.e. not a raw file)
+        ST_BAYER,
+        ST_FUJI_XTRANS,
+        //ST_FOVEON,
+        //ST_FUJI_EXR
+    } eSensorType;
+
 class ImageIO : virtual public ImageDatas {
 
     protected:
