@@ -44,12 +44,13 @@ ImProcCoordinator::ImProcCoordinator ()
       satcurve(65536,0),
       lhskcurve(65536,0),
       clcurve(65536,0),
-
+      clToningcurve(65536,0),
+      cl2Toningcurve(65536,0),
+	  Noisecurve(65536,0),
       vhist16(65536),vhist16bw(65536),
       lhist16(65536), lhist16Cropped(65536),
       lhist16CAM(65536), lhist16CroppedCAM(65536),
       lhist16CCAM(65536),
-      lhist16CCAMAF(65536), lhist16ClabAF(65536),
       histCropped(65536),
       lhist16Clad(65536),lhist16CLlad(65536),
       lhist16LClad(65536), lhist16LLClad(65536),
@@ -80,8 +81,10 @@ ImProcCoordinator::ImProcCoordinator ()
       bcurvehist(256), bcurvehistCropped(256), bbeforehist(256),
 
       pW(-1), pH(-1),
-      plistener(NULL), imageListener(NULL), aeListener(NULL), hListener(NULL),acListener(NULL), abwListener(NULL),
-      resultValid(false), changeSinceLast(0), updaterRunning(false), destroying(false)
+      plistener(NULL), imageListener(NULL), aeListener(NULL), hListener(NULL),acListener(NULL), abwListener(NULL),actListener(NULL),
+      resultValid(false), changeSinceLast(0), updaterRunning(false), destroying(false),utili(false),autili(false),lldenoiseutili(false), opautili(false),
+	  butili(false),ccutili(false),cclutili(false),clcutili(false),fullw(1),fullh(1)
+
     {}
 
 void ImProcCoordinator::assign (ImageSource* imgsrc) {
@@ -106,18 +109,17 @@ ImProcCoordinator::~ImProcCoordinator () {
     updaterThreadStart.unlock ();
 }
 
-DetailedCrop* ImProcCoordinator::createCrop  () { 
+DetailedCrop* ImProcCoordinator::createCrop  (::EditDataProvider *editDataProvider) {
 
-    return new Crop (this); 
+    return new Crop (this, editDataProvider);
 }
 
 
 // todo: bitmask containing desired actions, taken from changesSinceLast
-// cropCall: calling crop, used to prevent self-updates
+// cropCall: calling crop, used to prevent self-updates  ...doesn't seem to be used
 void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
 
     MyMutex::MyLock processingLock(mProcessing);
-
     int numofphases = 14;
     int readyphase = 0;
 
@@ -142,11 +144,19 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
     RAWParams rp = params.raw;
     if( !highDetailNeeded ){
         // if below 100% magnification, take a fast path
-        rp.dmethod = RAWParams::methodstring[RAWParams::fast];
-        rp.hotdeadpix_filt = false;
-        rp.ccSteps = 0;
-        //rp.all_enhance = false;
-        }
+        if(rp.bayersensor.method != RAWParams::BayerSensor::methodstring[RAWParams::BayerSensor::none] && rp.bayersensor.method != RAWParams::BayerSensor::methodstring[RAWParams::BayerSensor::mono])
+            rp.bayersensor.method = RAWParams::BayerSensor::methodstring[RAWParams::BayerSensor::fast];
+        //bayerrp.all_enhance = false;
+
+        if(rp.xtranssensor.method != RAWParams::XTransSensor::methodstring[RAWParams::XTransSensor::none] && rp.xtranssensor.method != RAWParams::XTransSensor::methodstring[RAWParams::XTransSensor::mono])
+            rp.xtranssensor.method = RAWParams::XTransSensor::methodstring[RAWParams::XTransSensor::fast];
+
+        rp.bayersensor.ccSteps = 0;
+        rp.xtranssensor.ccSteps = 0;
+        /* Commented out the following line so that the hot pixel filter works at <100% zoom levels too, to fix issue 2535.
+         * rp.deadPixelFilter = rp.hotPixelFilter = false;
+         */
+    }
 
     progress ("Applying white balance, color correction & sRGB conversion...",100*readyphase/numofphases);
     // raw auto CA is bypassed if no high detail is needed, so we have to compute it when high detail is needed
@@ -176,7 +186,13 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
         || (!params.toneCurve.hrenabled && params.toneCurve.method=="Color" && imgsrc->IsrgbSourceModified()))
     {
 
-        if (settings->verbose) printf("Demosaic %s\n",rp.dmethod.c_str());
+        if (settings->verbose) {
+            if (imgsrc->getSensorType() == ST_BAYER)
+                printf("Demosaic Bayer image using method: %s\n",rp.bayersensor.method.c_str());
+            else if (imgsrc->getSensorType() == ST_FUJI_XTRANS)
+                printf("Demosaic X-Trans image with using method: %s\n",rp.xtranssensor.method.c_str());
+        }
+        imgsrc->isRAW();
 
         imgsrc->demosaic( rp );
 
@@ -249,13 +265,27 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
         imgsrc->getImage (currWB, tr, orig_prev, pp, params.toneCurve, params.icm, params.raw);
         //ColorTemp::CAT02 (orig_prev, &params)	;
 
-        //imgsrc->convertColorSpace(orig_prev, params.icm, params.raw);
-
+		Imagefloat *calclum ;
+		lldenoiseutili=false;
+		params.dirpyrDenoise.getCurves(dnNoisCurve,lldenoiseutili);
+		if(lldenoiseutili && scale==1 && params.dirpyrDenoise.enabled ){//only allocate memory if enabled and scale=1	
+			calclum = new Imagefloat (pW, pH);//for Luminance denoise curve
+				if(orig_prev !=  calclum)
+					orig_prev->copyData(calclum);
+		
+			imgsrc->convertColorSpace(calclum, params.icm, currWB, params.raw);//claculate values after colorspace conversion
+		}
+		
         if (todo & M_LINDENOISE) {
-            //printf("denoising!\n");
-            if (scale==1 && params.dirpyrDenoise.enabled)
-                ipf.RGB_denoise(orig_prev, orig_prev, imgsrc->isRAW(), params.dirpyrDenoise, params.defringe, imgsrc->getDirPyrDenoiseExpComp());
-        }
+			
+			if (scale==1 && params.dirpyrDenoise.enabled) {
+			
+			ipf.RGB_denoise(orig_prev, orig_prev, calclum, imgsrc->isRAW(), params.dirpyrDenoise, params.defringe, imgsrc->getDirPyrDenoiseExpComp(), dnNoisCurve, lldenoiseutili);
+
+			}
+		}
+	//	delete calclum;
+		
         imgsrc->convertColorSpace(orig_prev, params.icm, currWB, params.raw);
 
         ipf.firstAnalysis (orig_prev, &params, vhist16, imgsrc->getGamma());
@@ -282,6 +312,8 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
         double radius = sqrt (double(pW*pW+pH*pH)) / 2.0;
         double shradius = params.sh.radius;
         if (!params.sh.hq) shradius *= radius / 1800.0;
+        if(!shmap)
+			shmap = new SHMap (pW, pH, true);
         shmap->update (oprevi, shradius, ipf.lumimul, params.sh.hq, scale);
     }
     readyphase++;
@@ -300,9 +332,9 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
 
     progress ("Exposure curve & CIELAB conversion...",100*readyphase/numofphases);
     if ((todo & M_RGBCURVE) || (todo & M_CROP)) {
-        if (hListener) oprevi->calcCroppedHistogram(params, scale, histCropped);
+//        if (hListener) oprevi->calcCroppedHistogram(params, scale, histCropped);
 
-        // complexCurve also calculated pre-curves histogram dependend on crop
+        //complexCurve also calculated pre-curves histogram depending on crop
         ipf.g = imgsrc->getGamma();
         ipf.iGamma = true;
         CurveFactory::complexCurve (params.toneCurve.expcomp, params.toneCurve.black/65535.0,
@@ -315,55 +347,132 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
         CurveFactory::RGBCurve (params.rgbCurves.gcurve, gCurve, scale==1 ? 1 : 1);
         CurveFactory::RGBCurve (params.rgbCurves.bcurve, bCurve, scale==1 ? 1 : 1);
 
+        TMatrix wprof = iccStore->workingSpaceMatrix (params.icm.working);
+        double wp[3][3] = {
+            {wprof[0][0],wprof[0][1],wprof[0][2]},
+            {wprof[1][0],wprof[1][1],wprof[1][2]},
+            {wprof[2][0],wprof[2][1],wprof[2][2]}};
+        TMatrix wiprof = iccStore->workingSpaceInverseMatrix (params.icm.working);
+        double wip[3][3] = {
+            {wiprof[0][0],wiprof[0][1],wiprof[0][2]},
+            {wiprof[1][0],wiprof[1][1],wiprof[1][2]},
+            {wiprof[2][0],wiprof[2][1],wiprof[2][2]}
+        };
+		opautili=false;
+        params.colorToning.getCurves(ctColorCurve, ctOpacityCurve, wp, wip, opautili);
+		
+        bool clctoningutili=false;
+        bool llctoningutili=false;
+        CurveFactory::curveToningCL(clctoningutili, params.colorToning.clcurve, clToningcurve,scale==1 ? 1 : 16);
+        //	clToningcurve.dump("CLToning3");
+        CurveFactory::curveToningLL(llctoningutili, params.colorToning.cl2curve, cl2Toningcurve,scale==1 ? 1 : 16);
+
         CurveFactory::curveBW (params.blackwhite.beforeCurve,params.blackwhite.afterCurve, vhist16bw, histToneCurveBW, beforeToneCurveBW, afterToneCurveBW,scale==1 ? 1 : 1);
 
-        //initialize rrm bbm ggm different from zero to avoid black screen in some cases
-        double rrm=33.;
-        double ggm=33.;
-        double bbm=33.;
 
+        float satLimit = float(params.colorToning.satProtectionThreshold)/100.f*0.7f+0.3f;
+        float satLimitOpacity = 1.f-(float(params.colorToning.saturatedOpacity)/100.f);
+
+        int satTH=80;
+        int satPR=30;
+        int indi=0;
+        if(params.colorToning.enabled  && params.colorToning.autosat){//for colortoning evaluation of saturation settings
+            float moyS=0.f;
+            float eqty=0.f;
+            ipf.moyeqt (oprevi, moyS, eqty);//return image : mean saturation and standard dev of saturation
+            //printf("moy=%f ET=%f\n", moyS,eqty);
+            float satp=((moyS+1.5f*eqty)-0.3f)/0.7f;//1.5 sigma ==> 93% pixels with high saturation -0.3 / 0.7 convert to Hombre scale
+            if(satp >= 0.92f) satp=0.92f;//avoid values too high (out of gamut)
+            if(satp <= 0.15f) satp=0.15f;//avoid too low values
+
+            //satTH=(int) 100.f*satp;
+            //satPR=(int) 100.f*(moyS-0.85f*eqty);//-0.85 sigma==>20% pixels with low saturation
+            satLimit= 100.f*satp;
+            satTH = (int) 100.f*satp;
+
+            satLimitOpacity= 100.f*(moyS-0.85f*eqty);//-0.85 sigma==>20% pixels with low saturation
+            satPR= (int) 100.f*(moyS-0.85f*eqty);
+        }
+        if(actListener) {
+            //if(params.blackwhite.enabled) {actListener->autoColorTonChanged(0, satTH, satPR);}
+            if(params.blackwhite.enabled && params.colorToning.autosat) {actListener->autoColorTonChanged(0, satTH, satPR);indi=0;}//hide sliders only if autosat
+            else {
+                if(params.colorToning.autosat){
+                    if     (params.colorToning.method=="Lab")        indi=1;
+                    else if(params.colorToning.method=="RGBCurves")  indi=1;
+                    else if(params.colorToning.method=="RGBSliders") indi=1;
+                    else if(params.colorToning.method=="Splico")     indi=2;
+                    else if(params.colorToning.method=="Splitlr")    indi=2;
+
+                    //actListener->autoColorTonChanged(indi, satTH, satPR);
+                }
+            }
+        }
         // if it's just crop we just need the histogram, no image updates
-        if ( todo!=MINUPDATE ) {
-            ipf.rgbProc (oprevi, oprevl, hltonecurve, shtonecurve, tonecurve, shmap, params.toneCurve.saturation,
-                         rCurve, gCurve, bCurve, customToneCurve1, customToneCurve2,beforeToneCurveBW, afterToneCurveBW, rrm, ggm, bbm, bwAutoR, bwAutoG, bwAutoB, params.toneCurve.expcomp, params.toneCurve.hlcompr, params.toneCurve.hlcomprthresh);
+        if ( todo & M_RGBCURVE ) {
+			//initialize rrm bbm ggm different from zero to avoid black screen in some cases
+			double rrm=33.;
+			double ggm=33.;
+			double bbm=33.;
+            ipf.rgbProc (oprevi, oprevl, NULL, hltonecurve, shtonecurve, tonecurve, shmap, params.toneCurve.saturation,
+                         rCurve, gCurve, bCurve, satLimit ,satLimitOpacity, ctColorCurve, ctOpacityCurve, opautili, clToningcurve, cl2Toningcurve, customToneCurve1, customToneCurve2,beforeToneCurveBW, afterToneCurveBW, rrm, ggm, bbm, bwAutoR, bwAutoG, bwAutoB, params.toneCurve.expcomp, params.toneCurve.hlcompr, params.toneCurve.hlcomprthresh);
             if(params.blackwhite.enabled && params.blackwhite.autoc && abwListener) {
                 if (settings->verbose)
                     printf("ImProcCoordinator / Auto B&W coefs:   R=%.2f   G=%.2f   B=%.2f\n", bwAutoR, bwAutoG, bwAutoB);
                 abwListener->BWChanged((float) rrm, (float) ggm, (float) bbm);
             }
+            if(params.colorToning.autosat && actListener) {
+                if (settings->verbose)
+                    printf("ImProcCoordinator / Auto CT:  indi=%d   satH=%d  satPR=%d\n", indi,(int)satLimit , (int) satLimitOpacity);
+                actListener->autoColorTonChanged(indi, (int) satLimit, (int)satLimitOpacity);//change sliders autosat
+            }
             // correct GUI black and white with value
         }
-
         // compute L channel histogram
-        int x1, y1, x2, y2, pos, poscc;
+        int x1, y1, x2, y2, pos;
         params.crop.mapToResized(pW, pH, scale, x1, x2,  y1, y2); 
         lhist16.clear(); lhist16Cropped.clear();
         lhist16Clad.clear(); lhist16CLlad.clear();lhist16LLClad.clear();
-        lhist16ClabAF.clear();
         for (int x=0; x<pH; x++)
             for (int y=0; y<pW; y++) {
                 pos=CLIP((int)(oprevl->L[x][y]));
                 lhist16[pos]++;
-                if (y>=y1 && y<y2 && x>=x1 && x<x2) {lhist16Cropped[pos]++;}
+                if (y>=y1 && y<y2 && x>=x1 && x<x2)
+					lhist16Cropped[pos]++;
             }
- 
     }
     readyphase++;
-    utili=false;
-    autili=false;
-    butili=false;
-    ccutili=false;
-    cclutili=false;
-    clcutili=false;
+//    utili=false;
+//    autili=false;
+//    butili=false;
+//    ccutili=false;
+//    cclutili=false;
+//    clcutili=false;
     if ((todo & M_LUMACURVE) || (todo & M_CROP)) {
+        utili = false;
         CurveFactory::complexLCurve (params.labCurve.brightness, params.labCurve.contrast, params.labCurve.lcurve, lhist16, lhist16Cropped,
                                      lumacurve, histLCurve, scale==1 ? 1 : 16, utili);
     }
     if (todo & M_LUMACURVE) {
+        autili=false;
+        butili=false;
+        ccutili=false;
+        cclutili=false;
+        clcutili=false;
 
         CurveFactory::curveCL(clcutili, params.labCurve.clcurve, clcurve, lhist16CLlad, histCLurve, scale==1 ? 1 : 16);
+        float adjustr=1.0f;
 
-        CurveFactory::complexsgnCurve (autili, butili,ccutili,cclutili, params.labCurve.chromaticity, params.labCurve.rstprotection,
+
+/*      if      (params.icm.working=="ProPhoto")   {adjustr =       adjustbg = 1.2f;}// 1.2 instead 1.0 because it's very rare to have C>170..
+        else if (params.icm.working=="Adobe RGB")  {adjustr = 1.8f; adjustbg = 1.4f;}
+        else if (params.icm.working=="sRGB")       {adjustr = 2.0f; adjustbg = 1.7f;}
+        else if (params.icm.working=="WideGamut")  {adjustr =       adjustbg = 1.2f;}
+        else if (params.icm.working=="Beta RGB")   {adjustr =       adjustbg = 1.4f;}
+        else if (params.icm.working=="BestRGB")    {adjustr =       adjustbg = 1.4f;}
+        else if (params.icm.working=="BruceRGB")   {adjustr = 1.8f; adjustbg = 1.5f;}
+*/
+        CurveFactory::complexsgnCurve (adjustr, autili, butili,ccutili,cclutili, params.labCurve.chromaticity, params.labCurve.rstprotection,
                                        params.labCurve.acurve, params.labCurve.bcurve,params.labCurve.cccurve,params.labCurve.lccurve,chroma_acurve, chroma_bcurve, satcurve,lhskcurve,
                                        lhist16Clad, lhist16LLClad, histCCurve, histLLCurve, scale==1 ? 1 : 16);
     }
@@ -372,7 +481,7 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
 
         progress ("Applying Color Boost...",100*readyphase/numofphases);
 
-        ipf.chromiLuminanceCurve (pW,nprevl, nprevl, chroma_acurve, chroma_bcurve, satcurve, lhskcurve, clcurve, lumacurve, utili, autili, butili, ccutili,cclutili,clcutili, histCCurve, histCLurve, histLLCurve, histLCurve);
+        ipf.chromiLuminanceCurve (NULL, pW,nprevl, nprevl, chroma_acurve, chroma_bcurve, satcurve, lhskcurve, clcurve, lumacurve, utili, autili, butili, ccutili,cclutili,clcutili, histCCurve, histCLurve, histLLCurve, histLCurve);
         ipf.vibrance(nprevl);
         if((params.colorappearance.enabled && !params.colorappearance.tonecie) ||  (!params.colorappearance.enabled)) ipf.EPDToneMap(nprevl,5,1);
         // for all treatments Defringe, Sharpening, Contrast detail , Microcontrast they are activated if "CIECAM" function are disabled
@@ -414,42 +523,48 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
                 delete [] buffer;
                 readyphase++;
             }
+        }
+        //if (scale==1) {
             if((params.colorappearance.enabled && !settings->autocielab) || (!params.colorappearance.enabled)){
-            //if(params.colorappearance.enabled && !params.colorappearance.sharpcie){
                 progress ("Pyramid equalizer...",100*readyphase/numofphases);
-                ipf.dirpyrequalizer (nprevl);
+                ipf.dirpyrequalizer (nprevl, scale);
+                //ipf.Lanczoslab (nprevl, nprevl, 1.f/scale);
                 readyphase++;
             }
-        }
+        //}
 
-        //L histo  and Chroma histo for ciecam
-        // histogram well be for Lab (Lch) values, because very difficult to do with J,Q, M, s, C
-        int x1, y1, x2, y2, pos, posc;
-        params.crop.mapToResized(pW, pH, scale, x1, x2,  y1, y2);
-        lhist16CAM.clear(); lhist16CroppedCAM.clear();
-        lhist16CCAM.clear();
-        lhist16CCAMAF.clear();
-        for (int x=0; x<pH; x++)
-            for (int y=0; y<pW; y++) {
-                pos=CLIP((int)(nprevl->L[x][y]));
-                posc=CLIP((int)sqrt(nprevl->a[x][y]*nprevl->a[x][y] + nprevl->b[x][y]*nprevl->b[x][y]));
-                if(!params.colorappearance.datacie) lhist16CCAM[posc]++;
-                if(!params.colorappearance.datacie)lhist16CAM[pos]++;
-                if (y>=y1 && y<y2 && x>=x1 && x<x2) {lhist16CroppedCAM[pos]++;}
-            }
-        LUTu dummy;
-        CurveFactory::curveLightBrightColor (
-                params.colorappearance.curveMode, params.colorappearance.curve,
-                params.colorappearance.curveMode2, params.colorappearance.curve2,
-                params.colorappearance.curveMode3, params.colorappearance.curve3,
-                lhist16CAM, lhist16CroppedCAM,histLCAM,
-                lhist16CCAM, histCCAM,
-                customColCurve1,
-                customColCurve2,
-                customColCurve3,
-                scale==1 ? 1 : 1
-        );
+        
         if(params.colorappearance.enabled){
+			//L histo  and Chroma histo for ciecam
+			// histogram well be for Lab (Lch) values, because very difficult to do with J,Q, M, s, C
+			int x1, y1, x2, y2, pos, posc;
+			params.crop.mapToResized(pW, pH, scale, x1, x2,  y1, y2);
+			lhist16CAM.clear(); lhist16CroppedCAM.clear();
+			lhist16CCAM.clear();
+			for (int x=0; x<pH; x++)
+				for (int y=0; y<pW; y++) {
+					pos=CLIP((int)(nprevl->L[x][y]));
+					if(!params.colorappearance.datacie) {
+						posc=CLIP((int)sqrt(nprevl->a[x][y]*nprevl->a[x][y] + nprevl->b[x][y]*nprevl->b[x][y]));
+						lhist16CAM[pos]++;
+						lhist16CCAM[posc]++;
+					}
+					if (y>=y1 && y<y2 && x>=x1 && x<x2)
+						lhist16CroppedCAM[pos]++;
+				}
+
+			LUTu dummy;
+			CurveFactory::curveLightBrightColor (
+					params.colorappearance.curveMode, params.colorappearance.curve,
+					params.colorappearance.curveMode2, params.colorappearance.curve2,
+					params.colorappearance.curveMode3, params.colorappearance.curve3,
+					lhist16CAM, lhist16CroppedCAM,histLCAM,
+					lhist16CCAM, histCCAM,
+					customColCurve1,
+					customColCurve2,
+					customColCurve3,
+					scale==1 ? 1 : 1
+			);
             float fnum = imgsrc->getMetaData()->getFNumber  ();        // F number
             float fiso = imgsrc->getMetaData()->getISOSpeed () ;       // ISO
             float fspeed = imgsrc->getMetaData()->getShutterSpeed () ; // Speed
@@ -469,9 +584,6 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
             int endh=pH;
             float d;
             double dd;
-            float **buffer = new float*[pH];
-            for (int i=0; i<pH; i++)
-                buffer[i] = new float[pW];
             bool execsharp=false;
             if(scale==1) execsharp=true;
 
@@ -483,19 +595,16 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
             if (!CAMBrightCurveQ && (params.colorappearance.algo=="QM" || params.colorappearance.algo=="ALL"))
                 CAMBrightCurveQ(65536,0);
             if(settings->ciecamfloat){
-                ipf.ciecam_02float (ncie, float(adap), begh, endh, pW, 2, nprevl, &params, customColCurve1,customColCurve2,customColCurve3, histLCAM, histCCAM, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, (float**)buffer, execsharp, d);
+                ipf.ciecam_02float (ncie, float(adap), begh, endh, pW, 2, nprevl, &params, customColCurve1,customColCurve2,customColCurve3, histLCAM, histCCAM, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, execsharp, d, scale, 1);
                 if(params.colorappearance.autodegree && acListener && params.colorappearance.enabled) acListener->autoCamChanged(100.*(double)d);
                 if(params.colorappearance.autoadapscen && acListener && params.colorappearance.enabled) acListener->adapCamChanged(adap);//real value of adapt scene luminosity
             }
             else {
-                ipf.ciecam_02 (ncie, adap, begh, endh, pW, 2, nprevl, &params, customColCurve1,customColCurve2,customColCurve3, histLCAM, histCCAM, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, (float**)buffer, execsharp, dd);
+                ipf.ciecam_02 (ncie, adap, begh, endh, pW, 2, nprevl, &params, customColCurve1,customColCurve2,customColCurve3, histLCAM, histCCAM, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, execsharp, dd, scale, 1);
                 if(params.colorappearance.autodegree && acListener && params.colorappearance.enabled) acListener->autoCamChanged(100.*dd);
                 if(params.colorappearance.autoadapscen && acListener && params.colorappearance.enabled) acListener->adapCamChanged(adap);
             }
 
-            for (int i=0; i<pH; i++)
-                delete [] buffer[i];
-            delete [] buffer;
             readyphase++;
         }
         else {
@@ -525,8 +634,13 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
             ipf.lab2monitorRgb (nprevl, previmg);
             delete workimg;
             Glib::ustring outProfile=params.icm.output;
-            if (params.icm.output=="" || params.icm.output==ColorManagementParams::NoICMString) outProfile="sRGB";
-            workimg = ipf.lab2rgb (nprevl, 0,0,pW,pH, outProfile, true);
+            Glib::ustring workProfile=params.icm.working;
+
+            if(settings->HistogramWorking) workimg = ipf.lab2rgb (nprevl, 0,0,pW,pH, workProfile, true);
+            else {
+                if (params.icm.output=="" || params.icm.output==ColorManagementParams::NoICMString) outProfile="sRGB";
+                workimg = ipf.lab2rgb (nprevl, 0,0,pW,pH, outProfile, false);
+            }
         }
         catch(char * str)
         {
@@ -547,7 +661,7 @@ void ImProcCoordinator::updatePreviewImage (int todo, Crop* cropCall) {
 
     if (hListener) {
         updateLRGBHistograms ();
-        hListener->histogramChanged (histRed, histGreen, histBlue, histLuma, histToneCurve, histLCurve,histCCurve, histCLurve, histLLCurve, histLCAM, histCCAM, histRedRaw, histGreenRaw, histBlueRaw, histChroma);
+        hListener->histogramChanged (histRed, histGreen, histBlue, histLuma, histToneCurve, histLCurve,histCCurve, /*histCLurve, histLLCurve,*/ histLCAM, histCCAM, histRedRaw, histGreenRaw, histBlueRaw, histChroma);
     }
 }
 
@@ -572,7 +686,8 @@ void ImProcCoordinator::freeAll () {
             delete previmg;
 
         delete workimg;
-        delete shmap;
+        if(shmap)
+			delete shmap; shmap = NULL;
 
     }
     allocated = false;
@@ -617,7 +732,9 @@ if (settings->verbose) printf ("setscale before lock\n");
         //ncie is only used in ImProcCoordinator::updatePreviewImage, it will be allocated on first use and deleted if not used anymore
         previmg = new Image8 (pW, pH);
         workimg = new Image8 (pW, pH);
-        shmap = new SHMap (pW, pH, true);
+   		if(params.sh.enabled) {
+			shmap = new SHMap (pW, pH, true);
+   		}
 
         allocated = true;
     }
@@ -640,6 +757,26 @@ void ImProcCoordinator::updateLRGBHistograms () {
     int x1, y1, x2, y2;
     params.crop.mapToResized(pW, pH, scale, x1, x2, y1, y2); 
 
+#pragma omp parallel sections
+{
+#pragma omp section
+{
+    histChroma.clear();
+    for (int i=y1; i<y2; i++)
+        for (int j=x1; j<x2; j++) {
+            histChroma[(int)(sqrtf(SQR(nprevl->a[i][j]) + SQR(nprevl->b[i][j]))/188.f)]++;//188 = 48000/256
+        }
+}
+#pragma omp section
+{
+    histLuma.clear();
+    for (int i=y1; i<y2; i++)
+        for (int j=x1; j<x2; j++) {
+            histLuma[(int)(nprevl->L[i][j]/128.f)]++;
+        }
+}
+#pragma omp section
+{
     histRed.clear();
     histGreen.clear();
     histBlue.clear();
@@ -656,22 +793,9 @@ void ImProcCoordinator::updateLRGBHistograms () {
             histBlue[b]++;
         }
     }
-    histLuma.clear();
-    histChroma.clear();
-    for (int i=y1; i<y2; i++)
-        for (int j=x1; j<x2; j++) {
-            histChroma[(int)(sqrt(nprevl->a[i][j]*nprevl->a[i][j] + nprevl->b[i][j]*nprevl->b[i][j]))/188]++;//188 = 48000/256
-            histLuma[(int)(nprevl->L[i][j]/128)]++;
-        }
+}
+}
 
-    /*for (int i=0; i<256; i++) {
-        Lhist[i] = (int)(256*sqrt(Lhist[i]));
-        rhist[i] = (int)(256*sqrt(rhist[i]));
-        ghist[i] = (int)(256*sqrt(ghist[i]));
-        bhist[i] = (int)(256*sqrt(bhist[i]));
-        bcrgbhist[i] = (int)(256*sqrt(bcrgbhist[i]));
-        bcLhist[i] = (int)(256*sqrt(bcLhist[i]));
-    }*/
 }
 
 void ImProcCoordinator::progress (Glib::ustring str, int pr) {
@@ -686,7 +810,7 @@ bool ImProcCoordinator::getAutoWB (double& temp, double& green, double equal) {
 
     if (imgsrc) {
         if (lastAwbEqual != equal) {
-            MyMutex::MyLock lock(minit);  // Also used in crop window
+// Issue 2500            MyMutex::MyLock lock(minit);  // Also used in crop window
             double rm, gm, bm;
             imgsrc->getAutoWBMultipliers(rm, gm, bm);
             if (rm != -1) {
@@ -839,8 +963,8 @@ void ImProcCoordinator::startProcessing () {
     #undef THREAD_PRIORITY_NORMAL
 
     if (!destroying) {
-        updaterThreadStart.lock ();
         if (!updaterRunning) {
+			updaterThreadStart.lock ();
             thread = NULL;
             updaterRunning = true;
             updaterThreadStart.unlock ();
@@ -850,8 +974,6 @@ void ImProcCoordinator::startProcessing () {
             thread = Glib::Thread::create(sigc::mem_fun(*this, &ImProcCoordinator::process), 0, true, true, Glib::THREAD_PRIORITY_NORMAL);
 
         }
-        else
-            updaterThreadStart.unlock ();
     }
 }
 
