@@ -81,7 +81,6 @@ class ImProcCoordinator : public StagedImageProcessor {
 
         float bwAutoR, bwAutoG, bwAutoB;
         float CAMMean;
-
         LUTf hltonecurve;
         LUTf shtonecurve;
         LUTf tonecurve;
@@ -92,13 +91,14 @@ class ImProcCoordinator : public StagedImageProcessor {
         LUTf satcurve;
         LUTf lhskcurve;
         LUTf clcurve;
+        LUTf clToningcurve;
+        LUTf cl2Toningcurve;
+        LUTf Noisecurve;
 
         LUTu vhist16,vhist16bw;
         LUTu lhist16,lhist16Cropped;
         LUTu lhist16CAM,lhist16CroppedCAM;
         LUTu lhist16CCAM;
-        LUTu lhist16CCAMAF;
-        LUTu lhist16ClabAF;
         LUTu histCropped;
         LUTu lhist16Clad,lhist16CLlad,lhist16LClad,lhist16LLClad;
         LUTu histRed, histRedRaw;
@@ -118,9 +118,13 @@ class ImProcCoordinator : public StagedImageProcessor {
         bool ccutili;
         bool cclutili;
         bool clcutili;
-
+		bool lldenoiseutili;
+		bool opautili;
         ToneCurve customToneCurve1;
         ToneCurve customToneCurve2;
+        ColorGradientCurve ctColorCurve;
+        OpacityCurve ctOpacityCurve;
+        NoisCurve dnNoisCurve;
         ColorAppearance customColCurve1;
         ColorAppearance customColCurve2;
         ColorAppearance customColCurve3;
@@ -141,6 +145,7 @@ class ImProcCoordinator : public StagedImageProcessor {
         AutoExpListener* aeListener;
         AutoCamListener* acListener;
         AutoBWListener* abwListener;
+        AutoColorTonListener* actListener;
 
         HistogramListener* hListener;
         std::vector<SizeListener*> sizeListeners;
@@ -198,13 +203,16 @@ class ImProcCoordinator : public StagedImageProcessor {
         int getPreviewWidth ()     { return pW; }
         int getPreviewHeight ()    { return pH; }
 
-        DetailedCrop* createCrop  ();
+        DetailedCrop* createCrop  (::EditDataProvider *editDataProvider);
 
         bool getAutoWB   (double& temp, double& green, double equal);
         void getCamWB    (double& temp, double& green);
         void getSpotWB   (int x, int y, int rectSize, double& temp, double& green);
         void getAutoCrop (double ratio, int &x, int &y, int &w, int &h);
 
+        bool updateTryLock () {return updaterThreadStart.trylock();}
+        void updateUnLock () {updaterThreadStart.unlock();}
+
         void setProgressListener (ProgressListener* pl)  { plistener = pl; }
         void setPreviewImageListener    (PreviewImageListener* il)     {imageListener = il; }
         void setSizeListener     (SizeListener* il)      {sizeListeners.push_back (il); }
@@ -212,7 +220,8 @@ class ImProcCoordinator : public StagedImageProcessor {
         void setAutoExpListener  (AutoExpListener* ael)  {aeListener = ael; }
         void setHistogramListener(HistogramListener *h)  {hListener = h; }
         void setAutoCamListener  (AutoCamListener* acl)  {acListener = acl; }
-        void setAutoBWListener  (AutoBWListener* abw)  {abwListener = abw; }
+        void setAutoBWListener   (AutoBWListener* abw)   {abwListener = abw; }
+        void setAutoColorTonListener   (AutoColorTonListener* bwct)   {actListener = bwct; }
 
         void saveInputICCReference (const Glib::ustring& fname);
 
