@@ -120,7 +120,7 @@ enum ProcEvent {
     EvLaCurve=95,
     EvLbCurve=96,
     EvDemosaicMethod=97,
-    EvPreProcessHotDeadPixel=98,
+    EvPreProcessHotPixel=98,
     EvSaturation=99,
     EvHSVEqualizerH=100,
     EvHSVEqualizerS=101,
@@ -188,7 +188,7 @@ enum ProcEvent {
 	EvRGBgCurve=163,
 	EvRGBbCurve=164,
 	EvNeutralExp=165,
-//	EvLBWtoning=166,  -- can be reused --
+	EvDemosaicMethodPreProc=166,
 	EvLCCCurve=167,
 	EvLCHCurve=168,
 	EvVibranceSkinTonesCurve=169,
@@ -272,9 +272,59 @@ enum ProcEvent {
 	EvLLHCurve=246,
 	EvLHHCurve=247,
 	EvDirPyrEqualizerThreshold=248,
-	EvDPDNenhance=249,	
+	EvDPDNenhance=249,
+	EvBWMethodalg=250,
+	EvDirPyrEqualizerSkin=251,
+	EvDirPyrEqlgamutlab=252,
+	EvDirPyrEqualizerHueskin=253,
+//	EvDirPyrEqualizeralg=254,
+	EvDPDNmedian=254,
+	EvDPDNmedmet=255,
+	EvColorToningEnabled=256,
+	EvColorToningColor =257,
+	EvColorToningOpacity=258,
+	EvColorToningCLCurve=259,
+	EvColorToningMethod=260,
+//	EvColorToningTwocolor=259,
+	EvColorToningLLCurve=261,
+	EvColorToningredlow=262,
+	EvColorToninggreenlow=263,
+	EvColorToningbluelow=264,
+	EvColorToningredmed=265,
+	EvColorToninggreenmed=266,
+	EvColorToningbluemed=267,
+	EvColorToningredhigh=268,
+	EvColorToninggreenhigh=269,
+	EvColorToningbluehigh=270,
+	EvColorToningbalance=271,
+	EvColorToningNeutral=272,
+	EvColorToningsatlow=273,
+	EvColorToningsathigh=274,
+	EvColorToningTwocolor=275,
+	EvColorToningNeutralcur=276,
+	EvColorToningLumamode=277,
+	EvColorToningShadows=278,
+	EvColorToningHighights=279,
+	EvColorToningSatProtection=280,
+	EvColorToningSatThreshold=281,
+	EvColorToningStrength=282,
+	EvColorToningautosat=283,
+	EvDPDNmetmed=284,	
+	EvDPDNrgbmet=285,
+	EvDPDNpasses=286,	
+	EvFlatFieldClipControl=287,
+	EvFlatFieldAutoClipControl=288,
+	EvPreProcessExpBlackRed=289,
+	EvPreProcessExpBlackGreen=290,
+	EvPreProcessExpBlackBlue=291,
+    EvFilmSimulationEnabled=292,
+    EvFilmSimulationStrength=293,
+    EvFilmSimulationFilename=294,
+	EvDPDNLCurve=295,
+	EvDPDNsmet=296,	
+    EvPreProcessDeadPixel=297,
 	
-	NUMOFEVENTS=250
+	NUMOFEVENTS	
 };
 }
 #endif
