@@ -68,7 +68,7 @@ class RawImageSource : public ImageSource {
         static LUTf invGrad;  // for fast_demosaic
         static LUTf initInvGrad ();
         static bool findInputProfile(Glib::ustring inProfile, cmsHPROFILE embedded, std::string camName, DCPProfile **dcpProf, cmsHPROFILE& in);
-        static void colorSpaceConversion (Imagefloat* im, ColorManagementParams &cmp, ColorTemp &wb, float rawWhitePoint, cmsHPROFILE embedded, cmsHPROFILE camprofile, double cam[3][3], const std::string &camName);
+        static void colorSpaceConversion_ (Imagefloat* im, ColorManagementParams &cmp, ColorTemp &wb, double pre_mul[3], const RAWParams &raw, cmsHPROFILE embedded, cmsHPROFILE camprofile, double cam[3][3], const std::string &camName);
 
     protected:
         MyMutex getImageMutex;  // locks getImage
@@ -153,11 +153,13 @@ class RawImageSource : public ImageSource {
 
         bool        IsrgbSourceModified() {return rgbSourceModified;} // tracks whether cached rgb output of demosaic has been modified
 
+		void		processFlatField(const RAWParams &raw, RawImage *riFlatFile, unsigned short black[4]);
         void        copyOriginalPixels(const RAWParams &raw, RawImage *ri, RawImage *riDark, RawImage *riFlatFile  );
         void        cfaboxblur  (RawImage *riFlatFile, float* cfablur, int boxH, int boxW );
         void        scaleColors (int winx,int winy,int winw,int winh, const RAWParams &raw);// raw for cblack
 
         void        getImage    (ColorTemp ctemp, int tran, Imagefloat* image, PreviewProps pp, ToneCurveParams hrp, ColorManagementParams cmp, RAWParams raw);
+        eSensorType getSensorType () { return ri!=NULL ? ri->getSensorType() : ST_NONE; }
         ColorTemp   getWB       () { return camera_wb; }
         void        getAutoWBMultipliers (double &rm, double &gm, double &bm);
         ColorTemp   getSpotWB   (std::vector<Coord2D> &red, std::vector<Coord2D> &green, std::vector<Coord2D> &blue, int tran, double equal);
@@ -180,17 +182,13 @@ class RawImageSource : public ImageSource {
         void        getRAWHistogram (LUTu & histRedRaw, LUTu & histGreenRaw, LUTu & histBlueRaw);
 
         void convertColorSpace(Imagefloat* image, ColorManagementParams cmp, ColorTemp &wb, RAWParams raw);
-        //static void colorSpaceConversion16 (Image16*    im, ColorManagementParams cmp, cmsHPROFILE embedded, cmsHPROFILE camprofile, double cam[3][3], std::string camName);
-        static void colorSpaceConversion   (Imagefloat* im, ColorManagementParams cmp, ColorTemp &wb, cmsHPROFILE embedded, cmsHPROFILE camprofile, double cam[3][3], std::string camName) {
-            colorSpaceConversion (im, cmp, wb, 0.0f, embedded, camprofile, cam, camName);
-        }
-        static void colorSpaceConversion   (Imagefloat* im, ColorManagementParams cmp, ColorTemp &wb, RAWParams raw, cmsHPROFILE embedded, cmsHPROFILE camprofile, double cam[3][3], std::string camName) {
-            colorSpaceConversion (im, cmp, wb, float(raw.expos), embedded, camprofile, cam, camName);
+        static void colorSpaceConversion   (Imagefloat* im, ColorManagementParams cmp, ColorTemp &wb, double pre_mul[3], RAWParams raw, cmsHPROFILE embedded, cmsHPROFILE camprofile, double cam[3][3], std::string camName) {
+            colorSpaceConversion_ (im, cmp, wb, pre_mul, raw, embedded, camprofile, cam, camName);
         }
         static void inverse33 (const double (*coeff)[3], double (*icoeff)[3]);
 
         void boxblur2(float** src, float** dst, int H, int W, int box );
-        void boxblur_resamp(float **src, float **dst, float & max, int H, int W, int box, int samp );
+        void boxblur_resamp(float **src, float **dst, int H, int W, int box, int samp );
 
         //void boxblur_resamp(float **red, float **green, float **blue, int H, int W, float thresh[3], float max[3],
         //                multi_array2D<float,3> & hfsize, multi_array2D<float,3> & hilite, int box );
@@ -212,15 +210,15 @@ class RawImageSource : public ImageSource {
         inline  void convert_to_cielab_row  (float* ar, float* ag, float* ab, float* oL, float* oa, float* ob);
         inline  void interpolate_row_g      (float* agh, float* agv, int i);
         inline  void interpolate_row_rb     (float* ar, float* ab, float* pg, float* cg, float* ng, int i);
-        inline  void interpolate_row_rb_mul_pp (float* ar, float* ab, float* pg, float* cg, float* ng, int i, double r_mul, double g_mul, double b_mul, int x1, int width, int skip);
+        inline  void interpolate_row_rb_mul_pp (float* ar, float* ab, float* pg, float* cg, float* ng, int i, float r_mul, float g_mul, float b_mul, int x1, int width, int skip);
 
         int  LinEqSolve( int nDim, double* pfMatr, double* pfVect, double* pfSolution);//Emil's CA auto correction
         void CA_correct_RT	(double cared, double cablue);
         void ddct8x8s(int isgn, float a[8][8]);
         void processRawWhitepoint (float expos, float preser);  // exposure before interpolation
 
-        int  cfaCleanFromMap( PixelsMap &bitmapBads );
-        int  findHotDeadPixel( PixelsMap &bpMap, float thresh);
+        int  interpolateBadPixels( PixelsMap &bitmapBads );
+        int  findHotDeadPixels( PixelsMap &bpMap, float thresh, bool findHotPixels, bool findDeadPixels );
 
         void cfa_linedn (float linenoiselevel);//Emil's line denoise
         void cfa_tile_denoise (fftwf_complex * fcfablox, int vblk, int hblk, int numblox_H, int numblox_W, float noisevar, float * rolloff );
@@ -228,7 +226,7 @@ class RawImageSource : public ImageSource {
 
         void green_equilibrate (float greenthresh);//Emil's green equilibration
 
-        void nodemosaic();
+        void nodemosaic(bool bw);
         void eahd_demosaic();
         void hphd_demosaic();
         void vng4_demosaic();
@@ -257,7 +255,10 @@ class RawImageSource : public ImageSource {
         void restore_from_buffer(float (*image)[4], float (*image2)[3]);
         void dcb_refinement(float (*image)[4], int x0, int y0);
         void dcb_color_full(float (*image)[4], int x0, int y0, float (*chroma)[2]);
-
+        void cielab (const float (*rgb)[3], float* l, float* a, float *b, const int width, const int height, const int labWidth, const float xyz_cam[3][3]);
+        void xtransborder_interpolate (int border);
+        void xtrans_interpolate (int passes, bool useCieLab);
+        void fast_xtrans_interpolate ();
         void    transLine   (float* red, float* green, float* blue, int i, Imagefloat* image, int tran, int imw, int imh, int fw);
         void    hflip       (Imagefloat* im);
         void    vflip       (Imagefloat* im);
