@@ -118,7 +118,7 @@ LUMINANCECURVE,   // EvLSaturation,
 LUMINANCECURVE,   // EvLaCurve,
 LUMINANCECURVE,   // EvLbCurve,
 DEMOSAIC,         // EvDemosaicMethod
-DARKFRAME,        // EvPreProcessHotDeadPixel
+DARKFRAME,        // EvPreProcessHotPixel
 RGBCURVE,         // EvSaturation,
 RGBCURVE,         // EvHSVEqualizerH,
 RGBCURVE,         // EvHSVEqualizerS,
@@ -186,7 +186,7 @@ RGBCURVE,         // EvRGBrCurve
 RGBCURVE,         // EvRGBgCurve
 RGBCURVE,         // EvRGBbCurve
 RGBCURVE,         // EvNeutralExp
-NONE,             // --unused--,
+DEMOSAIC|M_PREPROC, // EvDemosaicMethodPreProc
 LUMINANCECURVE,   // EvLCCurve
 LUMINANCECURVE,   // EvLCHCurve
 RGBCURVE,         // EvVibranceSkinTonesCurve
@@ -269,10 +269,57 @@ LUMINANCECURVE,   // EvLCLCurve
 LUMINANCECURVE,   // EvLLHCurve
 LUMINANCECURVE,   // EvLHHCurve
 DIRPYREQUALIZER,  // EvDirPyrEqualizerThreshold
-ALLNORAW          // EvDPDNenhance
-
-
-//LUMINANCECURVE    // EvCATsharpcie
+ALLNORAW,         // EvDPDNenhance
+RGBCURVE,         // EvBWMethodalg
+DIRPYREQUALIZER,  // EvDirPyrEqualizerSkin
+DIRPYREQUALIZER,  // EvDirPyrEqlgamutlab
+DIRPYREQUALIZER,  // EvDirPyrEqualizerHueskin
+ALLNORAW,         // EvDPDNmedian
+ALLNORAW,         //EvDPDNmedmet
+//DIRPYREQUALIZER   // EvDirPyrEqualizeralg
+RGBCURVE,         // EvColorToningEnabled
+RGBCURVE,         // EvColorToningColor
+RGBCURVE,         // EvColorToningOpacity
+RGBCURVE,         // EvColorToningCLCurve
+RGBCURVE,         // EvColorToningMethod
+//RGBCURVE,       // EvColorToningTwocolor
+RGBCURVE,         // EvColorToningLLCurve
+RGBCURVE,         // EvColorToningredlow
+RGBCURVE,         // EvColorToninggreenlow
+RGBCURVE,         // EvColorToningbluelow
+RGBCURVE,         // EvColorToningredmed
+RGBCURVE,         // EvColorToninggreenmed
+RGBCURVE,         // EvColorToningbluemed
+RGBCURVE,         // EvColorToningredhigh
+RGBCURVE,         // EvColorToninggreenhigh
+RGBCURVE,         // EvColorToningbluehigh
+RGBCURVE,         // EvColorToningbalance
+RGBCURVE,         // EvColorToningNeutral
+RGBCURVE,         // EvColorToningsatlow
+RGBCURVE,         // EvColorToningsathigh
+RGBCURVE,         // EvColorToningTwocolor
+RGBCURVE,         // EvColorToningNeutralcur
+RGBCURVE,         // EvColorToningLumamode
+RGBCURVE,         // EvColorToningShadows
+RGBCURVE,         // EvColorToningHighights
+RGBCURVE,         // EvColorToningSatProtection
+RGBCURVE,         // EvColorToningSatThreshold
+RGBCURVE,			//EvColorToningStrength
+RGBCURVE,			//EvColorToningautosat
+ALLNORAW, 			//EvDPDNmetmed
+ALLNORAW, 			//EvDPDNrgbmet
+ALLNORAW,			//EvDPDNpasses
+FLATFIELD,        // EvFlatFieldClipControl
+FLATFIELD,        // EvFlatFieldAutoClipControl
+DARKFRAME,        // EvPreProcessExpBlackRed
+DARKFRAME,        // EvPreProcessExpBlackGreen
+DARKFRAME,        // EvPreProcessExpBlackBlue
+RGBCURVE,         //EvFilmSimulationEnabled
+RGBCURVE,         //EvFilmSimulationStrength
+RGBCURVE,         //EvFilmSimulationFilename
+ALLNORAW,			//	EvDPDNLCurve
+ALLNORAW,			//	EvDPDNsmet
+DARKFRAME        // EvPreProcessDeadPixel
 
 
 };
