@@ -39,6 +39,7 @@
  *
  */
 
+    class EditDataProvider;
 
 namespace rtengine {
 
@@ -232,7 +233,7 @@ namespace rtengine {
               * @param histBlue is the array of size 256 containing the histogram of the blue channel
               * @param histLuma is the array of size 256 containing the histogram of the luminance channel
               * other for curves backgrounds, histRAW is RAW without colors */
-            virtual void histogramChanged (LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma, LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve, LUTu & histCLurve, LUTu & histLLCurve, LUTu & histLCAM, LUTu & histCCAM,
+            virtual void histogramChanged (LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma, LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve,/* LUTu & histCLurve,LUTu & histLLCurve, */LUTu & histLCAM, LUTu & histCCAM,
                 LUTu & histRedRaw, LUTu & histGreenRaw, LUTu & histBlueRaw, LUTu & histChroma) {}
     };
 
@@ -257,6 +258,12 @@ namespace rtengine {
             virtual void autoCamChanged (double ccam) {}
             virtual void adapCamChanged (double cadap) {}
     };
+
+    class AutoColorTonListener {
+        public :
+            virtual ~AutoColorTonListener() {}
+            virtual void autoColorTonChanged (int bwct, int satthres, int satprot) {}
+    };
 	
 	class AutoBWListener {
 		public :
@@ -329,8 +336,14 @@ namespace rtengine {
               * @return the height of the preview image */
             virtual int         getPreviewHeight () =0;
 
-            /** Creates and returns a Crop instance that acts as a window on the image */
-            virtual DetailedCrop* createCrop  () =0;
+			virtual bool		updateTryLock() = 0;
+
+			virtual void		updateUnLock() = 0;
+
+            /** Creates and returns a Crop instance that acts as a window on the image
+              * @param editDataProvider pointer to the EditDataProvider that communicates with the EditSubscriber
+              * @return a pointer to the Crop object that handles the image data trough its own pipeline */
+            virtual DetailedCrop* createCrop  (::EditDataProvider *editDataProvider) =0;
 
             virtual bool        getAutoWB   (double& temp, double& green, double equal) =0;
             virtual void        getCamWB    (double& temp, double& green) =0;
@@ -347,7 +360,8 @@ namespace rtengine {
             virtual void        setPreviewImageListener (PreviewImageListener* l) =0;
             virtual void        setAutoCamListener      (AutoCamListener* l) =0;
             virtual void        setAutoBWListener     	(AutoBWListener* l) =0;
-
+            virtual void        setAutoColorTonListener (AutoColorTonListener* l) =0;
+						
             virtual ~StagedImageProcessor () {}
 
         /** Returns a staged, cached image processing manager supporting partial updates
@@ -410,7 +424,7 @@ namespace rtengine {
    * @param pl is an optional ProgressListener if you want to keep track of the progress
    * @param tunnelMetaData tunnels IPTC and XMP to output without change
    * @return the resulting image, with the output profile applied, exif and iptc data set. You have to save it or you can access the pixel data directly.  */  
-    IImage16* processImage (ProcessingJob* job, int& errorCode, ProgressListener* pl = NULL, bool tunnelMetaData=false);
+    IImage16* processImage (ProcessingJob* job, int& errorCode, ProgressListener* pl = NULL, bool tunnelMetaData=false, bool flush = false);
 
 /** This class is used to control the batch processing. The class implementing this interface will be called when the full processing of an
    * image is ready and the next job to process is needed. */
