@@ -38,10 +38,13 @@
 #include "rawimage.h"
 #include "jpeg.h"
 #include "../rtgui/ppversion.h"
+#include "improccoordinator.h"
+
 
 extern Options options;
 
 namespace rtengine {
+using namespace procparams;
 
 Thumbnail* Thumbnail::loadFromImage (const Glib::ustring& fname, int &w, int &h, int fixwh, double wbEq) {
 
@@ -151,7 +154,16 @@ Thumbnail* Thumbnail::loadQuickFromRaw (const Glib::ustring& fname, RawMetaDataL
         const char* data((const char*)fdata(ri->get_thumbOffset(),ri->get_file()));
         if ( (unsigned char)data[1] == 0xd8 )
         {
+#if defined( __WIN32__ ) && defined( __x86_64__ )
+			// This is a hack for Issue 2425, because loadJPEGFromMemory crashes on Win64 when jpg marker is incorrect
+			// (should be 0xff 0xd8, but is 0x02 0xd8 for mrw files)
+        	std::string suffix = fname.length() > 4 ? fname.substr(fname.length()-3) : "";
+        	for (int i = 0; i < suffix.length(); i++) suffix[i] = std::tolower(suffix[i]);
+			if(suffix != "mrw" || (unsigned char)data[0] == 0xff)
+				err = img->loadJPEGFromMemory(data,ri->get_thumbLength());
+#else
             err = img->loadJPEGFromMemory(data,ri->get_thumbLength());
+#endif
         }
         else
         {
@@ -162,7 +174,7 @@ Thumbnail* Thumbnail::loadQuickFromRaw (const Glib::ustring& fname, RawMetaDataL
     // did we succeed?
     if ( err ) 
     {
-        printf("loadfromMemory: error\n");
+        printf("Could not extract thumb from %s\n",fname.data());
         delete img;
         delete ri;
         return NULL;
@@ -272,8 +284,9 @@ Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocati
 	unsigned filter = ri->get_filters();
 	int firstgreen = 1;
 	// locate first green location in the first row
-	while (!FISGREEN(filter,1,firstgreen))
-		firstgreen++;
+	if(ri->getSensorType()!=ST_FUJI_XTRANS)
+		while (!FISGREEN(filter,1,firstgreen))
+			firstgreen++;
 
 	int skip = 1;
 	if (ri->get_FujiWidth() != 0){
@@ -303,7 +316,7 @@ Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocati
 	DCraw::dcrawImage_t image = ri->get_image();
 
 	Imagefloat* tmpImg = new Imagefloat(tmpw, tmph);
-	if (ri->isBayer()) {
+	if (ri->getSensorType()==ST_BAYER) {
 		// demosaicing! (sort of)
 		for (int row = 1, y = 0; row < height - 1 && y < tmph; row += vskip, y++) {
 			rofs = row * width;
@@ -323,15 +336,47 @@ Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocati
 				tmpImg->b(y,x) = b;
 			}
 		}
-	} else {
+	} else if (ri->get_colors() == 1) {
 		for (int row = 1, y = 0; row < height - 1 && y < tmph; row += vskip, y++) {
 			rofs = row * width;
 			for (int col = firstgreen, x = 0; col < width - 1 && x < tmpw; col
 					+= hskip, x++) {
 				int ofs = rofs + col;
-				tmpImg->r(y,x) = image[ofs][0];
-				tmpImg->g(y,x) = image[ofs][1];
-				tmpImg->b(y,x) = image[ofs][2];
+				tmpImg->r(y,x) = tmpImg->g(y,x) = tmpImg->b(y,x) = image[ofs][0];
+			}
+		}
+	} else {
+		if(ri->getSensorType()==ST_FUJI_XTRANS) {
+			for( int row=1, y = 0; row < height-1 && y < tmph; row+=vskip, y++) {
+				rofs = row * width;
+				for( int col=1, x = 0; col < width-1 && x < tmpw; col+=hskip, x++ ) {
+					int ofs = rofs + col;
+					float sum[3] = {};
+					int c;
+					for(int v=-1;v<=1;v++) {
+						for(int h=-1;h<=1;h++) {
+							c = ri->XTRANSFC(row+v,col+h);
+							sum[c] += image[ofs + v*width + h][c];
+						}
+					}
+					c = ri->XTRANSFC(row,col);
+
+					switch (c) {
+						case 0: tmpImg->r(y,x) = image[ofs][0]; tmpImg->g(y,x) = sum[1] / 5.f; tmpImg->b(y,x) = sum[2] / 3.f; break;
+						case 1: tmpImg->r(y,x) = sum[0] / 2.f; tmpImg->g(y,x) = image[ofs][1]; tmpImg->b(y,x) = sum[2] / 2.f; break;
+						case 2: tmpImg->r(y,x) = sum[0] / 3.f; tmpImg->g(y,x) = sum[1] / 5.f; tmpImg->b(y,x) = image[ofs][2]; break;
+					}
+				}
+			}
+		} else {
+			for (int row = 1, y = 0; row < height - 1 && y < tmph; row += vskip, y++) {
+				rofs = row * width;
+				for (int col = firstgreen, x = 0; col < width - 1 && x < tmpw; col += hskip, x++) {
+					int ofs = rofs + col;
+					tmpImg->r(y,x) = image[ofs][0];
+					tmpImg->g(y,x) = image[ofs][1];
+					tmpImg->b(y,x) = image[ofs][2];
+				}
 			}
 		}
 	}
@@ -396,13 +441,29 @@ Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocati
 			start = 8;
 			end = width - 8;
 		}
-		for (int j = start; j < end; j++)
-			if (FISGREEN(filter,i,j))
-                tpp->aeHistogram[((int)(tpp->camwbGreen*image[i* width+j][1]))>>tpp->aeHistCompression]+=gadd;
-			else if (FISRED(filter,i,j))
-                tpp->aeHistogram[((int)(tpp->camwbRed * image[i* width+j][0]))>>tpp->aeHistCompression]+=radd;
-			else if (FISBLUE(filter,i,j))
-                tpp->aeHistogram[((int)(tpp->camwbBlue *image[i* width+j][2]))>>tpp->aeHistCompression]+=badd;
+		if (ri->get_colors() == 1) {
+			for (int j = start; j < end; j++) {
+				tpp->aeHistogram[((int)(image[i* width+j][0]))>>tpp->aeHistCompression]+=radd;
+				tpp->aeHistogram[((int)(image[i* width+j][0]))>>tpp->aeHistCompression]+=gadd;
+				tpp->aeHistogram[((int)(image[i* width+j][0]))>>tpp->aeHistCompression]+=badd;
+			}
+		} else if(ri->getSensorType()!=ST_FUJI_XTRANS) {
+			for (int j = start; j < end; j++)
+				if (FISGREEN(filter,i,j))
+					tpp->aeHistogram[((int)(tpp->camwbGreen*image[i* width+j][1]))>>tpp->aeHistCompression]+=gadd;
+				else if (FISRED(filter,i,j))
+					tpp->aeHistogram[((int)(tpp->camwbRed * image[i* width+j][0]))>>tpp->aeHistCompression]+=radd;
+				else if (FISBLUE(filter,i,j))
+					tpp->aeHistogram[((int)(tpp->camwbBlue *image[i* width+j][2]))>>tpp->aeHistCompression]+=badd;
+		} else {
+			for (int j = start; j < end; j++)
+				if (ri->ISXTRANSGREEN(i,j))
+					tpp->aeHistogram[((int)(tpp->camwbGreen*image[i* width+j][1]))>>tpp->aeHistCompression]+=gadd;
+				else if (ri->ISXTRANSRED(i,j))
+					tpp->aeHistogram[((int)(tpp->camwbRed * image[i* width+j][0]))>>tpp->aeHistCompression]+=radd;
+				else if (ri->ISXTRANSBLUE(i,j))
+					tpp->aeHistogram[((int)(tpp->camwbBlue *image[i* width+j][2]))>>tpp->aeHistCompression]+=badd;
+		}
 	}
 
 	// generate autoWB
@@ -423,27 +484,59 @@ Thumbnail* Thumbnail::loadFromRaw (const Glib::ustring& fname, RawMetaDataLocati
 			start = 32;
 			end = width - 32;
 		}
-		for (int j = start; j < end; j++) {
-			if (FISGREEN(filter,i,j)) {
-				double d = tpp->defGain * image[i * width + j][1];
-				if (d > 64000.)
-					continue;
-				avg_g += d;
-				gn++;
+		if(ri->getSensorType()!=ST_FUJI_XTRANS) {
+			for (int j = start; j < end; j++) {
+				if (!filter) {
+					double d = tpp->defGain * image[i * width + j][0];
+					if (d > 64000.)
+						continue;
+					avg_g += d; avg_r += d; avg_b += d;
+					rn++; gn++; bn++;
+				} else if (FISGREEN(filter,i,j)) {
+					double d = tpp->defGain * image[i * width + j][1];
+					if (d > 64000.)
+						continue;
+					avg_g += d;
+					gn++;
+				}
+				else if (FISRED(filter,i,j)) {
+					double d = tpp->defGain * image[i * width + j][0];
+					if (d > 64000.)
+						continue;
+					avg_r += d;
+					rn++;
+				}
+				else if (FISBLUE(filter,i,j)) {
+					double d = tpp->defGain * image[i * width + j][2];
+					if (d > 64000.)
+						continue;
+					avg_b += d;
+					bn++;
+				}
 			}
-			else if (FISRED(filter,i,j)) {
-				double d = tpp->defGain * image[i * width + j][0];
-				if (d > 64000.)
-					continue;
-				avg_r += d;
-				rn++;
-			}
-			else if (FISBLUE(filter,i,j)) {
-				double d = tpp->defGain * image[i * width + j][2];
-				if (d > 64000.)
-					continue;
-				avg_b += d;
-				bn++;
+		} else  {
+			for (int j = start; j < end; j++) {
+				if (ri->ISXTRANSGREEN(i,j)) {
+					double d = tpp->defGain * image[i * width + j][1];
+					if (d > 64000.)
+						continue;
+					avg_g += d;
+					gn++;
+				}
+				else if (ri->ISXTRANSRED(i,j)) {
+					double d = tpp->defGain * image[i * width + j][0];
+					if (d > 64000.)
+						continue;
+					avg_r += d;
+					rn++;
+				}
+				else if (ri->ISXTRANSBLUE(i,j)) {
+					double d = tpp->defGain * image[i * width + j][2];
+					if (d > 64000.)
+						continue;
+					avg_b += d;
+					bn++;
+				}
 			}
 		}
 	}
@@ -515,7 +608,8 @@ Thumbnail::Thumbnail () :
     redMultiplier(1.0), greenMultiplier(1.0), blueMultiplier(1.0),
     defGain(1.0),
     scaleForSave(8192),
-    gammaCorrected(false) {
+    gammaCorrected(false),
+    aeHistCompression(3) {
 }
 
 Thumbnail::~Thumbnail () {
@@ -556,7 +650,6 @@ IImage8* Thumbnail::quickProcessImage (const procparams::ProcParams& params, int
 // Full thumbnail processing, second stage if complete profile exists
 IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rheight, TypeInterpolation interp, std::string camName, 
     double focalLen, double focalLen35mm, float focusDist, float shutter, float fnumber, float iso,std::string expcomp_, double& myscale) {
-
     // check if the WB's equalizer value has changed
     if (wbEqual < (params.wb.equal-5e-4) || wbEqual > (params.wb.equal+5e-4)) {
         wbEqual = params.wb.equal;
@@ -564,7 +657,6 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
         ColorTemp cTemp;
         cTemp.mul2temp (redAWBMul, greenAWBMul, blueAWBMul, wbEqual, autoWBTemp, autoWBGreen);
     }
-
     // compute WB multipliers
     ColorTemp currWB = ColorTemp (params.wb.temperature, params.wb.green, params.wb.equal,params.wb.method);
     if (params.wb.method=="Camera") {
@@ -670,10 +762,12 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
     // if luma denoise has to be done for thumbnails, it should be right here
 
     // perform color space transformation
-    if (isRaw)
-        RawImageSource::colorSpaceConversion (baseImg, params.icm, currWB, embProfile, camProfile, cam2xyz, camName );
-    else
+    if (isRaw) {
+        double pre_mul[3] = { redMultiplier, greenMultiplier, blueMultiplier };
+        RawImageSource::colorSpaceConversion (baseImg, params.icm, currWB, pre_mul, params.raw, embProfile, camProfile, cam2xyz, camName );
+    } else {
         StdImageSource::colorSpaceConversion (baseImg, params.icm, embProfile, thumbImg->getSampleFormat());
+    }
 
     int fw = baseImg->width;
     int fh = baseImg->height;
@@ -729,6 +823,8 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
 	LUTf satcurve (65536);
 	LUTf lhskcurve (65536);
 	LUTf clcurve (65536);
+	LUTf clToningcurve (65536);
+	LUTf cl2Toningcurve (65536);
 	
 	LUTf rCurve (65536);
 	LUTf gCurve (65536);
@@ -737,6 +833,10 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
 	LUTu dummy;
 
 	ToneCurve customToneCurve1, customToneCurve2;
+	ColorGradientCurve ctColorCurve;
+	OpacityCurve ctOpacityCurve;
+  //  NoisCurve dnNoisCurve;
+	
     ColorAppearance customColCurve1;
     ColorAppearance customColCurve2;
     ColorAppearance customColCurve3;
@@ -754,16 +854,61 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
 	CurveFactory::RGBCurve (params.rgbCurves.rcurve, rCurve, 16);
 	CurveFactory::RGBCurve (params.rgbCurves.gcurve, gCurve, 16);
 	CurveFactory::RGBCurve (params.rgbCurves.bcurve, bCurve, 16);
-	
-	LabImage* labView = new LabImage (fw,fh);
-	CieImage* cieView = new CieImage (fw,fh);
+
+	TMatrix wprof = iccStore->workingSpaceMatrix (params.icm.working);
+	double wp[3][3] = {
+		{wprof[0][0],wprof[0][1],wprof[0][2]},
+		{wprof[1][0],wprof[1][1],wprof[1][2]},
+		{wprof[2][0],wprof[2][1],wprof[2][2]}};
+	TMatrix wiprof = iccStore->workingSpaceInverseMatrix (params.icm.working);
+	double wip[3][3] = {
+			{wiprof[0][0],wiprof[0][1],wiprof[0][2]},
+			{wiprof[1][0],wiprof[1][1],wiprof[1][2]},
+			{wiprof[2][0],wiprof[2][1],wiprof[2][2]}
+			};
+	bool opautili=false;		
+	params.colorToning.getCurves(ctColorCurve, ctOpacityCurve, wp, wip, opautili);
+	//params.dirpyrDenoise.getCurves(dnNoisCurve, lldenoisutili);
+
+	bool clctoningutili=false;
+	bool llctoningutili=false;
+    CurveFactory::curveToningCL(clctoningutili, params.colorToning.clcurve, clToningcurve,scale==1 ? 1 : 16);
+    CurveFactory::curveToningLL(llctoningutili, params.colorToning.cl2curve, cl2Toningcurve, scale==1 ? 1 : 16);
 	
     CurveFactory::curveBW (params.blackwhite.beforeCurve, params.blackwhite.afterCurve, hist16, dummy, customToneCurvebw1, customToneCurvebw2, 16);
 	
 	double rrm, ggm, bbm;
     float autor, autog, autob;
+	float satLimit = float(params.colorToning.satProtectionThreshold)/100.f*0.7f+0.3f;
+	float satLimitOpacity = 1.f-(float(params.colorToning.saturatedOpacity)/100.f);
+		
+		if(params.colorToning.enabled  && params.colorToning.autosat){//for colortoning evaluation of saturation settings
+			float moyS=0.f;
+			float eqty=0.f;
+			ipf.moyeqt (baseImg, moyS, eqty);//return image : mean saturation and standard dev of saturation 
+			//printf("moy=%f ET=%f\n", moyS,eqty);
+			float satp=((moyS+1.5f*eqty)-0.3f)/0.7f;//1.5 sigma ==> 93% pixels with high saturation -0.3 / 0.7 convert to Hombre scale
+			if(satp >= 0.92f) satp=0.92f;//avoid values too high (out of gamut)
+			if(satp <= 0.15f) satp=0.15f;//avoid too low values
+			
+			satLimit= 100.f*satp;
+			
+			satLimitOpacity= 100.f*(moyS-0.85f*eqty);//-0.85 sigma==>20% pixels with low saturation
+		} 
+	
     autor = autog = autob = -9000.f; // This will ask to compute the "auto" values for the B&W tool
-    ipf.rgbProc (baseImg, labView, curve1, curve2, curve, shmap, params.toneCurve.saturation, rCurve, gCurve, bCurve, customToneCurve1, customToneCurve2, customToneCurvebw1, customToneCurvebw2,rrm, ggm, bbm, autor, autog, autob, expcomp, hlcompr, hlcomprthresh);
+
+	LabImage* labView = new LabImage (fw,fh);
+    ipf.rgbProc (baseImg, labView, NULL, curve1, curve2, curve, shmap, params.toneCurve.saturation, rCurve, gCurve, bCurve, satLimit ,satLimitOpacity, ctColorCurve, ctOpacityCurve, opautili, clToningcurve, cl2Toningcurve, customToneCurve1, customToneCurve2, customToneCurvebw1, customToneCurvebw2,rrm, ggm, bbm, autor, autog, autob, expcomp, hlcompr, hlcomprthresh);
+
+    // freeing up some memory
+    customToneCurve1.Reset();
+    customToneCurve2.Reset();
+    ctColorCurve.Reset();
+    ctOpacityCurve.Reset();
+ //   dnNoisCurve.Reset();
+    customToneCurvebw1.Reset();
+    customToneCurvebw2.Reset();
 
     if (shmap)
         delete shmap;
@@ -774,7 +919,7 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
         for (int j=0; j<fw; j++){
             hist16[CLIP((int)((labView->L[i][j])))]++;
             hist16C[CLIP((int)sqrt(labView->a[i][j]*labView->a[i][j] + labView->b[i][j]*labView->b[i][j]))]++;
-			}
+        }
     // luminance processing
 //	ipf.EPDToneMap(labView,0,6);
 	
@@ -785,20 +930,21 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
 	bool cclutili=false;
 	bool clcutili=false;
 	
-    CurveFactory::complexLCurve (params.labCurve.brightness, params.labCurve.contrast, params.labCurve.lcurve, 
+    CurveFactory::complexLCurve (params.labCurve.brightness, params.labCurve.contrast, params.labCurve.lcurve,
         hist16, hist16, curve, dummy, 16, utili);
 	
 	CurveFactory::curveCL(clcutili, params.labCurve.clcurve, clcurve, hist16C, dummy, 16);
 	
-    CurveFactory::complexsgnCurve (autili, butili, ccutili, cclutili,params.labCurve.chromaticity, params.labCurve.rstprotection,
+    CurveFactory::complexsgnCurve (1.f, autili, butili, ccutili, cclutili,params.labCurve.chromaticity, params.labCurve.rstprotection,
 								   params.labCurve.acurve, params.labCurve.bcurve,params.labCurve.cccurve,params.labCurve.lccurve, curve1, curve2, satcurve,lhskcurve,
-									hist16C, hist16C, dummy, dummy,
+								   hist16C, hist16C, dummy, dummy,
 								   16);
     //ipf.luminanceCurve (labView, labView, curve);
-    ipf.chromiLuminanceCurve (1,labView, labView, curve1, curve2, satcurve,lhskcurve, clcurve, curve, utili, autili, butili, ccutili,cclutili, clcutili, dummy, dummy, dummy, dummy);
+ 
+
+    ipf.chromiLuminanceCurve (NULL, 1,labView, labView, curve1, curve2, satcurve,lhskcurve, clcurve, curve, utili, autili, butili, ccutili,cclutili, clcutili, dummy, dummy, dummy, dummy);
 	
 	ipf.vibrance(labView);
-	int begh = 0, endh = labView->H;
 
 	if((params.colorappearance.enabled && !params.colorappearance.tonecie) || !params.colorappearance.enabled) ipf.EPDToneMap(labView,5,6);
 
@@ -816,9 +962,7 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
 					16);
 
 	if(params.colorappearance.enabled){
-		float** buffer = new float*[fh];
-		for (int i=0; i<fh; i++)
-			buffer[i] = new float[fw];
+		int begh = 0, endh = labView->H;
 		bool execsharp=false;
 		float d;
 		float fnum = fnumber;// F number
@@ -847,10 +991,13 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
 		LUTf CAMBrightCurveJ;
 		LUTf CAMBrightCurveQ;
 		float CAMMean;
-		ipf.ciecam_02float (cieView, adap, begh, endh, 1, 2, labView, &params,customColCurve1,customColCurve2,customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 6, (float**)buffer, execsharp, d);
-		for (int i=0; i<fh; i++)
-			delete [] buffer[i];
-		delete [] buffer; buffer=NULL;
+		int sk;
+		int scale;
+		sk=16;
+		int rtt=0;		
+		CieImage* cieView = new CieImage (fw,fh);
+		ipf.ciecam_02float (cieView, adap, begh, endh, 1, 2, labView, &params,customColCurve1,customColCurve2,customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 6, execsharp, d, sk, rtt);
+		delete cieView;
 	}
     // color processing
     //ipf.colorCurve (labView, labView);
@@ -860,7 +1007,6 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
     ipf.lab2monitorRgb (labView, readyImg);
     delete labView;
     delete baseImg;
-    delete cieView;
     // calculate scale
     if (params.coarse.rotate==90 || params.coarse.rotate==270) 
         myscale = scale * thumbImg->width / fh;
@@ -868,7 +1014,6 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
         myscale = scale * thumbImg->height / fh;
 
     myscale = 1.0 / myscale;
-
 /*    // apply crop
     if (params.crop.enabled) {
         int ix = 0;
@@ -882,6 +1027,7 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
                 else
                     ix += 3;
     }*/
+
     return readyImg;
 }
 
