@@ -39,7 +39,7 @@
 namespace rtengine {
 extern const Settings* settings;
 
-IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* pl, bool tunnelMetaData) {
+IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* pl, bool tunnelMetaData, bool flush) {
 
     errorCode = 0;
 
@@ -128,13 +128,47 @@ IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* p
     imgsrc->getImage (currWB, tr, baseImg, pp, params.toneCurve, params.icm, params.raw);
     if (pl) pl->setProgress (0.45);
 
+//	LUTf Noisecurve (65536,0);
+//!!!// auto exposure!!!
+    double expcomp = params.toneCurve.expcomp;
+	int    bright = params.toneCurve.brightness;
+	int	   contr = params.toneCurve.contrast;
+	int    black = params.toneCurve.black;
+	int	   hlcompr = params.toneCurve.hlcompr;
+	int    hlcomprthresh = params.toneCurve.hlcomprthresh;
+
+    if (params.toneCurve.autoexp) {
+		LUTu aehist; int aehistcompr;
+		imgsrc->getAutoExpHistogram (aehist, aehistcompr);
+		ipf.getAutoExp (aehist, aehistcompr, imgsrc->getDefGain(), params.toneCurve.clip, expcomp, bright, contr, black, hlcompr,hlcomprthresh);
+    }
+
+    // at this stage, we can flush the raw data to free up quite an important amount of memory
+    // commented out because it makes the application crash when batch processing...
+    // TODO: find a better place to flush rawData and rawRGB
+    if(flush) {
+		imgsrc->flushRawData();
+		imgsrc->flushRGB();
+    }
 
     // perform luma/chroma denoise
-//	CieImage *cieView;    
-
+//	CieImage *cieView;  
+ 	NoisCurve dnNoisCurve;
+    bool lldenoiseutili=false;
+	Imagefloat *calclum ;	
+    params.dirpyrDenoise.getCurves(dnNoisCurve, lldenoiseutili);
+	if (params.dirpyrDenoise.enabled  && lldenoiseutili) {
+		calclum = new Imagefloat (fw, fh);//for luminance denoise curve
+			if(baseImg !=  calclum)
+				baseImg->copyData(calclum);
+			imgsrc->convertColorSpace(calclum, params.icm, currWB, params.raw);
+	}
     if (params.dirpyrDenoise.enabled) {
-		ipf.RGB_denoise(baseImg, baseImg, imgsrc->isRAW(), params.dirpyrDenoise, params.defringe, imgsrc->getDirPyrDenoiseExpComp());
-    }
+       // CurveFactory::denoiseLL(lldenoiseutili, params.dirpyrDenoise.lcurve, Noisecurve,1);
+		//params.dirpyrDenoise.getCurves(dnNoisCurve);	
+		ipf.RGB_denoise(baseImg, baseImg, calclum, imgsrc->isRAW(), params.dirpyrDenoise, params.defringe, imgsrc->getDirPyrDenoiseExpComp(), dnNoisCurve, lldenoiseutili);
+   }
+ //  delete calclum;
     imgsrc->convertColorSpace(baseImg, params.icm, currWB, params.raw);
 
     // perform first analysis
@@ -162,25 +196,6 @@ IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* p
 		shmap->update (baseImg, shradius, ipf.lumimul, params.sh.hq, 1);
     }
     // RGB processing
-//!!!// auto exposure!!!
-    double expcomp = params.toneCurve.expcomp;
-	int    bright = params.toneCurve.brightness;
-	int	   contr = params.toneCurve.contrast;
-	int    black = params.toneCurve.black;
-	int	   hlcompr = params.toneCurve.hlcompr;
-	int    hlcomprthresh = params.toneCurve.hlcomprthresh;
-
-    if (params.toneCurve.autoexp) {
-		LUTu aehist; int aehistcompr;
-		imgsrc->getAutoExpHistogram (aehist, aehistcompr);
-		ipf.getAutoExp (aehist, aehistcompr, imgsrc->getDefGain(), params.toneCurve.clip, expcomp, bright, contr, black, hlcompr,hlcomprthresh);
-    }
-
-    // at this stage, we can flush the raw data to free up quite an important amount of memory
-    // commented out because it makes the application crash when batch processing...
-    // TODO: find a better place to flush rawData and rawRGB
-    //imgsrc->flushRawData();
-    //imgsrc->flushRGB();
 
     LUTf curve1 (65536,0);
     LUTf curve2 (65536,0);
@@ -189,6 +204,8 @@ IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* p
 	LUTf lhskcurve (65536,0);
 	LUTf lumacurve(65536,0);
 	LUTf clcurve (65536,0);
+	LUTf clToningcurve (65536,0);
+	LUTf cl2Toningcurve (65536,0);
 
 	LUTf rCurve (65536,0);
 	LUTf gCurve (65536,0);
@@ -196,9 +213,12 @@ IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* p
 	LUTu dummy;
 
 	ToneCurve customToneCurve1, customToneCurve2;
+	ColorGradientCurve ctColorCurve;
+	OpacityCurve ctOpacityCurve;
 	ColorAppearance customColCurve1, customColCurve2,customColCurve3 ;
 	ToneCurve customToneCurvebw1;
 	ToneCurve customToneCurvebw2;
+	//if(params.blackwhite.enabled) params.toneCurve.hrenabled=false;
 
 	ipf.g = imgsrc->getGamma();
 	ipf.iGamma = true;
@@ -210,17 +230,63 @@ IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* p
 	CurveFactory::RGBCurve (params.rgbCurves.gcurve, gCurve, 1);
 	CurveFactory::RGBCurve (params.rgbCurves.bcurve, bCurve, 1);
 
+	TMatrix wprof = iccStore->workingSpaceMatrix (params.icm.working);
+    TMatrix wiprof = iccStore->workingSpaceInverseMatrix (params.icm.working);
+
+	double wp[3][3] = {
+		{wprof[0][0],wprof[0][1],wprof[0][2]},
+		{wprof[1][0],wprof[1][1],wprof[1][2]},
+		{wprof[2][0],wprof[2][1],wprof[2][2]}};
+	double wip[3][3] = {
+		{wiprof[0][0],wiprof[0][1],wiprof[0][2]},
+		{wiprof[1][0],wiprof[1][1],wiprof[1][2]},
+		{wiprof[2][0],wiprof[2][1],wiprof[2][2]}
+	};
+	bool opautili=false;
+	params.colorToning.getCurves(ctColorCurve, ctOpacityCurve, wp, wip, opautili);
+
+	bool clctoningutili=false;
+	CurveFactory::curveToningCL(clctoningutili, params.colorToning.clcurve, clToningcurve, 1);
+	bool llctoningutili=false;
+	CurveFactory::curveToningLL(llctoningutili, params.colorToning.cl2curve, cl2Toningcurve, 1);
+
     LabImage* labView = new LabImage (fw,fh);
 
 
 	CurveFactory::curveBW (params.blackwhite.beforeCurve, params.blackwhite.afterCurve, hist16, dummy, customToneCurvebw1, customToneCurvebw2, 1);
 	double rrm, ggm, bbm;
     float autor, autog, autob;
+	float satLimit = float(params.colorToning.satProtectionThreshold)/100.f*0.7f+0.3f;
+	float satLimitOpacity = 1.f-(float(params.colorToning.saturatedOpacity)/100.f);
+		
+		if(params.colorToning.enabled  && params.colorToning.autosat){//for colortoning evaluation of saturation settings
+			float moyS=0.f;
+			float eqty=0.f;
+			ipf.moyeqt (baseImg, moyS, eqty);//return image : mean saturation and standard dev of saturation 
+			//printf("moy=%f ET=%f\n", moyS,eqty);
+			float satp=((moyS+1.5f*eqty)-0.3f)/0.7f;//1.5 sigma ==> 93% pixels with high saturation -0.3 / 0.7 convert to Hombre scale
+			if(satp >= 0.92f) satp=0.92f;//avoid values too high (out of gamut)
+			if(satp <= 0.15f) satp=0.15f;//avoid too low values
+			
+			satLimit= 100.f*satp;
+			
+			satLimitOpacity= 100.f*(moyS-0.85f*eqty);//-0.85 sigma==>20% pixels with low saturation
+		} 
+	
     autor = -9000.f; // This will ask to compute the "auto" values for the B&W tool (have to be inferior to -5000)
-    ipf.rgbProc (baseImg, labView, curve1, curve2, curve, shmap, params.toneCurve.saturation, rCurve, gCurve, bCurve, customToneCurve1, customToneCurve2,customToneCurvebw1, customToneCurvebw2, rrm, ggm, bbm, autor, autog, autob, expcomp, hlcompr, hlcomprthresh);
+    ipf.rgbProc (baseImg, labView, NULL, curve1, curve2, curve, shmap, params.toneCurve.saturation, rCurve, gCurve, bCurve, satLimit ,satLimitOpacity, ctColorCurve, ctOpacityCurve, opautili, clToningcurve, cl2Toningcurve,customToneCurve1, customToneCurve2,customToneCurvebw1, customToneCurvebw2, rrm, ggm, bbm, autor, autog, autob, expcomp, hlcompr, hlcomprthresh);
     if (settings->verbose)
         printf("Output image / Auto B&W coefs:   R=%.2f   G=%.2f   B=%.2f\n", autor, autog, autob);
 
+    // freeing up some memory
+    customToneCurve1.Reset();
+    customToneCurve2.Reset();
+    ctColorCurve.Reset();
+    ctOpacityCurve.Reset();
+	dnNoisCurve.Reset();
+    customToneCurvebw1.Reset();
+    customToneCurvebw2.Reset();
+
     // Freeing baseImg because not used anymore
     delete baseImg;
     baseImg = NULL;
@@ -272,12 +338,12 @@ IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* p
 	CurveFactory::complexLCurve (params.labCurve.brightness, params.labCurve.contrast, params.labCurve.lcurve,hist16, hist16, lumacurve, dummy, 1, utili);
 	CurveFactory::curveCL(clcutili, params.labCurve.clcurve, clcurve, hist16C, dummy, 1);
 
-	CurveFactory::complexsgnCurve (autili, butili, ccutili, cclutili, params.labCurve.chromaticity, params.labCurve.rstprotection,
+	CurveFactory::complexsgnCurve (1.f, autili, butili, ccutili, cclutili, params.labCurve.chromaticity, params.labCurve.rstprotection,
 								   params.labCurve.acurve, params.labCurve.bcurve, params.labCurve.cccurve,params.labCurve.lccurve,curve1, curve2, satcurve,lhskcurve, 
 								   hist16C, hist16C, dummy,dummy,
 								   1);
 
-	ipf.chromiLuminanceCurve (1,labView, labView, curve1, curve2, satcurve,lhskcurve,clcurve, lumacurve, utili, autili, butili, ccutili,cclutili, clcutili, dummy, dummy, dummy, dummy);
+	ipf.chromiLuminanceCurve (NULL, 1,labView, labView, curve1, curve2, satcurve,lhskcurve,clcurve, lumacurve, utili, autili, butili, ccutili,cclutili, clcutili, dummy, dummy, dummy, dummy);
 	
  	if((params.colorappearance.enabled && !params.colorappearance.tonecie) || (!params.colorappearance.enabled))ipf.EPDToneMap(labView,5,1);
 	
@@ -309,7 +375,7 @@ IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* p
                 delete [] buffer;
     }
 	// directional pyramid equalizer
-	if((params.colorappearance.enabled && !settings->autocielab)  || !params.colorappearance.enabled) ipf.dirpyrequalizer (labView);//TODO: this is the luminance tonecurve, not the RGB one
+	if((params.colorappearance.enabled && !settings->autocielab)  || !params.colorappearance.enabled) ipf.dirpyrequalizer (labView, 1);//TODO: this is the luminance tonecurve, not the RGB one
 	
 	//Colorappearance and tone-mapping associated
 	
@@ -329,23 +395,20 @@ IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* p
 					customColCurve2,
 					customColCurve3,
 					1);
-	float adap2,adap;
-	double ada, ada2;
+	double adap;
 	if(params.colorappearance.enabled){
 		float fnum = imgsrc->getMetaData()->getFNumber  ();// F number
 		float fiso = imgsrc->getMetaData()->getISOSpeed () ;// ISO
 		float fspeed = imgsrc->getMetaData()->getShutterSpeed () ;//speed
 		float fcomp = imgsrc->getMetaData()->getExpComp  ();//compensation + -
-		if(fnum < 0.3f || fiso < 5.f || fspeed < 0.00001f) {adap=adap2=2000.f;ada=ada2=2000.;}//if no exif data or wrong
+		if(fnum < 0.3f || fiso < 5.f || fspeed < 0.00001f) {
+			adap=2000.;
+		}//if no exif data or wrong
 		else {
 			float E_V = fcomp + log2 ((fnum*fnum) / fspeed / (fiso/100.f));
-			float expo2= params.toneCurve.expcomp;// exposure compensation in tonecurve ==> direct EV
-			E_V += expo2;
-			float expo1;//exposure raw white point
-			expo1=log2(params.raw.expos);//log2 ==>linear to EV
-			E_V += expo1;
-			adap2 = adap= powf(2.f, E_V-3.f);//cd / m2
-			ada=ada2=(double) adap;
+			E_V += params.toneCurve.expcomp;// exposure compensation in tonecurve ==> direct EV
+			E_V += log2(params.raw.expos);// exposure raw white point ; log2 ==> linear to EV
+			adap = powf(2.f, E_V-3.f);//cd / m2
 		}
 		LUTf CAMBrightCurveJ;
 		LUTf CAMBrightCurveQ;
@@ -354,29 +417,18 @@ IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* p
 			float d;
 			double dd;
 
-			float** buffer = new float*[fh];
-			for (int i=0; i<fh; i++)
-			buffer[i] = new float[fw];
-			if(settings->ciecamfloat) ipf.ciecam_02float (cieView, adap, begh, endh,1,2, labView, &params,customColCurve1,customColCurve2,customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, (float**)buffer, true, d);
-			else ipf.ciecam_02 (cieView, ada, begh, endh,1,2, labView, &params,customColCurve1,customColCurve2,customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, (float**)buffer, true, dd);
-			for (int i=0; i<fh; i++)
-			delete [] buffer[i];
-			delete [] buffer;
+			int sk=1;
+			if(settings->ciecamfloat) ipf.ciecam_02float (cieView, float(adap), begh, endh,1,2, labView, &params,customColCurve1,customColCurve2,customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, true, d, sk, 1);
+			else ipf.ciecam_02 (cieView, adap, begh, endh,1,2, labView, &params,customColCurve1,customColCurve2,customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, true, dd, 1, 1);
 		}
 		else {
 			int f_h=2,f_w=2;
 			float d;
 
 			double dd;
-			float** buffer = new float*[f_h];
-			for (int i=0; i<f_h; i++)
-			buffer[i] = new float[f_w];
-			if(settings->ciecamfloat) ipf.ciecam_02float (cieView, adap, begh, endh,1,2, labView, &params,customColCurve1,customColCurve2,customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, (float**)buffer, true, d);
-			else ipf.ciecam_02 (cieView, adap, begh, endh,1, 2, labView, &params,customColCurve1,customColCurve2,customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, (float**)buffer, true, dd);
-
-			for (int i=0; i<f_h; i++)
-			delete [] buffer[i];
-			delete [] buffer;
+			int sk=1;
+			if(settings->ciecamfloat) ipf.ciecam_02float (cieView, float(adap), begh, endh,1,2, labView, &params,customColCurve1,customColCurve2,customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, true, d, sk, 1);
+			else ipf.ciecam_02 (cieView, adap, begh, endh,1, 2, labView, &params,customColCurve1,customColCurve2,customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 1, true, dd, 1, 1);
 		}
 	}	
     delete cieView;
@@ -420,9 +472,8 @@ IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* p
         else if (params.icm.working=="Beta RGB")   ns=4;
         else if (params.icm.working=="BestRGB")    ns=5;
         else if (params.icm.working=="BruceRGB")   ns=6;
-
-
-        readyImg = ipf.lab2rgb16b (labView, cx, cy, cw, ch, params.icm.output, params.icm.working, params.icm.gamma, params.icm.freegamma, params.icm.gampos, params.icm.slpos, ga0,ga1,ga2,ga3,ga4,ga5,ga6 );
+	//	if(params.blackwhite.enabled) params.toneCurve.hrenabled=false;
+        readyImg = ipf.lab2rgb16b (labView, cx, cy, cw, ch, params.icm.output, params.icm.working, params.icm.gamma, params.icm.freegamma, params.icm.gampos, params.icm.slpos, ga0,ga1,ga2,ga3,ga4,ga5,ga6, params.blackwhite.enabled );
         customGamma = true;
 
         //or selected Free gamma
@@ -567,13 +618,24 @@ IImage16* processImage (ProcessingJob* pjob, int& errorCode, ProgressListener* p
     else {
         // if Default gamma mode: we use the profile selected in the "Output profile" combobox;
         // gamma come from the selected profile, otherwise it comes from "Free gamma" tool
-        readyImg = ipf.lab2rgb16 (labView, cx, cy, cw, ch, params.icm.output);
+
+        //  readyImg = ipf.lab2rgb16 (labView, cx, cy, cw, ch, params.icm.output, params.blackwhite.enabled);
+      bool bwonly = params.blackwhite.enabled &&  !params.colorToning.enabled ;
+        readyImg = ipf.lab2rgb16 (labView, cx, cy, cw, ch, params.icm.output, bwonly);
         if (settings->verbose) printf("Output profile: \"%s\"\n", params.icm.output.c_str());
     }
 
     delete labView;
     labView = NULL;
-
+	
+	if(params.blackwhite.enabled &&  !params.colorToning.enabled ) {//force BW r=g=b
+		for (int ccw=0;ccw<cw;ccw++) {
+			for (int cch=0;cch<ch;cch++) {
+			readyImg->r(cch,ccw)=readyImg->g(cch,ccw);
+			readyImg->b(cch,ccw)=readyImg->g(cch,ccw);
+			}
+		}
+	}
     if (pl) pl->setProgress (0.70);
 
     if (params.resize.enabled) {
@@ -708,7 +770,7 @@ void batchProcessingThread (ProcessingJob* job, BatchProcessingListener* bpl, bo
     
     while (currentJob) {
         int errorCode;
-        IImage16* img = processImage (currentJob, errorCode, bpl, tunnelMetaData);
+        IImage16* img = processImage (currentJob, errorCode, bpl, tunnelMetaData, true);
         if (errorCode) {
             bpl->error (M("MAIN_MSG_CANNOTLOAD"));
             currentJob = NULL;
@@ -726,7 +788,12 @@ void batchProcessingThread (ProcessingJob* job, BatchProcessingListener* bpl, bo
 void startBatchProcessing (ProcessingJob* job, BatchProcessingListener* bpl, bool tunnelMetaData) {
 
     if (bpl)
+#if __GNUC__ == 4 && __GNUC_MINOR__ >= 8 && defined( WIN32 ) && defined(__x86_64__)
+		// See Issue 2384 "Very bad response time on win7/64 using gcc 4.8 when queue is running"
+        Glib::Thread::create(sigc::bind(sigc::ptr_fun(batchProcessingThread), job, bpl, tunnelMetaData), 0, true, true, Glib::THREAD_PRIORITY_NORMAL);
+#else
         Glib::Thread::create(sigc::bind(sigc::ptr_fun(batchProcessingThread), job, bpl, tunnelMetaData), 0, true, true, Glib::THREAD_PRIORITY_LOW);
+#endif
     
 }
 
