@@ -1291,5 +1291,18 @@ static INLINE vfloat xcbrtf(vfloat d) {
 
   return y;
 }
+
+static INLINE vfloat LIMV( vfloat a, vfloat b, vfloat c ) {
+return _mm_max_ps( b, _mm_min_ps(a,c));
+}
+
+static INLINE vfloat ULIMV( vfloat a, vfloat b, vfloat c  ){
+	return vself( vmaskf_lt(b,c), LIMV(a,b,c), LIMV(a,c,b));
+}
+
+static INLINE vfloat SQRV(vfloat a){
+	return _mm_mul_ps( a,a );
+}
+
 #endif // __SSE2__
 #endif // SLEEFSSEAVX
