@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -19,7 +19,8 @@
 #ifndef _SIMPLEUTILS_
 #define _SIMPLEUTILS_
 
-namespace rtengine {
+namespace rtengine
+{
 
 void bilinearInterp (const unsigned char* src, int sw, int sh, unsigned char* dst, int dw, int dh);
 void nearestInterp (const unsigned char* src, int sw, int sh, unsigned char* dst, int dw, int dh);
