@@ -217,44 +217,44 @@ FAPictureModeInterpreter faPictureModeInterpreter;
 
 
 const TagAttrib fujiAttribs[] = {
- {0, 1, 0, 0, 0x0000, "Version", &stdInterpreter},
- {0, 1, 0, 0, 0x0010, "InternalSerialNumber", &stdInterpreter},
- {0, 1, 0, 0, 0x1000, "Quality", &stdInterpreter},
- {0, 1, 0, 0, 0x1001, "Sharpness", &faSharpnessInterpreter},
- {0, 1, 0, 0, 0x1002, "WhiteBalance", &faWhiteBalanceInterpreter},
- {0, 1, 0, 0, 0x1003, "Saturation", &faSaturationInterpreter},
- {0, 1, 0, 0, 0x1004, "Contrast", &faContrastInterpreter},
- {0, 1, 0, 0, 0x1005, "ColorTemperature", &stdInterpreter},
- {0, 1, 0, 0, 0x1006, "Contrast2", &faContrast2Interpreter},
- {0, 1, 0, 0, 0x100a, "WhiteBalanceFineTune", &stdInterpreter},
- {0, 1, 0, 0, 0x100b, "NoiseReduction", &faNoiseReductionInterpreter},
- {0, 1, 0, 0, 0x1010, "FujiFlashMode", &faFlashInterpreter},
- {0, 1, 0, 0, 0x1011, "FlashExposureComp", &stdInterpreter},
- {0, 1, 0, 0, 0x1020, "Macro", &faOnOffInterpreter},
- {0, 1, 0, 0, 0x1021, "FocusMode", &faFocusModeInterpreter},
- {0, 1, 0, 0, 0x1023, "FocusPixel", &stdInterpreter},
- {0, 1, 0, 0, 0x1030, "SlowSync", &faOnOffInterpreter},
- {0, 1, 0, 0, 0x1031, "PictureMode", &faPictureModeInterpreter},
- {0, 1, 0, 0, 0x1100, "AutoBracketing", &faOnOffInterpreter},
- {0, 1, 0, 0, 0x1101, "SequenceNumber", &stdInterpreter},
- {0, 1, 0, 0, 0x1210, "ColorMode", &faColorModeInterpreter},
- {0, 1, 0, 0, 0x1300, "BlurWarning", &faOnOffInterpreter},
- {0, 1, 0, 0, 0x1301, "FocusWarning", &faOnOffInterpreter},
- {0, 1, 0, 0, 0x1302, "ExposureWarning", &faOnOffInterpreter},
- {0, 1, 0, 0, 0x1400, "DynamicRange", &faDynamicRangeInterpreter},
- {0, 1, 0, 0, 0x1401, "FilmMode", &faFilmModeInterpreter},
- {0, 1, 0, 0, 0x1402, "DynamicRangeSetting", &faDRSettingInterpreter},
- {0, 1, 0, 0, 0x1403, "DevelopmentDynamicRange", &stdInterpreter},
- {0, 1, 0, 0, 0x1404, "MinFocalLength", &stdInterpreter},
- {0, 1, 0, 0, 0x1405, "MaxFocalLength", &stdInterpreter},
- {0, 1, 0, 0, 0x1406, "MaxApertureAtMinFocal", &stdInterpreter},
- {0, 1, 0, 0, 0x1407, "MaxApertureAtMaxFocal", &stdInterpreter},
- {0, 1, 0, 0, 0x140b, "AutoDynamicRange", &stdInterpreter},
- {0, 1, 0, 0, 0x4100, "FacesDetected", &stdInterpreter},
- {0, 1, 0, 0, 0x8000, "FileSource", &stdInterpreter},
- {0, 1, 0, 0, 0x8002, "OrderNumber", &stdInterpreter},
- {0, 1, 0, 0, 0x8003, "FrameNumber", &stdInterpreter},
- {-1, 0, 0,  0, 0, "", NULL}};
+ {0, AC_WRITE, 0, 0, 0x0000, AUTO, "Version", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x0010, AUTO, "InternalSerialNumber", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1000, AUTO, "Quality", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1001, AUTO, "Sharpness", &faSharpnessInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1002, AUTO, "WhiteBalance", &faWhiteBalanceInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1003, AUTO, "Saturation", &faSaturationInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1004, AUTO, "Contrast", &faContrastInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1005, AUTO, "ColorTemperature", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1006, AUTO, "Contrast2", &faContrast2Interpreter},
+ {0, AC_WRITE, 0, 0, 0x100a, AUTO, "WhiteBalanceFineTune", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x100b, AUTO, "NoiseReduction", &faNoiseReductionInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1010, AUTO, "FujiFlashMode", &faFlashInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1011, AUTO, "FlashExposureComp", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1020, AUTO, "Macro", &faOnOffInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1021, AUTO, "FocusMode", &faFocusModeInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1023, AUTO, "FocusPixel", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1030, AUTO, "SlowSync", &faOnOffInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1031, AUTO, "PictureMode", &faPictureModeInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1100, AUTO, "AutoBracketing", &faOnOffInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1101, AUTO, "SequenceNumber", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1210, AUTO, "ColorMode", &faColorModeInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1300, AUTO, "BlurWarning", &faOnOffInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1301, AUTO, "FocusWarning", &faOnOffInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1302, AUTO, "ExposureWarning", &faOnOffInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1400, AUTO, "DynamicRange", &faDynamicRangeInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1401, AUTO, "FilmMode", &faFilmModeInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1402, AUTO, "DynamicRangeSetting", &faDRSettingInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1403, AUTO, "DevelopmentDynamicRange", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1404, AUTO, "MinFocalLength", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1405, AUTO, "MaxFocalLength", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1406, AUTO, "MaxApertureAtMinFocal", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x1407, AUTO, "MaxApertureAtMaxFocal", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x140b, AUTO, "AutoDynamicRange", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x4100, AUTO, "FacesDetected", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x8000, AUTO, "FileSource", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x8002, AUTO, "OrderNumber", &stdInterpreter},
+ {0, AC_WRITE, 0, 0, 0x8003, AUTO, "FrameNumber", &stdInterpreter},
+ {-1, AC_DONTWRITE, 0,  0, 0, AUTO, "", NULL}};
 }
 #endif
 
