@@ -76,8 +76,17 @@
 #define ADDSET_BLACKWHITE_HUES          68
 #define ADDSET_BLACKWHITE_GAMMA         69
 #define ADDSET_DIRPYREQ_THRESHOLD       70
+#define ADDSET_DIRPYREQ_SKINPROTECT     71
+#define ADDSET_COLORTONING_SPLIT        72
+#define ADDSET_COLORTONING_SATTHRESHOLD 73
+#define ADDSET_COLORTONING_SATOPACITY   74
+#define ADDSET_COLORTONING_BALANCE      75
+#define ADDSET_COLORTONING_STRENGTH     76
+#define ADDSET_DIRPYRDN_PASSES          77
+#define ADDSET_RAWFFCLIPCONTROL         78
+#define ADDSET_FILMSIMULATION_STRENGTH  79
 
 // When adding items, make sure to update ADDSET_PARAM_NUM
-#define ADDSET_PARAM_NUM                71 // THIS IS USED AS A DELIMITER!!
+#define ADDSET_PARAM_NUM                80 // THIS IS USED AS A DELIMITER!!
 
 #endif
