@@ -29,10 +29,10 @@
 
 static double one2one(double val) { return val; }
 
-Adjuster::Adjuster (Glib::ustring vlabel, double vmin, double vmax, double vstep, double vdefault, Gtk::Image *imgIcon, double2double_fun slider2value_, double2double_fun value2slider_) {
+Adjuster::Adjuster (Glib::ustring vlabel, double vmin, double vmax, double vstep, double vdefault, Gtk::Image *imgIcon1, Gtk::Image *imgIcon2, double2double_fun slider2value_, double2double_fun value2slider_) {
 
   Gtk::HBox *hbox2=NULL;
-
+  label = NULL;
   adjusterListener = NULL;
   afterReset = false;
   blocked = false;
@@ -50,7 +50,7 @@ Adjuster::Adjuster (Glib::ustring vlabel, double vmin, double vmax, double vstep
   delay = options.adjusterDelay;		// delay is no more static, so we can set the delay individually (useful for the RAW editor tab)
 
   set_border_width (0);
-  set_spacing (2);
+  set_spacing (0);
 
   hbox = Gtk::manage (new Gtk::HBox ());
   hbox->set_border_width(0);
@@ -82,24 +82,26 @@ Adjuster::Adjuster (Glib::ustring vlabel, double vmin, double vmax, double vstep
 
   if (vlabel.empty()) {
     // No label, everything goes in hbox
-    if (imgIcon) hbox->pack_start (*imgIcon, Gtk::PACK_SHRINK);
+    if (imgIcon1) hbox->pack_start (*imgIcon1, Gtk::PACK_SHRINK, 0);
+    hbox->pack_start (*slider, Gtk::PACK_EXPAND_WIDGET, 0);
+    if (imgIcon2) hbox->pack_start (*imgIcon2, Gtk::PACK_SHRINK, 0);
     hbox->pack_end (*reset, Gtk::PACK_SHRINK, 0); 
     hbox->pack_end (*spin, Gtk::PACK_SHRINK, 0);
-    hbox->pack_start (*slider, true, true);
   }
   else {
     // A label is provided, spreading the widgets in 2 rows
     hbox->pack_start (*label);
     hbox->pack_end (*reset, Gtk::PACK_SHRINK, 0);
     hbox->pack_end (*spin, Gtk::PACK_SHRINK, 0);
-    if (!imgIcon) {
+    if (!imgIcon1 || !imgIcon2) {
       pack_start (*slider, true, true);
     }
     else {
       // A second HBox is necessary
       hbox2 = Gtk::manage (new Gtk::HBox());
-      hbox2->pack_start (*imgIcon, Gtk::PACK_SHRINK);
+      if (imgIcon1) hbox2->pack_start (*imgIcon1, Gtk::PACK_SHRINK, 0);
       hbox2->pack_start (*slider, true, true);
+      if (imgIcon2) hbox2->pack_start (*imgIcon2, Gtk::PACK_SHRINK, 0);
       pack_start (*hbox2, true, true);
     }
   }
@@ -448,6 +450,7 @@ void Adjuster::showEditedCB () {
         hbox->pack_start (*editedCheckBox, Gtk::PACK_SHRINK, 2);
         hbox->reorder_child (*editedCheckBox, 0);
         editedChange = editedCheckBox->signal_toggled().connect( sigc::mem_fun(*this, &Adjuster::editedToggled) );
+        editedCheckBox->show();
     }
 }
 
@@ -469,21 +472,21 @@ void Adjuster::editedToggled () {
     eventPending = false;
 }
 
-double Adjuster::trimValue (double& val) {
+double Adjuster::trimValue (double val) {
 
     if      (val > vMax) val = vMax;  // shapeValue(vMax) ?
     else if (val < vMin) val = vMin;  // shapeValue(vMin) ?
     return val;
 }
 
-int Adjuster::trimValue (int& val) {
+int Adjuster::trimValue (int val) {
 
     if      (val > (int)vMax) val = (int)vMax;  // shapeValue(vMax) ?
     else if (val < (int)vMin) val = (int)vMin;  // shapeValue(vMin) ?
     return val;
 }
 
-float Adjuster::trimValue (float& val) {
+float Adjuster::trimValue (float val) {
 
     if      (val > (float)vMax) val = (float)vMax;  // shapeValue(vMax) ?
     else if (val < (float)vMin) val = (float)vMin;  // shapeValue(vMin) ?
