@@ -19,6 +19,7 @@
 #define _BATCHQUEUE_
 
 #include <gtkmm.h>
+#include "threadutils.h"
 #include "batchqueueentry.h"
 #include "../rtengine/rtengine.h"
 #include "options.h"
@@ -28,7 +29,8 @@
 class BatchQueueListener {
 
     public:
-        virtual void queueSizeChanged     (int qsize, bool queueEmptied) =0;
+        virtual ~BatchQueueListener () {}
+        virtual void queueSizeChanged     (int qsize, bool queueEmptied, bool queueError, Glib::ustring queueErrorMessage) =0;
         virtual bool canStartNext         () =0;
 };
 
@@ -39,8 +41,11 @@ class BatchQueue  : public ThumbBrowserBase,
 
   protected:
     int getMaxThumbnailHeight() const;
+    void saveThumbnailHeight (int height);
+    int  getThumbnailHeight ();
 
     BatchQueueEntry* processing;  // holds the currently processed image
+    int sequence; // holds the current sequence index
 
     Glib::ustring nameTemplate;
     
@@ -49,6 +54,8 @@ class BatchQueue  : public ThumbBrowserBase,
     Gtk::ImageMenuItem* tail;
     Gtk::MenuItem* selall;
     Gtk::Menu* pmenu;
+    
+    Glib::RefPtr<Gtk::AccelGroup> pmaccelgroup;
 
     BatchQueueListener* listener;
 
@@ -61,27 +68,37 @@ class BatchQueue  : public ThumbBrowserBase,
     BatchQueue ();
     ~BatchQueue ();
 
-    void addEntries (std::vector<BatchQueueEntry*> &entries, bool head=false);
+    void addEntries (std::vector<BatchQueueEntry*> &entries, bool head=false, bool save=true);
     void cancelItems (std::vector<ThumbBrowserEntryBase*>* items);
     void headItems (std::vector<ThumbBrowserEntryBase*>* items);
     void tailItems (std::vector<ThumbBrowserEntryBase*>* items);
     void selectAll ();
 
     void startProcessing ();
-    
-    bool hasJobs () { return (!fd.empty()); }
+
+    bool hasJobs () {
+        // not sure that this lock is necessary, but it's safer to keep it...
+        // TODO: Check for Linux
+        #if PROTECT_VECTORS
+        MYREADERLOCK(l, entryRW);
+        #endif
+        return (!fd.empty());
+    }
 
     rtengine::ProcessingJob* imageReady (rtengine::IImage16* img);
+    void error (Glib::ustring msg);
     void setProgress (double p);
     void rightClicked (ThumbBrowserEntryBase* entry);
+    bool keyPressed (GdkEventKey* event);
     void buttonPressed (LWButton* button, int actionCode, void* actionData);
     void redrawNeeded  (LWButton* button);
     
     void setBatchQueueListener (BatchQueueListener* l) { listener = l; }
 
-    void loadBatchQueue ();
+    bool loadBatchQueue ();
+    void resizeLoadedQueue();
 
-    static Glib::ustring calcAutoFileNameBase (const Glib::ustring& origFileName);
+    static Glib::ustring calcAutoFileNameBase (const Glib::ustring& origFileName, int sequence = 0);
     static int calcMaxThumbnailHeight();
 };
 
