@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -25,7 +25,7 @@
 
 using namespace rtengine::procparams;
 
-BatchToolPanelCoordinator::BatchToolPanelCoordinator (FilePanel* parent) : ToolPanelCoordinator(), parent(parent) {
+BatchToolPanelCoordinator::BatchToolPanelCoordinator (FilePanel* parent) : ToolPanelCoordinator(), parent(parent), somethingChanged(false) {
 
 	blockedUpdate = false;
 	// remove exif panel and iptc panel
@@ -140,16 +140,21 @@ void BatchToolPanelCoordinator::initSession () {
 			sharpenEdge->setAdjusterBehavior (false, false);
 			sharpenMicro->setAdjusterBehavior (false, false);
 			icm->setAdjusterBehavior (false, false);
-			
+
 			chmixer->setAdjusterBehavior (false);
 			blackwhite->setAdjusterBehavior (false,false);
-			
+			colortoning->setAdjusterBehavior (false, false, false, false, false);
+			filmSimulation->setAdjusterBehavior(false);
+
 			shadowshighlights->setAdjusterBehavior (false, false, false);
-			dirpyrequalizer->setAdjusterBehavior (false, false);
-			dirpyrdenoise->setAdjusterBehavior (false, false,false,false,false,false);
-			preprocess->setAdjusterBehavior (false, false);
+			dirpyrequalizer->setAdjusterBehavior (false, false, false);
+			dirpyrdenoise->setAdjusterBehavior (false, false,false,false,false,false, false);
+			bayerpreprocess->setAdjusterBehavior (false, false);
 			rawcacorrection->setAdjusterBehavior (false);
-			rawexposure->setAdjusterBehavior (false, false, false);
+			flatfield->setAdjusterBehavior(false);
+			rawexposure->setAdjusterBehavior (false, false);
+			bayerrawexposure->setAdjusterBehavior (false);
+			xtransrawexposure->setAdjusterBehavior (false);
 		}
 		else {
 
@@ -172,15 +177,21 @@ void BatchToolPanelCoordinator::initSession () {
 			sharpenEdge->setAdjusterBehavior (options.baBehav[ADDSET_SHARPENEDGE_AMOUNT],options.baBehav[ADDSET_SHARPENEDGE_PASS]);
 			sharpenMicro->setAdjusterBehavior (options.baBehav[ADDSET_SHARPENMICRO_AMOUNT],options.baBehav[ADDSET_SHARPENMICRO_UNIFORMITY]);
 			icm->setAdjusterBehavior (options.baBehav[ADDSET_FREE_OUPUT_GAMMA],options.baBehav[ADDSET_FREE_OUTPUT_SLOPE]);
-			
+//			colortoning->setAdjusterBehavior (options.baBehav[ADDSET_COLORTONING_SPLIT], options.baBehav[ADDSET_COLORTONING_SATTHRESHOLD], options.baBehav[ADDSET_COLORTONING_SATOPACITY], options.baBehav[ADDSET_COLORTONING_STRPROTECT], options.baBehav[ADDSET_COLORTONING_BALANCE]);
+			colortoning->setAdjusterBehavior (options.baBehav[ADDSET_COLORTONING_SPLIT], options.baBehav[ADDSET_COLORTONING_SATTHRESHOLD], options.baBehav[ADDSET_COLORTONING_SATOPACITY], options.baBehav[ADDSET_COLORTONING_STRENGTH], options.baBehav[ADDSET_COLORTONING_BALANCE]);
+			filmSimulation->setAdjusterBehavior(options.baBehav[ADDSET_FILMSIMULATION_STRENGTH]);
+
 			chmixer->setAdjusterBehavior (options.baBehav[ADDSET_CHMIXER] );
 			blackwhite->setAdjusterBehavior (options.baBehav[ADDSET_BLACKWHITE_HUES],options.baBehav[ADDSET_BLACKWHITE_GAMMA]);
 			shadowshighlights->setAdjusterBehavior (options.baBehav[ADDSET_SH_HIGHLIGHTS], options.baBehav[ADDSET_SH_SHADOWS], options.baBehav[ADDSET_SH_LOCALCONTRAST]);
-			dirpyrequalizer->setAdjusterBehavior (options.baBehav[ADDSET_DIRPYREQ], options.baBehav[ADDSET_DIRPYREQ_THRESHOLD]);
-			dirpyrdenoise->setAdjusterBehavior (options.baBehav[ADDSET_DIRPYRDN_LUMA],options.baBehav[ADDSET_DIRPYRDN_LUMDET],options.baBehav[ADDSET_DIRPYRDN_CHROMA],options.baBehav[ADDSET_DIRPYRDN_CHROMARED],options.baBehav[ADDSET_DIRPYRDN_CHROMABLUE], options.baBehav[ADDSET_DIRPYRDN_GAMMA]);
-			preprocess->setAdjusterBehavior (options.baBehav[ADDSET_PREPROCESS_LINEDENOISE], options.baBehav[ADDSET_PREPROCESS_GREENEQUIL]);
+			dirpyrequalizer->setAdjusterBehavior (options.baBehav[ADDSET_DIRPYREQ], options.baBehav[ADDSET_DIRPYREQ_THRESHOLD], options.baBehav[ADDSET_DIRPYREQ_SKINPROTECT]);
+			dirpyrdenoise->setAdjusterBehavior (options.baBehav[ADDSET_DIRPYRDN_LUMA],options.baBehav[ADDSET_DIRPYRDN_LUMDET],options.baBehav[ADDSET_DIRPYRDN_CHROMA],options.baBehav[ADDSET_DIRPYRDN_CHROMARED],options.baBehav[ADDSET_DIRPYRDN_CHROMABLUE], options.baBehav[ADDSET_DIRPYRDN_GAMMA], options.baBehav[ADDSET_DIRPYRDN_PASSES]);
+			bayerpreprocess->setAdjusterBehavior (options.baBehav[ADDSET_PREPROCESS_LINEDENOISE], options.baBehav[ADDSET_PREPROCESS_GREENEQUIL]);
 			rawcacorrection->setAdjusterBehavior (options.baBehav[ADDSET_RAWCACORR]);
-			rawexposure->setAdjusterBehavior (options.baBehav[ADDSET_RAWEXPOS_LINEAR], options.baBehav[ADDSET_RAWEXPOS_PRESER], options.baBehav[ADDSET_RAWEXPOS_BLACKS]);
+			flatfield->setAdjusterBehavior(options.baBehav[ADDSET_RAWFFCLIPCONTROL]);
+			rawexposure->setAdjusterBehavior (options.baBehav[ADDSET_RAWEXPOS_LINEAR], options.baBehav[ADDSET_RAWEXPOS_PRESER]);
+			bayerrawexposure->setAdjusterBehavior (options.baBehav[ADDSET_RAWEXPOS_BLACKS]);
+			xtransrawexposure->setAdjusterBehavior (options.baBehav[ADDSET_RAWEXPOS_BLACKS]);
 
 			if (options.baBehav[ADDSET_TC_EXPCOMP])  pparams.toneCurve.expcomp = 0;
 			if (options.baBehav[ADDSET_TC_HLCOMPAMOUNT])  pparams.toneCurve.hlcompr = 0;
@@ -235,11 +246,21 @@ void BatchToolPanelCoordinator::initSession () {
 
 			if (options.baBehav[ADDSET_FREE_OUPUT_GAMMA])  pparams.icm.gampos = 0;
 			if (options.baBehav[ADDSET_FREE_OUTPUT_SLOPE])  pparams.icm.slpos = 0;
-			
+
 			//if (options.baBehav[ADDSET_CBOOST_AMOUNT])  pparams.colorBoost.amount = 0;
 
 			//if (options.baBehav[ADDSET_CS_BLUEYELLOW])  pparams.colorShift.a = 0;
 			//if (options.baBehav[ADDSET_CS_GREENMAGENTA])  pparams.colorShift.b = 0;
+			if (options.baBehav[ADDSET_COLORTONING_SPLIT]) pparams.colorToning.redlow  = pparams.colorToning.greenlow  = pparams.colorToning.bluelow =
+			                                               pparams.colorToning.redmed  = pparams.colorToning.greenmed  = pparams.colorToning.bluemed =
+			                                               pparams.colorToning.redhigh = pparams.colorToning.greenhigh = pparams.colorToning.bluehigh =
+			                                               pparams.colorToning.satlow = pparams.colorToning.sathigh = 0;
+			if (options.baBehav[ADDSET_COLORTONING_SATTHRESHOLD]) pparams.colorToning.satProtectionThreshold = 0;
+			if (options.baBehav[ADDSET_COLORTONING_SATOPACITY]) pparams.colorToning.saturatedOpacity = 0;
+			if (options.baBehav[ADDSET_COLORTONING_BALANCE]) pparams.colorToning.balance = 0;
+			if (options.baBehav[ADDSET_COLORTONING_STRENGTH]) pparams.colorToning.strength = 0;
+
+			if (options.baBehav[ADDSET_FILMSIMULATION_STRENGTH]) pparams.filmSimulation.strength = 0;
 
 			if (options.baBehav[ADDSET_ROTATE_DEGREE])  pparams.rotate.degree = 0;
 			if (options.baBehav[ADDSET_DIST_AMOUNT])  pparams.distortion.amount = 0;
@@ -262,21 +283,27 @@ void BatchToolPanelCoordinator::initSession () {
 
 			if (options.baBehav[ADDSET_DIRPYREQ]) for (int i=0; i<5; i++) pparams.dirpyrequalizer.mult[i] = 0;
 			if (options.baBehav[ADDSET_DIRPYREQ_THRESHOLD]) pparams.dirpyrequalizer.threshold = 0;
+			if (options.baBehav[ADDSET_DIRPYREQ_SKINPROTECT]) pparams.dirpyrequalizer.skinprotect = 0;
 
 			if (options.baBehav[ADDSET_DIRPYRDN_LUMA]) pparams.dirpyrDenoise.luma = 0;
-			
+
 			if (options.baBehav[ADDSET_DIRPYRDN_CHROMA]) pparams.dirpyrDenoise.chroma = 0;
 			if (options.baBehav[ADDSET_DIRPYRDN_CHROMARED]) pparams.dirpyrDenoise.redchro = 0;
 			if (options.baBehav[ADDSET_DIRPYRDN_CHROMABLUE]) pparams.dirpyrDenoise.bluechro = 0;
 //			pparams.dirpyrDenoise.Ldetail = pparams.dirpyrDenoise.luma = pparams.dirpyrDenoise.chroma = 0;
 			if (options.baBehav[ADDSET_DIRPYRDN_GAMMA])  pparams.dirpyrDenoise.gamma = 0;
 
-			if (options.baBehav[ADDSET_PREPROCESS_GREENEQUIL])  pparams.raw.greenthresh = 0;
-			if (options.baBehav[ADDSET_PREPROCESS_LINEDENOISE])  pparams.raw.linenoise = 0;
 			if (options.baBehav[ADDSET_RAWCACORR])  pparams.raw.cablue = pparams.raw.cared = 0;
 			if (options.baBehav[ADDSET_RAWEXPOS_LINEAR])  pparams.raw.expos = 0;
 			if (options.baBehav[ADDSET_RAWEXPOS_PRESER])  pparams.raw.preser = 0;
-			if (options.baBehav[ADDSET_RAWEXPOS_BLACKS])  pparams.raw.blackzero = pparams.raw.blackone = pparams.raw.blacktwo = pparams.raw.blackthree = 0;
+			if (options.baBehav[ADDSET_RAWEXPOS_BLACKS]) {
+				pparams.raw.bayersensor.black0 = pparams.raw.bayersensor.black1 = pparams.raw.bayersensor.black2 = pparams.raw.bayersensor.black3 = 0;
+				pparams.raw.xtranssensor.blackred = pparams.raw.xtranssensor.blackgreen = pparams.raw.xtranssensor.blackblue = 0;
+			}
+			if (options.baBehav[ADDSET_RAWFFCLIPCONTROL])  pparams.raw.ff_clipControl = 0;
+
+			if (options.baBehav[ADDSET_PREPROCESS_GREENEQUIL])  pparams.raw.bayersensor.greenthresh = 0;
+			if (options.baBehav[ADDSET_PREPROCESS_LINEDENOISE])  pparams.raw.bayersensor.linenoise = 0;
 		}
 
 		for (size_t i=0; i<toolPanels.size(); i++) {
@@ -299,14 +326,127 @@ void BatchToolPanelCoordinator::panelChanged (rtengine::ProcEvent event, const G
 
     somethingChanged = true;
 
-    pparamsEdited.set (false);        
+    pparamsEdited.set (false);
     // read new values from the gui
     for (size_t i=0; i<toolPanels.size(); i++)
         toolPanels[i]->write (&pparams, &pparamsEdited);
 
-    // TODO: We may update the crop on coarse rotate events here, like in ToolPanelCoordinator::panelChanged
+    // If only a single item is selected, we emulate the behaviour of the editor tool panel coordinator,
+    // otherwise we adjust the inital parameters on a per-image basis.
+    if (selected.size()==1) {
+        // Compensate rotation on flip
+        if (event==rtengine::EvCTHFlip || event==rtengine::EvCTVFlip) {
+            if (fabs(pparams.rotate.degree)>0.001) {
+                  pparams.rotate.degree *= -1;
+                rotate->read (&pparams);
+            }
+        }
 
-    if (event==rtengine::EvAutoExp || event==rtengine::EvClip) 
+        int w, h;
+        selected[0]->getFinalSize (selected[0]->getProcParams (), w, h);
+        crop->setDimensions(w, h);
+
+        // Some transformations change the crop and resize parameter for convenience.
+        if (event==rtengine::EvCTHFlip) {
+            crop->hFlipCrop ();
+            crop->write (&pparams, &pparamsEdited);
+        }
+        else if (event==rtengine::EvCTVFlip) {
+            crop->vFlipCrop ();
+            crop->write (&pparams, &pparamsEdited);
+        }
+        else if (event==rtengine::EvCTRotate) {
+            crop->rotateCrop (pparams.coarse.rotate, pparams.coarse.hflip, pparams.coarse.vflip);
+            crop->write (&pparams, &pparamsEdited);
+            resize->update (pparams.crop.enabled, pparams.crop.w, pparams.crop.h, w, h);
+            resize->write (&pparams, &pparamsEdited);
+        }
+        else if (event==rtengine::EvCrop) {
+            resize->update (pparams.crop.enabled, pparams.crop.w, pparams.crop.h);
+            resize->write (&pparams, &pparamsEdited);
+        }
+    }
+    else {
+        // Compensate rotation on flip
+        if (event==rtengine::EvCTHFlip || event==rtengine::EvCTVFlip) {
+            for (size_t i=0; i<selected.size(); i++) {
+                if (fabs(initialPP[i].rotate.degree) > 0.001) {
+                    initialPP[i].rotate.degree *= -1.0;
+
+                    pparamsEdited.rotate.degree = false;
+                }
+            }
+        }
+
+        // some transformations make the crop change for convenience
+        if (event==rtengine::EvCTHFlip) {
+            for (size_t i=0; i<selected.size(); i++) {
+                int w, h;
+                selected[i]->getFinalSize (selected[i]->getProcParams (), w, h);
+
+                rtengine::procparams::CropParams& crop = initialPP[i].crop;
+                crop.x = w - crop.x - crop.w;
+
+                pparamsEdited.crop.x = false;
+            }
+        }
+        else if (event==rtengine::EvCTVFlip) {
+            for (size_t i=0; i<selected.size(); i++) {
+                int w, h;
+                selected[i]->getFinalSize (selected[i]->getProcParams (), w, h);
+
+                rtengine::procparams::CropParams& crop = initialPP[i].crop;
+                crop.y = h - crop.y - crop.h;
+
+                pparamsEdited.crop.y = false;
+            }
+        }
+        else if (event==rtengine::EvCTRotate) {
+            int newDeg = pparams.coarse.rotate;
+            for (size_t i=0; i<selected.size(); i++) {
+                int w, h;
+                selected[i]->getFinalSize (selected[i]->getProcParams (), w, h);
+
+                int oldDeg = initialPP[i].coarse.rotate;
+
+                rtengine::procparams::CropParams& crop = initialPP[i].crop;
+                int rotation = (360 + newDeg - oldDeg) % 360;
+                ProcParams pptemp = selected[i]->getProcParams(); // Get actual procparams
+                if((pptemp.coarse.hflip != pptemp.coarse.vflip) && ((rotation%180)==90))
+                    rotation = (rotation + 180)%360;
+
+
+                switch (rotation) {
+                case 90:
+                    std::swap(crop.x, crop.y);
+                    std::swap(crop.w, crop.h);
+
+                    crop.x = h - crop.x - crop.w;
+                    break;
+                case 270:
+                    std::swap(crop.x, crop.y);
+                    std::swap(crop.w, crop.h);
+
+                    crop.y = w - crop.y - crop.h;
+                    break;
+                case 180:
+                    crop.x = w - crop.x - crop.w;
+                    crop.y = h - crop.y - crop.h;
+                    break;
+                }
+
+                initialPP[i].coarse.rotate = newDeg;
+
+            }
+            pparamsEdited.crop.x = false;
+            pparamsEdited.crop.y = false;
+            pparamsEdited.crop.w = false;
+            pparamsEdited.crop.h = false;
+            pparamsEdited.coarse.rotate = false;
+        }
+    }
+
+    if (event==rtengine::EvAutoExp || event==rtengine::EvClip)
         for (size_t i=0; i<selected.size(); i++) {
             initialPP[i].toneCurve.autoexp = pparams.toneCurve.autoexp;
             initialPP[i].toneCurve.clip = pparams.toneCurve.clip;
@@ -350,10 +490,10 @@ void BatchToolPanelCoordinator::getAutoWB (double& temp, double& green, double e
 }
 
 void BatchToolPanelCoordinator::getCamWB (double& temp, double& green) {
-    
+
     if (!selected.empty())
         selected[0]->getCamWB (temp, green);
-}    
+}
 
 void BatchToolPanelCoordinator::optionsChanged () {
 
@@ -432,7 +572,7 @@ void BatchToolPanelCoordinator::cropSelectionReady () {
 }
 
 CropGUIListener* BatchToolPanelCoordinator::startCropEditing (Thumbnail* thm) {
-    
+
     if (thm) {
         int w, h;
         thm->getFinalSize (thm->getProcParams (), w, h);
