@@ -22,15 +22,14 @@
 #include <iomanip>
 #include <cmath>
 #include "guiutils.h"
+#include "edit.h"
 
 using namespace rtengine;
 using namespace rtengine::procparams;
 
 
-BlackWhite::BlackWhite (): Gtk::VBox(), FoldableToolPanel(this) {
+BlackWhite::BlackWhite (): FoldableToolPanel(this) {
 	CurveListener::setMulti(true);
-	set_border_width(4);
-	set_spacing(4);
 
 	nextredbw = 0.3333;
 	nextgreenbw = 0.3333;
@@ -81,6 +80,7 @@ BlackWhite::BlackWhite (): Gtk::VBox(), FoldableToolPanel(this) {
 	luminanceCEG = new CurveEditorGroup (options.lastBWCurvesDir, M("TP_BWMIX_CHANNEL"));
 	luminanceCEG->setCurveListener (this);
 	luminanceCurve = static_cast<FlatCurveEditor*>(luminanceCEG->addCurve(CT_Flat, M("TP_BWMIX_VAL")));
+	luminanceCurve->setEditID(EUID_BlackWhiteLuminance, BT_SINGLEPLANE_FLOAT);
 	luminanceCurve->setBottomBarBgGradient(bottomMilestones);
 	luminanceCurve->setCurveColorProvider(this, 3);
 	luminanceCurve->setTooltip(M("TP_BWMIX_CURVEEDITOR_LH_TOOLTIP"));
@@ -235,6 +235,22 @@ BlackWhite::BlackWhite (): Gtk::VBox(), FoldableToolPanel(this) {
 	filterSep2 = Gtk::manage (new  Gtk::HSeparator());
 	mixerVBox->pack_start (*filterSep2);
 
+	algoHBox = Gtk::manage (new Gtk::HBox ());
+	algoHBox->set_border_width (0);
+	algoHBox->set_spacing (2);
+	algoHBox->set_tooltip_markup (M("TP_BWMIX_ALGO_TOOLTIP"));
+	
+	alLabel = Gtk::manage (new Gtk::Label (M("TP_BWMIX_ALGO")+":"));
+	algoHBox->pack_start (*alLabel, Gtk::PACK_SHRINK);
+
+	algo = Gtk::manage (new MyComboBoxText ());
+	algo->append_text (M("TP_BWMIX_ALGO_LI"));
+	algo->append_text (M("TP_BWMIX_ALGO_SP"));
+	algo->set_active (1);
+	algoHBox->pack_start (*algo);
+	mixerVBox->pack_start(*algoHBox);	
+	algoconn = algo->signal_changed().connect ( sigc::mem_fun(*this, &BlackWhite::algoChanged) );
+	
 	mixerOrange= Gtk::manage(new Adjuster (/*M("TP_BWMIX_ORANGE")*/"", -100, 200, 1, 33, imgIcon[1]));
 	if (mixerOrange->delay < 50) mixerOrange->delay = 50;
 	mixerOrange->setAdjusterListener (this);
@@ -323,6 +339,7 @@ BlackWhite::BlackWhite (): Gtk::VBox(), FoldableToolPanel(this) {
 	beforeCurveCEG->setCurveListener (this);
 
 	beforeCurve = static_cast<DiagonalCurveEditor*>(beforeCurveCEG->addCurve(CT_Diagonal, "", beforeCurveMode));
+	beforeCurve->setEditID(EUID_BlackWhiteBeforeCurve, BT_IMAGEFLOAT);
 	beforeCurve->setBottomBarBgGradient(bottomMilestonesbw);
 	beforeCurve->setLeftBarBgGradient(bottomMilestonesbw);
 	beforeCurve->setTooltip(M("TP_BWMIX_CURVEEDITOR_BEFORE_TOOLTIP"));
@@ -346,6 +363,7 @@ BlackWhite::BlackWhite (): Gtk::VBox(), FoldableToolPanel(this) {
 
 //	afterCurve = static_cast<DiagonalCurveEditor*>(afterCurveCEG->addCurve(CT_Diagonal, "", afterCurveMode));
 	afterCurve = static_cast<DiagonalCurveEditor*>(afterCurveCEG->addCurve(CT_Diagonal, ""));
+	afterCurve->setEditID(EUID_BlackWhiteAfterCurve, BT_SINGLEPLANE_FLOAT);
 	afterCurve->setBottomBarBgGradient(bottomMilestonesbw);
 	afterCurve->setLeftBarBgGradient(bottomMilestonesbw);
 	afterCurve->setTooltip(M("TP_BWMIX_CURVEEDITOR_AFTER_TOOLTIP"));
@@ -493,6 +511,17 @@ void BlackWhite::read (const ProcParams* pp, const ParamsEdited* pedited) {
 	autoch->set_active (pp->blackwhite.autoc);
 	lastAuto = pp->blackwhite.autoc;
 
+	algoconn.block(true);
+	if (pedited && !pedited->blackwhite.algo)
+		algo->set_active (2);
+	else if (pp->blackwhite.algo=="LI")
+		algo->set_active (0);
+	else if (pp->blackwhite.algo=="SP")
+		algo->set_active (1);
+	algoconn.block(false);
+	algoChanged();
+	
+	
 	if (pedited) {
 		luminanceCurve->setUnChanged (!pedited->blackwhite.luminanceCurve);
 		beforeCurve->setUnChanged (!pedited->blackwhite.beforeCurve);
@@ -581,6 +610,8 @@ void BlackWhite::write (ProcParams* pp, ParamsEdited* pedited) {
 		pedited->blackwhite.beforeCurve = !beforeCurve->isUnChanged ();
 		pedited->blackwhite.beforeCurveMode = beforeCurveMode->get_active_row_number() != 4;
 		pedited->blackwhite.afterCurve = !afterCurve->isUnChanged ();
+		pedited->blackwhite.algo          = algo->get_active_text()!=M("GENERAL_UNCHANGED");
+		
 //		pedited->blackwhite.afterCurveMode = afterCurveMode->get_active_row_number() != 1;
 	}
 	if (method->get_active_row_number()==0)
@@ -590,10 +621,20 @@ void BlackWhite::write (ProcParams* pp, ParamsEdited* pedited) {
 	else if (method->get_active_row_number()==2)
 		pp->blackwhite.method = "ChannelMixer";
 
+	if (algo->get_active_row_number()==0)
+		pp->blackwhite.algo = "LI";
+	else if (algo->get_active_row_number()==1)
+		pp->blackwhite.algo = "SP";
+		
 	pp->blackwhite.setting = getSettingString();
 	pp->blackwhite.filter = getFilterString();
 }
 
+void BlackWhite::algoChanged () {
+	if (listener && (multiImage||enabled->get_active()) ) {
+		listener->panelChanged (EvBWMethodalg, algo->get_active_text ());}
+}
+
 void BlackWhite::curveChanged (CurveEditor* ce) {
 	if (listener) {
 		if (ce == beforeCurve)
@@ -621,10 +662,13 @@ bool BlackWhite::curveMode1Changed2_ () {
 	return false;
 }
 */
-void BlackWhite::colorForValue (double valX, double valY, int callerId, ColorCaller* caller) {
+void BlackWhite::colorForValue (double valX, double valY, enum ColorCaller::ElemType elemType, int callerId, ColorCaller* caller) {
 
 	float r, g, b;
 
+	if (elemType == ColorCaller::CCET_VERTICAL_BAR)
+		valY = 0.5f;
+
 	if (callerId == 1) {        // Hue = f(Hue)
 
 		float h = float((valY - 0.5) * 2. + valX);
@@ -780,7 +824,7 @@ void BlackWhite::enabled_toggled () {
 	if (listener) {
 		if (enabled->get_inconsistent())
 			listener->panelChanged (EvBWChmixEnabled, M("GENERAL_UNCHANGED"));
-		else if (enabled->get_active ()) {
+		else if (enabled->get_active ()) { 
 			listener->panelChanged (EvBWChmixEnabled, M("GENERAL_ENABLED"));
 		}
 		else {
@@ -1045,7 +1089,7 @@ void BlackWhite::updateRGBLabel () {
 		}
 		double mixR, mixG, mixB;
 		Glib::ustring sSetting = getSettingString();
-		Color::computeBWMixerConstants(sSetting, getFilterString(), r, g, b,
+		Color::computeBWMixerConstants(sSetting, getFilterString(),getalgoString(), r, g, b,
 				mixerOrange->getValue(), mixerYellow->getValue(), mixerCyan->getValue(), mixerPurple->getValue(), mixerMagenta->getValue(),
 				autoch->get_active(), enabledcc->get_active(), kcorrec, mixR, mixG, mixB);
 		RGBLabels->set_text(
@@ -1095,6 +1139,7 @@ void BlackWhite::setBatchMode (bool batchMode) {
 	beforeCurveMode->append_text (M("GENERAL_UNCHANGED"));
 	afterCurveCEG->setBatchMode (batchMode);
 //	afterCurveMode->append_text (M("GENERAL_UNCHANGED"));
+	algo->append_text (M("GENERAL_UNCHANGED"));
 
 	showLuminance();
 	showFilter();
@@ -1108,6 +1153,11 @@ void BlackWhite::autoOpenCurve () {
 	beforeCurve->openIfNonlinear();
 	afterCurve->openIfNonlinear();
 }
+void BlackWhite::setEditProvider (EditDataProvider *provider) {
+	luminanceCurve->setEditProvider(provider);
+	beforeCurve->setEditProvider(provider);
+	afterCurve->setEditProvider(provider);
+}
 
 void BlackWhite::setAdjusterBehavior (bool bwadd, bool bwgadd) {
 
@@ -1185,6 +1235,8 @@ void BlackWhite::showMixer(int nChannels, bool RGBIsSensitive) {
 		mixerGreen->show(); mixerGreen->set_sensitive (RGBIsSensitive);
 		mixerBlue->show();  mixerBlue->set_sensitive (RGBIsSensitive);
 		filterSep2->hide();
+		algo->hide();
+		alLabel->hide();
 		mixerOrange->hide();
 		mixerYellow->hide();
 		mixerCyan->hide();
@@ -1197,6 +1249,8 @@ void BlackWhite::showMixer(int nChannels, bool RGBIsSensitive) {
 		mixerBlue->show();  mixerBlue->set_sensitive (true);
 		filterSep2->show();
 		mixerOrange->show();
+		algo->show();
+		alLabel->show();
 		mixerYellow->show();
 		mixerCyan->show();
 		mixerMagenta->show();
@@ -1219,6 +1273,15 @@ void BlackWhite::hideGamma() {
 		gammaFrame->hide();
 }
 
+Glib::ustring BlackWhite::getalgoString() {
+	Glib::ustring retVal;
+	if (algo->get_active_row_number()==0)
+		retVal = "LI";
+	else if (algo->get_active_row_number()==1)
+		retVal = "SP";
+	return retVal;		
+}
+
 Glib::ustring BlackWhite::getSettingString() {
 	Glib::ustring retVal;
 	if (setting->get_active_row_number()==0)
