@@ -28,7 +28,7 @@
 #include "mycurve.h"
 #include "colorprovider.h"
 
-class BlackWhite : public Gtk::VBox, public AdjusterListener, public FoldableToolPanel, public rtengine::AutoBWListener, public CurveListener, public ColorProvider{
+class BlackWhite : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel, public rtengine::AutoBWListener, public CurveListener, public ColorProvider{
 
   protected:
 	FlatCurveEditor*     luminanceCurve;
@@ -44,6 +44,10 @@ class BlackWhite : public Gtk::VBox, public AdjusterListener, public FoldableToo
 	Gtk::HBox*           autoHBox;
 	Gtk::Button*         neutral;
 	Gtk::Label*          RGBLabels;
+    MyComboBoxText*   algo;
+    sigc::connection  algoconn;
+	Gtk::Label*          alLabel;
+	Gtk::HBox*        algoHBox;
 
 	Adjuster *mixerRed;
 	Adjuster *mixerGreen;
@@ -104,6 +108,7 @@ class BlackWhite : public Gtk::VBox, public AdjusterListener, public FoldableToo
 	void setDefaults     (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
 	void setBatchMode    (bool batchMode);
 	void autoOpenCurve   ();
+	void setEditProvider (EditDataProvider *provider);
 
 	void autoch_toggled  ();
 	void neutral_pressed ();
@@ -117,7 +122,7 @@ class BlackWhite : public Gtk::VBox, public AdjusterListener, public FoldableToo
 	void methodChanged       ();
 	void filterChanged       ();
 	void settingChanged      ();
-	virtual void colorForValue (double valX, double valY, int callerId, ColorCaller* caller);
+	virtual void colorForValue (double valX, double valY, enum ColorCaller::ElemType elemType, int callerId, ColorCaller* caller);
 	void BWChanged           (double redbw, double greenbw, double bluebw);
 	bool BWComputed_         ();
 	void curveChanged        (CurveEditor* ce);
@@ -125,9 +130,12 @@ class BlackWhite : public Gtk::VBox, public AdjusterListener, public FoldableToo
 	bool curveMode1Changed_  ();
 	void curveMode1Changed2  ();
 	bool curveMode1Changed2_ ();
+    void algoChanged         ();
 
 	Glib::ustring getSettingString ();
 	Glib::ustring getFilterString  ();
+	Glib::ustring getalgoString  ();
+	
 };
 
 #endif
