@@ -21,12 +21,14 @@
 
 #include <glibmm.h>
 #include "../rtengine/rtengine.h"
+#include "threadutils.h"
 #include "thumbnail.h"
 
 class BQEntryUpdateListener {
 
     public:
-        virtual void updateImage (guint8* img, int w, int h) {}
+        virtual ~BQEntryUpdateListener () {}
+        virtual void updateImage (guint8* img, int w, int h, int origw, int origh, guint8* newOPreview) {}
 };
 
 class BatchQueueEntryUpdater {
@@ -35,6 +37,8 @@ class BatchQueueEntryUpdater {
         guint8* oimg;
         int ow, oh, newh;
         BQEntryUpdateListener* listener;
+        rtengine::ProcParams* pparams;
+        Thumbnail* thumbnail;
     };
 
   protected:
@@ -42,12 +46,12 @@ class BatchQueueEntryUpdater {
     bool stopped;
     std::list<Job> jqueue;
     Glib::Thread* thread;
-    Glib::Mutex* qMutex;
+    MyMutex* qMutex;
 
   public:
     BatchQueueEntryUpdater ();
 
-    void process    (guint8* oimg, int ow, int oh, int newh, BQEntryUpdateListener* listener);
+    void process    (guint8* oimg, int ow, int oh, int newh, BQEntryUpdateListener* listener, rtengine::ProcParams* pparams=NULL, Thumbnail* thumbnail=NULL);
     void removeJobs (BQEntryUpdateListener* listener);
     void terminate  ();
 
