@@ -25,14 +25,12 @@
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-ColorAppearance::ColorAppearance () : Gtk::VBox(), FoldableToolPanel(this) {
+ColorAppearance::ColorAppearance () : FoldableToolPanel(this) {
 	CurveListener::setMulti(true);
 	std::vector<GradientMilestone> milestones;
 	milestones.push_back( GradientMilestone(0., 0., 0., 0.) );
 	milestones.push_back( GradientMilestone(1., 1., 1., 1.) );
 
-	set_border_width(4);
-
 	enabled = Gtk::manage (new Gtk::CheckButton (M("GENERAL_ENABLED")));
 	enabled->set_active (false);
 	pack_start (*enabled);
@@ -934,9 +932,13 @@ bool ColorAppearance::adapCamComputed_ () {
 }
 
 
-void ColorAppearance::colorForValue (double valX, double valY, int callerId, ColorCaller *caller) {
+void ColorAppearance::colorForValue (double valX, double valY, enum ColorCaller::ElemType elemType, int callerId, ColorCaller *caller) {
 
 	float R, G, B;
+
+	if (elemType==ColorCaller::CCET_VERTICAL_BAR)
+		valY = 0.5;
+
 	if (callerId == 1) {    // cc - bottom bar
 
 		float value = (1.f - 0.7f) * float(valX) + 0.7f;
@@ -1099,7 +1101,7 @@ void ColorAppearance::algoChanged () {
 		schroma->show();
 		qbright->hide();
 		colorh->hide();
-		tonecie->hide();		
+		tonecie->hide();
 //		sharpcie->hide();
 		curveEditorG->show();
 		curveEditorG2->show();
@@ -1132,7 +1134,7 @@ void ColorAppearance::algoChanged () {
 		schroma->show();
 		qbright->show();
 		colorh->show();
-		tonecie->show();		
+		tonecie->show();
 //		sharpcie->show();
 //		sharpcie->hide();
 		curveEditorG->show();
@@ -1167,19 +1169,18 @@ void ColorAppearance::setBatchMode (bool batchMode) {
 	wbmodel->append_text (M("GENERAL_UNCHANGED"));
 	algo->append_text (M("GENERAL_UNCHANGED"));
 	toneCurveMode->append_text (M("GENERAL_UNCHANGED"));
-//	toneCurveMode2->append_text (M("GENERAL_UNCHANGED"));
-//	toneCurveMode3->append_text (M("GENERAL_UNCHANGED"));
+	toneCurveMode2->append_text (M("GENERAL_UNCHANGED"));
+	toneCurveMode3->append_text (M("GENERAL_UNCHANGED"));
 
 	curveEditorG->setBatchMode (batchMode);
-//	curveEditorG2->setBatchMode (batchMode);
-//	curveEditorG3->setBatchMode (batchMode);
+	curveEditorG2->setBatchMode (batchMode);
+	curveEditorG3->setBatchMode (batchMode);
 }
 
-void ColorAppearance::updateCurveBackgroundHistogram (LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve, LUTu & histCLurve, LUTu & histLLCurve, LUTu & histLCAM,  LUTu & histCCAM, LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma){
+void ColorAppearance::updateCurveBackgroundHistogram (LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve,/* LUTu & histCLurve, LUTu & histLLCurve,*/ LUTu & histLCAM,  LUTu & histCCAM, LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma){
 
 	shape->updateBackgroundHistogram (histLCAM);
 	shape3->updateBackgroundHistogram (histCCAM);
-	
 }
 
 
