@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -23,7 +23,6 @@
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-extern Glib::ustring argv0;
 extern Options options;
 
 class RefreshSpinHelper {
@@ -35,9 +34,7 @@ class RefreshSpinHelper {
             : crop(_crop), notify(_notify) {}
 };
 
-Crop::Crop (): Gtk::VBox(), FoldableToolPanel(this) {
-
-  set_border_width(4);
+Crop::Crop (): FoldableToolPanel(this) {
 
   clistener = NULL;
 
@@ -75,12 +72,12 @@ Crop::Crop (): Gtk::VBox(), FoldableToolPanel(this) {
   h = Gtk::manage (new MySpinButton ());
   h->set_size_request (60, -1);
   hb2->pack_start (*h);
-  
+
   pack_start (*hb2, Gtk::PACK_SHRINK, 4);
 
   selectCrop = Gtk::manage (new Gtk::Button (M("TP_CROP_SELECTCROP")));
   selectCrop->set_image (*Gtk::manage (new RTImage ("crop.png")));
-  
+
   pack_start (*selectCrop, Gtk::PACK_SHRINK, 2);
 
   Gtk::HBox* hb3 = Gtk::manage (new Gtk::HBox ());
@@ -105,7 +102,7 @@ Crop::Crop (): Gtk::VBox(), FoldableToolPanel(this) {
   hb31->pack_start (*guide);
 
   pack_start (*hb31, Gtk::PACK_SHRINK, 4);
-  
+
   // ppibox START
   ppibox = Gtk::manage (new Gtk::VBox());
   ppibox->pack_start (*Gtk::manage (new  Gtk::HSeparator()), Gtk::PACK_SHRINK, 2);
@@ -126,13 +123,13 @@ Crop::Crop (): Gtk::VBox(), FoldableToolPanel(this) {
   sizebox->pack_start (*sizein, Gtk::PACK_SHRINK, 4);
   sizebox->pack_start (*Gtk::manage (new  Gtk::HSeparator()), Gtk::PACK_SHRINK, 6);
   sizebox->pack_start (*hb4, Gtk::PACK_SHRINK, 2);
-  
+
   ppibox->pack_start (*sizebox, Gtk::PACK_SHRINK, 1);
   pack_start (*ppibox, Gtk::PACK_SHRINK, 0);
 
   ppi->set_value (300);
   // ppibox END
-  
+
  /****************
  * Crop Ratio
  *****************/
@@ -167,7 +164,7 @@ Crop::Crop (): Gtk::VBox(), FoldableToolPanel(this) {
   cropratio[25].label = "45:35 - ePassport";       cropratio[25].value = 45.0/35.0;
 
 
-    
+
   // populate the combobox
   for (int i=0; i<NumberOfCropRatios; i++) {
      ratio->append_text (cropratio[i].label);
@@ -180,6 +177,7 @@ Crop::Crop (): Gtk::VBox(), FoldableToolPanel(this) {
   orientation->set_active (0);
 
   guide->append_text (M("TP_CROP_GTNONE"));
+  guide->append_text (M("TP_CROP_GTFRAME"));
   guide->append_text (M("TP_CROP_GTRULETHIRDS"));
   guide->append_text (M("TP_CROP_GTDIAGONALS"));
   guide->append_text (M("TP_CROP_GTHARMMEANS1"));
@@ -188,7 +186,6 @@ Crop::Crop (): Gtk::VBox(), FoldableToolPanel(this) {
   guide->append_text (M("TP_CROP_GTHARMMEANS4"));
   guide->append_text (M("TP_CROP_GTGRID"));
   guide->append_text (M("TP_CROP_GTEPASSPORT"));
-  guide->append_text (M("TP_CROP_GTFRAME"));
   guide->set_active (0);
 
   w->set_range (0, maxw);
@@ -251,7 +248,7 @@ void Crop::readOptions () {
 void Crop::read (const ProcParams* pp, const ParamsEdited* pedited) {
 
     disableListener ();
-    
+
     xconn.block (true);
     yconn.block (true);
     wconn.block (true);
@@ -274,30 +271,31 @@ void Crop::read (const ProcParams* pp, const ParamsEdited* pedited) {
     ratio->set_active_text (pp->crop.ratio);
     fixr->set_active (pp->crop.fixratio);
 
+    const bool flip_orientation = pp->crop.fixratio && cropratio[ratio->get_active_row_number()].value < 1.0;
     if (pp->crop.orientation == "Landscape")
-        orientation->set_active (0);
+        orientation->set_active (flip_orientation ? 1 : 0);
     else if (pp->crop.orientation == "Portrait")
-        orientation->set_active (1);
-    
+        orientation->set_active (flip_orientation ? 0 : 1);
+
     if (pp->crop.guide == "None")
         guide->set_active (0);
-    else if (pp->crop.guide == "Rule of thirds")
-        guide->set_active (1);
-    else if (pp->crop.guide == "Rule of diagonals")
-        guide->set_active (2);
-    else if (pp->crop.guide == "Harmonic means 1")
-        guide->set_active (3);
-    else if (pp->crop.guide == "Harmonic means 2")
-        guide->set_active (4);
-    else if (pp->crop.guide == "Harmonic means 3")
-        guide->set_active (5);
-    else if (pp->crop.guide == "Harmonic means 4")
-        guide->set_active (6);
-    else if (pp->crop.guide == "Grid")
-        guide->set_active (7);
-    else if (pp->crop.guide == "ePassport")
-        guide->set_active (8);
     else if (pp->crop.guide == "Frame")
+        guide->set_active (1);
+    else if (pp->crop.guide == "Rule of thirds")
+        guide->set_active (2);
+    else if (pp->crop.guide == "Rule of diagonals")
+        guide->set_active (3);
+    else if (pp->crop.guide == "Harmonic means 1")
+        guide->set_active (4);
+    else if (pp->crop.guide == "Harmonic means 2")
+        guide->set_active (5);
+    else if (pp->crop.guide == "Harmonic means 3")
+        guide->set_active (6);
+    else if (pp->crop.guide == "Harmonic means 4")
+        guide->set_active (7);
+    else if (pp->crop.guide == "Grid")
+        guide->set_active (8);
+    else if (pp->crop.guide == "ePassport")
         guide->set_active (9);
 
     x->set_value (pp->crop.x);
@@ -309,7 +307,7 @@ void Crop::read (const ProcParams* pp, const ParamsEdited* pedited) {
     ny = pp->crop.y;
     nw = pp->crop.w;
     nh = pp->crop.h;
-    
+
     lastRotationDeg = pp->coarse.rotate;
 
     wDirty = false;
@@ -323,11 +321,11 @@ void Crop::read (const ProcParams* pp, const ParamsEdited* pedited) {
         xDirty = pedited->crop.x;
         yDirty = pedited->crop.y;
         if (!pedited->crop.ratio)
-            ratio->set_active (8);
-        if (!pedited->crop.orientation) 
-            orientation->set_active (2);
-        if (!pedited->crop.guide) 
-            guide->set_active (7);
+            ratio->set_active_text (M("GENERAL_UNCHANGED"));
+        if (!pedited->crop.orientation)
+            orientation->set_active_text (M("GENERAL_UNCHANGED"));
+        if (!pedited->crop.guide)
+            guide->set_active_text (M("GENERAL_UNCHANGED"));
         enabled->set_inconsistent (!pedited->crop.enabled);
         fixr->set_inconsistent (!pedited->crop.fixratio);
     }
@@ -358,37 +356,39 @@ void Crop::write (ProcParams* pp, ParamsEdited* pedited) {
   pp->crop.fixratio = fixr->get_active ();
   pp->crop.ratio = ratio->get_active_text ();
 
+  // for historical reasons we store orientation different if ratio is written as 2:3 instead of 3:2, but in GUI 'landscape' is always long side horizontal regardless of the ratio is written short or long side first.
+  const bool flip_orientation = fixr->get_active() && cropratio[ratio->get_active_row_number()].value < 1.0;
   if (orientation->get_active_row_number()==0)
-      pp->crop.orientation = "Landscape";
+      pp->crop.orientation = flip_orientation ? "Portrait" : "Landscape";
   else if (orientation->get_active_row_number()==1)
-      pp->crop.orientation = "Portrait";
+      pp->crop.orientation = flip_orientation ? "Landscape" : "Portrait";
 
   if (guide->get_active_row_number()==0)
     pp->crop.guide = "None";
   else if (guide->get_active_row_number()==1)
-    pp->crop.guide = "Rule of thirds";
-  else if (guide->get_active_row_number()==2)
-    pp->crop.guide = "Rule of diagonals";
-  else if (guide->get_active_row_number()==3)
-    pp->crop.guide = "Harmonic means 1";
-  else if (guide->get_active_row_number()==4)
-    pp->crop.guide = "Harmonic means 2";
-  else if (guide->get_active_row_number()==5)
-    pp->crop.guide = "Harmonic means 3";
-  else if (guide->get_active_row_number()==6)
-    pp->crop.guide = "Harmonic means 4";
-  else if (guide->get_active_row_number()==7)
-    pp->crop.guide = "Grid";
-  else if (guide->get_active_row_number()==8)
-    pp->crop.guide = "ePassport";
-  else if (guide->get_active_row_number()==9)
     pp->crop.guide = "Frame";
+  else if (guide->get_active_row_number()==2)
+    pp->crop.guide = "Rule of thirds";
+  else if (guide->get_active_row_number()==3)
+    pp->crop.guide = "Rule of diagonals";
+  else if (guide->get_active_row_number()==4)
+    pp->crop.guide = "Harmonic means 1";
+  else if (guide->get_active_row_number()==5)
+    pp->crop.guide = "Harmonic means 2";
+  else if (guide->get_active_row_number()==6)
+    pp->crop.guide = "Harmonic means 3";
+  else if (guide->get_active_row_number()==7)
+    pp->crop.guide = "Harmonic means 4";
+  else if (guide->get_active_row_number()==8)
+    pp->crop.guide = "Grid";
+  else if (guide->get_active_row_number()==9)
+    pp->crop.guide = "ePassport";
 
     if (pedited) {
         pedited->crop.enabled       = !enabled->get_inconsistent();
-        pedited->crop.ratio         = ratio->get_active_row_number() != 9;
-        pedited->crop.orientation   = orientation->get_active_row_number() != 2;
-        pedited->crop.guide         = guide->get_active_row_number() != 9;
+        pedited->crop.ratio         = ratio->get_active_text() != M("GENERAL_UNCHANGED");
+        pedited->crop.orientation   = orientation->get_active_text() != M("GENERAL_UNCHANGED");
+        pedited->crop.guide         = guide->get_active_text() != M("GENERAL_UNCHANGED");
         pedited->crop.fixratio      = !fixr->get_inconsistent();
         pedited->crop.w             = wDirty;
         pedited->crop.h             = hDirty;
@@ -433,6 +433,10 @@ void Crop::trim (ProcParams* pp, int ow, int oh) {
 	}
 }
 
+bool Crop::inImageArea (int x, int y) {
+	return x>=0 && x<maxw && y>=0 && y<maxh;
+}
+
 void Crop::selectPressed () {
 
   if (clistener)
@@ -441,8 +445,19 @@ void Crop::selectPressed () {
 
 void Crop::notifyListener () {
 
-    if (listener && enabled->get_active ()) 
-        listener->panelChanged (EvCrop, Glib::ustring::compose ("%1=%2, %3=%4\n%5=%6, %7=%8", M("TP_CROP_X"), nx, M("TP_CROP_Y"), ny, M("TP_CROP_W"), nw, M("TP_CROP_H"), nh));
+    if (listener && enabled->get_active ())
+        if (nw == 1 && nh == 1) {
+            econn.block (true);
+            enabled->set_active (false);
+            econn.block (false);
+            nx = (int)x->get_value ();
+            ny = (int)x->get_value ();
+            nw = (int)w->get_value ();
+            nh = (int)h->get_value ();
+            listener->panelChanged (EvCrop, M("GENERAL_DISABLED"));
+        }
+        else
+            listener->panelChanged (EvCrop, Glib::ustring::compose ("%1=%2, %3=%4\n%5=%6, %7=%8", M("TP_CROP_X"), nx, M("TP_CROP_Y"), ny, M("TP_CROP_W"), nw, M("TP_CROP_H"), nh));
 }
 
 void Crop::enabledChanged () {
@@ -494,32 +509,34 @@ void Crop::vFlipCrop () {
     g_idle_add (refreshSpinsUI, new RefreshSpinHelper (this, false));
 }
 
-void Crop::rotateCrop (int deg) {
-
-    int tmp;
-    switch ((360+deg-lastRotationDeg)%360) {
-        case 90:
-            tmp = nx;
-            nx = maxh - ny - nh;
-            ny = tmp;
-            tmp = nw;
-            nw = nh;
-            nh = tmp;
-            break;
-        case 270:
-            tmp = ny;
-            ny = maxw - nx - nw;
-            nx = tmp;
-            tmp = nw;
-            nw = nh;
-            nh = tmp;
-            break;
-        case 180:
-            nx = maxw - nx - nw;
-            ny = maxh - ny - nh;
-            break;
-    }
+void Crop::rotateCrop (int deg, bool hflip, bool vflip) {
 
+	int rotation = (360+deg-lastRotationDeg)%360;
+	if((hflip != vflip) && ((rotation%180)==90))
+		rotation = (rotation + 180)%360;
+	int tmp;
+	switch (rotation) {
+		case 90:
+			tmp = nx;
+			nx = maxh - ny - nh;
+			ny = tmp;
+			tmp = nw;
+			nw = nh;
+			nh = tmp;
+			break;
+		case 270:
+			tmp = ny;
+			ny = maxw - nx - nw;
+			nx = tmp;
+			tmp = nw;
+			nw = nh;
+			nh = tmp;
+			break;
+		case 180:
+			nx = maxw - nx - nw;
+			ny = maxh - ny - nh;
+			break;
+	}
     lastRotationDeg = deg;
     g_idle_add (refreshSpinsUI, new RefreshSpinHelper (this, false));
 }
@@ -590,7 +607,7 @@ void Crop::ratioChanged () {
 // Correct current crop if it doesn't fit
 void Crop::adjustCropToRatio() {
     if (fixr->get_active() && !fixr->get_inconsistent()) {
- 
+
 //        int W = w->get_value ();
 //        int H = h->get_value ();
         int W = nw;
@@ -747,8 +764,9 @@ void Crop::cropWidth1Resized (int &X, int &Y, int &W, int &H) {
     if (fixr->get_active()) {
         double r = getRatio();
         H = (int)round(W / r);
-        if (H > maxh) {
-            H = maxh;
+        int Hmax = min(ny + nh, maxh - ny);
+        if (H > Hmax) {
+            H = Hmax;
             W = H * r;
         }
         ny = ny - (H - nh) / 2.0;
@@ -771,8 +789,9 @@ void Crop::cropWidth2Resized (int &X, int &Y, int &W, int &H) {
     if (fixr->get_active()) {
         double r = getRatio();
         H = (int)round(W / r);
-        if (H > maxh) {
-            H = maxh;
+        int Hmax = min(ny + nh, maxh - ny);
+        if (H > Hmax) {
+            H = Hmax;
             W = H * r;
         }
         ny = ny - (H - nh) / 2.0;
@@ -795,8 +814,9 @@ void Crop::cropHeight1Resized (int &X, int &Y, int &W, int &H) {
     if (fixr->get_active()) {
         double r = getRatio();
         W = (int)round(H * r);
-        if (W > maxw) {
-            W = maxw;
+        int Wmax = min(nx + nw, maxw - nx);
+        if (W > Wmax) {
+            W = Wmax;
             H = W / r;
         }
         nx = nx - (W - nw) / 2.0;
@@ -819,8 +839,9 @@ void Crop::cropHeight2Resized (int &X, int &Y, int &W, int &H) {
     if (fixr->get_active()) {
         double r = getRatio();
         W = (int)round(H * r);
-        if (W > maxw) {
-            W = maxw;
+        int Wmax = min(nx + nw, maxw - nx);
+        if (W > Wmax) {
+            W = Wmax;
             H = W / r;
         }
         nx = nx - (W - nw) / 2.0; // nx must be floating point to avoid drifting
@@ -939,12 +960,10 @@ void Crop::cropInit (int &x, int &y, int &w, int &h) {
   nh = 1;
 
   w = 1; h = 1;
-  
+
   econn.block (true);
   enabled->set_active (1);
   econn.block (false);
-  g_idle_add (refreshSpinsUI, new RefreshSpinHelper (this, false));
-//  Glib::signal_idle().connect (sigc::mem_fun(*this, &Crop::refreshSpins));
 }
 
 void Crop::cropResized (int &x, int &y, int& x2, int& y2) {
@@ -988,21 +1007,21 @@ void Crop::cropResized (int &x, int &y, int& x2, int& y2) {
     if (y<=y2) {
       int W2max = (int)round ((maxh-Y) * r);
       if (W>W2max)
-        W = W2max;  
+        W = W2max;
     }
     else {
       int W2max = (int)round (y * r);
       if (W>W2max)
-        W = W2max;  
+        W = W2max;
     }
     H = (int)round(W / r);
     if (x<x2)
       x2 = x + W - 1;
-    else 
+    else
       x2 = x - W + 1;
-    if (y<y2) 
+    if (y<y2)
       y2 = y + H - 1;
-    else 
+    else
       y2 = y - H + 1;
   }
 
@@ -1043,6 +1062,8 @@ double Crop::getRatio () {
     return r;
 
   r = cropratio[ratio->get_active_row_number()].value;
+  if (r < 1.0)
+    r = 1.0 / r; // convert to long side first (eg 4:5 becomes 5:4)
 
   if (orientation->get_active_row_number()==0)
     return r;
@@ -1054,8 +1075,8 @@ void Crop::setBatchMode (bool batchMode) {
 
     ToolPanel::setBatchMode (batchMode);
 
-	ratio->append_text ("(Unchanged)");
-	orientation->append_text ("(Unchanged)");
-	guide->append_text ("(Unchanged)");
+    ratio->append_text (M("GENERAL_UNCHANGED"));
+    orientation->append_text (M("GENERAL_UNCHANGED"));
+    guide->append_text (M("GENERAL_UNCHANGED"));
     removeIfThere (this, ppibox);
 }
