@@ -38,7 +38,7 @@ class CropRatio {
         double value;
 };
 
-class Crop : public Gtk::VBox, public CropGUIListener, public FoldableToolPanel, public rtengine::SizeListener {
+class Crop : public ToolParamBlock, public CropGUIListener, public FoldableToolPanel, public rtengine::SizeListener {
 
   protected:
     Gtk::CheckButton* enabled;
@@ -88,7 +88,6 @@ class Crop : public Gtk::VBox, public CropGUIListener, public FoldableToolPanel,
     void notifyListener ();
     void sizeChanged    (int w, int h, int ow, int oh);
     void trim           (rtengine::procparams::ProcParams* pp, int ow, int oh);
-    
     void readOptions    ();
     void writeOptions   ();
 
@@ -104,6 +103,7 @@ class Crop : public Gtk::VBox, public CropGUIListener, public FoldableToolPanel,
     void cropInit           (int &x, int &y, int &w, int &h);
     void cropResized        (int &x, int &y, int& x2, int& y2);
     void cropManipReady     ();
+    bool inImageArea        (int x, int y);
     double getRatio         ();
 
     void setCropPanelListener (CropPanelListener* cl) { clistener = cl; }
@@ -111,7 +111,7 @@ class Crop : public Gtk::VBox, public CropGUIListener, public FoldableToolPanel,
     void resizeScaleChanged (double rsc);
     void hFlipCrop          ();
     void vFlipCrop          ();
-    void rotateCrop         (int deg);
+    void rotateCrop         (int deg, bool hflip, bool vflip);
 };
 
 #endif
