@@ -21,14 +21,16 @@
 
 #include <cstring>
 #include "guiutils.h"
+#include "cropwindow.h"
+#include "../rtengine/dcrop.h"
 #include "../rtengine/refreshmap.h"
 
 using namespace rtengine;
 
-CropHandler::CropHandler () 
-    : zoom(10), cx(0), cy(0), cw(0), ch(0),
+CropHandler::CropHandler ()
+    : zoom(10), ww(0), wh(0), cx(0), cy(0), cw(0), ch(0),
     cropX(0), cropY(0), cropW(0), cropH(0), enabled(false),
-    cropimg(NULL), cropimgtrue(NULL), ipc(NULL), crop(NULL), listener(NULL) {
+    cropimg(NULL), cropimgtrue(NULL), ipc(NULL), crop(NULL), listener(NULL), isLowUpdatePriority(false) {
 
     chi = new CropHandlerIdleHelper;
     chi->destroyed = false;
@@ -43,7 +45,8 @@ CropHandler::~CropHandler () {
 
     setEnabled (false);
     if (crop) {
-        crop->destroy ();
+        //crop->destroy ();
+        delete crop; // will do the same than destroy, plus delete the object
         crop = NULL;
     }
     cimg.lock ();
@@ -53,7 +56,11 @@ CropHandler::~CropHandler () {
         delete chi;
     cimg.unlock ();
 }
-        
+
+void CropHandler::setEditSubscriber (EditSubscriber* newSubscriber) {
+    (static_cast<rtengine::Crop *>(crop))->setEditSubscriber(newSubscriber);
+}
+
 void CropHandler::newImage (StagedImageProcessor* ipc_) {
 
     ipc = ipc_;
@@ -61,9 +68,13 @@ void CropHandler::newImage (StagedImageProcessor* ipc_) {
     cy = 0;
     
     if (!ipc)
-	    return;
-	
-	crop = ipc->createCrop ();
+        return;
+
+    EditDataProvider *editDataProvider = NULL;
+    CropWindow *cropWin = listener ? static_cast<CropWindow*>(listener) : NULL;
+    if (cropWin)
+        editDataProvider = cropWin->getImageArea();
+    crop = ipc->createCrop (editDataProvider);
     ipc->setSizeListener (this);
     crop->setListener (enabled ? this : NULL);
     initial = true;
