@@ -89,6 +89,7 @@ protected:
 	void updateGUI (CurveEditor* ce);
 	void curveResetPressed ();
 	void curveChanged ();
+	float blendPipetteValues(float chan1, float chan2, float chan3);
 	void setUnChanged (bool uc, CurveEditor* ce);
 };
 
@@ -113,9 +114,18 @@ public:
 	virtual ~CurveEditorSubGroup();
 	int getValUnchanged() { return valUnchanged; }
 	int getValLinear() { return valLinear; }
+	void updateEditButton(CurveEditor* curve, Gtk::ToggleButton *button, sigc::connection &connection);
 	virtual void updateBackgroundHistogram (CurveEditor* ce) {}
 	virtual void switchGUI() = 0;
 	virtual void refresh(CurveEditor *curveToRefresh) = 0;
+	virtual void editModeSwitchedOff() = 0;
+
+	virtual void pipetteMouseOver(EditDataProvider *provider, int modifierKey) =0;
+	virtual void pipetteButton1Pressed(EditDataProvider *provider, int modifierKey) =0;
+	virtual void pipetteButton1Released(EditDataProvider *provider) =0;
+	virtual void pipetteDrag(EditDataProvider *provider, int modifierKey) =0;
+
+	virtual bool curveReset (CurveEditor *ce) = 0; // Reset a curve editor, return TRUE if successful (curve changed)
 
 protected:
 
@@ -129,7 +139,6 @@ protected:
 	Glib::ustring outputFile ();
 	Glib::ustring inputFile ();
 
-	virtual bool curveReset (int cType, double iValue) = 0; // Reset a curve editor, return TRUE if successful (curve changed)
 	virtual void storeCurveValues (CurveEditor* ce, const std::vector<double>& p) = 0;
 	virtual void storeDisplayedCurve () = 0;
 	virtual void restoreDisplayedHistogram() {};
