@@ -19,7 +19,7 @@
 #ifndef _DARKFRAME_H_
 #define _DARKFRAME_H_
 
-#include <auto_ptr.h>
+#include <memory>
 #include <gtkmm.h>
 #include "toolpanel.h"
 #include "../rtengine/rawimage.h"
@@ -28,10 +28,11 @@
 class DFProvider {
   public:
     virtual rtengine::RawImage* getDF() = 0;
+    virtual Glib::ustring GetCurrentImageFilePath() {};
     // add other info here
 };
 
-class DarkFrame : public Gtk::VBox, public FoldableToolPanel {
+class DarkFrame : public ToolParamBlock, public FoldableToolPanel {
 
 protected:
 
@@ -46,6 +47,8 @@ protected:
 	bool lastDFauto;
     DFProvider *dfp;
 	sigc::connection dfautoconn, dfFile;
+    bool b_filter_asCurrent;
+    bool israw;
 
 public:
 
