@@ -23,9 +23,8 @@
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-Defringe::Defringe () : Gtk::VBox(), FoldableToolPanel(this)  {
+Defringe::Defringe () : FoldableToolPanel(this)  {
 
-  set_border_width(4);
   std::vector<GradientMilestone> bottomMilestones;
   float R, G, B;
   for (int i=0; i<7; i++) {
@@ -38,7 +37,7 @@ Defringe::Defringe () : Gtk::VBox(), FoldableToolPanel(this)  {
   enabled->set_active (false);
   enabled->set_tooltip_markup (M("TP_SHARPENING_TOOLTIP"));
   
-  enabled->show ();
+ // enabled->show ();
   pack_start (*enabled);
 
   Gtk::HSeparator *hsep1 = Gtk::manage (new  Gtk::HSeparator());
@@ -60,23 +59,29 @@ Defringe::Defringe () : Gtk::VBox(), FoldableToolPanel(this)  {
   threshold    = Gtk::manage (new Adjuster (M("TP_DEFRINGE_THRESHOLD"), 0, 100, 1, 13));
   radius->setAdjusterListener (this);
   threshold->setAdjusterListener (this); 
-  radius->show();
-  threshold->show();
+ // radius->show();
+ // threshold->show();
 
   pack_start (*radius);
   pack_start (*threshold);
   curveEditorPF->curveListComplete();
 
   pack_start (*curveEditorPF, Gtk::PACK_SHRINK, 4);
+  
+  show ();
 }
 
 Defringe::~Defringe () {
     delete curveEditorPF;
 }
 
-void Defringe::colorForValue (double valX, double valY, int callerId, ColorCaller *caller) {
+void Defringe::colorForValue (double valX, double valY, enum ColorCaller::ElemType elemType, int callerId, ColorCaller *caller) {
 
     float R, G, B;
+
+    if (elemType==ColorCaller::CCET_VERTICAL_BAR)
+        valY = 0.5;
+
     if (callerId == 1) { // ch
         Color::hsv2rgb01(float(valX), float(valY), 0.5f, R, G, B);
     }
@@ -112,7 +117,7 @@ void Defringe::read (const ProcParams* pp, const ParamsEdited* pedited) {
 
 void Defringe::autoOpenCurve () {
     // WARNING: The following line won't work, since linear is a flat curve at 0.
-    chshape->openIfNonlinear();
+   // chshape->openIfNonlinear();
 }
 
 void Defringe::write (ProcParams* pp, ParamsEdited* pedited) {
