@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -27,33 +27,31 @@
 #include "curveeditorgroup.h"
 #include "colorprovider.h"
 
-class Defringe : public Gtk::VBox, public AdjusterListener, public FoldableToolPanel, public CurveListener, public ColorProvider{
+class Defringe : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel, public CurveListener, public ColorProvider
+{
 
-  protected:
+protected:
     CurveEditorGroup* curveEditorPF;
     FlatCurveEditor*   chshape;
 
     Adjuster* radius;
     Adjuster* threshold;
-    Gtk::CheckButton* enabled;
-    bool lastEnabled;
-    sigc::connection enaConn;
-	bool edges;
+    bool edges;
 
-  public:
+public:
 
     Defringe ();
     ~Defringe ();
-    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited=NULL); 
-    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited=NULL);
-    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
+    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited = NULL);
+    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited = NULL);
+    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited = NULL);
     void setBatchMode   (bool batchMode);
     void autoOpenCurve  ();
     void curveChanged   ();
 
     void adjusterChanged (Adjuster* a, double newval);
     void enabledChanged  ();
-    virtual void colorForValue (double valX, double valY, int callerId, ColorCaller* caller);
+    virtual void colorForValue (double valX, double valY, enum ColorCaller::ElemType elemType, int callerId, ColorCaller* caller);
 
 };
 
