@@ -32,7 +32,7 @@
 using namespace rtengine::procparams;
 
 EditorPanel::EditorPanel (FilePanel* filePanel) 
-    : beforePreviewHandler(NULL), beforeIarea(NULL), parent(NULL), ipc(NULL), beforeIpc(NULL), isProcessing(false), catalogPane(NULL) {
+    : beforePreviewHandler(NULL), beforeIarea(NULL), beforeBox(NULL), afterBox(NULL), afterHeaderBox(NULL), parent(NULL), ipc(NULL), beforeIpc(NULL), isProcessing(false), catalogPane(NULL), iHistoryShow(NULL), iHistoryHide(NULL), iBeforeLockON(NULL),iBeforeLockOFF(NULL), iRightPanel_1_Show(NULL), iRightPanel_1_Hide(NULL), iTopPanel_1_Show(NULL), iTopPanel_1_Hide(NULL), openThm(NULL) {
 
     epih = new EditorPanelIdleHelper;
     epih->epanel = this;
@@ -132,6 +132,7 @@ EditorPanel::EditorPanel (FilePanel* filePanel)
     Gtk::VSeparator* vsepz4 = Gtk::manage (new Gtk::VSeparator ());
 
     iareapanel = new ImageAreaPanel ();
+    tpc->setEditProvider(iareapanel->imageArea);
 
     Gtk::HBox* toolBarPanel = Gtk::manage (new Gtk::HBox ());
     toolBarPanel->pack_start (*hidehp, Gtk::PACK_SHRINK, 1);
@@ -373,9 +374,20 @@ EditorPanel::~EditorPanel () {
     if(catalogPane)
         delete catalogPane;
 
-    if (!iTopPanel_1_Show) delete iTopPanel_1_Show;
-    if (!iTopPanel_1_Hide) delete iTopPanel_1_Hide;
-
+    if (iTopPanel_1_Show) delete iTopPanel_1_Show;
+    if (iTopPanel_1_Hide) delete iTopPanel_1_Hide;
+    if (iHistoryShow)
+		delete iHistoryShow;
+    if (iHistoryHide)
+		delete iHistoryHide;
+    if(iBeforeLockON)
+        delete iBeforeLockON;
+    if(iBeforeLockOFF)
+        delete iBeforeLockOFF;
+    if(iRightPanel_1_Show)
+        delete iRightPanel_1_Show;
+    if(iRightPanel_1_Hide)
+        delete iRightPanel_1_Hide;
 }
 
 void EditorPanel::leftPaneButtonReleased(GdkEventButton *event) {
@@ -537,13 +549,13 @@ void EditorPanel::saveProfile () {
 }
 
 Glib::ustring EditorPanel::getShortName () {
-
-    return Glib::path_get_basename (openThm->getFileName ());
+   if (openThm) return Glib::path_get_basename (openThm->getFileName ());
+   else return "";
 }
 
 Glib::ustring EditorPanel::getFileName () {
-
-    return openThm->getFileName ();
+    if (openThm) return openThm->getFileName ();
+    else return "";
 }
 
 // TODO!!!
@@ -1202,7 +1214,7 @@ void EditorPanel::saveAsPressed () {
 				rtengine::ProcessingJob* job = rtengine::ProcessingJob::create (ipc->getInitialImage(), pparams);
 
 				ProgressConnector<rtengine::IImage16*> *ld = new ProgressConnector<rtengine::IImage16*>();
-				ld->startFunc(sigc::bind(sigc::ptr_fun(&rtengine::processImage), job, err, parent->getProgressListener(), options.tunnelMetaData ),
+				ld->startFunc(sigc::bind(sigc::ptr_fun(&rtengine::processImage), job, err, parent->getProgressListener(), options.tunnelMetaData, false ),
 							  sigc::bind(sigc::mem_fun( *this,&EditorPanel::idle_saveImage ),ld,fnameOut,sf ));
 				saveimgas->set_sensitive(false);
 				sendtogimp->set_sensitive(false);
@@ -1236,7 +1248,7 @@ void EditorPanel::sendToGimpPressed () {
     ipc->getParams (&pparams);
     rtengine::ProcessingJob* job = rtengine::ProcessingJob::create (ipc->getInitialImage(), pparams);
     ProgressConnector<rtengine::IImage16*> *ld = new ProgressConnector<rtengine::IImage16*>();
-    ld->startFunc(sigc::bind(sigc::ptr_fun(&rtengine::processImage), job, err, parent->getProgressListener(), options.tunnelMetaData ),
+    ld->startFunc(sigc::bind(sigc::ptr_fun(&rtengine::processImage), job, err, parent->getProgressListener(), options.tunnelMetaData, false ),
     		      sigc::bind(sigc::mem_fun( *this,&EditorPanel::idle_sendToGimp ),ld ));
     saveimgas->set_sensitive(false);
     sendtogimp->set_sensitive(false);
@@ -1496,11 +1508,11 @@ void EditorPanel::tbBeforeLock_toggled () {
 	tbBeforeLock->get_active()? tbBeforeLock->set_image (*iBeforeLockON) : tbBeforeLock->set_image (*iBeforeLockOFF);
 }
 
-void EditorPanel::histogramChanged (LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma, LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve, LUTu & histCLurve, LUTu & histLLCurve, LUTu & histLCAM, LUTu & histCCAM,
+void EditorPanel::histogramChanged (LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma, LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve, /*LUTu & histCLurve, LUTu & histLLCurve,*/ LUTu & histLCAM, LUTu & histCCAM,
     LUTu & histRedRaw, LUTu & histGreenRaw, LUTu & histBlueRaw , LUTu & histChroma) {
 
     if (histogramPanel) histogramPanel->histogramChanged (histRed, histGreen, histBlue, histLuma, histRedRaw, histGreenRaw, histBlueRaw, histChroma);
-    tpc->updateCurveBackgroundHistogram (histToneCurve, histLCurve, histCCurve, histCLurve,  histLLCurve, histLCAM, histCCAM, histRed, histGreen, histBlue, histLuma);
+    tpc->updateCurveBackgroundHistogram (histToneCurve, histLCurve, histCCurve,/*histCLurve,  histLLCurve,*/ histLCAM, histCCAM, histRed, histGreen, histBlue, histLuma);
 }
 
 bool EditorPanel::CheckSidePanelsVisibility() {
