@@ -23,12 +23,12 @@
 #include "adjuster.h"
 #include "toolpanel.h"
 
-class EdgePreservingDecompositionUI : public Gtk::VBox, public AdjusterListener, public FoldableToolPanel {
+class EdgePreservingDecompositionUI : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel {
 protected:
-	Adjuster *Strength;
-	Adjuster *EdgeStopping;
-	Adjuster *Scale;
-	Adjuster *ReweightingIterates;
+	Adjuster *strength;
+	Adjuster *edgeStopping;
+	Adjuster *scale;
+	Adjuster *reweightingIterates;
 
 	Gtk::CheckButton* enabled;
 	bool lastEnabled;
