@@ -49,27 +49,49 @@ ExportPanel::ExportPanel () : listener (NULL) {
 	bypass_dirpyrDenoise    = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_DIRPYRDENOISE")));
 	bypass_sh_hq            = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_SH_HQ")));
 	bypass_dirpyrequalizer  = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_DIRPYREQUALIZER")));
-	//bypass_raw_all_enhance  = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_ALL_ENHANCE")));
 	bypass_raw_ccSteps      = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_CCSTEPS")));
-	bypass_raw_linenoise    = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_LINENOISE")));
-	bypass_raw_greenthresh  = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_GREENTHRESH")));
 	bypass_raw_ca           = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_CA")));
 	bypass_raw_df           = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_DF")));
 	bypass_raw_ff           = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_FF")));
-	bypass_raw_dcb_iterations = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_DCB_ITERATIONS")));
-	bypass_raw_dcb_enhance    = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_DCB_ENHANCE")));
-	bypass_raw_lmmse_iterations = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_LMMSE_ITERATIONS")));
 
-	Gtk::HBox* hb_raw_dmethod = Gtk::manage (new Gtk::HBox ());
-	hb_raw_dmethod->pack_start (*Gtk::manage (new Gtk::Label ( M("EXPORT_RAW_DMETHOD") +": ")),Gtk::PACK_SHRINK, 4);
-	raw_dmethod = Gtk::manage (new MyComboBoxText ());
-	for( size_t i=0; i< procparams::RAWParams::numMethods;i++)
-		raw_dmethod->append_text(procparams::RAWParams::methodstring[i]);
+	// ---------------------- Bayer sensor frame -----------------------
 
-	raw_dmethod->set_active(0);
-	hb_raw_dmethod->pack_end (*raw_dmethod, Gtk::PACK_EXPAND_WIDGET, 4);
+	Gtk::Frame *bayerFrame = Gtk::manage( new Gtk::Frame(M("TP_RAW_SENSOR_BAYER")));
+	Gtk::VBox* bayerFrameVBox = Gtk::manage (new Gtk::VBox ());
 
-	// start packing
+	Gtk::HBox* hb_raw_bayer_method = Gtk::manage (new Gtk::HBox ());
+	hb_raw_bayer_method->pack_start (*Gtk::manage (new Gtk::Label ( M("EXPORT_RAW_DMETHOD") +": ")),Gtk::PACK_SHRINK, 4);
+	raw_bayer_method = Gtk::manage (new MyComboBoxText ());
+	for( size_t i=0; i< procparams::RAWParams::BayerSensor::numMethods;i++)
+		raw_bayer_method->append_text(procparams::RAWParams::BayerSensor::methodstring[i]);
+
+	raw_bayer_method->set_active(0);
+	hb_raw_bayer_method->pack_end (*raw_bayer_method, Gtk::PACK_EXPAND_WIDGET, 4);
+
+	//bypass_raw_all_enhance  = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_ALL_ENHANCE")));
+	bypass_raw_bayer_linenoise    = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_LINENOISE")));
+	bypass_raw_bayer_greenthresh  = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_GREENTHRESH")));
+	bypass_raw_bayer_dcb_iterations = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_DCB_ITERATIONS")));
+	bypass_raw_bayer_dcb_enhance    = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_DCB_ENHANCE")));
+	bypass_raw_bayer_lmmse_iterations = Gtk::manage ( new Gtk::CheckButton (M("EXPORT_BYPASS_RAW_LMMSE_ITERATIONS")));
+
+	// ---------------------- Bayer sensor frame -----------------------
+
+	Gtk::Frame *xtransFrame = Gtk::manage( new Gtk::Frame(M("TP_RAW_SENSOR_XTRANS")));
+	Gtk::VBox* xtransFrameVBox = Gtk::manage (new Gtk::VBox ());
+
+	Gtk::HBox* hb_raw_xtrans_method = Gtk::manage (new Gtk::HBox ());
+	hb_raw_xtrans_method->pack_start (*Gtk::manage (new Gtk::Label ( M("EXPORT_RAW_DMETHOD") +": ")),Gtk::PACK_SHRINK, 4);
+	raw_xtrans_method = Gtk::manage (new MyComboBoxText ());
+	for( size_t i=0; i< procparams::RAWParams::XTransSensor::numMethods;i++)
+		raw_xtrans_method->append_text(procparams::RAWParams::XTransSensor::methodstring[i]);
+
+	raw_xtrans_method->set_active(0);
+	hb_raw_xtrans_method->pack_end (*raw_xtrans_method, Gtk::PACK_EXPAND_WIDGET, 4);
+
+	// ----------------------------------------------------------------
+
+	// start global packing
 	pack_start(*bypass_ALL          , Gtk::PACK_SHRINK, 4);
 	pack_start(*Gtk::manage(new Gtk::HSeparator ()), Gtk::PACK_SHRINK, 4);
 	pack_start(*bypass_sharpening   , Gtk::PACK_SHRINK, 4);
@@ -82,16 +104,21 @@ ExportPanel::ExportPanel () : listener (NULL) {
 	pack_start(*bypass_sh_hq        , Gtk::PACK_SHRINK, 4);
 	pack_start(*bypass_dirpyrequalizer , Gtk::PACK_SHRINK, 4);
 
-	pack_start(*hb_raw_dmethod         , Gtk::PACK_SHRINK, 4);
-	//pack_start(*bypass_raw_all_enhance , Gtk::PACK_SHRINK, 4);
+	bayerFrameVBox->pack_start(*hb_raw_bayer_method, Gtk::PACK_SHRINK, 4);
+	//bayerFrameVBox->pack_start(*bypass_raw_all_enhance , Gtk::PACK_SHRINK, 4);
+	bayerFrameVBox->pack_start(*bypass_raw_bayer_dcb_iterations, Gtk::PACK_SHRINK, 4);
+	bayerFrameVBox->pack_start(*bypass_raw_bayer_dcb_enhance   , Gtk::PACK_SHRINK, 4);
+	bayerFrameVBox->pack_start(*bypass_raw_bayer_lmmse_iterations, Gtk::PACK_SHRINK, 4);
+	bayerFrameVBox->pack_start(*bypass_raw_bayer_linenoise   , Gtk::PACK_SHRINK, 4);
+	bayerFrameVBox->pack_start(*bypass_raw_bayer_greenthresh , Gtk::PACK_SHRINK, 4);
+	bayerFrame->add(*bayerFrameVBox);
+
+	xtransFrameVBox->pack_start(*hb_raw_xtrans_method, Gtk::PACK_SHRINK, 4);
+	xtransFrame->add(*xtransFrameVBox);
+
 	pack_start(*bypass_raw_ccSteps     , Gtk::PACK_SHRINK, 4);
-	pack_start(*bypass_raw_dcb_iterations, Gtk::PACK_SHRINK, 4);
-	pack_start(*bypass_raw_dcb_enhance   , Gtk::PACK_SHRINK, 4);
 	pack_start(*bypass_raw_ca         , Gtk::PACK_SHRINK, 4);
-	pack_start(*bypass_raw_lmmse_iterations, Gtk::PACK_SHRINK, 4);
 
-	pack_start(*bypass_raw_linenoise   , Gtk::PACK_SHRINK, 4);
-	pack_start(*bypass_raw_greenthresh , Gtk::PACK_SHRINK, 4);
 	pack_start(*bypass_raw_df         , Gtk::PACK_SHRINK, 4);
 	pack_start(*bypass_raw_ff         , Gtk::PACK_SHRINK, 4);
 
@@ -154,25 +181,25 @@ ExportPanel::ExportPanel () : listener (NULL) {
 	//btnExportSaveSettings->signal_clicked().connect( sigc::mem_fun(*this, &ExportPanel::SaveSettings) );
 	bypass_ALLconn = bypass_ALL->signal_toggled().connect (sigc::mem_fun(*this, &ExportPanel::bypassALL_Toggled));
 
-	bypass_sharpeningConn         = bypass_sharpening->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_sharpenEdgeConn        = bypass_sharpenEdge->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_sharpenMicroConn       = bypass_sharpenMicro->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_sharpeningConn           = bypass_sharpening->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_sharpenEdgeConn          = bypass_sharpenEdge->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_sharpenMicroConn         = bypass_sharpenMicro->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
 	//bypass_lumaDenoiseConn        = bypass_lumaDenoise->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
 	//bypass_colorDenoiseConn       = bypass_colorDenoise->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_defringeConn           = bypass_defringe->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_dirpyrDenoiseConn      = bypass_dirpyrDenoise->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_sh_hqConn              = bypass_sh_hq->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_dirpyrequalizerConn    = bypass_dirpyrequalizer->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	//bypass_raw_all_enhanceConn    = bypass_raw_all_enhance->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_raw_ccStepsConn        = bypass_raw_ccSteps->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_raw_dcb_iterationsConn = bypass_raw_dcb_iterations->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_raw_dcb_enhanceConn    = bypass_raw_dcb_enhance->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_raw_lmmse_iterationsConn = bypass_raw_lmmse_iterations->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_raw_caConn             = bypass_raw_ca->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_raw_linenoiseConn      = bypass_raw_linenoise->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_raw_greenthreshConn    = bypass_raw_greenthresh->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_raw_dfConn             = bypass_raw_df->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
-	bypass_raw_ffConn             = bypass_raw_ff->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_defringeConn             = bypass_defringe->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_dirpyrDenoiseConn        = bypass_dirpyrDenoise->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_sh_hqConn                = bypass_sh_hq->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_dirpyrequalizerConn      = bypass_dirpyrequalizer->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	//bypass_raw_all_enhanceConn    = bypass_raw_bayer_all_enhance->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_raw_bayer_dcb_iterationsConn   = bypass_raw_bayer_dcb_iterations->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_raw_bayer_dcb_enhanceConn      = bypass_raw_bayer_dcb_enhance->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_raw_bayer_lmmse_iterationsConn = bypass_raw_bayer_lmmse_iterations->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_raw_bayer_linenoiseConn        = bypass_raw_bayer_linenoise->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_raw_bayer_greenthreshConn      = bypass_raw_bayer_greenthresh->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_raw_ccStepsConn          = bypass_raw_ccSteps->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_raw_caConn               = bypass_raw_ca->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_raw_dfConn               = bypass_raw_df->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
+	bypass_raw_ffConn               = bypass_raw_ff->signal_toggled().connect (sigc::bind (sigc::mem_fun(*bypass_ALL, &Gtk::CheckButton::set_inconsistent), true));
 
 	LoadDefaultSettings();
 }
@@ -194,30 +221,35 @@ void ExportPanel::FastExportPressed (){
 
 void ExportPanel::SaveSettingsAsDefault(){
 	// Save fast export settings to options
-	options.fastexport_bypass_sharpening         = bypass_sharpening->get_active        ();
-	options.fastexport_bypass_sharpenEdge        = bypass_sharpenEdge->get_active       ();
-	options.fastexport_bypass_sharpenMicro       = bypass_sharpenMicro->get_active      ();
+	options.fastexport_bypass_sharpening           = bypass_sharpening->get_active        ();
+	options.fastexport_bypass_sharpenEdge          = bypass_sharpenEdge->get_active       ();
+	options.fastexport_bypass_sharpenMicro         = bypass_sharpenMicro->get_active      ();
 	//options.fastexport_bypass_lumaDenoise        = bypass_lumaDenoise->get_active       ();
 	//options.fastexport_bypass_colorDenoise       = bypass_colorDenoise->get_active      ();
-	options.fastexport_bypass_defringe           = bypass_defringe->get_active          ();
-	options.fastexport_bypass_dirpyrDenoise      = bypass_dirpyrDenoise->get_active     ();
-	options.fastexport_bypass_sh_hq              = bypass_sh_hq->get_active             ();
-	options.fastexport_bypass_dirpyrequalizer    = bypass_dirpyrequalizer->get_active   ();
-	//options.fastexport_bypass_raw_all_enhance    = bypass_raw_all_enhance->get_active   ();
-	options.fastexport_bypass_raw_ccSteps        = bypass_raw_ccSteps->get_active       ();
-	options.fastexport_bypass_raw_dcb_iterations = bypass_raw_dcb_iterations->get_active();
-	options.fastexport_bypass_raw_dcb_enhance    = bypass_raw_dcb_enhance->get_active   ();
-	options.fastexport_bypass_raw_lmmse_iterations = bypass_raw_lmmse_iterations->get_active();
-	options.fastexport_bypass_raw_ca             = bypass_raw_ca->get_active            ();
-	options.fastexport_bypass_raw_linenoise      = bypass_raw_linenoise->get_active     ();
-	options.fastexport_bypass_raw_greenthresh    = bypass_raw_greenthresh->get_active   ();
-	options.fastexport_bypass_raw_df             = bypass_raw_df->get_active            ();
-	options.fastexport_bypass_raw_ff             = bypass_raw_ff->get_active            ();
+	options.fastexport_bypass_defringe             = bypass_defringe->get_active          ();
+	options.fastexport_bypass_dirpyrDenoise        = bypass_dirpyrDenoise->get_active     ();
+	options.fastexport_bypass_sh_hq                = bypass_sh_hq->get_active             ();
+	options.fastexport_bypass_dirpyrequalizer      = bypass_dirpyrequalizer->get_active   ();
+	//options.fastexport_bypass_raw_bayer_all_enhance    = bypass_raw_all_enhance->get_active           ();
+	options.fastexport_bypass_raw_bayer_dcb_iterations   = bypass_raw_bayer_dcb_iterations->get_active  ();
+	options.fastexport_bypass_raw_bayer_dcb_enhance      = bypass_raw_bayer_dcb_enhance->get_active     ();
+	options.fastexport_bypass_raw_bayer_lmmse_iterations = bypass_raw_bayer_lmmse_iterations->get_active();
+	options.fastexport_bypass_raw_bayer_linenoise        = bypass_raw_bayer_linenoise->get_active       ();
+	options.fastexport_bypass_raw_bayer_greenthresh      = bypass_raw_bayer_greenthresh->get_active     ();
+	options.fastexport_bypass_raw_ccSteps          = bypass_raw_ccSteps->get_active       ();
+	options.fastexport_bypass_raw_ca               = bypass_raw_ca->get_active            ();
+	options.fastexport_bypass_raw_df               = bypass_raw_df->get_active            ();
+	options.fastexport_bypass_raw_ff               = bypass_raw_ff->get_active            ();
 
-	//saving demosaic_method
-	int currentRow = raw_dmethod->get_active_row_number();
-	if( currentRow>=0 && currentRow < procparams::RAWParams::numMethods)
-		options.fastexport_raw_dmethod = procparams::RAWParams::methodstring[currentRow];
+	//saving Bayer demosaic_method
+	int currentRow = raw_bayer_method->get_active_row_number();
+	if( currentRow>=0 && currentRow < procparams::RAWParams::BayerSensor::numMethods)
+		options.fastexport_raw_bayer_method = procparams::RAWParams::BayerSensor::methodstring[currentRow];
+
+	//saving X-Trans demosaic_method
+	currentRow = raw_xtrans_method->get_active_row_number();
+	if( currentRow>=0 && currentRow < procparams::RAWParams::XTransSensor::numMethods)
+		options.fastexport_raw_xtrans_method = procparams::RAWParams::XTransSensor::methodstring[currentRow];
 
 //	options.fastexport_icm_input        = icm_input       ;
 //	options.fastexport_icm_working      = icm_working     ;
@@ -251,30 +283,38 @@ void ExportPanel::LoadDefaultSettings(){
 	bypass_sharpening->set_active        (options.fastexport_bypass_sharpening         );
 	bypass_sharpenEdge->set_active       (options.fastexport_bypass_sharpenEdge        );
 	bypass_sharpenMicro->set_active      (options.fastexport_bypass_sharpenMicro       );
-	//bypass_lumaDenoise->set_active       (options.fastexport_bypass_lumaDenoise        );
-	//bypass_colorDenoise->set_active      (options.fastexport_bypass_colorDenoise       );
+	//bypass_lumaDenoise->set_active     (options.fastexport_bypass_lumaDenoise        );
+	//bypass_colorDenoise->set_active    (options.fastexport_bypass_colorDenoise       );
 	bypass_defringe->set_active          (options.fastexport_bypass_defringe           );
 	bypass_dirpyrDenoise->set_active     (options.fastexport_bypass_dirpyrDenoise      );
 	bypass_sh_hq->set_active             (options.fastexport_bypass_sh_hq              );
 	bypass_dirpyrequalizer->set_active   (options.fastexport_bypass_dirpyrequalizer    );
-	//bypass_raw_all_enhance->set_active   (options.fastexport_bypass_raw_all_enhance    );
+	//bypass_raw_bayer_all_enhance->set_active   (options.fastexport_bypass_raw_bayer_all_enhance     );
+	bypass_raw_bayer_dcb_iterations->set_active  (options.fastexport_bypass_raw_bayer_dcb_iterations  );
+	bypass_raw_bayer_dcb_enhance->set_active     (options.fastexport_bypass_raw_bayer_dcb_enhance     );
+	bypass_raw_bayer_lmmse_iterations->set_active(options.fastexport_bypass_raw_bayer_lmmse_iterations);
+	bypass_raw_bayer_linenoise->set_active       (options.fastexport_bypass_raw_bayer_linenoise       );
+	bypass_raw_bayer_greenthresh->set_active     (options.fastexport_bypass_raw_bayer_greenthresh     );
 	bypass_raw_ccSteps->set_active       (options.fastexport_bypass_raw_ccSteps        );
-	bypass_raw_dcb_iterations->set_active(options.fastexport_bypass_raw_dcb_iterations );
-	bypass_raw_dcb_enhance->set_active   (options.fastexport_bypass_raw_dcb_enhance    );
-	bypass_raw_lmmse_iterations->set_active(options.fastexport_bypass_raw_lmmse_iterations );
 	bypass_raw_ca->set_active            (options.fastexport_bypass_raw_ca             );
-	bypass_raw_linenoise->set_active     (options.fastexport_bypass_raw_linenoise      );
-	bypass_raw_greenthresh->set_active   (options.fastexport_bypass_raw_greenthresh    );
 	bypass_raw_df->set_active            (options.fastexport_bypass_raw_df             );
 	bypass_raw_ff->set_active            (options.fastexport_bypass_raw_ff             );
 
-	//demosaic method
-	raw_dmethod->set_active(procparams::RAWParams::numMethods);
-    for( size_t i=0; i< procparams::RAWParams::numMethods;i++)
-	   if( options.fastexport_raw_dmethod == procparams::RAWParams::methodstring[i]){
-		   raw_dmethod->set_active(i);
-		   break;
-	   }
+	// Bayer demosaic method
+	raw_bayer_method->set_active(procparams::RAWParams::BayerSensor::numMethods);
+	for( size_t i=0; i< procparams::RAWParams::BayerSensor::numMethods;i++)
+		if( options.fastexport_raw_bayer_method == procparams::RAWParams::BayerSensor::methodstring[i]) {
+			raw_bayer_method->set_active(i);
+			break;
+		}
+
+	// X-Trans demosaic method
+	raw_xtrans_method->set_active(procparams::RAWParams::XTransSensor::numMethods);
+	for( size_t i=0; i< procparams::RAWParams::XTransSensor::numMethods;i++)
+		if( options.fastexport_raw_xtrans_method == procparams::RAWParams::XTransSensor::methodstring[i]) {
+			raw_xtrans_method->set_active(i);
+			break;
+		}
 
 //    icm_input        = options.fastexport_icm_input       ;
 //    icm_working      = options.fastexport_icm_working     ;
@@ -327,14 +367,14 @@ void ExportPanel::bypassALL_Toggled(){
 	bypass_dirpyrDenoiseConn.block      (true);
 	bypass_sh_hqConn.block              (true);
 	bypass_dirpyrequalizerConn.block    (true);
-	//bypass_raw_all_enhanceConn.block    (true);
+	//bypass_raw_bayer_all_enhanceConn.block    (true);
+	bypass_raw_bayer_dcb_iterationsConn.block   (true);
+	bypass_raw_bayer_dcb_enhanceConn.block      (true);
+	bypass_raw_bayer_lmmse_iterationsConn.block (true);
+	bypass_raw_bayer_linenoiseConn.block        (true);
+	bypass_raw_bayer_greenthreshConn.block      (true);
 	bypass_raw_ccStepsConn.block        (true);
-	bypass_raw_dcb_iterationsConn.block (true);
-	bypass_raw_dcb_enhanceConn.block    (true);
-	bypass_raw_lmmse_iterationsConn.block (true);
 	bypass_raw_caConn.block             (true);
-	bypass_raw_linenoiseConn.block      (true);
-	bypass_raw_greenthreshConn.block    (true);
 	bypass_raw_dfConn.block             (true);
 	bypass_raw_ffConn.block             (true);
 
@@ -349,36 +389,36 @@ void ExportPanel::bypassALL_Toggled(){
 	bypass_dirpyrDenoise->set_active(bypass_ALL->get_active());
 	bypass_sh_hq->set_active(bypass_ALL->get_active());
 	bypass_dirpyrequalizer->set_active(bypass_ALL->get_active());
-	//bypass_raw_all_enhance->set_active(bypass_ALL->get_active());
+	//bypass_raw_bayer_all_enhance->set_active(bypass_ALL->get_active());
+	bypass_raw_bayer_dcb_iterations->set_active(bypass_ALL->get_active());
+	bypass_raw_bayer_dcb_enhance->set_active(bypass_ALL->get_active());
+	bypass_raw_bayer_lmmse_iterations->set_active(bypass_ALL->get_active());
+	bypass_raw_bayer_linenoise->set_active(bypass_ALL->get_active());
+	bypass_raw_bayer_greenthresh->set_active(bypass_ALL->get_active());
 	bypass_raw_ccSteps->set_active(bypass_ALL->get_active());
-	bypass_raw_dcb_iterations->set_active(bypass_ALL->get_active());
-	bypass_raw_dcb_enhance->set_active(bypass_ALL->get_active());
-	bypass_raw_lmmse_iterations->set_active(bypass_ALL->get_active());
 	bypass_raw_ca->set_active(bypass_ALL->get_active());
-	bypass_raw_linenoise->set_active(bypass_ALL->get_active());
-	bypass_raw_greenthresh->set_active(bypass_ALL->get_active());
 	bypass_raw_df->set_active(bypass_ALL->get_active());
 	bypass_raw_ff->set_active(bypass_ALL->get_active());
 
-	bypass_sharpeningConn.block         (false);
-	bypass_sharpenEdgeConn.block        (false);
-	bypass_sharpenMicroConn.block       (false);
+	bypass_sharpeningConn.block           (false);
+	bypass_sharpenEdgeConn.block          (false);
+	bypass_sharpenMicroConn.block         (false);
 	//bypass_lumaDenoiseConn.block        (false);
 	//bypass_colorDenoiseConn.block       (false);
-	bypass_defringeConn.block           (false);
-	bypass_dirpyrDenoiseConn.block      (false);
-	bypass_sh_hqConn.block              (false);
-	bypass_dirpyrequalizerConn.block    (false);
-	//bypass_raw_all_enhanceConn.block    (false);
-	bypass_raw_ccStepsConn.block        (false);
-	bypass_raw_dcb_iterationsConn.block (false);
-	bypass_raw_dcb_enhanceConn.block    (false);
-	bypass_raw_lmmse_iterationsConn.block (false);
-	bypass_raw_caConn.block             (false);
-	bypass_raw_linenoiseConn.block      (false);
-	bypass_raw_greenthreshConn.block    (false);
-	bypass_raw_dfConn.block             (false);
-	bypass_raw_ffConn.block             (false);
+	bypass_defringeConn.block             (false);
+	bypass_dirpyrDenoiseConn.block        (false);
+	bypass_sh_hqConn.block                (false);
+	bypass_dirpyrequalizerConn.block      (false);
+	//bypass_raw_bayer_all_enhanceConn.block    (false);
+	bypass_raw_bayer_dcb_iterationsConn.block   (false);
+	bypass_raw_bayer_dcb_enhanceConn.block      (false);
+	bypass_raw_bayer_lmmse_iterationsConn.block (false);
+	bypass_raw_bayer_linenoiseConn.block        (false);
+	bypass_raw_bayer_greenthreshConn.block      (false);
+	bypass_raw_ccStepsConn.block          (false);
+	bypass_raw_caConn.block               (false);
+	bypass_raw_dfConn.block               (false);
+	bypass_raw_ffConn.block               (false);
 }
 
 /*
@@ -391,16 +431,17 @@ fastexport_bypass_defringe
 fastexport_bypass_dirpyrDenoise
 fastexport_bypass_sh_hq
 fastexport_bypass_dirpyrequalizer
-fastexport_bypass_raw_all_enhance
+fastexport_raw_bayer_method
+fastexport_bypass_raw_bayer_all_enhance
+fastexport_bypass_raw_bayer_dcb_iterations
+fastexport_bypass_raw_bayer_dcb_enhance
+fastexport_bypass_raw_bayer_linenoise
+fastexport_bypass_raw_bayer_greenthresh
+fastexport_raw_xtrans_method
 fastexport_bypass_raw_ccSteps
-fastexport_bypass_raw_dcb_iterations
-fastexport_bypass_raw_dcb_enhance
 fastexport_bypass_raw_ca
-fastexport_bypass_raw_linenoise
-fastexport_bypass_raw_greenthresh
 fastexport_bypass_raw_df
 fastexport_bypass_raw_ff
-fastexport_raw_dmethod
 fastexport_icm_input
 fastexport_icm_working
 fastexport_icm_output
