@@ -42,8 +42,6 @@ FileBrowser::FileBrowser ()
 
     profileStore.addListener(this);
 
-    signal_style_changed().connect( sigc::mem_fun(*this, &FileBrowser::styleChanged) );
-    
     int p = 0;
     pmenu = new Gtk::Menu ();
     pmenu->attach (*Gtk::manage(open = new Gtk::MenuItem (M("FILEBROWSER_POPUPOPEN"))), 0, 1, p, p+1); p++;
@@ -108,7 +106,7 @@ FileBrowser::FileBrowser ()
     /***********************
      * external programs
      * *********************/
-#if PROTECT_VECTORS
+#if defined(WIN32) && defined(PROTECT_VECTORS)
     Gtk::manage(miOpenDefaultViewer=new Gtk::MenuItem (M("FILEBROWSER_OPENDEFAULTVIEWER")));
 #else
     miOpenDefaultViewer=NULL;
@@ -899,7 +897,7 @@ bool FileBrowser::keyPressed (GdkEventKey* event) {
     bool alt   = event->state & GDK_MOD1_MASK;
     bool altgr = event->state & GDK_MOD2_MASK;
 
-    if ((event->keyval==GDK_C || event->keyval==GDK_c) && ctrl) {
+    if ((event->keyval==GDK_C || event->keyval==GDK_c || event->keyval==GDK_Insert) && ctrl) {
         copyProfile ();
         return true;
     }
@@ -907,6 +905,10 @@ bool FileBrowser::keyPressed (GdkEventKey* event) {
         pasteProfile ();
         return true;
     }
+    else if (event->keyval==GDK_Insert && shift) {
+        pasteProfile ();
+        return true;
+    }
     else if ((event->keyval==GDK_V || event->keyval==GDK_v) && ctrl && shift) {
         partPasteProfile ();
         return true;
@@ -1208,11 +1210,24 @@ bool FileBrowser::checkFilter (ThumbBrowserEntryBase* entryb) { // true -> entry
     	FileName = FileName.uppercase();
     	//printf("FileBrowser::checkFilter FileName = '%s'; find() result= %i \n",FileName.c_str(), FileName.find(filter.queryFileName.uppercase()));
     	
+    	Glib::ustring decodedQueryFileName;
+    	bool MatchEqual;
+
+    	// Determine the match mode - check if the first 2 characters are equal to "!="
+    	if (filter.queryFileName.find("!=")==0){
+    		decodedQueryFileName = filter.queryFileName.substr (2,filter.queryFileName.length()-2);
+    		MatchEqual = false;
+    	}
+    	else {
+    		decodedQueryFileName = filter.queryFileName;
+    		MatchEqual = true;
+    	}
+
     	// Consider that queryFileName consist of comma separated values (FilterString)
     	// Evaluate if ANY of these FilterString are contained in the filename
     	// This will construct OR filter within the filter.queryFileName
     	int iFilenameMatch=0;
-    	std::vector<Glib::ustring> vFilterStrings = Glib::Regex::split_simple(",", filter.queryFileName.uppercase());
+    	std::vector<Glib::ustring> vFilterStrings = Glib::Regex::split_simple(",", decodedQueryFileName.uppercase());
     	for(int i=0; i<vFilterStrings.size(); i++) {
     		// ignore empty vFilterStrings. Otherwise filter will always return true if
     		// e.g. filter.queryFileName ends on "," and will stop being a filter
@@ -1220,8 +1235,15 @@ bool FileBrowser::checkFilter (ThumbBrowserEntryBase* entryb) { // true -> entry
     			if (FileName.find(vFilterStrings.at(i))!=-1) iFilenameMatch++;
     		}
     	}
-    	if (iFilenameMatch==0) //none of the vFilterStrings found in FileName
-        	 return false;
+
+    	if (MatchEqual==true){
+    		if (iFilenameMatch==0) //none of the vFilterStrings found in FileName
+    		  	return false;
+    	}
+    	else{
+    		if (iFilenameMatch>0) // match is found for at least one of vFilterStrings in FileName
+    			return false;
+    	}
 
     	/*experimental Regex support, this is unlikely to be useful to photographers*/
     	//bool matchfound=Glib::Regex::match_simple(filter.queryFileName.uppercase(),FileName);
@@ -1478,7 +1500,7 @@ void FileBrowser::openPrevImage () {
             if (selected[0]->thumbnail->getFileName()==fd[i]->filename) {// located 1-st image in current selection
                 if (i>0 && tbl) {
                     // find the first not-filtered-out (previous) image
-                    for (size_t k=i-1; k>=0; k--){
+                    for (ssize_t k=(ssize_t)i-1; k>=0; k--){
                         if (!fd[k]->filtered/*checkFilter (fd[k])*/){
                             // clear current selection
                             for (size_t j=0; j<selected.size(); j++)
