@@ -475,6 +475,7 @@ std::vector<Glib::ustring> FileCatalog::getFileList () {
     std::vector<Glib::ustring> names;
     Glib::RefPtr<Gio::File> dir = Gio::File::create_for_path (selectedDirectory);
     safe_build_file_list (dir, names, selectedDirectory, &(options.parsedExtensions));
+// Issue 2406    std::sort (names.begin(), names.end());
     return names;
 }
 
@@ -702,12 +703,10 @@ void FileCatalog::_openImage (std::vector<Thumbnail*> tmb) {
     if (enabled && listener!=NULL) {
     	bool continueToLoad=true;
         for (size_t i=0; i< tmb.size() && continueToLoad; i++) {
-            if (editedFiles.find (tmb[i]->getFileName())==editedFiles.end()){
-                // Open the image here, and stop if in Single Editor mode, or if an image couldn't
-                // be opened, would it be because the file doesn't exist or because of lack of RAM
-                if( !(listener->fileSelected (tmb[i])) && !options.tabbedUI )
-                    continueToLoad = false;
-            }
+			// Open the image here, and stop if in Single Editor mode, or if an image couldn't
+			// be opened, would it be because the file doesn't exist or because of lack of RAM
+			if( !(listener->fileSelected (tmb[i])) && !options.tabbedUI )
+				continueToLoad = false;
             tmb[i]->decreaseRef ();
         }
     }
@@ -897,34 +896,35 @@ void FileCatalog::developRequested (std::vector<FileBrowserEntry*> tbe, bool fas
 				if (options.fastexport_bypass_sharpening         ) params.sharpening.enabled          = false;
 				if (options.fastexport_bypass_sharpenEdge        ) params.sharpenEdge.enabled         = false;
 				if (options.fastexport_bypass_sharpenMicro       ) params.sharpenMicro.enabled        = false;
-				//if (options.fastexport_bypass_lumaDenoise        ) params.lumaDenoise.enabled         = false;
-				//if (options.fastexport_bypass_colorDenoise       ) params.colorDenoise.enabled        = false;
+				//if (options.fastexport_bypass_lumaDenoise      ) params.lumaDenoise.enabled         = false;
+				//if (options.fastexport_bypass_colorDenoise     ) params.colorDenoise.enabled        = false;
 				if (options.fastexport_bypass_defringe           ) params.defringe.enabled            = false;
 				if (options.fastexport_bypass_dirpyrDenoise      ) params.dirpyrDenoise.enabled       = false;
 				if (options.fastexport_bypass_sh_hq              ) params.sh.hq                       = false;
 				if (options.fastexport_bypass_dirpyrequalizer    ) params.dirpyrequalizer.enabled     = false;
-				//if (options.fastexport_bypass_raw_all_enhance    ) params.raw.all_enhance             = false;
-				if (options.fastexport_bypass_raw_ccSteps        ) params.raw.ccSteps                 = 0;
-				if (options.fastexport_bypass_raw_dcb_iterations ) params.raw.dcb_iterations          = 0;
-				if (options.fastexport_bypass_raw_dcb_enhance    ) params.raw.dcb_enhance             = false;
-				if (options.fastexport_bypass_raw_lmmse_iterations ) params.raw.lmmse_iterations          = 0;
-				if (options.fastexport_bypass_raw_ca             ) {params.raw.ca_autocorrect =false; params.raw.cared=0; params.raw.cablue=0;}
-				if (options.fastexport_bypass_raw_linenoise      ) params.raw.linenoise               = 0;
-				if (options.fastexport_bypass_raw_greenthresh    ) params.raw.greenthresh             = 0;
-				if (options.fastexport_bypass_raw_df             ) {params.raw.df_autoselect = false; params.raw.dark_frame="";}
-				if (options.fastexport_bypass_raw_ff             ) {params.raw.ff_AutoSelect = false; params.raw.ff_file="";}
-				params.raw.dmethod       = options.fastexport_raw_dmethod     ;
-				params.icm.input         = options.fastexport_icm_input       ;
-				params.icm.working       = options.fastexport_icm_working     ;
-				params.icm.output        = options.fastexport_icm_output      ;
-				params.icm.gamma         = options.fastexport_icm_gamma       ;
-				params.resize.enabled    = options.fastexport_resize_enabled  ;
-				params.resize.scale      = options.fastexport_resize_scale    ;
-				params.resize.appliesTo  = options.fastexport_resize_appliesTo;
-				params.resize.method     = options.fastexport_resize_method   ;
-				params.resize.dataspec   = options.fastexport_resize_dataspec ;
-				params.resize.width      = options.fastexport_resize_width    ;
-				params.resize.height     = options.fastexport_resize_height   ;
+				//if (options.fastexport_bypass_raw_bayer_all_enhance   ) params.raw.bayersensor.all_enhance       = false;
+				if (options.fastexport_bypass_raw_bayer_dcb_iterations  ) params.raw.bayersensor.dcb_iterations    = 0;
+				if (options.fastexport_bypass_raw_bayer_dcb_enhance     ) params.raw.bayersensor.dcb_enhance       = false;
+				if (options.fastexport_bypass_raw_bayer_lmmse_iterations) params.raw.bayersensor.lmmse_iterations  = 0;
+				if (options.fastexport_bypass_raw_bayer_linenoise       ) params.raw.bayersensor.linenoise         = 0;
+				if (options.fastexport_bypass_raw_bayer_greenthresh     ) params.raw.bayersensor.greenthresh       = 0;
+				if (options.fastexport_bypass_raw_ccSteps        ) {params.raw.bayersensor.ccSteps = params.raw.xtranssensor.ccSteps = 0;}
+				if (options.fastexport_bypass_raw_ca             ) {params.raw.ca_autocorrect = false; params.raw.cared=0; params.raw.cablue=0;}
+				if (options.fastexport_bypass_raw_df             ) {params.raw.df_autoselect  = false; params.raw.dark_frame="";}
+				if (options.fastexport_bypass_raw_ff             ) {params.raw.ff_AutoSelect  = false; params.raw.ff_file="";}
+				params.raw.bayersensor.method  = options.fastexport_raw_bayer_method ;
+				params.raw.xtranssensor.method = options.fastexport_raw_xtrans_method;
+				params.icm.input               = options.fastexport_icm_input        ;
+				params.icm.working             = options.fastexport_icm_working      ;
+				params.icm.output              = options.fastexport_icm_output       ;
+				params.icm.gamma               = options.fastexport_icm_gamma        ;
+				params.resize.enabled          = options.fastexport_resize_enabled   ;
+				params.resize.scale            = options.fastexport_resize_scale     ;
+				params.resize.appliesTo        = options.fastexport_resize_appliesTo ;
+				params.resize.method           = options.fastexport_resize_method    ;
+				params.resize.dataspec         = options.fastexport_resize_dataspec  ;
+				params.resize.width            = options.fastexport_resize_width     ;
+				params.resize.height           = options.fastexport_resize_height    ;
             }
 
             rtengine::ProcessingJob* pjob = rtengine::ProcessingJob::create (fbe->filename, th->getType()==FT_Raw, params);
@@ -991,8 +991,9 @@ void FileCatalog::renameRequested  (std::vector<FileBrowserEntry*> tbe) {
 				}
 				else {
 					success = true;
-            if (!safe_g_rename (ofname, nfname)) {
+					if (!safe_g_rename (ofname, nfname)) {
 						cacheMgr->renameEntry (ofname, tbe[i]->thumbnail->getMD5(), nfname);
+						safe_g_remove(ofname + paramFileExtension);
 						reparseDirectory ();
 					}
 				}
@@ -1649,22 +1650,26 @@ void FileCatalog::tbRightPanel_1_visible (bool visible){
 void FileCatalog::tbLeftPanel_1_toggled () {
     removeIfThere (filepanel->dirpaned, filepanel->placespaned, false);
     if (tbLeftPanel_1->get_active()){
-    	filepanel->dirpaned->pack1 (*filepanel->placespaned, false, true);
+        filepanel->dirpaned->pack1 (*filepanel->placespaned, false, true);
         tbLeftPanel_1->set_image (*iLeftPanel_1_Hide);
+        options.browserDirPanelOpened = true;
     }
     else {
-    	tbLeftPanel_1->set_image (*iLeftPanel_1_Show);
+        tbLeftPanel_1->set_image (*iLeftPanel_1_Show);
+        options.browserDirPanelOpened = false;
     }
 }
 
 void FileCatalog::tbRightPanel_1_toggled () {
     if (tbRightPanel_1->get_active()){
-    	filepanel->rightBox->show();
-    	tbRightPanel_1->set_image (*iRightPanel_1_Hide);
+        filepanel->rightBox->show();
+        tbRightPanel_1->set_image (*iRightPanel_1_Hide);
+        options.browserToolPanelOpened = true;
     }
     else{
-    	filepanel->rightBox->hide();
-    	tbRightPanel_1->set_image (*iRightPanel_1_Show);
+        filepanel->rightBox->hide();
+        tbRightPanel_1->set_image (*iRightPanel_1_Show);
+        options.browserToolPanelOpened = false;
     }
 }
 
@@ -1684,6 +1689,15 @@ void FileCatalog::toggleSidePanels(){
 	tbRightPanel_1->set_active (!bAllSidePanelsVisible);
 }
 
+void FileCatalog::toggleLeftPanel() {
+	tbLeftPanel_1->set_active (!tbLeftPanel_1->get_active());
+}
+
+void FileCatalog::toggleRightPanel() {
+	tbRightPanel_1->set_active (!tbRightPanel_1->get_active());
+}
+
+
 void FileCatalog::selectImage (Glib::ustring fname, bool clearFilters) {
 
 	Glib::ustring dirname = Glib::path_get_dirname(fname);
