@@ -25,10 +25,8 @@ using namespace rtengine::procparams;
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-HSVEqualizer::HSVEqualizer () : Gtk::VBox(), FoldableToolPanel(this) {
+HSVEqualizer::HSVEqualizer () : FoldableToolPanel(this) {
 	
-	set_border_width(4);
-
 	std::vector<GradientMilestone> bottomMilestones;
 	float R, G, B;
 	// -0.1 rad < Hue < 1.6 rad
@@ -42,16 +40,19 @@ HSVEqualizer::HSVEqualizer () : Gtk::VBox(), FoldableToolPanel(this) {
 	curveEditorG->setCurveListener (this);
 
 	hshape = static_cast<FlatCurveEditor*>(curveEditorG->addCurve(CT_Flat, M("TP_HSVEQUALIZER_HUE")));
+	hshape->setEditID(EUID_HSV_H, BT_SINGLEPLANE_FLOAT);
 	hshape->setBottomBarBgGradient(bottomMilestones);
 	//hshape->setLeftBarColorProvider(this);  Not working yet
 	hshape->setCurveColorProvider(this, 1);
 
 	sshape = static_cast<FlatCurveEditor*>(curveEditorG->addCurve(CT_Flat, M("TP_HSVEQUALIZER_SAT")));
+	sshape->setEditID(EUID_HSV_S, BT_SINGLEPLANE_FLOAT);
 	sshape->setBottomBarBgGradient(bottomMilestones);
 	//sshape->setLeftBarColorProvider(this);  Not working yet
 	sshape->setCurveColorProvider(this, 2);
 
 	vshape = static_cast<FlatCurveEditor*>(curveEditorG->addCurve(CT_Flat, M("TP_HSVEQUALIZER_VAL")));
+	vshape->setEditID(EUID_HSV_V, BT_SINGLEPLANE_FLOAT);
 	vshape->setBottomBarBgGradient(bottomMilestones);
 	//vshape->setLeftBarColorProvider(this);  Not working yet
 	vshape->setCurveColorProvider(this, 3);
@@ -88,6 +89,12 @@ void HSVEqualizer::read (const ProcParams* pp, const ParamsEdited* pedited) {
     enableListener ();
 }
 
+void HSVEqualizer::setEditProvider (EditDataProvider *provider) {
+    hshape->setEditProvider(provider);
+    sshape->setEditProvider(provider);
+    vshape->setEditProvider(provider);
+}
+
 void HSVEqualizer::autoOpenCurve () {
     // Open up the first curve if selected
     bool active = hshape->openIfNonlinear();
@@ -109,32 +116,6 @@ void HSVEqualizer::write (ProcParams* pp, ParamsEdited* pedited) {
     }
 }
 
-/*
-void HSVEqualizer::setDefaults (const ProcParams* defParams, const ParamsEdited* pedited) {
-	
-    for (int i = 0; i < 8; i++) {
-        sat[i]->setDefault(defParams->hsvequalizer.sat[i]);
-		val[i]->setDefault(defParams->hsvequalizer.val[i]);
-        hue[i]->setDefault(defParams->hsvequalizer.hue[i]);
-    }
-    
-    if (pedited) {
-        for (int i = 0; i < 8; i++) {
-            sat[i]->setDefaultEditedState(pedited->hsvequalizer.sat[i] ? Edited : UnEdited);
-			val[i]->setDefaultEditedState(pedited->hsvequalizer.val[i] ? Edited : UnEdited);
-            hue[i]->setDefaultEditedState(pedited->hsvequalizer.hue[i] ? Edited : UnEdited);
-        }
-    }
-    else {
-        for (int i = 0; i < 8; i++) {
-            sat[i]->setDefaultEditedState(Irrelevant);
-			val[i]->setDefaultEditedState(Irrelevant);
-            hue[i]->setDefaultEditedState(Irrelevant);
-        }
-    }
-}
-*/
-
 /*
  * Curve listener
  *
@@ -153,62 +134,13 @@ void HSVEqualizer::curveChanged (CurveEditor* ce) {
 	}
 }
 
-/*
-void HSVEqualizer::adjusterChanged (Adjuster* a, double newval) {
-	
-	if (listener && enabled->get_active()) {
-        std::stringstream ss;
-        ss << "(";
-        int i;		
-		if (hsvchannel->get_active_row_number()==0) {
-			for (i = 0; i < 8; i++) {
-				if (i > 0) {
-					ss << ", ";
-				}
-				if (i == 4) {
-					ss << "\n";
-				}
-				ss << static_cast<int>(sat[i]->getValue());
-			}
-			ss << ")";
-			listener->panelChanged (EvHSVEqualizerS, ss.str());
-		} 
-		else if (hsvchannel->get_active_row_number()==1) {
-			for (i = 0; i < 8; i++) {
-				if (i > 0) {
-					ss << ", ";
-				}
-				if (i == 4) {
-					ss << "\n";
-				}
-				ss << static_cast<int>(val[i]->getValue());
-			}
-			ss << ")";
-			listener->panelChanged (EvHSVEqualizerV, ss.str());
-		}
-		else if (hsvchannel->get_active_row_number()==2) {
-			for (i = 0; i < 8; i++) {
-				if (i > 0) {
-					ss << ", ";
-				}
-				if (i == 4) {
-					ss << "\n";
-				}
-				ss << static_cast<int>(hue[i]->getValue());
-			}
-			ss << ")";
-			listener->panelChanged (EvHSVEqualizerH, ss.str());
-		}
-		
-		//listener->panelChanged (EvHSVEqualizer, ss.str());
-	}
-}
-*/
-
-void HSVEqualizer::colorForValue (double valX, double valY, int callerId, ColorCaller* caller) {
+void HSVEqualizer::colorForValue (double valX, double valY, enum ColorCaller::ElemType elemType, int callerId, ColorCaller* caller) {
 
 	float r, g, b;
 
+	if (elemType==ColorCaller::CCET_VERTICAL_BAR)
+		valY = 0.5;
+
 	if (callerId == 1) {        // Hue = f(Hue)
 
 		float h = float((valY - 0.5) * 2. + valX);
