@@ -29,13 +29,11 @@
 #include "colorprovider.h"
 
 
-class HSVEqualizer : public Gtk::VBox, public AdjusterListener, public FoldableToolPanel, public CurveListener, public ColorProvider
+class HSVEqualizer : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel, public CurveListener, public ColorProvider
 {
 
 protected:
 
-    Gtk::CheckButton * enabled;
-
 	CurveEditorGroup*  curveEditorG;
 	FlatCurveEditor*   hshape;
 	FlatCurveEditor*   sshape;
@@ -46,13 +44,14 @@ public:
     HSVEqualizer ();
     virtual ~HSVEqualizer ();
 
-    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited=NULL); 
-    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited=NULL);
-    void curveChanged   (CurveEditor* ce);
-    //void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
-    void setBatchMode   (bool batchMode);
-    void autoOpenCurve  ();
-    virtual void colorForValue (double valX, double valY, int callerId, ColorCaller* caller);
+    void read            (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited=NULL);
+    void write           (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited=NULL);
+    void curveChanged    (CurveEditor* ce);
+    //void setDefaults     (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
+    void setBatchMode    (bool batchMode);
+    void setEditProvider (EditDataProvider *provider);
+    void autoOpenCurve   ();
+    virtual void colorForValue (double valX, double valY, enum ColorCaller::ElemType elemType, int callerId, ColorCaller* caller);
    
     //void adjusterChanged (Adjuster* a, double newval);
 };
