@@ -19,8 +19,7 @@
 #ifndef _ICMPANEL_
 #define _ICMPANEL_
 
-#include <auto_ptr.h>
-
+#include <memory>
 #include <gtkmm.h>
 #include "adjuster.h"
 #include "guiutils.h"
@@ -35,7 +34,7 @@ class ICMPanelListener {
         virtual void saveInputICCReference (Glib::ustring fname) {}
 };
 
-class ICMPanel : public Gtk::VBox, public AdjusterListener, public FoldableToolPanel {
+class ICMPanel : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel {
 
     protected:
         Adjuster* gampos;
