@@ -33,9 +33,9 @@ ImageArea::ImageArea (ImageAreaPanel* p) : parent(p) {
 	pmlistener = NULL;
 	pmhlistener = NULL;
     focusGrabber = NULL;
+    flawnOverWindow = NULL;
     mainCropWindow = NULL;
     previewHandler = NULL;
-    lastClosedX = -1;
 	showClippedH = false;
 	showClippedS = false;
     listener = NULL;
@@ -44,7 +44,8 @@ ImageArea::ImageArea (ImageAreaPanel* p) : parent(p) {
     indClippedPanel = Gtk::manage (new IndicateClippedPanel (this));
     previewModePanel =  Gtk::manage (new PreviewModePanel (this));
 
-    signal_style_changed().connect( sigc::mem_fun(*this, &ImageArea::styleChanged) );
+    add_events(Gdk::LEAVE_NOTIFY_MASK);
+
     signal_size_allocate().connect( sigc::mem_fun(*this, &ImageArea::on_resized) );
 
     dirty = false;
@@ -91,6 +92,7 @@ void ImageArea::on_resized (Gtk::Allocation& req) {
 			mainCropWindow->setPointerMotionHListener (pmhlistener);
 			mainCropWindow->setPosition (0, 0);
 			mainCropWindow->setSize (get_width(), get_height(), false);  // this execute the refresh itself
+			mainCropWindow->enable();  // start processing !
 		}
 		else {
 			mainCropWindow->setSize (get_width(), get_height());
@@ -103,10 +105,6 @@ void ImageArea::setImProcCoordinator (rtengine::StagedImageProcessor* ipc_) {
     if( !ipc_ ){
         focusGrabber = NULL;
         std::list<CropWindow*>::iterator i = cropWins.begin();
-        if( i!=cropWins.end() ){
-            (*i)->getPosition (lastClosedX, lastClosedY);
-            (*i)->getSize (lastClosedW, lastClosedH);
-        }
         for( ;i!=cropWins.end();i++ ){
         	delete *i;
         }
@@ -123,7 +121,7 @@ void ImageArea::setPreviewHandler (PreviewHandler* ph) {
     previewHandler = ph; 
 }
 
-void ImageArea::styleChanged (const Glib::RefPtr<Gtk::Style>& style) {
+void ImageArea::on_style_changed (const Glib::RefPtr<Gtk::Style>& style) {
 
     // TODO: notify all crop windows that the style has been changed
     queue_draw ();
@@ -181,8 +179,10 @@ bool ImageArea::on_expose_event(GdkEventExpose* event) {
     Glib::RefPtr<Gdk::Window> window = get_window();
     Cairo::RefPtr<Cairo::Context> cr = get_window()->create_cairo_context();
 
-    if (mainCropWindow)
+    if (mainCropWindow) {
+        //printf("MainCropWindow (%d x %d)\n", window->get_width(), window->get_height());
         mainCropWindow->expose (cr);
+    }
 
     if (options.showInfo==true && infotext!="") {
         int fnw, fnh;
@@ -204,11 +204,22 @@ bool ImageArea::on_expose_event(GdkEventExpose* event) {
 bool ImageArea::on_motion_notify_event (GdkEventMotion* event) {
 
     if (focusGrabber) 
-        focusGrabber->pointerMoved (event->x, event->y);
+        focusGrabber->pointerMoved (event->state, event->x, event->y);
     else {
         CropWindow* cw = getCropWindow (event->x, event->y);
-        if (cw) 
-            cw->pointerMoved (event->x, event->y);
+        if (cw) {
+            if (cw != flawnOverWindow) {
+                if (flawnOverWindow)
+                    flawnOverWindow->flawnOver(false);
+                cw->flawnOver(true);
+                flawnOverWindow = cw;
+            }
+            cw->pointerMoved (event->state, event->x, event->y);
+        }
+        else if (flawnOverWindow) {
+            flawnOverWindow->flawnOver(false);
+            flawnOverWindow = NULL;
+        }
     }
     return true;
 }
@@ -256,6 +267,70 @@ bool ImageArea::on_button_release_event (GdkEventButton* event) {
     return true;
 }
 
+bool ImageArea::on_leave_notify_event  (GdkEventCrossing* event) {
+    if (flawnOverWindow) {
+        flawnOverWindow->flawnOver(false);
+        flawnOverWindow = NULL;
+    }
+    if (focusGrabber) {
+        focusGrabber->flawnOver(false);
+        focusGrabber->leaveNotify (event);
+    }
+    else {
+        CropWindow* cw = getCropWindow (event->x, event->y);
+
+        if (cw) {
+            cw->flawnOver(false);
+            cw->leaveNotify (event);
+        }
+    }
+    return true;
+}
+
+void ImageArea::subscribe(EditSubscriber *subscriber) {
+    mainCropWindow->cropHandler.setEditSubscriber(subscriber);
+    for (std::list<CropWindow*>::iterator i=cropWins.begin(); i!=cropWins.end(); i++)
+        (*i)->cropHandler.setEditSubscriber(subscriber);
+
+    EditDataProvider::subscribe(subscriber);
+
+    if (listener && listener->getToolBar())
+        listener->getToolBar()->startEditMode ();
+
+    if (subscriber->getEditingType() == ET_OBJECTS) {
+        // In this case, no need to reprocess the image, so we redraw the image to display the geometry
+        queue_draw();
+    }
+}
+
+void ImageArea::unsubscribe() {
+    bool wasObjectType = false;
+    EditSubscriber*  oldSubscriber = EditDataProvider::getCurrSubscriber();
+    if (oldSubscriber && oldSubscriber->getEditingType()==ET_OBJECTS)
+        wasObjectType = true;
+
+    EditDataProvider::unsubscribe();
+    // Ask the Crops to free-up edit mode buffers
+    mainCropWindow->cropHandler.setEditSubscriber(NULL);
+    for (std::list<CropWindow*>::iterator i=cropWins.begin(); i!=cropWins.end(); i++)
+        (*i)->cropHandler.setEditSubscriber(NULL);
+    setToolHand();
+
+    if (listener && listener->getToolBar())
+        listener->getToolBar()->stopEditMode ();
+
+    if (wasObjectType)
+        queue_draw();
+}
+
+void ImageArea::getImageSize (int &w, int&h) {
+    if (ipc) {
+        w = ipc->getFullWidth();
+        h = ipc->getFullHeight();
+    }
+    else
+        w = h = 0;
+}
 
 void ImageArea::grabFocus (CropWindow* cw) {
     
@@ -270,51 +345,75 @@ void ImageArea::unGrabFocus () {
 }
 
 void ImageArea::addCropWindow () { 
-    if (!mainCropWindow) return;  // if called but no image is loaded, it would crash
+    if (!mainCropWindow)
+		return;  // if called but no image is loaded, it would crash
 
     CropWindow* cw = new CropWindow (this, ipc, true);
     cw->zoom11();
     cw->setCropGUIListener (cropgl);
     cw->setPointerMotionListener (pmlistener);
     cw->setPointerMotionHListener (pmhlistener);
+    int lastWidth = options.detailWindowWidth;
+    int lastHeight = options.detailWindowHeight;
+	if (lastWidth<lastHeight)
+		lastHeight=lastWidth;
+	if (lastHeight<lastWidth)
+		lastWidth=lastHeight;
+
+    if(!cropWins.empty()) {
+		CropWindow *lastCrop;
+		lastCrop = cropWins.front();
+		if(lastCrop)
+			lastCrop->getSize(lastWidth,lastHeight);
+    }
+
     cropWins.push_front (cw);
 
-    // Position the new crop window in a checkerboard, or used the last position
-    if (lastClosedX<0) {
-        int K = 2;
-        int hBorder = get_width()/K/8;
-        int vBorder = get_height()/K/8;
-        int N = cropWins.size()-1;
-        int layer = N/K/K;
-        int row = K-1 - (N % (K*K)) / K;
-        int col = K-1 - (N % (K*K)) % K;
-        int cropwidth, cropheight;
-        
-        cropwidth = get_width()/K - hBorder;
-        cropheight = get_height()/K - vBorder;
+    // Position the new crop window this way: start from top right going down to bottom. When bottom is reached, continue top left going down......
+	int N = cropWins.size()-1;
+	int cropwidth, cropheight;
+	
+	if(lastWidth <= 0) { // this is only the case for very first start of RT 4.1 or when options file is deleted
+		cropwidth = 200;
+		cropheight = 200;
+	} else {
+		cropwidth = lastWidth;
+		cropheight = lastHeight;
+	}
 
-        if (options.squareDetailWindow){
-			// force square CropWindow (this is faster as area is smaller)
-			if (cropwidth<cropheight) cropheight=cropwidth;
-			if (cropheight<cropwidth) cropwidth=cropheight;
-        }
+	cw->setSize (cropwidth,cropheight);
+	int x,y;
+	int maxRows = get_height()/cropheight;
+	if(maxRows == 0)
+		maxRows = 1;
 
-        cw->setSize (cropwidth,cropheight);
-        cw->setPosition (col*get_width()/K + hBorder/2 + layer*30, row*get_height()/K + vBorder/2 + layer*30);
-    }
-    else {
-        cw->setPosition (lastClosedX, lastClosedY);
-        cw->setSize(lastClosedW, lastClosedH);
-    }
-    int x0,y0,w,h,wc,hc;
-    mainCropWindow->getCropRectangle(x0,y0,w,h );
-    cw->getCropSize(wc,hc);
-    cw->setCropPosition(x0+w/2-wc/2,y0+h/2-hc/2);
-    mainCropWindow->setObservedCropWin (cropWins.front());
+	int col = N / maxRows;
+	if(col % 2) { // from left side
+		col = col/2;
+		x = col*cropwidth;
+		if(x >= get_width() - 50)
+			x = get_width() - 50;
+	}
+	else {		// from right side
+		col /= 2;
+		col++;
+		x = get_width() - col * cropwidth;
+		if(x <= 0)
+			x = 0;
+	}
 
-    ipc->startProcessing(M_HIGHQUAL);
+	y = cropheight * (N%maxRows);
+	cw->setPosition (x, y);
+	cw->enable(); // start processing!
 
-//    queue_draw (); 
+	int x0,y0,w,h,wc,hc;
+	mainCropWindow->getCropRectangle(x0,y0,w,h );
+	cw->getCropSize(wc,hc);
+	cw->setCropPosition(x0+w/2-wc/2,y0+h/2-hc/2);
+	mainCropWindow->setObservedCropWin (cropWins.front());
+
+	if(cropWins.size()==1) // after first detail window we already have high quality
+		ipc->startProcessing(M_HIGHQUAL);
 }
 
 
@@ -330,12 +429,9 @@ void ImageArea::cropWindowSelected (CropWindow* cw) {
 void ImageArea::cropWindowClosed (CropWindow* cw) { 
     
     focusGrabber = NULL; 
-    cw->getPosition (lastClosedX, lastClosedY);
-    cw->getSize (lastClosedW, lastClosedH);
     std::list<CropWindow*>::iterator i = std::find (cropWins.begin(), cropWins.end(), cw);
     if (i!=cropWins.end())
         cropWins.erase (i);
-    delete cw;
     if (!cropWins.empty())
         mainCropWindow->setObservedCropWin (cropWins.front());
     else
@@ -469,8 +565,9 @@ ToolMode ImageArea::getToolMode () {
 
 void ImageArea::setToolHand () { 
     
-    if (listener && listener->getToolBar())
-        listener->getToolBar()->setTool (TMHand); 
+    if (listener && listener->getToolBar()) {
+        listener->getToolBar()->setTool (TMHand);
+    }
 }
 
 int ImageArea::getSpotWBRectSize  () { 
