@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -30,77 +30,92 @@
 #include "zoompanel.h"
 #include "indclippedpanel.h"
 #include "previewmodepanel.h"
+#include "edit.h"
 
 class ImageAreaPanel;
-class ImageArea : public Gtk::DrawingArea, public CropWindowListener {
+class ImageArea : public Gtk::DrawingArea, public CropWindowListener, public EditDataProvider
+{
 
     friend class ZoomPanel;
 
-  protected:
+protected:
 
     Glib::ustring infotext;
     Glib::RefPtr<Pango::Layout> ilayout;
     Glib::RefPtr<Pango::Layout> deglayout;
     Glib::RefPtr<Gdk::Pixbuf>   ipixbuf;
-	bool showClippedH, showClippedS;
+    bool showClippedH, showClippedS;
+
+    ImageAreaPanel* parent;
 
-    ImageAreaPanel* parent;   
-  
     std::list<CropWindow*> cropWins;
     PreviewHandler* previewHandler;
     rtengine::StagedImageProcessor* ipc;
 
-    int lastClosedX, lastClosedY, lastClosedW, lastClosedH;
-
     bool        dirty;
     CropWindow* focusGrabber;
     CropGUIListener* cropgl;
-	PointerMotionListener* pmlistener;
-	PointerMotionListener* pmhlistener;
+    PointerMotionListener* pmlistener;
+    PointerMotionListener* pmhlistener;
     ImageAreaToolListener* listener;
 
     CropWindow* getCropWindow (int x, int y);
-
-  public:
+    bool firstOpen;
+    int fullImageWidth, fullImageHeight;
+public:
     CropWindow* mainCropWindow;
+    CropWindow* flawnOverWindow;
     ZoomPanel* zoomPanel;
-	IndicateClippedPanel* indClippedPanel;
-	PreviewModePanel* previewModePanel;
-	ImageArea* iLinkedImageArea; // used to set a reference to the Before image area, which is set when before/after view is enabled
+    IndicateClippedPanel* indClippedPanel;
+    PreviewModePanel* previewModePanel;
+    ImageArea* iLinkedImageArea; // used to set a reference to the Before image area, which is set when before/after view is enabled
 
     ImageArea (ImageAreaPanel* p);
     ~ImageArea ();
-    
+
     void setImProcCoordinator (rtengine::StagedImageProcessor* ipc_);
-    void setPreviewModePanel(PreviewModePanel* previewModePanel_){previewModePanel = previewModePanel_;};
-    void setIndicateClippedPanel(IndicateClippedPanel* indClippedPanel_){indClippedPanel = indClippedPanel_;};
-    
+    void setPreviewModePanel(PreviewModePanel* previewModePanel_)
+    {
+        previewModePanel = previewModePanel_;
+    };
+    void setIndicateClippedPanel(IndicateClippedPanel* indClippedPanel_)
+    {
+        indClippedPanel = indClippedPanel_;
+    };
+
     void getScrollImageSize (int& w, int& h);
     void getScrollPosition  (int& x, int& y);
     void setScrollPosition  (int x, int y);     // called by the imageareapanel when the scrollbars have been changed
-    
+
     // enabling and setting text of info area
     void setInfoText (Glib::ustring text);
     void infoEnabled (bool e);
 
     // widget base events
     void on_realize ();
-    bool on_expose_event        (GdkEventExpose* event);
-    bool on_motion_notify_event (GdkEventMotion* event);
-    bool on_button_press_event  (GdkEventButton* event);
+    bool on_expose_event         (GdkEventExpose* event);
+    bool on_motion_notify_event  (GdkEventMotion* event);
+    bool on_button_press_event   (GdkEventButton* event);
     bool on_button_release_event (GdkEventButton* event);
-    bool on_scroll_event        (GdkEventScroll* event);
-    void on_resized             (Gtk::Allocation& req);
-    void styleChanged (const Glib::RefPtr<Gtk::Style>& style);
-    void syncBeforeAfterViews       ();
+    bool on_scroll_event         (GdkEventScroll* event);
+    bool on_leave_notify_event   (GdkEventCrossing* event);
+    void on_resized              (Gtk::Allocation& req);
+    void on_style_changed        (const Glib::RefPtr<Gtk::Style>& style);
+    void syncBeforeAfterViews    ();
 
     void            setCropGUIListener       (CropGUIListener* l);
     void            setPointerMotionListener  (PointerMotionListener* pml);
     void            setPointerMotionHListener (PointerMotionListener* pml);
-    void            setImageAreaToolListener (ImageAreaToolListener* l) { listener = l; }
+    void            setImageAreaToolListener (ImageAreaToolListener* l)
+    {
+        listener = l;
+    }
     void            setPreviewHandler        (PreviewHandler* ph);
-    PreviewHandler* getPreviewHandler        ()                         { return previewHandler; }
-    
+    PreviewHandler* getPreviewHandler        ()
+    {
+        return previewHandler;
+    }
+
     void grabFocus          (CropWindow* cw);
     void unGrabFocus        ();
     void addCropWindow      ();
@@ -112,18 +127,26 @@ class ImageArea : public Gtk::DrawingArea, public CropWindowListener {
     void spotWBSelected     (int x, int y);
     int  getSpotWBRectSize  ();
     void redraw             ();
-    
+
     void zoomFit     ();
-    double getZoom   ();  
-    void   setZoom   (double zoom);  
-    
-    // cropwindowlistener interface
+    double getZoom   ();
+    void   setZoom   (double zoom);
+
+    // EditDataProvider interface
+    void subscribe(EditSubscriber *subscriber);
+    void unsubscribe();
+    void getImageSize (int &w, int&h);
+
+    // CropWindowListener interface
     void cropPositionChanged   (CropWindow* cw);
-    void cropWindowSizeChanged (CropWindow* cw);  
+    void cropWindowSizeChanged (CropWindow* cw);
     void cropZoomChanged       (CropWindow* cw);
     void initialImageArrived   (CropWindow* cw) ;
 
-    CropWindow* getMainCropWindow () { return mainCropWindow; }
+    CropWindow* getMainCropWindow ()
+    {
+        return mainCropWindow;
+    }
 };
 
 
