@@ -27,24 +27,23 @@
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-LensProfilePanel::LensProfilePanel () : Gtk::VBox(), FoldableToolPanel(this)
+LensProfilePanel::LensProfilePanel () : FoldableToolPanel(this, "lensprof", M("TP_LENSPROFILE_LABEL"))
 {
-    set_border_width(4);
-
     hbLCPFile = Gtk::manage(new Gtk::HBox());
 
     lLCPFileHead = Gtk::manage(new Gtk::Label(M("GENERAL_FILE")));
     hbLCPFile->pack_start(*lLCPFileHead, Gtk::PACK_SHRINK, 4);
 
     fcbLCPFile = Gtk::manage(new MyFileChooserButton(M("TP_LENSPROFILE_LABEL"), Gtk::FILE_CHOOSER_ACTION_OPEN));
-    
+
     Gtk::FileFilter filterLCP;
-    filterLCP.set_name(M("TP_LENSPROFILE_FILEDLGFILTERLCP"));
+    filterLCP.set_name(M("FILECHOOSER_FILTER_LCP"));
     filterLCP.add_pattern("*.lcp");
     filterLCP.add_pattern("*.LCP");
     fcbLCPFile->add_filter(filterLCP);
-    
-    Glib::ustring defDir=lcpStore->getDefaultCommonDirectory();
+
+    Glib::ustring defDir = lcpStore->getDefaultCommonDirectory();
+
     if (!defDir.empty()) {
 #ifdef WIN32
         fcbLCPFile->set_show_hidden(true);  // ProgramData is hidden on Windows
@@ -73,7 +72,7 @@ LensProfilePanel::LensProfilePanel () : Gtk::VBox(), FoldableToolPanel(this)
     ckbUseVign->signal_toggled().connect( sigc::mem_fun(*this, &LensProfilePanel::onUseVignChanged) );
     ckbUseCA->signal_toggled().connect( sigc::mem_fun(*this, &LensProfilePanel::onUseCAChanged) );
 
-    allowFocusDep=true;
+    allowFocusDep = true;
 }
 
 void LensProfilePanel::read(const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited)
@@ -85,39 +84,50 @@ void LensProfilePanel::read(const rtengine::procparams::ProcParams* pp, const Pa
         updateDisabled(true);
     } else {
         Glib::ustring fname = fcbLCPFile->get_filename();
-        if (!pp->lensProf.lcpFile.empty())
+
+        if (!pp->lensProf.lcpFile.empty()) {
             fcbLCPFile->unselect_filename(fname);
+        } else {
+            Glib::ustring lastFolder = fcbLCPFile->get_current_folder();
+            fcbLCPFile->set_filename("");
+            fcbLCPFile->set_current_folder(lastFolder);
+        }
+
         updateDisabled(false);
     }
 
     ckbUseDist->set_active (pp->lensProf.useDist);
-    ckbUseVign->set_active (pp->lensProf.useVign);
-    ckbUseCA->set_active   (pp->lensProf.useCA);
+    ckbUseVign->set_active (pp->lensProf.useVign && isRaw);
+    ckbUseCA->set_active   (pp->lensProf.useCA && isRaw);
 
-    lcpFileChanged=useDistChanged=useVignChanged=useCAChanged=false;
+    lcpFileChanged = useDistChanged = useVignChanged = useCAChanged = false;
 
     enableListener ();
 }
 
-void LensProfilePanel::setRawMeta(bool raw, const rtengine::ImageMetaData* pMeta) {
-    if (!raw || pMeta->getFocusDist()<=0) {
+void LensProfilePanel::setRawMeta(bool raw, const rtengine::ImageMetaData* pMeta)
+{
+    if (!raw || pMeta->getFocusDist() <= 0) {
         disableListener();
-        
+
         // CA is very focus layer dependend, otherwise it might even worsen things
-        allowFocusDep=false;
+        allowFocusDep = false;
         ckbUseCA->set_active(false);
         ckbUseCA->set_sensitive(false);
-        
+
         enableListener();
     }
+
+    isRaw = raw;
 }
 
 void LensProfilePanel::write( rtengine::procparams::ProcParams* pp, ParamsEdited* pedited)
 {
-    if (lcpStore->isValidLCPFileName(fcbLCPFile->get_filename()))
+    if (lcpStore->isValidLCPFileName(fcbLCPFile->get_filename())) {
         pp->lensProf.lcpFile = fcbLCPFile->get_filename();
-    else
+    } else {
         pp->lensProf.lcpFile = "";
+    }
 
     pp->lensProf.useDist = ckbUseDist->get_active();
     pp->lensProf.useVign = ckbUseVign->get_active();
@@ -133,42 +143,54 @@ void LensProfilePanel::write( rtengine::procparams::ProcParams* pp, ParamsEdited
 
 void LensProfilePanel::onLCPFileChanged()
 {
-    lcpFileChanged=true;
+    lcpFileChanged = true;
     updateDisabled(lcpStore->isValidLCPFileName(fcbLCPFile->get_filename()));
 
-    if (listener)
+    if (listener) {
         listener->panelChanged (EvLCPFile, Glib::path_get_basename(fcbLCPFile->get_filename()));
+    }
 }
 
 void LensProfilePanel::onLCPFileReset()
 {
-    lcpFileChanged=true;
+    lcpFileChanged = true;
 
     fcbLCPFile->unselect_filename(fcbLCPFile->get_filename());
     updateDisabled(false);
 
-    if (listener)
+    if (listener) {
         listener->panelChanged (EvLCPFile, M("GENERAL_NONE"));
+    }
 }
 
 void LensProfilePanel::onUseDistChanged()
 {
-    useDistChanged=true;
-    if (listener) listener->panelChanged (EvLCPUseDist, ckbUseDist->get_active() ? M("GENERAL_ENABLED") : M("GENERAL_DISABLED"));
+    useDistChanged = true;
+
+    if (listener) {
+        listener->panelChanged (EvLCPUseDist, ckbUseDist->get_active() ? M("GENERAL_ENABLED") : M("GENERAL_DISABLED"));
+    }
 }
 void LensProfilePanel::onUseVignChanged()
 {
-    useVignChanged=true;
-    if (listener) listener->panelChanged (EvLCPUseVign, ckbUseVign->get_active() ? M("GENERAL_ENABLED") : M("GENERAL_DISABLED"));
+    useVignChanged = true;
+
+    if (listener) {
+        listener->panelChanged (EvLCPUseVign, ckbUseVign->get_active() ? M("GENERAL_ENABLED") : M("GENERAL_DISABLED"));
+    }
 }
 void LensProfilePanel::onUseCAChanged()
 {
-    useCAChanged=true;
-    if (listener) listener->panelChanged (EvLCPUseCA, ckbUseCA->get_active() ? M("GENERAL_ENABLED") : M("GENERAL_DISABLED"));
+    useCAChanged = true;
+
+    if (listener) {
+        listener->panelChanged (EvLCPUseCA, ckbUseCA->get_active() ? M("GENERAL_ENABLED") : M("GENERAL_DISABLED"));
+    }
 }
 
-void LensProfilePanel::updateDisabled(bool enable) {
+void LensProfilePanel::updateDisabled(bool enable)
+{
     ckbUseDist->set_sensitive(enable);
-    ckbUseVign->set_sensitive(enable);
+    ckbUseVign->set_sensitive(enable && isRaw);
     ckbUseCA->set_sensitive(enable && allowFocusDep);
 }
