@@ -16,17 +16,25 @@
  *  You should have received a copy of the GNU General Public License
  *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
  */
+#ifdef WIN32
+// Desired auto detect function is Vista+
+#if __GNUC__ == 4 && __GNUC_MINOR__ >= 8
+#define WINVER 0x0600 // switching to WINVER for gcc 4.8.1 support on Winx64
+#else
+#define _WIN32_WINNT 0x0600
+#endif
+#include <windows.h>
+#include <winnls.h>
+#if __GNUC__ == 4 && __GNUC_MINOR__ >= 8
+#undef WINVER
+#else
+#undef _WIN32_WINNT
+#endif
+#endif
 #include <glib/gstdio.h>
 #include "multilangmgr.h"
 #include <cstring>
 #include "../rtengine/safegtk.h"
-#ifdef WIN32
-// Desired auto detect function is Vista+
-#define _WIN32_WINNT 0x0600
-#include <windows.h>
-#include <winnls.h>
-#undef _WIN32_WINNT
-#endif
 
 MultiLangMgr langMgr;
 
@@ -130,7 +138,7 @@ Glib::ustring MultiLangMgr::getOSUserLanguage() {
         }
 #endif
 #elif defined(__linux__) || defined(__APPLE__)
-    langName = TranslateRFC2Language(std::setlocale(LC_CTYPE,""));
+    langName = TranslateRFC2Language(setlocale(LC_CTYPE,""));
 #endif
     }
 
@@ -149,27 +157,30 @@ Glib::ustring MultiLangMgr::TranslateRFC2Language(Glib::ustring rfcName) {
 
     //printf("Lang: %s - %s\n",major.c_str(),minor.c_str());
 
-    if (major=="cs") return "Czech";
     if (major=="ca") return "Catala";
-    if (major=="fr") return "Francais";
-    if (major=="de") return "Deutsch";
-    if (major=="sr") return "Serbian (Cyrilic Characters)";
     if (major=="zh")
         return (minor=="CN" || minor=="SG") ? "Chinese (Simplified)" : "Chinese (Traditional)";
+    if (major=="cs") return "Czech";
     if (major=="da") return "Dansk";
+    if (major=="de") return "Deutsch";
     if (major=="es") return "Espanol";
+    if (major=="eu") return "Euskara";
+    if (major=="fr") return "Francais";
     if (major=="el") return "Greek";
     if (major=="he") return "Hebrew";
-    if (major=="it") return "Italian";
+    if (major=="it") return "Italiano";
     if (major=="ja") return "Japanese";
+    if (major=="lv") return "Latvian";
+    if (major=="hu") return "Magyar";
     if (major=="nl") return "Nederlands";
     if (major=="nn" || major=="nb") return "Norsk BM";
     if (major=="pl") return "Polish";
     if (major=="pt") return "Portugues (Brasil)";
     if (major=="ru") return "Russian";
+    if (major=="sr") return "Serbian (Cyrilic Characters)";
     if (major=="sk") return "Slovak";
     if (major=="fi") return "Suomi";
-    if (major=="se") return "Swedish";
+    if (major=="sv") return "Swedish";
     if (major=="tr") return "Turkish";
 
     // Don't split en-US, en-GB, etc. since only default english is constantly updated
