@@ -226,6 +226,44 @@ void MyDiagonalCurve::draw (int handle) {
         cr->fill ();
     }
 
+    // draw the pipette values
+    if (pipetteR > -1.f || pipetteG > -1.f || pipetteB > -1.f) {
+        int n=0;
+        if (pipetteR > -1.f) ++n;
+        if (pipetteG > -1.f) ++n;
+        if (pipetteB > -1.f) ++n;
+
+        if (n > 1) {
+            if (pipetteR > -1.f) {
+                cr->set_source_rgba (1., 0., 0., 0.5); // WARNING: assuming that red values are stored in pipetteR, which might not be the case!
+                cr->move_to (double(graphX)+1.5 + double(graphW-3)*pipetteR, double(graphY)-1.5);
+                cr->rel_line_to (0, double(-graphH+3));
+                cr->stroke ();
+            }
+            if (pipetteG > -1.f) {
+                cr->set_source_rgba (0., 1., 0., 0.5); // WARNING: assuming that green values are stored in pipetteG, which might not be the case!
+                cr->move_to (double(graphX)+1.5 + double(graphW-3)*pipetteG, double(graphY)-1.5);
+                cr->rel_line_to (0, double(-graphH+3));
+                cr->stroke ();
+            }
+            if (pipetteB > -1.f) {
+                cr->set_source_rgba (0., 0., 1., 0.5); // WARNING: assuming that blue values are stored in pipetteB, which might not be the case!
+                cr->move_to (double(graphX)+1.5 + double(graphW-3)*pipetteB, double(graphY)-1.5);
+                cr->rel_line_to (0, double(-graphH+3));
+                cr->stroke ();
+            }
+        }
+        if (pipetteVal > -1.f) {
+            cr->set_line_width (2.);
+            c = style->get_fg (state);
+            cr->set_source_rgb (c.get_red_p(), c.get_green_p(), c.get_blue_p());
+            cr->move_to (double(graphX)+1.5 + double(graphW-3)*pipetteVal, double(graphY)-1.5);
+            cr->rel_line_to (0, double(-graphH+3));
+            cr->stroke ();
+            cr->set_line_width (1.);
+        }
+    }
+
     c = style->get_fg (state);
 
     // draw the cage of the NURBS curve
@@ -241,10 +279,10 @@ void MyDiagonalCurve::draw (int handle) {
         for (unsigned int i = 1; i < nbPoints; i++) {
             int pos = i*2+1;
 
-            double x1 = double(graphX)+1.5 + double(graphW-3)*points[pos-2];  // project (curve.x[i], 0, 1, graphW);
-            double y1 = double(graphY)-1.5 - double(graphH-3)*points[pos-1];  // project (curve.y[i], 0, 1, graphH);
-            double x2 = double(graphX)+0.5 + double(graphW-3)*points[pos];    // project (curve.x[i], 0, 1, graphW);
-            double y2 = double(graphY)-1.5 - double(graphH-3)*points[pos+1];  // project (curve.y[i], 0, 1, graphH);
+            double x1 = double(graphX)+1.5 + double(graphW-3)*points[pos-2];  // project (curve.at(i), 0, 1, graphW);
+            double y1 = double(graphY)-1.5 - double(graphH-3)*points[pos-1];  // project (curve.y.at(i)i], 0, 1, graphH);
+            double x2 = double(graphX)+0.5 + double(graphW-3)*points[pos];    // project (curve.at(i), 0, 1, graphW);
+            double y2 = double(graphY)-1.5 - double(graphH-3)*points[pos+1];  // project (curve.y.at(i), 0, 1, graphH);
 
             // set the color of the line when the point is snapped to the cage
             if (curve.x.size() == nbPoints && snapToElmt >= 1000 && ((i == (snapToElmt-1000)) || (i == (snapToElmt-999))))
@@ -301,7 +339,7 @@ void MyDiagonalCurve::draw (int handle) {
     if (curve.type!=DCT_Parametric) {
         c = style->get_fg (state);
         for (int i = 0; i < (int)curve.x.size(); ++i) {
-            if (curve.x[i] == -1) continue;
+            if (curve.x.at(i) == -1) continue;
             if (snapToElmt >= 1000) {
                 int pt = snapToElmt-1000;
                 if (i >= (pt-1) && i <= (pt+1))
@@ -316,8 +354,8 @@ void MyDiagonalCurve::draw (int handle) {
                     cr->set_source_rgb (c.get_red_p(), c.get_green_p(), c.get_blue_p());
             }
 
-            double x = double(graphX+1) + double((graphW-2) * curve.x[i]); // project (curve.x[i], 0, 1, graphW);
-            double y = double(graphY-1) - double((graphH-2) * curve.y[i]); // project (curve.y[i], 0, 1, graphH);
+            double x = double(graphX+1) + double((graphW-2) * curve.x.at(i)); // project (curve.x.at(i), 0, 1, graphW);
+            double y = double(graphY-1) - double((graphH-2) * curve.y.at(i)); // project (curve.y.at(i), 0, 1, graphH);
 
             cr->arc (x, y, RADIUS+0.5, 0, 2*M_PI);
             cr->fill ();
@@ -337,8 +375,6 @@ void MyDiagonalCurve::draw (int handle) {
 bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 
 	CursorShape new_type = cursor_type;
-	int src, dst;
-	std::vector<double>::iterator itx, ity;
 
 	bool retval = false;
 	int num = (int)curve.x.size();
@@ -346,12 +382,12 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 	/* graphW and graphH are the size of the graph */
 	calcDimensions();
 
-	double minDistanceX = double(MIN_DISTANCE) / double(graphW-1);
-	double minDistanceY = double(MIN_DISTANCE) / double(graphH-1);
-
 	if ((graphW < 0) || (graphH < 0))
 		return false;
 
+	double minDistanceX = double(MIN_DISTANCE) / double(graphW-1);
+	double minDistanceY = double(MIN_DISTANCE) / double(graphH-1);
+
 	switch (event->type) {
 	case Gdk::CONFIGURE: {
 		// Happen when the the window is resized
@@ -386,18 +422,19 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 		snapToElmt = -100;
 		if (curve.type!=DCT_Parametric) {
 			if (event->button.button == 1) {
+				std::vector<double>::iterator itx, ity;
 				buttonPressed = true;
 				add_modal_grab ();
 
 				// get the pointer position
-				getCursorPosition(event);
+				getCursorPosition(Gdk::EventType(event->type), event->motion.is_hint!=0, int(event->button.x), int(event->button.y), Gdk::ModifierType(event->button.state));
 				findClosestPoint();
 
 				new_type = CSMove;
 				if (distanceX > minDistanceX) {
 					/* insert a new control point */
 					if (num > 0) {
-						if (clampedX > curve.x[closest_point])
+						if (clampedX > curve.x.at(closest_point))
 							++closest_point;
 					}
 					itx = curve.x.begin();
@@ -408,8 +445,8 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 					num++;
 
 					// the graph is refreshed only if a new point is created (snaped to a pixel)
-					curve.x[closest_point] = clampedX;
-					curve.y[closest_point] = clampedY;
+					curve.x.at(closest_point) = clampedX;
+					curve.y.at(closest_point) = clampedY;
 
 					curveIsDirty = true;
 					setDirty(true);
@@ -418,8 +455,8 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 				}
 				grab_point = closest_point;
 				lit_point = closest_point;
-				ugpX = curve.x[closest_point];
-				ugpY = curve.y[closest_point];
+				ugpX = curve.x.at(closest_point);
+				ugpY = curve.y.at(closest_point);
 			}
 			if (buttonPressed) retval = true;
 		}
@@ -429,9 +466,11 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 		snapToElmt = -100;
 		if (curve.type!=DCT_Parametric) {
 			if (buttonPressed && event->button.button == 1) {
+				std::vector<double>::iterator itx, ity;
+				int src, dst;
 				buttonPressed = false;
 				/*  get the pointer position  */
-				getCursorPosition(event);
+				getCursorPosition(Gdk::EventType(event->type), event->motion.is_hint!=0, int(event->button.x), int(event->button.y), Gdk::ModifierType(event->button.state));
 				findClosestPoint();
 
 				remove_modal_grab ();
@@ -440,9 +479,9 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 				itx = curve.x.begin();
 				ity = curve.y.begin();
 				for (src = dst = 0; src < num; ++src)
-					if (curve.x[src] >= 0.0) {
-						curve.x[dst] = curve.x[src];
-						curve.y[dst] = curve.y[src];
+					if (curve.x.at(src) >= 0.0) {
+						curve.x.at(dst) = curve.x.at(src);
+						curve.y.at(dst) = curve.y.at(src);
 						++dst;
 						++itx;
 						++ity;
@@ -484,6 +523,7 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 			if (grab_point == -1) {
 				new_type = CSArrow;
 				lit_point = -1;
+				pipetteR = pipetteG = pipetteB = -1.f;
 				setDirty(true);
 				draw (lit_point);
 			}
@@ -499,7 +539,7 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 			snapToElmt = -100;
 
 			// get the pointer position
-			getCursorPosition(event);
+			getCursorPosition(Gdk::EventType(event->type), event->motion.is_hint!=0, int(event->button.x), int(event->button.y), Gdk::ModifierType(event->button.state));
 
 			if (grab_point == -1) {
 				// there's no point currently being moved
@@ -527,8 +567,8 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 				// a point is being moved
 
 				// bounds of the grabbed point
-				double leftBound         = (grab_point == 0    ) ? 0. : curve.x[grab_point-1];
-				double rightBound        = (grab_point == num-1) ? 1. : curve.x[grab_point+1];
+				double leftBound         = (grab_point == 0    ) ? 0. : curve.x.at(grab_point-1);
+				double rightBound        = (grab_point == num-1) ? 1. : curve.x.at(grab_point+1);
 				double const bottomBound = 0.;
 				double const topBound    = 1.;
 
@@ -538,8 +578,8 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 				double topDeletionBound    = topBound    + minDistanceY;
 
 				// we memorize the previous position of the point, for optimization purpose
-				double prevPosX = curve.x[grab_point];
-				double prevPosY = curve.y[grab_point];
+				double prevPosX = curve.x.at(grab_point);
+				double prevPosY = curve.y.at(grab_point);
 
 				// we memorize the previous position of the point, for optimization purpose
 				ugpX += deltaX;
@@ -550,57 +590,57 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 
 				// handling limitations along X axis
 				if (ugpX >= rightDeletionBound && (grab_point > 0 && grab_point < (num-1))) {
-					curve.x[grab_point] = -1.;
+					curve.x.at(grab_point) = -1.;
 				}
 				else if (ugpX <= leftDeletionBound && (grab_point > 0 && grab_point < (num-1))) {
-					curve.x[grab_point] = -1.;
+					curve.x.at(grab_point) = -1.;
 				}
 				else
 					// nextPosX is in bounds
-					curve.x[grab_point] = CLAMP(ugpX, leftBound, rightBound);
+					curve.x.at(grab_point) = CLAMP(ugpX, leftBound, rightBound);
 
 				// Handling limitations along Y axis
 				if (ugpY >= topDeletionBound && grab_point != 0 && grab_point != num-1) {
-					curve.x[grab_point] = -1.;
+					curve.x.at(grab_point) = -1.;
 				}
 				else if (ugpY <= bottomDeletionBound && grab_point != 0 && grab_point != num-1) {
-					curve.x[grab_point] = -1.;
+					curve.x.at(grab_point) = -1.;
 				}
 				else {
 					// snapping point to specific values
-					if (snapTo && curve.x[grab_point] != -1.) {
+					if (snapTo && curve.x.at(grab_point) != -1.) {
 						if (grab_point > 0 && grab_point < (curve.y.size()-1)) {
-							double prevX = curve.x[grab_point-1];
-							double prevY = curve.y[grab_point-1];
-							double nextX = curve.x[grab_point+1];
-							double nextY = curve.y[grab_point+1];
+							double prevX = curve.x.at(grab_point-1);
+							double prevY = curve.y.at(grab_point-1);
+							double nextX = curve.x.at(grab_point+1);
+							double nextY = curve.y.at(grab_point+1);
 
-							double ratio = (curve.x[grab_point]-prevX)/(nextX-prevX);
+							double ratio = (curve.x.at(grab_point)-prevX)/(nextX-prevX);
 							double y = (nextY-prevY) * ratio + prevY;
 
 							if (snapCoordinateY(y, ugpY)) snapToElmt = 1000+grab_point;
 						}
 						if (grab_point > 0) {
 							int prevP = grab_point-1;
-							if (snapCoordinateY(curve.y[prevP], ugpY)) snapToElmt = prevP;
+							if (snapCoordinateY(curve.y.at(prevP), ugpY)) snapToElmt = prevP;
 						}
 						if (grab_point < (curve.y.size()-1)) {
 							int nextP = grab_point+1;
-							if (snapCoordinateY(curve.y[nextP], ugpY)) snapToElmt = nextP;
+							if (snapCoordinateY(curve.y.at(nextP), ugpY)) snapToElmt = nextP;
 						}
-						if (snapCoordinateY(1.0,                 ugpY)) snapToElmt = -3;
-						if (snapCoordinateY(curve.x[grab_point], ugpY)) snapToElmt = -2;
-						if (snapCoordinateY(0.0,                 ugpY)) snapToElmt = -1;
+						if (snapCoordinateY(1.0,                    ugpY)) snapToElmt = -3;
+						if (snapCoordinateY(curve.x.at(grab_point), ugpY)) snapToElmt = -2;
+						if (snapCoordinateY(0.0,                    ugpY)) snapToElmt = -1;
 
-						curve.y[grab_point] = snapToValY;
+						curve.y.at(grab_point) = snapToValY;
 					}
 					else {
 						// nextPosY is in the bounds
-						curve.y[grab_point] = CLAMP(ugpY, 0.0, 1.0);
+						curve.y.at(grab_point) = CLAMP(ugpY, 0.0, 1.0);
 					}
 				}
 
-				if (curve.x[grab_point] != prevPosX || curve.y[grab_point] != prevPosY) {
+				if (curve.x.at(grab_point) != prevPosX || curve.y.at(grab_point) != prevPosY) {
 					// we recalculate the curve only if we have to
 					curveIsDirty = true;
 					setDirty(true);
@@ -623,29 +663,257 @@ bool MyDiagonalCurve::handleEvents (GdkEvent* event) {
 	return retval;
 }
 
-void MyDiagonalCurve::getCursorPosition(GdkEvent* event) {
+CursorShape MyDiagonalCurve::motionNotify(CursorShape type, double minDistanceX, double minDistanceY, int num) {
+	CursorShape new_type = type;
+
+	return new_type;
+}
+
+void MyDiagonalCurve::pipetteMouseOver (EditDataProvider *provider, int modifierKey) {
+	if (!provider) {
+		// occurs when leaving the preview area -> cleanup the curve editor
+		pipetteR = pipetteG = pipetteB = -1.f;
+		lit_point = -1;
+		return;
+	}
+
+	pipetteR = provider->pipetteVal[0];
+	pipetteG = provider->pipetteVal[1];
+	pipetteB = provider->pipetteVal[2];
+	pipetteVal = 0.f;
+	if (listener)
+		pipetteVal = listener->blendPipetteValues(pipetteR, pipetteG, pipetteB);
+	else {
+		int n = 0;
+		if (pipetteR != -1.f) {
+			pipetteVal += pipetteR;
+			++n;
+		}
+		if (pipetteG != -1.f) {
+			pipetteVal += pipetteG;
+			++n;
+		}
+		if (pipetteB != -1.f) {
+			pipetteVal += pipetteB;
+			++n;
+		}
+		if (n>1)
+			pipetteVal /= n;
+		else if (!n)
+			pipetteVal = -1.f;
+	}
+
+	/* graphW and graphH are the size of the graph */
+	calcDimensions();
+
+	if ((graphW < 0) || (graphH < 0))
+		return;
+
+	double minDistanceX = double(MIN_DISTANCE) / double(graphW-1);
+
+	if (curve.type == DCT_Linear || curve.type == DCT_Spline || curve.type == DCT_NURBS) {
+		// get the pointer position
+		int px = graphX + int(float(graphW)*pipetteVal);  // WARNING: converting pipetteVal from float to int, precision loss here!
+		getCursorPosition(Gdk::MOTION_NOTIFY, false, px, graphY, Gdk::ModifierType(modifierKey));
+
+		if (grab_point == -1) {
+			// there's no point currently being moved
+			int previous_lit_point = lit_point;
+			findClosestPoint();
+			if (cursorX<0 || cursorX>graphW || cursorY<0 || cursorY>graphH) {
+				// the cursor has left the graph area
+				lit_point = -1;
+			}
+			else if (distanceX <= minDistanceX) {
+				lit_point = closest_point;
+			}
+			else {
+				lit_point = -1;
+			}
+			if (lit_point != previous_lit_point) {
+				setDirty(true);
+				draw (lit_point);
+			}
+		}
+	}
+}
+
+
+void MyDiagonalCurve::pipetteButton1Pressed(EditDataProvider *provider, int modifierKey) {
+	int num = (int)curve.x.size();
+
+	/* graphW and graphH are the size of the graph */
+	calcDimensions();
+
+	double minDistanceX = double(MIN_DISTANCE) / double(graphW-1);
+
+	if ((graphW < 0) || (graphH < 0))
+		return;
+
+	snapToElmt = -100;
+	if (curve.type!=DCT_Parametric) {
+		std::vector<double>::iterator itx, ity;
+		buttonPressed = true;
+
+		// get the pointer position
+		int px = graphX + int(float(graphW)*pipetteVal);  // WARNING: converting pipetteVal from float to int, precision loss here!
+		getCursorPosition(Gdk::BUTTON_PRESS, false, px, graphY, Gdk::ModifierType(modifierKey));
+		findClosestPoint();
+
+		if (distanceX > minDistanceX) {
+			rtengine::DiagonalCurve rtCurve(getPoints(), 200);
+
+			/* insert a new control point */
+			if (num > 0) {
+				if (clampedX > curve.x.at(closest_point))
+					++closest_point;
+			}
+			itx = curve.x.begin();
+			ity = curve.y.begin();
+			for (int i=0; i<closest_point; i++) { itx++; ity++; }
+			curve.x.insert (itx, 0);
+			curve.y.insert (ity, 0);
+			num++;
+
+			// the graph is refreshed only if a new point is created (snaped to a pixel)
+			curve.x.at(closest_point) = clampedX;
+			curve.y.at(closest_point) = clampedY = rtCurve.getVal(pipetteVal);
+
+			curveIsDirty = true;
+			setDirty(true);
+			draw (closest_point);
+			notifyListener ();
+		}
+		grab_point = closest_point;
+		lit_point = closest_point;
+		ugpX = curve.x.at(closest_point);
+		ugpY = curve.y.at(closest_point);
+	}
+}
+
+void MyDiagonalCurve::pipetteButton1Released(EditDataProvider *provider) {
+	/* graphW and graphH are the size of the graph */
+	calcDimensions();
+
+	double minDistanceX = double(MIN_DISTANCE) / double(graphW-1);
+	//double minDistanceY = double(MIN_DISTANCE) / double(graphH-1);
+
+	if ((graphW < 0) || (graphH < 0))
+		return;
+
+	snapToElmt = -100;
+	if (curve.type!=DCT_Parametric) {
+		std::vector<double>::iterator itx, ity;
+		buttonPressed = false;
+		/*  get the pointer position  */
+		getCursorPosition(Gdk::EventType(Gdk::BUTTON_RELEASE), false, graphY, 0, Gdk::ModifierType(0));
+		findClosestPoint();
+
+		int previous_lit_point = lit_point;
+
+		if (distanceX <= minDistanceX) {
+			lit_point = closest_point;
+		}
+		else {
+			lit_point = -1;
+		}
+		if (lit_point != previous_lit_point) {
+			setDirty(true);
+			draw (lit_point);
+		}
+		grab_point = -1;
+		//notifyListener ();
+	}
+}
+
+void MyDiagonalCurve::pipetteDrag(EditDataProvider *provider, int modifierKey) {
+	if (curve.type==DCT_Parametric || graphW<0 || graphH<0)
+		return;
+
+	snapToMinDistY = snapToMinDistX = 10.;
+	snapToValY = snapToValX = 0.;
+	snapToElmt = -100;
+
+	/* graphW and graphH are the size of the graph */
+	calcDimensions();
+
+	getCursorPosition(Gdk::MOTION_NOTIFY, false, cursorX+graphX, graphY+provider->deltaScreen.y, Gdk::ModifierType(modifierKey));
+
+	// we memorize the previous position of the point, for optimization purpose
+	double prevPosX = curve.x.at(grab_point);
+	double prevPosY = curve.y.at(grab_point);
+
+	// we memorize the previous position of the point, for optimization purpose
+	ugpX += deltaX;
+	ugpY += deltaY;
+
+	// the unclamped grabbed point is brought back in the range
+	ugpY = CLAMP(ugpY, 0.0, 1.0);
+
+	// snapping point to specific values
+	if (snapTo && curve.x.at(grab_point) != -1.) {
+		if (grab_point > 0 && grab_point < (curve.y.size()-1)) {
+			double prevX = curve.x.at(grab_point-1);
+			double prevY = curve.y.at(grab_point-1);
+			double nextX = curve.x.at(grab_point+1);
+			double nextY = curve.y.at(grab_point+1);
+
+			double ratio = (curve.x.at(grab_point)-prevX)/(nextX-prevX);
+			double y = (nextY-prevY) * ratio + prevY;
+
+			if (snapCoordinateY(y, ugpY)) snapToElmt = 1000+grab_point;
+		}
+		if (grab_point > 0) {
+			int prevP = grab_point-1;
+			if (snapCoordinateY(curve.y.at(prevP), ugpY)) snapToElmt = prevP;
+		}
+		if (grab_point < (curve.y.size()-1)) {
+			int nextP = grab_point+1;
+			if (snapCoordinateY(curve.y.at(nextP), ugpY)) snapToElmt = nextP;
+		}
+		if (snapCoordinateY(1.0,                    ugpY)) snapToElmt = -3;
+		if (snapCoordinateY(curve.x.at(grab_point), ugpY)) snapToElmt = -2;
+		if (snapCoordinateY(0.0,                    ugpY)) snapToElmt = -1;
+
+		curve.y.at(grab_point) = snapToValY;
+	}
+	else {
+		// nextPosY is in the bounds
+		curve.y.at(grab_point) = ugpY;
+	}
+
+	if (curve.x.at(grab_point) != prevPosX || curve.y.at(grab_point) != prevPosY) {
+		// we recalculate the curve only if we have to
+		curveIsDirty = true;
+		setDirty(true);
+		draw (lit_point);
+		notifyListener ();
+	}
+}
+
+void MyDiagonalCurve::getCursorPosition(Gdk::EventType evType, bool isHint, int evX, int evY, Gdk::ModifierType modifierKey) {
 	int tx, ty;
 	int prevCursorX, prevCursorY;
 	double incrementX = 1. / double(graphW);
 	double incrementY = 1. / double(graphH);
 
 	// getting the cursor position
-	switch (event->type) {
+	switch (evType) {
 	case (Gdk::MOTION_NOTIFY) :
-		if (event->motion.is_hint) {
+		if (isHint) {
 			get_window()->get_pointer (tx, ty, mod_type);
 		}
 		else {
-			tx = int(event->button.x);
-			ty = int(event->button.y);
-			mod_type = (Gdk::ModifierType)event->button.state;
+			tx = evX;
+			ty = evY;
+			mod_type = modifierKey;
 		}
 		break;
 	case (Gdk::BUTTON_PRESS) :
 	case (Gdk::BUTTON_RELEASE) :
-		tx = int(event->button.x);
-		ty = int(event->button.y);
-		mod_type = (Gdk::ModifierType)event->button.state;
+		tx = evX;
+		ty = evY;
+		mod_type = modifierKey;
 		break;
 	default :
 		// The cursor position is not available
@@ -691,8 +959,8 @@ void MyDiagonalCurve::findClosestPoint() {
 
     if (curve.type!=DCT_Parametric) {
         for (int i = 0; i < (int)curve.x.size(); i++) {
-            double dX = curve.x[i] - clampedX;
-            double dY = curve.y[i] - clampedY;
+            double dX = curve.x.at(i) - clampedX;
+            double dY = curve.y.at(i) - clampedY;
             double currDistX = dX < 0. ? -dX : dX; //abs (dX);
             double currDistY = dY < 0. ? -dY : dY; //abs (dY);
             if (currDistX < distanceX) {
@@ -714,7 +982,7 @@ std::vector<double> MyDiagonalCurve::getPoints () {
     if (curve.type==DCT_Parametric) {
         result.push_back ((double)(DCT_Parametric));
         for (int i=0; i<(int)curve.x.size(); i++) {
-            result.push_back (curve.x[i]);
+            result.push_back (curve.x.at(i));
         }
     }
     else {
@@ -727,9 +995,9 @@ std::vector<double> MyDiagonalCurve::getPoints () {
             result.push_back (double(DCT_NURBS));
         // then we push all the points coordinate
         for (int i=0; i<(int)curve.x.size(); i++) {
-            if (curve.x[i]>=0) {
-                result.push_back (curve.x[i]);
-                result.push_back (curve.y[i]);
+            if (curve.x.at(i)>=0) {
+                result.push_back (curve.x.at(i));
+                result.push_back (curve.y.at(i));
             }
         }
     }
@@ -811,7 +1079,12 @@ void MyDiagonalCurve::updateBackgroundHistogram (LUTu & hist) {
 
 }
 
-void MyDiagonalCurve::reset(double identityValue) {
+void MyDiagonalCurve::reset(const std::vector<double> &resetCurve, double identityValue) {
+
+    if (!resetCurve.empty()) {
+        setPoints(resetCurve);
+        return;
+    }
 
     switch (curve.type) {
     case DCT_Spline :
