@@ -102,12 +102,13 @@ class MyFlatCurve : public MyCurve {
 		enum MouseOverAreas area;
 
 		void draw ();
-		void movePoint(bool moveX, bool moveY);
+		void movePoint(bool moveX, bool moveY, bool pipetteDrag=false);
 		void defaultCurve (double iVal=0.5);
 		void interpolate ();
-		void getCursorPosition(GdkEvent* event);
+		void getCursorPosition(Gdk::EventType evType, bool isHint, int evX, int evY, Gdk::ModifierType modifier);
 		void getMouseOverArea ();
 		bool getHandles(int n);
+		CursorShape motionNotify(CursorShape type, double minDistanceX, double minDistanceY, int num);
 		std::vector<double> get_vector (int veclen);
 
 	public:
@@ -118,8 +119,13 @@ class MyFlatCurve : public MyCurve {
 		void setPoints (const std::vector<double>& p);
 		void setType (FlatCurveType t);
 		bool handleEvents (GdkEvent* event);
-		void reset (double identityValue=0.5);
+		void reset (const std::vector<double> &resetCurve, double identityValue=0.5);
 		//void updateBackgroundHistogram (unsigned int* hist);
+
+		void pipetteMouseOver (EditDataProvider *provider, int modifierKey);
+		void pipetteButton1Pressed(EditDataProvider *provider, int modifierKey);
+		void pipetteButton1Released(EditDataProvider *provider);
+		void pipetteDrag(EditDataProvider *provider, int modifierKey);
 };
 
 #endif
