@@ -42,7 +42,8 @@ Glib::ustring Options::rtdir;
 Glib::ustring Options::cacheBaseDir;
 
 Options options;
-Glib::ustring versionString      = VERSION;
+Glib::ustring versionString       = VERSION;
+Glib::ustring versionSuffixString = VERSION_SUFFIX;
 Glib::ustring paramFileExtension = ".pp3";
 
 Options::Options () {
@@ -145,6 +146,8 @@ void Options::updatePaths() {
         lastRgbCurvesDir = preferredPath;
     if (lastLabCurvesDir.empty() || !safe_file_test (lastLabCurvesDir, Glib::FILE_TEST_EXISTS) || !safe_file_test (lastLabCurvesDir, Glib::FILE_TEST_IS_DIR))
         lastLabCurvesDir = preferredPath;
+    if (lastDenoiseCurvesDir.empty() || !safe_file_test (lastDenoiseCurvesDir, Glib::FILE_TEST_EXISTS) || !safe_file_test (lastDenoiseCurvesDir, Glib::FILE_TEST_IS_DIR))
+        lastDenoiseCurvesDir = preferredPath;
     if (lastPFCurvesDir.empty() || !safe_file_test (lastPFCurvesDir, Glib::FILE_TEST_EXISTS) || !safe_file_test (lastPFCurvesDir, Glib::FILE_TEST_IS_DIR))
         lastPFCurvesDir = preferredPath;
     if (lastHsvCurvesDir.empty() || !safe_file_test (lastHsvCurvesDir, Glib::FILE_TEST_EXISTS) || !safe_file_test (lastHsvCurvesDir, Glib::FILE_TEST_IS_DIR))
@@ -226,21 +229,23 @@ void Options::setDefaults () {
     font = "sans, 8";
     windowWidth = 1200;
     windowHeight = 680;
+    windowX = 0;
+    windowY = 0;
     windowMaximized = true;
     saveAsDialogWidth = 920;
     saveAsDialogHeight = 680;
     savesParamsAtExit = true;
     saveFormat.format = "jpg";
-    saveFormat.jpegQuality = 90;
+    saveFormat.jpegQuality = 92;
     saveFormat.jpegSubSamp = 2;
     saveFormat.pngCompression = 6;
     saveFormat.pngBits = 8;
-    saveFormat.tiffBits = 8;
+    saveFormat.tiffBits = 16;
     saveFormat.tiffUncompressed = true;
     saveFormat.saveParams = true;
 
     saveFormatBatch.format = "jpg";
-    saveFormatBatch.jpegQuality = 90;
+    saveFormatBatch.jpegQuality = 92;
     saveFormatBatch.jpegSubSamp = 2;
     saveFormatBatch.pngCompression = 6;
     saveFormatBatch.pngBits = 8;
@@ -258,13 +263,17 @@ void Options::setDefaults () {
     startupDir = STARTUPDIR_LAST;
     startupPath = "";
     useBundledProfiles = true;
+    detailWindowWidth = -1;
+    detailWindowHeight = -1;
     dirBrowserWidth = 260;
     dirBrowserHeight = 350;
     preferencesWidth = 800;
     preferencesHeight = 0;
-    toolPanelWidth = 390;
-    browserToolPanelWidth = 430;
+    toolPanelWidth = 400;
+    browserToolPanelWidth = 465;
     browserToolPanelHeight = 600;
+    browserToolPanelOpened = true;;
+    browserDirPanelOpened = true;
     historyPanelWidth = 330;
     lastScale = 5;
     panAccelFactor = 5;
@@ -343,14 +352,13 @@ void Options::setDefaults () {
 
     rgbDenoiseThreadLimit = 0;
 
-    filledProfile = true;
+    filledProfile = false;
 
     showProfileSelector = true;
     FileBrowserToolbarSingleRow = false;
     hideTPVScrollbar = false;
     UseIconNoText = true;
     whiteBalanceSpotSize = 8;
-    squareDetailWindow = true;
     menuGroupRank = true;
     menuGroupLabel = true;
     menuGroupFileOperations = true;
@@ -366,17 +374,18 @@ void Options::setDefaults () {
     fastexport_bypass_dirpyrDenoise      = true;
     fastexport_bypass_sh_hq              = true;
     fastexport_bypass_dirpyrequalizer    = true;
-    //fastexport_bypass_raw_all_enhance    = true;
+    fastexport_raw_bayer_method                  = "fast";
+    //fastexport_bypass_raw_bayer_all_enhance    = true;
+    fastexport_bypass_raw_bayer_dcb_iterations   = true;
+    fastexport_bypass_raw_bayer_dcb_enhance      = true;
+    fastexport_bypass_raw_bayer_lmmse_iterations = true;
+    fastexport_bypass_raw_bayer_linenoise        = true;
+    fastexport_bypass_raw_bayer_greenthresh      = true;
+    fastexport_raw_xtrans_method                 = "fast";
     fastexport_bypass_raw_ccSteps        = true;
-    fastexport_bypass_raw_dcb_iterations = true;
-    fastexport_bypass_raw_dcb_enhance    = true;
-    fastexport_bypass_raw_lmmse_iterations = true;
     fastexport_bypass_raw_ca             = true;
-    fastexport_bypass_raw_linenoise      = true;
-    fastexport_bypass_raw_greenthresh    = true;
     fastexport_bypass_raw_df             = true;
     fastexport_bypass_raw_ff             = true;
-    fastexport_raw_dmethod               = "fast";
     fastexport_icm_input                 = "(camera)";
     fastexport_icm_working               = "ProPhoto";
     fastexport_icm_output                = "RT_sRGB";
@@ -389,9 +398,18 @@ void Options::setDefaults () {
     fastexport_resize_width              = 900;
     fastexport_resize_height             = 900;
 
+    clutsDir = "./cluts";
+
     cutOverlayBrush = std::vector<double> (4);
     cutOverlayBrush[3] = 0.667;  // :-p
 
+    navGuideBrush = std::vector<double> (4);
+    //default to red
+    navGuideBrush[0] = 1.0;
+    navGuideBrush[1] = 0.0;
+    navGuideBrush[2] = 0.0;
+    navGuideBrush[3] = 1.0;
+
     sndEnable=true;
     sndLngEditProcDoneSecs=3.0;
 #ifdef __linux__
@@ -434,8 +452,6 @@ void Options::setDefaults () {
 			0,  // ADDSET_DIRPYRDN_CHROMABLUE
 			0,  // ADDSET_DIRPYRDN_GAMMA
 			0,  // ADDSET_CHMIXER
-			0,  // ADDSET_BLACKWHITE_HUES
-			0,  // ADDSET_BLACKWHITE_GAMMA
 			0,  // ADDSET_PREPROCESS_GREENEQUIL
 			0,  // ADDSET_PREPROCESS_LINEDENOISE
 			0,  // ADDSET_RAWCACORR
@@ -453,10 +469,16 @@ void Options::setDefaults () {
 			0,  // ADDSET_CAT_DEGREE
 			0,  // ADDSET_CAT_ADAPSCEN
 			0,  // ADDSET_CAT_ADAPLUM
+			0,  // ADDSET_CAT_LIGHT
+			0,  // ADDSET_CAT_RSTPRO
 			0,  // ADDSET_CAT_BADPIX
 			0,  // ADDSET_CAT_JLIGHT
 			0,  // ADDSET_CAT_CHROMA
  			0,  // ADDSET_CAT_CONTRAST
+			0,  // ADDSET_CAT_CHROMA_S
+			0,  // ADDSET_CAT_CHROMA_M
+			0,  // ADDSET_CAT_HUE
+			0,  // ADDSET_CAT_BADPIX
 			0,  // ADDSET_WB_EQUAL
 			0,  // ADDSET_GRADIENT_DEGREE
 			0,  // ADDSET_GRADIENT_FEATHER
@@ -465,7 +487,14 @@ void Options::setDefaults () {
 			0,  // ADDSET_PCVIGNETTE_STRENGTH
 			0,  // ADDSET_PCVIGNETTE_FEATHER
 			0,  // ADDSET_PCVIGNETTE_ROUNDNESS
-
+			0,  // ADDSET_BLACKWHITE_HUES
+			0,  // ADDSET_BLACKWHITE_GAMMA
+			0,  // ADDSET_DIRPYREQ_THRESHOLD
+			0,  // ADDSET_DIRPYREQ_SKINPROTECT
+			0,  // ADDSET_COLORTONING_SPLIT
+			0,	//ADDSET_DIRPYRDN_PASSES
+			0,  // ADDSET_RAWFFCLIPCONTROL
+            0,  // ADDSET_FILMSIMULATION_STRENGTH
 	};
     baBehav = std::vector<int> (babehav, babehav+ADDSET_PARAM_NUM);
     
@@ -501,12 +530,19 @@ void Options::setDefaults () {
     rtSettings.gamutICC = true;
     rtSettings.gamutLch = true;
     rtSettings.amchroma = 40;//between 20 and 140   low values increase effect..and also artefacts, high values reduces
+    rtSettings.artifact_cbdl = 4.;
+    rtSettings.level0_cbdl = 0;
+    rtSettings.level123_cbdl = 30;
 	
     rtSettings.ciecamfloat = true;
     rtSettings.protectred = 60;
     rtSettings.protectredh = 0.3;
     rtSettings.CRI_color =0;
 	rtSettings.autocielab=true;
+	rtSettings.denoiselabgamma=2;
+    rtSettings.HistogramWorking = false;
+ //   rtSettings.colortoningab =0.7;
+//rtSettings.decaction =0.3;	
 //	rtSettings.ciebadpixgauss=false;	
 	rtSettings.rgbcurveslumamode_gamut=true;
 	lastIccDir = rtSettings.iccDirectory;
@@ -520,6 +556,7 @@ void Options::setDefaults () {
 	// at the end of the "updatePaths" method.
 	lastRgbCurvesDir = "";
 	lastLabCurvesDir = "";
+	lastDenoiseCurvesDir = "";
 	lastPFCurvesDir = "";
 	lastHsvCurvesDir = "";
 	lastToneCurvesDir = "";
@@ -678,7 +715,11 @@ if (keyFile.has_group ("GUI")) {
     if (keyFile.has_key ("GUI", "Font"))            font            = keyFile.get_string  ("GUI", "Font");
     if (keyFile.has_key ("GUI", "WindowWidth"))     windowWidth     = keyFile.get_integer ("GUI", "WindowWidth");
     if (keyFile.has_key ("GUI", "WindowHeight"))    windowHeight    = keyFile.get_integer ("GUI", "WindowHeight");
+    if (keyFile.has_key ("GUI", "WindowX"))     	windowX     = keyFile.get_integer ("GUI", "WindowX");
+    if (keyFile.has_key ("GUI", "WindowY"))    		windowY    = keyFile.get_integer ("GUI", "WindowY");
     if (keyFile.has_key ("GUI", "WindowMaximized")) windowMaximized = keyFile.get_boolean ("GUI", "WindowMaximized");
+    if (keyFile.has_key ("GUI", "DetailWindowWidth"))   detailWindowWidth        = keyFile.get_integer ("GUI", "DetailWindowWidth");
+    if (keyFile.has_key ("GUI", "DetailWindowHeight"))  detailWindowHeight       = keyFile.get_integer ("GUI", "DetailWindowHeight");
     if (keyFile.has_key ("GUI", "DirBrowserWidth"))     dirBrowserWidth          = keyFile.get_integer ("GUI", "DirBrowserWidth");
     if (keyFile.has_key ("GUI", "DirBrowserHeight"))    dirBrowserHeight         = keyFile.get_integer ("GUI", "DirBrowserHeight");
     if (keyFile.has_key ("GUI", "PreferencesWidth"))    preferencesWidth         = keyFile.get_integer ("GUI", "PreferencesWidth");
@@ -686,8 +727,10 @@ if (keyFile.has_group ("GUI")) {
     if (keyFile.has_key ("GUI", "SaveAsDialogWidth"))   saveAsDialogWidth        = keyFile.get_integer ("GUI", "SaveAsDialogWidth");
     if (keyFile.has_key ("GUI", "SaveAsDialogHeight"))  saveAsDialogHeight       = keyFile.get_integer ("GUI", "SaveAsDialogHeight");
     if (keyFile.has_key ("GUI", "ToolPanelWidth"))      toolPanelWidth           = keyFile.get_integer ("GUI", "ToolPanelWidth");
-    if (keyFile.has_key ("GUI", "BrowserToolPanelWidth"))browserToolPanelWidth   = keyFile.get_integer ("GUI", "BrowserToolPanelWidth");
-    if (keyFile.has_key ("GUI", "BrowserToolPanelHeight"))browserToolPanelHeight = keyFile.get_integer ("GUI", "BrowserToolPanelHeight");
+    if (keyFile.has_key ("GUI", "BrowserToolPanelWidth"))  browserToolPanelWidth  = keyFile.get_integer ("GUI", "BrowserToolPanelWidth");
+    if (keyFile.has_key ("GUI", "BrowserToolPanelHeight")) browserToolPanelHeight = keyFile.get_integer ("GUI", "BrowserToolPanelHeight");
+    if (keyFile.has_key ("GUI", "BrowserToolPanelOpened")) browserToolPanelOpened = keyFile.get_boolean ("GUI", "BrowserToolPanelOpened");
+    if (keyFile.has_key ("GUI", "BrowserDirPanelOpened"))  browserDirPanelOpened  = keyFile.get_boolean ("GUI", "BrowserDirPanelOpened");
     if (keyFile.has_key ("GUI", "HistoryPanelWidth"))   historyPanelWidth = keyFile.get_integer ("GUI", "HistoryPanelWidth");
     if (keyFile.has_key ("GUI", "LastPreviewScale"))    lastScale         = keyFile.get_integer ("GUI", "LastPreviewScale");
     if (keyFile.has_key ("GUI", "PanAccelFactor"))      panAccelFactor    = keyFile.get_integer ("GUI", "PanAccelFactor");
@@ -704,14 +747,16 @@ if (keyFile.has_group ("GUI")) {
     if (keyFile.has_key ("GUI", "MultiDisplayMode"))    multiDisplayMode  = keyFile.get_integer ("GUI", "MultiDisplayMode");
     //if (keyFile.has_key ("GUI", "CurvePanelsExpanded")) crvOpen           = keyFile.get_integer_list ("GUI", "CurvePanelsExpanded");
     if (keyFile.has_key ("GUI", "CutOverlayBrush"))     cutOverlayBrush     = keyFile.get_double_list ("GUI", "CutOverlayBrush");
+    if (keyFile.has_key ("GUI", "NavGuideBrush"))       navGuideBrush       = keyFile.get_double_list ("GUI", "NavGuideBrush");
     if (keyFile.has_key ("GUI", "HistogramPosition"))   histogramPosition   = keyFile.get_integer ("GUI", "HistogramPosition");
     if (keyFile.has_key ("GUI", "HistogramBar"))        histogramBar        = keyFile.get_boolean ("GUI", "HistogramBar");
     if (keyFile.has_key ("GUI", "HistogramFullMode"))   histogramFullMode   = keyFile.get_boolean ("GUI", "HistogramFullMode");
     if (keyFile.has_key ("GUI", "ShowProfileSelector")) showProfileSelector = keyFile.get_boolean ("GUI", "ShowProfileSelector");
-    if (keyFile.has_key ("GUI", "SquareDetailWindow"))  squareDetailWindow  = keyFile.get_boolean ("GUI", "SquareDetailWindow");
     if (keyFile.has_key ("GUI", "FileBrowserToolbarSingleRow")) FileBrowserToolbarSingleRow = keyFile.get_boolean ("GUI", "FileBrowserToolbarSingleRow");
     if (keyFile.has_key ("GUI", "HideTPVScrollbar"))    hideTPVScrollbar    = keyFile.get_boolean ("GUI", "HideTPVScrollbar");
     if (keyFile.has_key ("GUI", "UseIconNoText"))    UseIconNoText    = keyFile.get_boolean ("GUI", "UseIconNoText");
+    if( keyFile.has_key ("GUI", "HistogramWorking"))    rtSettings.HistogramWorking          = keyFile.get_boolean("GUI", "HistogramWorking");
+	
 }
 
 if (keyFile.has_group ("Crop Settings")) { 
@@ -727,8 +772,14 @@ if (keyFile.has_group ("Color Management")) {
 
     if (keyFile.has_key ("Color Management", "Intent"))         rtSettings.colorimetricIntent   = keyFile.get_integer("Color Management", "Intent");
     if (keyFile.has_key ("Color Management", "CRI"))            rtSettings.CRI_color            = keyFile.get_integer("Color Management", "CRI");
+    if (keyFile.has_key ("Color Management", "DenoiseLabgamma"))rtSettings.denoiselabgamma       = keyFile.get_integer("Color Management", "DenoiseLabgamma");
     if (keyFile.has_key ("Color Management", "view"))           rtSettings.viewingdevice        = keyFile.get_integer("Color Management", "view");
     if (keyFile.has_key ("Color Management", "grey"))           rtSettings.viewingdevicegrey    = keyFile.get_integer("Color Management", "grey");
+    if (keyFile.has_key ("Color Management", "CBDLArtif"))      rtSettings.artifact_cbdl        = keyFile.get_double("Color Management", "CBDLArtif");
+    if (keyFile.has_key ("Color Management", "CBDLlevel0"))     rtSettings.level0_cbdl        = keyFile.get_double("Color Management", "CBDLlevel0");
+    if (keyFile.has_key ("Color Management", "CBDLlevel123"))   rtSettings.level123_cbdl        = keyFile.get_double("Color Management", "CBDLlevel123");
+ //   if (keyFile.has_key ("Color Management", "Colortoningab"))  rtSettings.colortoningab            = keyFile.get_double("Color Management", "Colortoningab");
+ //   if (keyFile.has_key ("Color Management", "Decaction"))   rtSettings.decaction        = keyFile.get_double("Color Management", "Decaction");
 
     if (keyFile.has_key ("Color Management", "WhiteBalanceSpotSize")) whiteBalanceSpotSize      = keyFile.get_integer("Color Management", "WhiteBalanceSpotSize");
     if( keyFile.has_key ("Color Management", "GamutICC"))       rtSettings.gamutICC             = keyFile.get_boolean("Color Management", "GamutICC");
@@ -747,6 +798,8 @@ if (keyFile.has_group ("Color Management")) {
     if( keyFile.has_key ("Color Management", "ProtectRed"))     rtSettings.protectred           = keyFile.get_integer("Color Management", "ProtectRed");
     if( keyFile.has_key ("Color Management", "ProtectRedH"))    rtSettings.protectredh          = keyFile.get_double("Color Management", "ProtectRedH");
     if( keyFile.has_key ("Color Management", "Amountchroma"))    rtSettings.amchroma            = keyFile.get_integer("Color Management", "Amountchroma");
+
+    if( keyFile.has_key ("Color Management", "ClutsDirectory")) clutsDir             = keyFile.get_string("Color Management", "ClutsDirectory");
 //    if( keyFile.has_key ("Color Management", "Ciebadpixgauss")) rtSettings.ciebadpixgauss       = keyFile.get_boolean("Color Management", "Ciebadpixgauss");
 
 }
@@ -766,23 +819,30 @@ if (keyFile.has_group ("Fast Export")) {
     if (keyFile.has_key ("Fast Export", "fastexport_bypass_sharpening"        ))  fastexport_bypass_sharpening          = keyFile.get_boolean ("Fast Export", "fastexport_bypass_sharpening"        );
     if (keyFile.has_key ("Fast Export", "fastexport_bypass_sharpenEdge"       ))  fastexport_bypass_sharpenEdge         = keyFile.get_boolean ("Fast Export", "fastexport_bypass_sharpenEdge"       );
     if (keyFile.has_key ("Fast Export", "fastexport_bypass_sharpenMicro"      ))  fastexport_bypass_sharpenMicro        = keyFile.get_boolean ("Fast Export", "fastexport_bypass_sharpenMicro"      );
-    //if (keyFile.has_key ("Fast Export", "fastexport_bypass_lumaDenoise"       ))  fastexport_bypass_lumaDenoise         = keyFile.get_boolean ("Fast Export", "fastexport_bypass_lumaDenoise"       );
-    //if (keyFile.has_key ("Fast Export", "fastexport_bypass_colorDenoise"      ))  fastexport_bypass_colorDenoise        = keyFile.get_boolean ("Fast Export", "fastexport_bypass_colorDenoise"      );
+    //if (keyFile.has_key ("Fast Export", "fastexport_bypass_lumaDenoise"     ))  fastexport_bypass_lumaDenoise         = keyFile.get_boolean ("Fast Export", "fastexport_bypass_lumaDenoise"       );
+    //if (keyFile.has_key ("Fast Export", "fastexport_bypass_colorDenoise"    ))  fastexport_bypass_colorDenoise        = keyFile.get_boolean ("Fast Export", "fastexport_bypass_colorDenoise"      );
     if (keyFile.has_key ("Fast Export", "fastexport_bypass_defringe"          ))  fastexport_bypass_defringe            = keyFile.get_boolean ("Fast Export", "fastexport_bypass_defringe"          );
     if (keyFile.has_key ("Fast Export", "fastexport_bypass_dirpyrDenoise"     ))  fastexport_bypass_dirpyrDenoise       = keyFile.get_boolean ("Fast Export", "fastexport_bypass_dirpyrDenoise"     );
     if (keyFile.has_key ("Fast Export", "fastexport_bypass_sh_hq"             ))  fastexport_bypass_sh_hq               = keyFile.get_boolean ("Fast Export", "fastexport_bypass_sh_hq"             );
     if (keyFile.has_key ("Fast Export", "fastexport_bypass_dirpyrequalizer"   ))  fastexport_bypass_dirpyrequalizer     = keyFile.get_boolean ("Fast Export", "fastexport_bypass_dirpyrequalizer"   );
-    //if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_all_enhance"   ))  fastexport_bypass_raw_all_enhance     = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_all_enhance"   );
+    if (keyFile.has_key ("Fast Export", "fastexport_raw_dmethod"              ))  fastexport_raw_bayer_method           = keyFile.get_string  ("Fast Export", "fastexport_raw_dmethod"              );
+    if (keyFile.has_key ("Fast Export", "fastexport_raw_bayer_method"         ))  fastexport_raw_bayer_method           = keyFile.get_string  ("Fast Export", "fastexport_raw_bayer_method"         );
+    //if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_bayer_all_enhance"   )) fastexport_bypass_raw_bayer_all_enhance       = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_all_enhance"           );
+    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_dcb_iterations"        )) fastexport_bypass_raw_bayer_dcb_iterations    = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_dcb_iterations"        );
+    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_bayer_dcb_iterations"  )) fastexport_bypass_raw_bayer_dcb_iterations    = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_bayer_dcb_iterations"  );
+    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_dcb_enhance"           )) fastexport_bypass_raw_bayer_dcb_enhance       = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_dcb_enhance"           );
+    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_bayer_dcb_enhance"     )) fastexport_bypass_raw_bayer_dcb_enhance       = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_bayer_dcb_enhance"     );
+    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_lmmse_iterations"      )) fastexport_bypass_raw_bayer_lmmse_iterations  = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_lmmse_iterations"      );
+    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_bayer_lmmse_iterations")) fastexport_bypass_raw_bayer_lmmse_iterations  = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_bayer_lmmse_iterations");
+    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_linenoise"             )) fastexport_bypass_raw_bayer_linenoise         = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_linenoise"             );
+    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_bayer_linenoise"       )) fastexport_bypass_raw_bayer_linenoise         = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_bayer_linenoise"       );
+    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_greenthresh"           )) fastexport_bypass_raw_bayer_greenthresh       = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_greenthresh"           );
+    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_bayer_greenthresh"     )) fastexport_bypass_raw_bayer_greenthresh       = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_bayer_greenthresh"     );
+    if (keyFile.has_key ("Fast Export", "fastexport_raw_xtrans_method"        ))  fastexport_raw_xtrans_method          = keyFile.get_string  ("Fast Export", "fastexport_raw_xtrans_method"        );
     if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_ccSteps"       ))  fastexport_bypass_raw_ccSteps         = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_ccSteps"       );
-    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_dcb_iterations"))  fastexport_bypass_raw_dcb_iterations  = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_dcb_iterations");
-    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_dcb_enhance"   ))  fastexport_bypass_raw_dcb_enhance     = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_dcb_enhance"   );
-    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_lmmse_iterations"))  fastexport_bypass_raw_lmmse_iterations  = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_lmmse_iterations");
     if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_ca"            ))  fastexport_bypass_raw_ca              = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_ca"            );
-    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_linenoise"     ))  fastexport_bypass_raw_linenoise       = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_linenoise"     );
-    if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_greenthresh"   ))  fastexport_bypass_raw_greenthresh     = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_greenthresh"   );
     if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_df"            ))  fastexport_bypass_raw_df              = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_df"            );
     if (keyFile.has_key ("Fast Export", "fastexport_bypass_raw_ff"            ))  fastexport_bypass_raw_ff              = keyFile.get_boolean ("Fast Export", "fastexport_bypass_raw_ff"            );
-    if (keyFile.has_key ("Fast Export", "fastexport_raw_dmethod"              ))  fastexport_raw_dmethod                = keyFile.get_string  ("Fast Export", "fastexport_raw_dmethod"              );
     if (keyFile.has_key ("Fast Export", "fastexport_icm_input"                ))  fastexport_icm_input                  = keyFile.get_string  ("Fast Export", "fastexport_icm_input"                );
     if (keyFile.has_key ("Fast Export", "fastexport_icm_working"              ))  fastexport_icm_working                = keyFile.get_string  ("Fast Export", "fastexport_icm_working"              );
     if (keyFile.has_key ("Fast Export", "fastexport_icm_output"               ))  fastexport_icm_output                 = keyFile.get_string  ("Fast Export", "fastexport_icm_output"               );
@@ -802,6 +862,7 @@ if (keyFile.has_group ("Dialogs")) {
     safeDirGet(keyFile, "Dialogs", "LastFlatfieldDir", lastFlatfieldDir);
     safeDirGet(keyFile, "Dialogs", "LastRgbCurvesDir", lastRgbCurvesDir);
     safeDirGet(keyFile, "Dialogs", "LastLabCurvesDir", lastLabCurvesDir);
+    safeDirGet(keyFile, "Dialogs", "LastDenoiseCurvesDir", lastDenoiseCurvesDir);
     safeDirGet(keyFile, "Dialogs", "LastPFCurvesDir", lastPFCurvesDir);
     safeDirGet(keyFile, "Dialogs", "LastHsvCurvesDir", lastHsvCurvesDir);
     safeDirGet(keyFile, "Dialogs", "LastBWCurvesDir", lastBWCurvesDir);
@@ -959,7 +1020,11 @@ int Options::saveToFile (Glib::ustring fname) {
     keyFile.set_string  ("GUI", "Font", font);
     keyFile.set_integer ("GUI", "WindowWidth", windowWidth);
     keyFile.set_integer ("GUI", "WindowHeight", windowHeight);
+    keyFile.set_integer ("GUI", "WindowX", windowX);
+    keyFile.set_integer ("GUI", "WindowY", windowY);
     keyFile.set_boolean ("GUI", "WindowMaximized", windowMaximized);
+    keyFile.set_integer ("GUI", "DetailWindowWidth", detailWindowWidth);
+    keyFile.set_integer ("GUI", "DetailWindowHeight", detailWindowHeight);
     keyFile.set_integer ("GUI", "DirBrowserWidth", dirBrowserWidth);
     keyFile.set_integer ("GUI", "DirBrowserHeight", dirBrowserHeight);
     keyFile.set_integer ("GUI", "PreferencesWidth", preferencesWidth);
@@ -969,6 +1034,8 @@ int Options::saveToFile (Glib::ustring fname) {
     keyFile.set_integer ("GUI", "ToolPanelWidth", toolPanelWidth);
     keyFile.set_integer ("GUI", "BrowserToolPanelWidth", browserToolPanelWidth);
     keyFile.set_integer ("GUI", "BrowserToolPanelHeight", browserToolPanelHeight);
+    keyFile.set_boolean ("GUI", "BrowserToolPanelOpened", browserToolPanelOpened);
+    keyFile.set_boolean ("GUI", "BrowserDirPanelOpened", browserDirPanelOpened);
     keyFile.set_integer ("GUI", "HistoryPanelWidth", historyPanelWidth);
     keyFile.set_integer ("GUI", "LastPreviewScale", lastScale);
     keyFile.set_integer ("GUI", "PanAccelFactor", panAccelFactor);
@@ -985,14 +1052,15 @@ int Options::saveToFile (Glib::ustring fname) {
     keyFile.set_integer_list ("GUI", "ToolPanelsExpanded", tpopen);
     keyFile.set_integer ("GUI", "MultiDisplayMode", multiDisplayMode);
     keyFile.set_double_list ("GUI", "CutOverlayBrush", cutOverlayBrush);
+    keyFile.set_double_list ("GUI", "NavGuideBrush", navGuideBrush);
     keyFile.set_integer ("GUI", "HistogramPosition", histogramPosition);
     keyFile.set_boolean ("GUI", "HistogramBar", histogramBar);
     keyFile.set_boolean ("GUI", "HistogramFullMode", histogramFullMode);
     keyFile.set_boolean ("GUI", "ShowProfileSelector", showProfileSelector);
-    keyFile.set_boolean ("GUI", "SquareDetailWindow", squareDetailWindow);
     keyFile.set_boolean ("GUI", "FileBrowserToolbarSingleRow", FileBrowserToolbarSingleRow);
     keyFile.set_boolean ("GUI", "HideTPVScrollbar", hideTPVScrollbar);
     keyFile.set_boolean ("GUI", "UseIconNoText", UseIconNoText);
+    keyFile.set_boolean ("GUI", "HistogramWorking", rtSettings.HistogramWorking);
 
     //Glib::ArrayHandle<int> crvopen = crvOpen;
     //keyFile.set_integer_list ("GUI", "CurvePanelsExpanded", crvopen);
@@ -1026,7 +1094,15 @@ int Options::saveToFile (Glib::ustring fname) {
     keyFile.set_integer ("Color Management", "Amountchroma", rtSettings.amchroma);
     keyFile.set_double  ("Color Management", "ProtectRedH", rtSettings.protectredh);
     keyFile.set_integer ("Color Management", "CRI", rtSettings.CRI_color);
+    keyFile.set_integer ("Color Management", "DenoiseLabgamma", rtSettings.denoiselabgamma);
 //    keyFile.set_boolean ("Color Management", "Ciebadpixgauss", rtSettings.ciebadpixgauss);
+    keyFile.set_double ("Color Management", "CBDLArtif", rtSettings.artifact_cbdl);
+    keyFile.set_double ("Color Management", "CBDLlevel0", rtSettings.level0_cbdl);
+    keyFile.set_double ("Color Management", "CBDLlevel123", rtSettings.level123_cbdl);
+ //   keyFile.set_double ("Color Management", "Colortoningab", rtSettings.colortoningab);
+//    keyFile.set_double ("Color Management", "Decaction", rtSettings.decaction);
+    keyFile.set_string ("Color Management", "ClutsDirectory", clutsDir);
+
 
     Glib::ArrayHandle<int> bab = baBehav;
     keyFile.set_integer_list ("Batch Processing", "AdjusterBehavior", bab);
@@ -1040,23 +1116,24 @@ int Options::saveToFile (Glib::ustring fname) {
     keyFile.set_boolean ("Fast Export", "fastexport_bypass_sharpening"         , fastexport_bypass_sharpening        );
     keyFile.set_boolean ("Fast Export", "fastexport_bypass_sharpenEdge"        , fastexport_bypass_sharpenEdge       );
     keyFile.set_boolean ("Fast Export", "fastexport_bypass_sharpenMicro"       , fastexport_bypass_sharpenMicro      );
-    //keyFile.set_boolean ("Fast Export", "fastexport_bypass_lumaDenoise"        , fastexport_bypass_lumaDenoise       );
-    //keyFile.set_boolean ("Fast Export", "fastexport_bypass_colorDenoise"       , fastexport_bypass_colorDenoise      );
+    //keyFile.set_boolean ("Fast Export", "fastexport_bypass_lumaDenoise"      , fastexport_bypass_lumaDenoise       );
+    //keyFile.set_boolean ("Fast Export", "fastexport_bypass_colorDenoise"     , fastexport_bypass_colorDenoise      );
     keyFile.set_boolean ("Fast Export", "fastexport_bypass_defringe"           , fastexport_bypass_defringe          );
     keyFile.set_boolean ("Fast Export", "fastexport_bypass_dirpyrDenoise"      , fastexport_bypass_dirpyrDenoise     );
     keyFile.set_boolean ("Fast Export", "fastexport_bypass_sh_hq"              , fastexport_bypass_sh_hq             );
     keyFile.set_boolean ("Fast Export", "fastexport_bypass_dirpyrequalizer"    , fastexport_bypass_dirpyrequalizer   );
-    //keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_all_enhance"    , fastexport_bypass_raw_all_enhance   );
+    keyFile.set_string  ("Fast Export", "fastexport_raw_bayer_method"          , fastexport_raw_bayer_method         );
+    //keyFile.set_boolean ("Fast Export", "fastexport_bypass_bayer_raw_all_enhance"   , fastexport_bypass_raw_bayer_all_enhance     );
+    keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_bayer_dcb_iterations"  , fastexport_bypass_raw_bayer_dcb_iterations  );
+    keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_bayer_dcb_enhance"     , fastexport_bypass_raw_bayer_dcb_enhance     );
+    keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_bayer_lmmse_iterations", fastexport_bypass_raw_bayer_lmmse_iterations);
+    keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_bayer_linenoise"       , fastexport_bypass_raw_bayer_linenoise       );
+    keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_bayer_greenthresh"     , fastexport_bypass_raw_bayer_greenthresh     );
+    keyFile.set_string  ("Fast Export", "fastexport_raw_xtrans_method"         , fastexport_raw_xtrans_method        );
     keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_ccSteps"        , fastexport_bypass_raw_ccSteps       );
-    keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_dcb_iterations" , fastexport_bypass_raw_dcb_iterations);
-    keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_dcb_enhance"    , fastexport_bypass_raw_dcb_enhance   );
-    keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_lmmse_iterations" , fastexport_bypass_raw_lmmse_iterations);
-	keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_ca"             , fastexport_bypass_raw_ca            );
-    keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_linenoise"      , fastexport_bypass_raw_linenoise     );
-    keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_greenthresh"    , fastexport_bypass_raw_greenthresh   );
+    keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_ca"             , fastexport_bypass_raw_ca            );
     keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_df"             , fastexport_bypass_raw_df            );
     keyFile.set_boolean ("Fast Export", "fastexport_bypass_raw_ff"             , fastexport_bypass_raw_ff            );
-    keyFile.set_string  ("Fast Export", "fastexport_raw_dmethod"               , fastexport_raw_dmethod              );
     keyFile.set_string  ("Fast Export", "fastexport_icm_input"                 , fastexport_icm_input                );
     keyFile.set_string  ("Fast Export", "fastexport_icm_working"               , fastexport_icm_working              );
     keyFile.set_string  ("Fast Export", "fastexport_icm_output"                , fastexport_icm_output               );
@@ -1074,6 +1151,7 @@ int Options::saveToFile (Glib::ustring fname) {
     keyFile.set_string ("Dialogs", "LastFlatfieldDir", lastFlatfieldDir);
     keyFile.set_string ("Dialogs", "LastRgbCurvesDir", lastRgbCurvesDir);
     keyFile.set_string ("Dialogs", "LastLabCurvesDir", lastLabCurvesDir);
+    keyFile.set_string ("Dialogs", "LastDenoiseCurvesDir", lastDenoiseCurvesDir);
     keyFile.set_string ("Dialogs", "LastPFCurvesDir", lastPFCurvesDir);
     keyFile.set_string ("Dialogs", "LastHsvCurvesDir", lastHsvCurvesDir);
     keyFile.set_string ("Dialogs", "LastBWCurvesDir", lastBWCurvesDir);
@@ -1094,28 +1172,34 @@ int Options::saveToFile (Glib::ustring fname) {
     }
 }
 
-void Options::load () {
+bool Options::load () {
 
-	// Find the application data path
+    // Find the application data path
 
-#ifdef WIN32
-	const gchar* dataPath;
-	Glib::ustring dPath;
+    const gchar* path;
+    Glib::ustring dPath;
 
-	dataPath = g_getenv("RT_CACHE");
-	if (dataPath != NULL)
-		rtdir = Glib::ustring(dataPath);
-	else {
+    path = g_getenv("RT_SETTINGS");
+    if (path != NULL) {
+        rtdir = Glib::ustring(path);
+        if (!Glib::path_is_absolute(rtdir))
+            return false;
+    }
+    else {
+        #ifdef WIN32
         WCHAR pathW[MAX_PATH]={0}; char pathA[MAX_PATH];
 
         if (SHGetSpecialFolderPathW(NULL,pathW,CSIDL_LOCAL_APPDATA,false)) {
             WideCharToMultiByte(CP_UTF8,0,pathW,-1,pathA,MAX_PATH,0,0);
             rtdir = Glib::build_filename(Glib::ustring(pathA), Glib::ustring(CACHEFOLDERNAME));
-		}
-	}
-#else
-    rtdir = Glib::build_filename(Glib::ustring(g_get_user_config_dir ()), Glib::ustring(CACHEFOLDERNAME));
-#endif
+        }
+        #else
+        rtdir = Glib::build_filename(Glib::ustring(g_get_user_config_dir ()), Glib::ustring(CACHEFOLDERNAME));
+        #endif
+    }
+
+    if (options.rtSettings.verbose)
+        printf("Settings directory (rtdir) = %s\n", rtdir.c_str());
 
     // Set the cache folder in RT's base folder
     cacheBaseDir = Glib::build_filename(argv0, "cache");
@@ -1123,6 +1207,22 @@ void Options::load () {
     // Read the global option file (the one located in the application's base folder)
     options.readFromFile (Glib::build_filename(argv0, "options"));
 
+    // Modify the path of the cache folder to the one provided in RT_CACHE environment variable
+    path = g_getenv("RT_CACHE");
+    if (path != NULL) {
+        cacheBaseDir = Glib::ustring(path);
+        if (!Glib::path_is_absolute(cacheBaseDir))
+            return false;
+    }
+    // No environment variable provided, so falling back to the multi user mode, is enabled
+    else if (options.multiUser) {
+        #ifdef WIN32
+        cacheBaseDir = Glib::build_filename(rtdir, "cache");
+        #else
+        cacheBaseDir = Glib::build_filename(Glib::ustring(g_get_user_cache_dir()), Glib::ustring(CACHEFOLDERNAME));
+        #endif
+    }
+
     // Check if RT is installed in Multi-User mode
     if (options.multiUser) {
         // Read the user option file (the one located somewhere in the user's home folder)
@@ -1133,12 +1233,6 @@ void Options::load () {
             // Save the option file
             options.saveToFile (Glib::build_filename(rtdir, "options"));
         }
-        // Modify the path of the cache folder to the user's personal folder
-#ifdef WIN32
-        cacheBaseDir = Glib::build_filename(rtdir, "cache");
-#else
-        cacheBaseDir = Glib::build_filename(Glib::ustring(g_get_user_cache_dir()), Glib::ustring(CACHEFOLDERNAME));
-#endif
 
 #ifdef __APPLE__
         // make sure .local/share exists on OS X so we don't get problems with recently-used.xbel
@@ -1146,6 +1240,9 @@ void Options::load () {
 #endif
     }
 
+    if (options.rtSettings.verbose)
+        printf("Cache directory (cacheBaseDir) = %s\n", cacheBaseDir.c_str());
+
     // Update profile's path and recreate it if necessary
     options.updatePaths();
 
@@ -1212,6 +1309,8 @@ void Options::load () {
 	langMgr.load(localeTranslation, new MultiLangMgr(languageTranslation, new MultiLangMgr(defaultTranslation)));
 
 	rtengine::init (&options.rtSettings, argv0, rtdir);
+
+	return true;
 }
 
 void Options::save () {
