@@ -49,6 +49,7 @@ class SaveFormat {
         int tiffBits;
         bool tiffUncompressed;
         bool saveParams;
+        SaveFormat () : format("jpg"), jpegQuality(90), jpegSubSamp(2), pngCompression(6), pngBits(8), tiffBits(8), tiffUncompressed(true), saveParams(true) {};
 };
 
 enum ThFileType {FT_Invalid=-1, FT_None=0, FT_Raw=1, FT_Jpeg=2, FT_Tiff=3, FT_Png=4, FT_Custom=5, FT_Tiff16=6, FT_Png16=7, FT_Custom16=8}; 
@@ -106,11 +107,17 @@ class Options {
     int toolPanelWidth;
     int browserToolPanelWidth;
     int browserToolPanelHeight;
+    bool browserToolPanelOpened;
+    bool browserDirPanelOpened;
     int historyPanelWidth;
     Glib::ustring font;
     int windowWidth;
     int windowHeight;
+    int windowX;
+    int windowY;
     bool windowMaximized;
+    int detailWindowWidth;
+    int detailWindowHeight;
     int dirBrowserWidth;
     int dirBrowserHeight;
     int preferencesWidth;
@@ -185,6 +192,7 @@ class Options {
     int previewSizeTab,previewSizeBrowser;
     int multiDisplayMode;  // 0=none, 1=Edit panels on other display
     std::vector<double> cutOverlayBrush;  // Red;Green;Blue;Alpha , all ranging 0..1
+    std::vector<double> navGuideBrush;  // Red;Green;Blue;Alpha , all ranging 0..1
     
     Glib::ustring sndBatchQueueDone;
     Glib::ustring sndLngEditProcDone;
@@ -193,15 +201,17 @@ class Options {
 
     bool tunnelMetaData;    // Pass through IPTC and XMP unchanged
     int histogramPosition;  // 0=disabled, 1=left pane, 2=right pane
+//    int histogramWorking;  // 0=disabled, 1=left pane, 2=right pane
     bool histogramBar;
     bool histogramFullMode;
     bool showProfileSelector;
-    bool squareDetailWindow;
     bool FileBrowserToolbarSingleRow;
     bool hideTPVScrollbar;
     bool UseIconNoText;
     int whiteBalanceSpotSize;
 
+    Glib::ustring clutsDir;
+
     // Performance options
     int rgbDenoiseThreadLimit; // maximum number of threads for the denoising tool ; 0 = use the maximum available
 
@@ -223,17 +233,18 @@ class Options {
     bool fastexport_bypass_dirpyrDenoise;
     bool fastexport_bypass_sh_hq;
     bool fastexport_bypass_dirpyrequalizer;
-    //bool fastexport_bypass_raw_all_enhance;
+    Glib::ustring fastexport_raw_bayer_method;
+    //bool fastexport_bypass_raw_bayer_all_enhance;
+    bool fastexport_bypass_raw_bayer_dcb_iterations;
+    bool fastexport_bypass_raw_bayer_dcb_enhance;
+    bool fastexport_bypass_raw_bayer_lmmse_iterations;
+    bool fastexport_bypass_raw_bayer_linenoise;
+    bool fastexport_bypass_raw_bayer_greenthresh;
+    Glib::ustring fastexport_raw_xtrans_method;
     bool fastexport_bypass_raw_ccSteps;
-    bool fastexport_bypass_raw_dcb_iterations;
-    bool fastexport_bypass_raw_dcb_enhance;
-    bool fastexport_bypass_raw_lmmse_iterations;
     bool fastexport_bypass_raw_ca;
-    bool fastexport_bypass_raw_linenoise;
-    bool fastexport_bypass_raw_greenthresh;
     bool fastexport_bypass_raw_df;
     bool fastexport_bypass_raw_ff;
-    Glib::ustring fastexport_raw_dmethod;
     Glib::ustring fastexport_icm_input;
     Glib::ustring fastexport_icm_working;
     Glib::ustring fastexport_icm_output;
@@ -252,9 +263,11 @@ class Options {
     Glib::ustring lastFlatfieldDir;
     Glib::ustring lastRgbCurvesDir;
     Glib::ustring lastLabCurvesDir;
+    Glib::ustring lastDenoiseCurvesDir;
     Glib::ustring lastPFCurvesDir;
     Glib::ustring lastHsvCurvesDir;
     Glib::ustring lastToneCurvesDir;
+    Glib::ustring lastColorToningCurvesDir;
     Glib::ustring lastVibranceCurvesDir;
     Glib::ustring lastProfilingReferenceDir;
     Glib::ustring lastBWCurvesDir;
@@ -266,7 +279,7 @@ class Options {
     void        setDefaults     ();
     int         readFromFile    (Glib::ustring fname);
     int         saveToFile      (Glib::ustring fname);
-    static void load            ();
+    static bool load            ();
     static void save            ();
 
     // if multiUser=false, send back the global profile path
@@ -287,6 +300,7 @@ extern Glib::ustring argv0;
 extern Glib::ustring argv1;
 extern bool simpleEditor;
 extern Glib::ustring versionString;
+extern Glib::ustring versionSuffixString;
 extern Glib::ustring paramFileExtension;
 
 #endif
