@@ -51,7 +51,6 @@ class ToneCurveParamsEdited {
         bool expcomp;
         bool hrenabled;
         bool method;
-		
 };
 
 class LCurveParamsEdited {
@@ -72,10 +71,9 @@ class LCurveParamsEdited {
         bool hhcurve;
         bool lccurve;
         bool clcurve;
-		
+
         bool enabled;
         bool method;
-		
 };
 
 class RGBCurvesParamsEdited {
@@ -87,6 +85,37 @@ class RGBCurvesParamsEdited {
         bool bcurve;
 };
 
+class ColorToningEdited {
+
+    public:
+        bool enabled;
+        bool opacityCurve;
+        bool colorCurve;
+        bool clcurve;
+        bool method;
+        bool autosat;
+        bool satprotectionthreshold;
+        bool saturatedopacity;
+        bool strength;
+        bool shadowsColSat;
+        bool hlColSat;
+        bool balance;
+        bool twocolor;
+        bool cl2curve;
+        bool redlow;
+        bool greenlow;
+        bool bluelow;
+        bool redmed;
+        bool greenmed;
+        bool bluemed;
+        bool redhigh;
+        bool greenhigh;
+        bool bluehigh;
+        bool satlow;
+        bool sathigh;
+        bool lumamode;
+};
+
 class SharpenEdgeParamsEdited {
 
     public :
@@ -234,23 +263,32 @@ class DirPyrDenoiseParamsEdited {
 public:
     bool enabled;
     bool enhance;
+	bool median;
     bool Ldetail;
     bool luma;
     bool chroma;
     bool redchro;
     bool bluechro;
     bool gamma;
+    bool lcurve;
+	
 //    bool perform;
 	bool dmethod;
+	bool smethod;
+    bool medmethod;
+    bool methodmed;
+    bool rgbmethod;
+    bool passes;
+	
 };
 
 class EPDParamsEdited{
 public:
     bool enabled;
-    bool Strength;
-    bool EdgeStopping;
-    bool Scale;
-    bool ReweightingIterates;
+    bool strength;
+    bool edgeStopping;
+    bool scale;
+    bool reweightingIterates;
 };
 
 
@@ -384,6 +422,8 @@ class BlackWhiteParamsEdited {
         bool afterCurve;
         bool afterCurveMode;
         bool autoc;
+		bool algo;
+		
 };
 
 class CACorrParamsEdited {
@@ -432,8 +472,12 @@ class DirPyrEqualizerParamsEdited {
 
     public:
         bool enabled;
+        bool gamutlab;
         bool mult[5];
         bool threshold;
+        bool skinprotect;
+        bool hueskin;
+   //     bool algo;
 };
 
 class HSVEqualizerParamsEdited {
@@ -444,35 +488,67 @@ class HSVEqualizerParamsEdited {
         bool vcurve;
 };
 
+class FilmSimulationParamsEdited {
+public:
+    bool enabled;
+    bool clutFilename;
+    bool strength;
+};
+
 class RAWParamsEdited {
 
     public:
-        bool ccSteps;
-        bool dmethod;
-        bool dcbIterations;
-        bool dcbEnhance;
-        bool lmmseIterations;
-        //bool allEnhance;
+        class BayerSensor {
+
+            public:
+                bool method;
+                bool ccSteps;
+                bool exBlack0;
+                bool exBlack1;
+                bool exBlack2;
+                bool exBlack3;
+                bool exTwoGreen;
+                bool dcbIterations;
+                bool dcbEnhance;
+                bool lmmseIterations;
+                //bool allEnhance;
+                bool greenEq;
+                bool linenoise;
+
+                bool isUnchanged() const;
+        };
+
+        class XTransSensor {
+
+            public:
+                bool method;
+                bool ccSteps;
+                bool exBlackRed;
+                bool exBlackGreen;
+                bool exBlackBlue;
+
+                bool isUnchanged() const;
+        };
+
+        BayerSensor bayersensor;
+        XTransSensor xtranssensor;
+
         bool caCorrection;
         bool caRed;
         bool caBlue;
-        bool greenEq;
-        bool hotDeadPixelFilter;
+        bool hotPixelFilter;
+        bool deadPixelFilter;
         bool hotDeadPixelThresh;
-        bool linenoise;
         bool darkFrame;
         bool dfAuto;
         bool ff_file;
         bool ff_AutoSelect;
         bool ff_BlurRadius;
         bool ff_BlurType;
+        bool ff_AutoClipControl;
+        bool ff_clipControl;
         bool exPos;
         bool exPreser;
-        bool exBlackzero;
-        bool exBlackone;
-        bool exBlacktwo;
-        bool exBlackthree;
-        bool exTwoGreen;
 
         bool isUnchanged() const;
 };
@@ -484,6 +560,7 @@ class ParamsEdited {
         ToneCurveParamsEdited         toneCurve;
         LCurveParamsEdited            labCurve;
         RGBCurvesParamsEdited         rgbCurves;
+        ColorToningEdited             colorToning;
         SharpeningParamsEdited        sharpening;
         SharpenEdgeParamsEdited       sharpenEdge;
         SharpenMicroParamsEdited      sharpenMicro;
@@ -496,7 +573,7 @@ class ParamsEdited {
         //ColorDenoiseParamsEdited      colorDenoise;
         DefringeParamsEdited          defringe;
         DirPyrDenoiseParamsEdited     dirpyrDenoise;
-        EPDParamsEdited               edgePreservingDecompositionUI;
+        EPDParamsEdited               epd;
         ImpulseDenoiseParamsEdited    impulseDenoise;
         SHParamsEdited                sh;
         CropParamsEdited              crop;
@@ -517,6 +594,7 @@ class ParamsEdited {
         RAWParamsEdited               raw;
         DirPyrEqualizerParamsEdited   dirpyrequalizer;
         HSVEqualizerParamsEdited      hsvequalizer;
+        FilmSimulationParamsEdited    filmSimulation;
         bool                          exif;
         bool                          iptc;
 
