@@ -46,9 +46,10 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
     // options in basic:
     wb          = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_WHITEBALANCE")));
     exposure    = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_EXPOSURE")));
-    hlrec       = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_HLRECONSTRUCTION")));
     sh          = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_SHADOWSHIGHLIGHTS")));
     epd         = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_EPD")));
+    pcvignette  = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_PCVIGNETTE")));
+    gradient    = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_GRADIENT")));
     labcurve    = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_LABCURVE")));
     colorappearance= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_COLORAPP")));
     // options in detail:
@@ -62,9 +63,12 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
     // options in color:
     vibrance    = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_VIBRANCE")));
     chmixer     = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_CHANNELMIXER")));
+    blackwhite   = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_CHANNELMIXERBW")));
     dirpyrden   = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_DIRPYRDENOISE")));
     hsveq		= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_HSVEQUALIZER")));
+    filmSimulation = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_FILMSIMULATION")) );
 	rgbcurves   = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RGBCURVES")));
+	colortoning = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_COLORTONING")));
 
     // options in lens:
     distortion  = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_DISTORTION")));
@@ -87,28 +91,30 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
     gam         = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_ICMGAMMA")));
 
     // options in raw:
-    raw_expos			= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWEXPOS_LINEAR")));
-    raw_preser			= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWEXPOS_PRESER")));
-    raw_black			= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWEXPOS_BLACK")));
-    raw_ca_autocorrect	= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWCACORR_AUTO")));
-    raw_cared			= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWCACORR_CARED")));
-    raw_cablue			= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWCACORR_CABLUE")));
-    raw_hotdeadpix_filt	= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_PREPROCESS_HOTDEADPIXFILT")));
-    raw_linenoise		= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_PREPROCESS_LINEDENOISE")));
-    raw_greenthresh		= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_PREPROCESS_GREENEQUIL")));
-    raw_dmethod			= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAW_DMETHOD")));
-    raw_ccSteps			= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAW_FALSECOLOR")));
-    raw_dcb_iterations	= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAW_DCBITERATIONS")));
-    raw_dcb_enhance		= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAW_DCBENHANCE")));
-    //raw_all_enhance		= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAW_ALLENHANCE")));
+    raw_expos           = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWEXPOS_LINEAR")));
+    raw_preser          = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWEXPOS_PRESER")));
+    raw_black           = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWEXPOS_BLACK")));
+    raw_ca_autocorrect  = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWCACORR_AUTO")));
+    raw_cared           = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWCACORR_CARED")));
+    raw_cablue          = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAWCACORR_CABLUE")));
+    raw_hotpix_filt     = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_PREPROCESS_HOTPIXFILT")));
+    raw_deadpix_filt    = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_PREPROCESS_DEADPIXFILT")));
+    raw_linenoise       = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_PREPROCESS_LINEDENOISE")));
+    raw_greenthresh     = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_PREPROCESS_GREENEQUIL")));
+    raw_method          = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAW_DMETHOD")));
+    raw_ccSteps         = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAW_FALSECOLOR")));
+    raw_dcb_iterations  = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAW_DCBITERATIONS")));
+    raw_dcb_enhance     = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAW_DCBENHANCE")));
+    //raw_all_enhance   = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAW_ALLENHANCE")));
     raw_lmmse_iterations= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_RAW_LMMSEITERATIONS")));
 
-	df_file        		= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_DARKFRAMEFILE")));
-	df_AutoSelect  		= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_DARKFRAMEAUTOSELECT")));
-	ff_file        		= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_FLATFIELDFILE")));
-	ff_AutoSelect  		= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_FLATFIELDAUTOSELECT")));
-	ff_BlurRadius  		= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_FLATFIELDBLURRADIUS")));
-	ff_BlurType    		= Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_FLATFIELDBLURTYPE")));
+    df_file             = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_DARKFRAMEFILE")));
+    df_AutoSelect       = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_DARKFRAMEAUTOSELECT")));
+    ff_file             = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_FLATFIELDFILE")));
+    ff_AutoSelect       = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_FLATFIELDAUTOSELECT")));
+    ff_BlurRadius       = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_FLATFIELDBLURRADIUS")));
+    ff_BlurType         = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_FLATFIELDBLURTYPE")));
+    ff_ClipControl      = Gtk::manage (new Gtk::CheckButton (M("PARTIALPASTE_FLATFIELDCLIPCONTROL")));
 
     Gtk::VBox* vboxes[7];
     Gtk::HSeparator* hseps[7];
@@ -123,9 +129,10 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
     vboxes[0]->pack_start (*hseps[0], Gtk::PACK_SHRINK, 2);
     vboxes[0]->pack_start (*wb, Gtk::PACK_SHRINK, 2);
     vboxes[0]->pack_start (*exposure, Gtk::PACK_SHRINK, 2);
-    vboxes[0]->pack_start (*hlrec, Gtk::PACK_SHRINK, 2);
     vboxes[0]->pack_start (*sh, Gtk::PACK_SHRINK, 2);
     vboxes[0]->pack_start (*epd, Gtk::PACK_SHRINK, 2);
+    vboxes[0]->pack_start (*pcvignette, Gtk::PACK_SHRINK, 2);
+    vboxes[0]->pack_start (*gradient, Gtk::PACK_SHRINK, 2);
     vboxes[0]->pack_start (*labcurve, Gtk::PACK_SHRINK, 2);
     vboxes[0]->pack_start (*colorappearance, Gtk::PACK_SHRINK, 2);
 
@@ -144,8 +151,11 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
     vboxes[2]->pack_start (*hseps[2], Gtk::PACK_SHRINK, 2);
     vboxes[2]->pack_start (*vibrance, Gtk::PACK_SHRINK, 2);
     vboxes[2]->pack_start (*chmixer, Gtk::PACK_SHRINK, 2);
+    vboxes[2]->pack_start (*blackwhite, Gtk::PACK_SHRINK, 2);
     vboxes[2]->pack_start (*hsveq, Gtk::PACK_SHRINK, 2);
+    vboxes[2]->pack_start (*filmSimulation, Gtk::PACK_SHRINK, 2);
     vboxes[2]->pack_start (*rgbcurves, Gtk::PACK_SHRINK, 2);
+    vboxes[2]->pack_start (*colortoning, Gtk::PACK_SHRINK, 2);
 
     vboxes[3]->pack_start (*lens, Gtk::PACK_SHRINK, 2);
     vboxes[3]->pack_start (*hseps[3], Gtk::PACK_SHRINK, 2);
@@ -172,7 +182,7 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
 
     vboxes[6]->pack_start (*raw, Gtk::PACK_SHRINK, 2);
 	vboxes[6]->pack_start (*hseps[6], Gtk::PACK_SHRINK, 2);
-	vboxes[6]->pack_start (*raw_dmethod, Gtk::PACK_SHRINK, 2);
+	vboxes[6]->pack_start (*raw_method, Gtk::PACK_SHRINK, 2);
 	vboxes[6]->pack_start (*raw_ccSteps, Gtk::PACK_SHRINK, 2);
 	vboxes[6]->pack_start (*raw_dcb_iterations, Gtk::PACK_SHRINK, 2);
 	vboxes[6]->pack_start (*raw_dcb_enhance, Gtk::PACK_SHRINK, 2);
@@ -181,7 +191,8 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
 	vboxes[6]->pack_start (*Gtk::manage (new Gtk::HSeparator ()), Gtk::PACK_SHRINK, 0);
 	vboxes[6]->pack_start (*raw_linenoise, Gtk::PACK_SHRINK, 2);
 	vboxes[6]->pack_start (*raw_greenthresh, Gtk::PACK_SHRINK, 2);
-	vboxes[6]->pack_start (*raw_hotdeadpix_filt, Gtk::PACK_SHRINK, 2);
+	vboxes[6]->pack_start (*raw_hotpix_filt, Gtk::PACK_SHRINK, 2);
+	vboxes[6]->pack_start (*raw_deadpix_filt, Gtk::PACK_SHRINK, 2);
 	vboxes[6]->pack_start (*Gtk::manage (new Gtk::HSeparator ()), Gtk::PACK_SHRINK, 0);
 	vboxes[6]->pack_start (*raw_expos, Gtk::PACK_SHRINK, 2);
 	vboxes[6]->pack_start (*raw_preser, Gtk::PACK_SHRINK, 2);
@@ -194,6 +205,7 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
 	vboxes[6]->pack_start (*ff_AutoSelect, Gtk::PACK_SHRINK, 2);
 	vboxes[6]->pack_start (*ff_BlurType, Gtk::PACK_SHRINK, 2);
 	vboxes[6]->pack_start (*ff_BlurRadius, Gtk::PACK_SHRINK, 2);
+	vboxes[6]->pack_start (*ff_ClipControl, Gtk::PACK_SHRINK, 2);
 	vboxes[6]->pack_start (*Gtk::manage (new Gtk::HSeparator ()), Gtk::PACK_SHRINK, 0);
 	vboxes[6]->pack_start (*raw_ca_autocorrect, Gtk::PACK_SHRINK, 2);
 	vboxes[6]->pack_start (*raw_cared, Gtk::PACK_SHRINK, 2);
@@ -243,9 +255,10 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
 
     wbConn          = wb->signal_toggled().connect (sigc::bind (sigc::mem_fun(*basic, &Gtk::CheckButton::set_inconsistent), true));    
     exposureConn    = exposure->signal_toggled().connect (sigc::bind (sigc::mem_fun(*basic, &Gtk::CheckButton::set_inconsistent), true));    
-    hlrecConn       = hlrec->signal_toggled().connect (sigc::bind (sigc::mem_fun(*basic, &Gtk::CheckButton::set_inconsistent), true));    
     shConn          = sh->signal_toggled().connect (sigc::bind (sigc::mem_fun(*basic, &Gtk::CheckButton::set_inconsistent), true));
     epdConn         = epd->signal_toggled().connect (sigc::bind (sigc::mem_fun(*basic, &Gtk::CheckButton::set_inconsistent), true));
+    pcvignetteConn  = pcvignette->signal_toggled().connect (sigc::bind (sigc::mem_fun(*basic, &Gtk::CheckButton::set_inconsistent), true));
+    gradientConn    = gradient->signal_toggled().connect (sigc::bind (sigc::mem_fun(*basic, &Gtk::CheckButton::set_inconsistent), true));
     labcurveConn    = labcurve->signal_toggled().connect (sigc::bind (sigc::mem_fun(*basic, &Gtk::CheckButton::set_inconsistent), true));
     colorappearanceConn=colorappearance->signal_toggled().connect (sigc::bind (sigc::mem_fun(*basic, &Gtk::CheckButton::set_inconsistent), true));
 
@@ -260,8 +273,11 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
 
     vibranceConn    = vibrance->signal_toggled().connect (sigc::bind (sigc::mem_fun(*color, &Gtk::CheckButton::set_inconsistent), true));
     chmixerConn     = chmixer->signal_toggled().connect (sigc::bind (sigc::mem_fun(*color, &Gtk::CheckButton::set_inconsistent), true));
+    chmixerbwConn   = blackwhite->signal_toggled().connect (sigc::bind (sigc::mem_fun(*color, &Gtk::CheckButton::set_inconsistent), true));
     hsveqConn		= hsveq->signal_toggled().connect (sigc::bind (sigc::mem_fun(*color, &Gtk::CheckButton::set_inconsistent), true));
+    filmSimulationConn = filmSimulation->signal_toggled().connect (sigc::bind (sigc::mem_fun(*color, &Gtk::CheckButton::set_inconsistent), true));
     rgbcurvesConn   = rgbcurves->signal_toggled().connect (sigc::bind (sigc::mem_fun(*color, &Gtk::CheckButton::set_inconsistent), true));
+    colortoningConn = colortoning->signal_toggled().connect (sigc::bind (sigc::mem_fun(*color, &Gtk::CheckButton::set_inconsistent), true));
 
     distortionConn  = distortion->signal_toggled().connect (sigc::bind (sigc::mem_fun(*lens, &Gtk::CheckButton::set_inconsistent), true));    
     cacorrConn      = cacorr->signal_toggled().connect (sigc::bind (sigc::mem_fun(*lens, &Gtk::CheckButton::set_inconsistent), true));    
@@ -280,7 +296,7 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
     icmConn         = icm->signal_toggled().connect (sigc::bind (sigc::mem_fun(*metaicm, &Gtk::CheckButton::set_inconsistent), true));    
     gamcsconn		= gam->signal_toggled().connect (sigc::bind (sigc::mem_fun(*metaicm, &Gtk::CheckButton::set_inconsistent), true));
 
-    raw_dmethodConn         = raw_dmethod->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
+    raw_methodConn         = raw_method->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
     raw_ccStepsConn         = raw_ccSteps->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
     raw_dcb_iterationsConn  = raw_dcb_iterations->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
     raw_dcb_enhanceConn     = raw_dcb_enhance->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
@@ -293,7 +309,8 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
     raw_ca_autocorrectConn  = raw_ca_autocorrect->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
     raw_caredConn           = raw_cared->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
     raw_cablueConn          = raw_cablue->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
-    raw_hotdeadpix_filtConn = raw_hotdeadpix_filt->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
+    raw_hotpix_filtConn     = raw_hotpix_filt->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
+    raw_deadpix_filtConn    = raw_deadpix_filt->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
     raw_linenoiseConn       = raw_linenoise->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
     raw_greenthreshConn     = raw_greenthresh->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
     df_fileConn             = df_file->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
@@ -302,6 +319,7 @@ PartialPasteDlg::PartialPasteDlg (Glib::ustring title) {
     ff_AutoSelectConn       = ff_AutoSelect->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
     ff_BlurRadiusConn       = ff_BlurRadius->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
     ff_BlurTypeConn         = ff_BlurType->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
+    ff_ClipControlConn      = ff_ClipControl->signal_toggled().connect (sigc::bind (sigc::mem_fun(*raw, &Gtk::CheckButton::set_inconsistent), true));
 
     add_button (Gtk::StockID("gtk-ok"), Gtk::RESPONSE_OK);
     add_button (Gtk::StockID("gtk-cancel"), Gtk::RESPONSE_CANCEL);
@@ -351,7 +369,7 @@ void PartialPasteDlg::everythingToggled () {
 
 void PartialPasteDlg::rawToggled () {
 
-	raw_dmethodConn.block (true);
+	raw_methodConn.block (true);
 	raw_ccStepsConn.block (true);
 	raw_dcb_iterationsConn.block (true);
 	raw_dcb_enhanceConn.block (true);
@@ -363,7 +381,8 @@ void PartialPasteDlg::rawToggled () {
 	raw_ca_autocorrectConn.block (true);
 	raw_caredConn.block (true);
 	raw_cablueConn.block (true);
-	raw_hotdeadpix_filtConn.block (true);
+	raw_hotpix_filtConn.block (true);
+	raw_deadpix_filtConn.block (true);
 	raw_linenoiseConn.block (true);
 	raw_greenthreshConn.block (true);
 	df_fileConn.block (true);
@@ -372,10 +391,11 @@ void PartialPasteDlg::rawToggled () {
 	ff_AutoSelectConn.block (true);
 	ff_BlurRadiusConn.block (true);
 	ff_BlurTypeConn.block (true);
+	ff_ClipControlConn.block (true);
 
     raw->set_inconsistent (false);
 
-    raw_dmethod->set_active (raw->get_active ());
+    raw_method->set_active (raw->get_active ());
     raw_ccSteps->set_active (raw->get_active ());
     raw_dcb_iterations->set_active (raw->get_active ());
     raw_dcb_enhance->set_active (raw->get_active ());
@@ -387,7 +407,8 @@ void PartialPasteDlg::rawToggled () {
     raw_ca_autocorrect->set_active (raw->get_active ());
     raw_cared->set_active (raw->get_active ());
     raw_cablue->set_active (raw->get_active ());
-    raw_hotdeadpix_filt->set_active (raw->get_active ());
+    raw_hotpix_filt->set_active (raw->get_active ());
+    raw_deadpix_filt->set_active (raw->get_active ());
     raw_linenoise->set_active (raw->get_active ());
     raw_greenthresh->set_active (raw->get_active ());
     df_file->set_active (raw->get_active ());
@@ -396,8 +417,9 @@ void PartialPasteDlg::rawToggled () {
     ff_AutoSelect->set_active (raw->get_active ());
     ff_BlurRadius->set_active (raw->get_active ());
     ff_BlurType->set_active (raw->get_active ());
+    ff_ClipControl->set_active (raw->get_active ());
 
-    raw_dmethodConn.block (false);
+    raw_methodConn.block (false);
     raw_ccStepsConn.block (false);
     raw_dcb_iterationsConn.block (false);
     raw_dcb_enhanceConn.block (false);
@@ -409,7 +431,8 @@ void PartialPasteDlg::rawToggled () {
     raw_ca_autocorrectConn.block (false);
     raw_caredConn.block (false);
     raw_cablueConn.block (false);
-    raw_hotdeadpix_filtConn.block (false);
+    raw_hotpix_filtConn.block (false);
+    raw_deadpix_filtConn.block (false);
     raw_linenoiseConn.block (false);
     raw_greenthreshConn.block (false);
     df_fileConn.block (false);
@@ -418,15 +441,17 @@ void PartialPasteDlg::rawToggled () {
     ff_AutoSelectConn.block (false);
     ff_BlurRadiusConn.block (false);
     ff_BlurTypeConn.block (false);
+    ff_ClipControlConn.block (false);
 }
 
 void PartialPasteDlg::basicToggled () {
 
     wbConn.block (true);
     exposureConn.block (true);
-    hlrecConn.block (true);
     shConn.block (true);
     epdConn.block(true);
+    pcvignetteConn.block (true);
+    gradientConn.block (true);
     labcurveConn.block (true);
     colorappearanceConn.block (true);
 
@@ -434,17 +459,19 @@ void PartialPasteDlg::basicToggled () {
 
     wb->set_active (basic->get_active ());
     exposure->set_active (basic->get_active ());
-    hlrec->set_active (basic->get_active ());
     sh->set_active (basic->get_active ());
     epd->set_active (basic->get_active ());
+    pcvignette->set_active (basic->get_active ());
+    gradient->set_active (basic->get_active ());
     labcurve->set_active (basic->get_active ());
     colorappearance->set_active (basic->get_active ());
 
     wbConn.block (false);
     exposureConn.block (false);
-    hlrecConn.block (false);
     shConn.block (false);
     epdConn.block (false);
+    pcvignetteConn.block (false);
+    gradientConn.block (false);
     labcurveConn.block (false);
     colorappearanceConn.block (false);
 }
@@ -485,21 +512,30 @@ void PartialPasteDlg::colorToggled () {
 
     vibranceConn.block (true);
     chmixerConn.block (true);
+    chmixerbwConn.block (true);
     hsveqConn.block (true);
+    filmSimulationConn.block (true);
     rgbcurvesConn.block (true);
+    colortoningConn.block (true);
     gamcsconn.block (true);
     color->set_inconsistent (false);
 
     vibrance->set_active (color->get_active ());
     chmixer->set_active (color->get_active ());
+    blackwhite->set_active (color->get_active ());
     hsveq->set_active (color->get_active ());
+    filmSimulation->set_active (color->get_active ());
     rgbcurves->set_active (color->get_active ());
+    colortoning->set_active(color->get_active ());
     icm->set_active (color->get_active ());
 
     vibranceConn.block (false);
+    chmixerbwConn.block (false);	
     chmixerConn.block (false);
     hsveqConn.block (false);
+    filmSimulationConn.block (false);
     rgbcurvesConn.block (false);
+    colortoningConn.block (false);
     gamcsconn.block (false);
 
 }
@@ -595,9 +631,10 @@ void PartialPasteDlg::applyPaste (rtengine::procparams::ProcParams* dstPP, Param
     // Now we filter out the filter depending on the checked items
     if (!wb->get_active ())          filterPE.wb         = falsePE.wb;
     if (!exposure->get_active ())    filterPE.toneCurve  = falsePE.toneCurve;
-    if (!hlrec->get_active ())       filterPE.hlrecovery = falsePE.hlrecovery;
     if (!sh->get_active ())          filterPE.sh         = falsePE.sh;
-    if (!epd->get_active ())         filterPE.edgePreservingDecompositionUI = falsePE.edgePreservingDecompositionUI;
+    if (!epd->get_active ())         filterPE.epd        = falsePE.epd;
+    if (!pcvignette->get_active ())  filterPE.pcvignette = falsePE.pcvignette;
+    if (!gradient->get_active ())    filterPE.gradient   = falsePE.gradient;
     if (!labcurve->get_active ())    filterPE.labCurve   = falsePE.labCurve;
     if (!colorappearance->get_active ()) filterPE.colorappearance= falsePE.colorappearance;
 
@@ -611,8 +648,11 @@ void PartialPasteDlg::applyPaste (rtengine::procparams::ProcParams* dstPP, Param
 
     if (!vibrance->get_active ())    filterPE.vibrance     = falsePE.vibrance;
     if (!chmixer->get_active ())     filterPE.chmixer      = falsePE.chmixer;
+    if (!blackwhite->get_active ())  filterPE.blackwhite   = falsePE.blackwhite;
     if (!hsveq->get_active ())       filterPE.hsvequalizer = falsePE.hsvequalizer;
+    if (!filmSimulation->get_active ()) filterPE.filmSimulation  = falsePE.filmSimulation;
     if (!rgbcurves->get_active ())   filterPE.rgbCurves    = falsePE.rgbCurves;
+    if (!colortoning->get_active ()) filterPE.colorToning  = falsePE.colorToning;
     if (!icm->get_active ())         filterPE.icm          = falsePE.icm;
 
     if (!distortion->get_active ())  filterPE.distortion   = falsePE.distortion;
@@ -631,33 +671,41 @@ void PartialPasteDlg::applyPaste (rtengine::procparams::ProcParams* dstPP, Param
     if (!iptc->get_active ())        filterPE.iptc = falsePE.iptc;
     if (!icm->get_active ())         filterPE.icm  = falsePE.icm;
 
-    if (!raw_dmethod->get_active ())           filterPE.raw.dmethod            = falsePE.raw.dmethod;
-    if (!raw_ccSteps->get_active ())           filterPE.raw.ccSteps            = falsePE.raw.ccSteps;
-    if (!raw_dcb_iterations->get_active ())    filterPE.raw.dcbIterations      = falsePE.raw.dcbIterations;
-    if (!raw_dcb_enhance->get_active ())       filterPE.raw.dcbEnhance         = falsePE.raw.dcbEnhance;
-    //if (!raw_all_enhance->get_active ())       filterPE.raw.allEnhance         = falsePE.raw.allEnhance;
-    if (!raw_lmmse_iterations->get_active ())    filterPE.raw.lmmseIterations      = falsePE.raw.lmmseIterations;
-
+    if (!raw_method->get_active ()) {          filterPE.raw.bayersensor.method   = falsePE.raw.bayersensor.method;
+                                               filterPE.raw.xtranssensor.method  = falsePE.raw.xtranssensor.method; }
+    if (!raw_ccSteps->get_active ()) {         filterPE.raw.bayersensor.ccSteps  = falsePE.raw.bayersensor.ccSteps;
+                                               filterPE.raw.xtranssensor.ccSteps = falsePE.raw.xtranssensor.ccSteps; }
+    if (!raw_dcb_iterations->get_active ())    filterPE.raw.bayersensor.dcbIterations   = falsePE.raw.bayersensor.dcbIterations;
+    if (!raw_dcb_enhance->get_active ())       filterPE.raw.bayersensor.dcbEnhance      = falsePE.raw.bayersensor.dcbEnhance;
+    //if (!raw_all_enhance->get_active ())     filterPE.raw.bayersensor.allEnhance      = falsePE.raw.bayersensor.allEnhance;
+    if (!raw_lmmse_iterations->get_active ())  filterPE.raw.bayersensor.lmmseIterations = falsePE.raw.bayersensor.lmmseIterations;
+    if (!raw_black->get_active ()) {           filterPE.raw.bayersensor.exBlack0        = falsePE.raw.bayersensor.exBlack0;
+                                               filterPE.raw.bayersensor.exBlack1        = falsePE.raw.bayersensor.exBlack1;
+                                               filterPE.raw.bayersensor.exBlack2        = falsePE.raw.bayersensor.exBlack2;
+                                               filterPE.raw.bayersensor.exBlack3        = falsePE.raw.bayersensor.exBlack3;
+                                               filterPE.raw.bayersensor.exTwoGreen      = falsePE.raw.bayersensor.exTwoGreen;
+                                               filterPE.raw.xtranssensor.exBlackRed     = falsePE.raw.xtranssensor.exBlackRed;
+                                               filterPE.raw.xtranssensor.exBlackGreen   = falsePE.raw.xtranssensor.exBlackGreen;
+                                               filterPE.raw.xtranssensor.exBlackBlue    = falsePE.raw.xtranssensor.exBlackBlue; }
+    if (!raw_linenoise->get_active ())         filterPE.raw.bayersensor.linenoise       = falsePE.raw.bayersensor.linenoise;
+    if (!raw_greenthresh->get_active ())       filterPE.raw.bayersensor.greenEq         = falsePE.raw.bayersensor.greenEq;
     if (!raw_expos->get_active ())             filterPE.raw.exPos              = falsePE.raw.exPos;
     if (!raw_preser->get_active ())            filterPE.raw.exPreser           = falsePE.raw.exPreser;
-    if (!raw_black->get_active ()) {           filterPE.raw.exBlackzero        = falsePE.raw.exBlackzero;
-                                               filterPE.raw.exBlackone         = falsePE.raw.exBlackone;
-                                               filterPE.raw.exBlacktwo         = falsePE.raw.exBlacktwo;
-                                               filterPE.raw.exBlackthree       = falsePE.raw.exBlackthree;
-                                               filterPE.raw.exTwoGreen         = falsePE.raw.exTwoGreen; }
     if (!raw_ca_autocorrect->get_active ())    filterPE.raw.caCorrection       = falsePE.raw.caCorrection;
     if (!raw_cared->get_active ())             filterPE.raw.caRed              = falsePE.raw.caRed;
     if (!raw_cablue->get_active ())            filterPE.raw.caBlue             = falsePE.raw.caBlue;
-    if (!raw_hotdeadpix_filt->get_active ()) { filterPE.raw.hotDeadPixelFilter = falsePE.raw.hotDeadPixelFilter;
+    if (!raw_hotpix_filt->get_active ())     { filterPE.raw.hotPixelFilter     = falsePE.raw.hotPixelFilter;
+                                               filterPE.raw.hotDeadPixelThresh = falsePE.raw.hotDeadPixelThresh; }
+    if (!raw_deadpix_filt->get_active ())    { filterPE.raw.deadPixelFilter    = falsePE.raw.deadPixelFilter;
                                                filterPE.raw.hotDeadPixelThresh = falsePE.raw.hotDeadPixelThresh; }
-    if (!raw_linenoise->get_active ())         filterPE.raw.linenoise          = falsePE.raw.linenoise;
-    if (!raw_greenthresh->get_active ())       filterPE.raw.greenEq            = falsePE.raw.greenEq;
     if (!df_file->get_active ())               filterPE.raw.darkFrame          = falsePE.raw.darkFrame;
     if (!df_AutoSelect->get_active ())         filterPE.raw.dfAuto             = falsePE.raw.dfAuto;
     if (!ff_file->get_active ())               filterPE.raw.ff_file            = falsePE.raw.ff_file;
     if (!ff_AutoSelect->get_active ())         filterPE.raw.ff_AutoSelect      = falsePE.raw.ff_AutoSelect;
     if (!ff_BlurRadius->get_active ())         filterPE.raw.ff_BlurRadius      = falsePE.raw.ff_BlurRadius;
     if (!ff_BlurType->get_active ())           filterPE.raw.ff_BlurType        = falsePE.raw.ff_BlurType;
+    if (!ff_ClipControl->get_active ()) {      filterPE.raw.ff_clipControl     = falsePE.raw.ff_clipControl;
+                                               filterPE.raw.ff_AutoClipControl = falsePE.raw.ff_AutoClipControl; }
 
     if (dstPE) *dstPE = filterPE;
 
