@@ -21,15 +21,16 @@
 #ifndef _POPUPTOGGLEBUTTON_
 #define _POPUPTOGGLEBUTTON_
 
-#include "popupbutton.h"
+#include <gtkmm/togglebutton.h>
 #include "popupcommon.h"
 
-class PopUpToggleButton : public Gtk::ToggleButton, public PopUpCommon {
+class PopUpToggleButton : public Gtk::ToggleButton, public PopUpCommon
+{
 
 public:
-	PopUpToggleButton (const Glib::ustring& label = "");
-	void show ();
-	void set_tooltip_text (const Glib::ustring &text);
+    PopUpToggleButton (const Glib::ustring& label = "");
+    void show ();
+    void set_tooltip_text (const Glib::ustring &text);
 };
 
 #endif
