@@ -72,6 +72,7 @@ class Preferences : public Gtk::Dialog, public ProfileStoreListener {
     Gtk::RadioButton* edOther;
     Gtk::FileChooserButton* darkFrameDir;
     Gtk::FileChooserButton* flatFieldDir;
+    Gtk::FileChooserButton* clutsDir;
     Gtk::Label *dfLabel;
     Gtk::Label *ffLabel;
 
@@ -85,7 +86,6 @@ class Preferences : public Gtk::Dialog, public ProfileStoreListener {
 	//Gtk::CheckButton* cbAutocielab;
 	Gtk::CheckButton* cbciecamfloat;
 
-    Gtk::CheckButton* blinkClipped;
 	Gtk::SpinButton*  hlThresh;
 	Gtk::SpinButton*  shThresh;
 
@@ -101,6 +101,7 @@ class Preferences : public Gtk::Dialog, public ProfileStoreListener {
     Gtk::CheckButton* chUseSystemTheme;
     Gtk::FontButton* fontbutton;
     Gtk::ColorButton* butCropCol;
+    Gtk::ColorButton* butNavGuideCol;
 	
     Gtk::SpinButton*   maxThumbSize;
     Gtk::SpinButton*   maxCacheEntries;
@@ -144,10 +145,10 @@ class Preferences : public Gtk::Dialog, public ProfileStoreListener {
     Gtk::ComboBoxText* custProfBuilderLabelType;
 
     Gtk::CheckButton* ckbHistogramPositionLeft;
+    Gtk::CheckButton* ckbHistogramWorking;
     Gtk::CheckButton* ckbShowProfileSelector;
     Gtk::CheckButton* ckbFileBrowserToolbarSingleRow;
     Gtk::CheckButton* ckbHideTPVScrollbar;
-    Gtk::CheckButton* ckbSquareDetailWindow;
     Gtk::CheckButton* ckbUseIconNoText;
 
     Glib::ustring storedValueRaw;
@@ -159,6 +160,8 @@ class Preferences : public Gtk::Dialog, public ProfileStoreListener {
     Glib::ustring initialTheme;
     Glib::ustring initialFont;
 
+    bool oldSlimUI;
+
     void fillPreferences ();
     void storePreferences ();
     void parseDir       (Glib::ustring dirname, std::vector<Glib::ustring>& items, Glib::ustring ext);
