@@ -20,20 +20,18 @@
 #define _PREPROCESS_H_
 
 #include <gtkmm.h>
-#include "adjuster.h"
+//#include "adjuster.h"
 #include "toolpanel.h"
 #include "../rtengine/rawimage.h"
 
-class PreProcess : public Gtk::VBox, public AdjusterListener, public FoldableToolPanel {
+class PreProcess : public ToolParamBlock, /*public AdjusterListener,*/ public FoldableToolPanel {
 
   protected:
-
-    Adjuster* lineDenoise;
-
-    Adjuster* greenEqThreshold;
-    Gtk::CheckButton* hotDeadPixel;
-	bool lastHot;
-	sigc::connection hdpixelconn;
+    Gtk::CheckButton* hotPixel;
+    Gtk::CheckButton* deadPixel;
+    bool lastHot,lastDead;
+    sigc::connection hpixelconn;
+    sigc::connection dpixelconn;
 
   public:
 
@@ -41,13 +39,15 @@ class PreProcess : public Gtk::VBox, public AdjusterListener, public FoldableToo
 
     void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited=NULL);
     void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited=NULL);
-    void setBatchMode   (bool batchMode);
-    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
+    //void setBatchMode   (bool batchMode);
+    //void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
 
-    void adjusterChanged     (Adjuster* a, double newval);
-    void hotDeadPixelChanged();
-    void setAdjusterBehavior (bool linedenoiseadd, bool greenequiladd);
-    void trimValues          (rtengine::procparams::ProcParams* pp);
+    void hotPixelChanged();
+    void deadPixelChanged();
+
+    //void adjusterChanged     (Adjuster* a, double newval);
+    //void setAdjusterBehavior (bool linedenoiseadd, bool greenequiladd);
+    //void trimValues          (rtengine::procparams::ProcParams* pp);
 };
 
 #endif
