@@ -22,10 +22,8 @@
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-RawProcess::RawProcess () : Gtk::VBox(), FoldableToolPanel(this)
+RawProcess::RawProcess () : FoldableToolPanel(this)
 {
-   set_border_width(4);
-
    Gtk::HBox* hb1 = Gtk::manage (new Gtk::HBox ());
    hb1->pack_start (*Gtk::manage (new Gtk::Label ( M("TP_RAW_DMETHOD") +": ")),Gtk::PACK_SHRINK, 4);
    dmethod = Gtk::manage (new MyComboBoxText ());
@@ -93,6 +91,7 @@ void RawProcess::read(const rtengine::procparams::ProcParams* pp, const ParamsEd
    for( size_t i=0; i< procparams::RAWParams::numMethods;i++)
        if( pp->raw.dmethod == procparams::RAWParams::methodstring[i]){
            dmethod->set_active(i);
+	   oldSelection = i;
            break;
        }
 
@@ -223,11 +222,17 @@ void RawProcess::methodChanged ()
 	}
 	
 	Glib::ustring methodName="";
-	if( curSelection>=0 && curSelection < procparams::RAWParams::numMethods)
+	bool ppreq = false;
+	if( curSelection>=0 && curSelection < procparams::RAWParams::numMethods) {
 	    methodName = procparams::RAWParams::methodstring[curSelection];
+	    if (curSelection == procparams::RAWParams::mono || oldSelection == procparams::RAWParams::mono) {
+		    ppreq = true;
+	    }
+	}
+	oldSelection = curSelection;
 
     if (listener)
-        listener->panelChanged (EvDemosaicMethod, methodName);
+	    listener->panelChanged (ppreq ? EvDemosaicMethodPreProc : EvDemosaicMethod, methodName);
 }
 
 void RawProcess::dcbEnhanceChanged ()
