@@ -25,7 +25,7 @@
 #include "toolpanel.h"
 
 
-class RawProcess : public Gtk::VBox, public AdjusterListener, public FoldableToolPanel{
+class RawProcess : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel{
 
   protected:
 
@@ -41,6 +41,7 @@ class RawProcess : public Gtk::VBox, public AdjusterListener, public FoldableToo
     Adjuster* lmmseIterations;
 
     bool lastDCBen;
+    int oldSelection;
 	//bool lastALLen;
     sigc::connection methodconn,dcbEnhconn;  //,allEnhconn;
   public:
