@@ -22,9 +22,7 @@
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-RGBCurves::RGBCurves () : Gtk::VBox(), FoldableToolPanel(this) {
-
-	set_border_width(4);
+RGBCurves::RGBCurves () : FoldableToolPanel(this) {
 
 	lumamode = Gtk::manage (new Gtk::CheckButton (M("TP_RGBCURVES_LUMAMODE")));
 	lumamode->set_tooltip_markup (M("TP_RGBCURVES_LUMAMODE_TOOLTIP"));
@@ -44,6 +42,7 @@ RGBCurves::RGBCurves () : Gtk::VBox(), FoldableToolPanel(this) {
 	curveEditorG->setCurveListener (this);
 
 	Rshape = static_cast<DiagonalCurveEditor*>(curveEditorG->addCurve(CT_Diagonal, M("TP_RGBCURVES_RED")));
+	Rshape->setEditID(EUID_RGB_R, BT_SINGLEPLANE_FLOAT);
 	milestones.push_back( GradientMilestone(0.0, 0.0, 0.0, 0.0) );
 	milestones.push_back( GradientMilestone(1.0, 1.0, 0.0, 0.0) );
 	Rshape->setBottomBarBgGradient(milestones);
@@ -51,11 +50,13 @@ RGBCurves::RGBCurves () : Gtk::VBox(), FoldableToolPanel(this) {
 
 	milestones[1].r = 0.0; milestones[1].g = 1.0;
 	Gshape = static_cast<DiagonalCurveEditor*>(curveEditorG->addCurve(CT_Diagonal, M("TP_RGBCURVES_GREEN")));
+	Gshape->setEditID(EUID_RGB_G, BT_SINGLEPLANE_FLOAT);
 	Gshape->setBottomBarBgGradient(milestones);
 	Gshape->setLeftBarBgGradient(milestones);
 
 	milestones[1].g = 0.0; milestones[1].b = 1.0;
 	Bshape = static_cast<DiagonalCurveEditor*>(curveEditorG->addCurve(CT_Diagonal, M("TP_RGBCURVES_BLUE")));
+	Bshape->setEditID(EUID_RGB_B, BT_SINGLEPLANE_FLOAT);
 	Bshape->setBottomBarBgGradient(milestones);
 	Bshape->setLeftBarBgGradient(milestones);
 
@@ -94,6 +95,12 @@ void RGBCurves::read (const ProcParams* pp, const ParamsEdited* pedited) {
     enableListener ();
 }
 
+void RGBCurves::setEditProvider (EditDataProvider *provider) {
+    Rshape->setEditProvider(provider);
+    Gshape->setEditProvider(provider);
+    Bshape->setEditProvider(provider);
+}
+
 void RGBCurves::autoOpenCurve  () {
     // Open up the first curve if selected
     bool active = Rshape->openIfNonlinear();
@@ -165,7 +172,7 @@ void RGBCurves::setBatchMode (bool batchMode) {
 }
 
 
-void RGBCurves::updateCurveBackgroundHistogram (LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve, LUTu & histCLurve, LUTu & histLLCurve, LUTu & histLCAM,  LUTu & histCCAM, LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma) {
+void RGBCurves::updateCurveBackgroundHistogram (LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve, /*LUTu & histCLurve, LUTu & histLLCurve,*/ LUTu & histLCAM,  LUTu & histCCAM, LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma) {
 
   //  Rshape->updateBackgroundHistogram (histRed);
   //  Gshape->updateBackgroundHistogram (histGreen);
