@@ -113,15 +113,20 @@ RTWindow::RTWindow ()
         gtkosx_application_ready (osxApp);
     }
 #endif
-    set_title("RawTherapee "+versionString);
+    versionStr = "RawTherapee "+versionString;
+    if (!versionSuffixString.empty())
+        versionStr += " "+versionSuffixString;
+    set_title_decorated("");
     property_allow_shrink() = true;
     set_default_size(options.windowWidth, options.windowHeight);
     set_modal(false);
     set_resizable(true);
     if (options.windowMaximized)
     	maximize();
-    else
+    else {
     	unmaximize();
+    	move(options.windowX,options.windowY);
+    }
 
     on_delete_has_run = false;
     is_fullscreen = false;
@@ -361,6 +366,13 @@ void RTWindow::on_mainNB_switch_page(GtkNotebookPage* page, guint page_num) {
 
         EditorPanel *ep = static_cast<EditorPanel*>(mainNB->get_nth_page(page_num));
         ep->setAspect();
+		
+        if (!isSingleTabMode() && mainNB->get_current_page ()>2){
+        	if (mainNB->get_n_pages()>2 && filesEdited.size()>0){
+			set_title_decorated(ep->getFileName());
+        	}
+		}
+
     } else {
         // in single tab mode with command line filename epanel does not exist yet
         if (isSingleTabMode() && epanel) {
@@ -385,7 +397,8 @@ void RTWindow::addEditorPanel (EditorPanel* ep, const std::string &name) {
         // construct closeable tab for the image
         Gtk::HBox* hb = Gtk::manage (new Gtk::HBox ());
         hb->pack_start (*Gtk::manage (new RTImage ("rtwindow.png")));
-        hb->pack_start (*Gtk::manage (new Gtk::Label (name)));
+        hb->pack_start (*Gtk::manage (new Gtk::Label (Glib::path_get_basename (name))));
+        hb->set_tooltip_markup (name);
         Gtk::Button* closeb = Gtk::manage (new Gtk::Button ());
         closeb->set_image (*Gtk::manage(new RTImage ("gtk-close.png")));
         closeb->set_relief (Gtk::RELIEF_NONE);
@@ -406,6 +419,7 @@ void RTWindow::addEditorPanel (EditorPanel* ep, const std::string &name) {
         mainNB->set_current_page (mainNB->page_num (*ep));
         mainNB->set_tab_reorderable (*ep, true);
 
+        set_title_decorated(name);
         epanels[ name ] = ep;
         filesEdited.insert ( name );
         fpanel->refreshEditedState (filesEdited);
@@ -420,14 +434,20 @@ void RTWindow::remEditorPanel (EditorPanel* ep) {
         EditWindow * wndEdit = EditWindow::getInstance(this);
         wndEdit->remEditorPanel(ep);
     } else {
-	    epanels.erase (ep->getShortName());
-	    filesEdited.erase (ep->getShortName ());
+	    epanels.erase (ep->getFileName());
+	    filesEdited.erase (ep->getFileName ());
 	    fpanel->refreshEditedState (filesEdited);
 
 	    mainNB->remove_page (*ep);
 
-	    if (mainNB->get_current_page () == mainNB->page_num (*bpanel))
+	    if (mainNB->get_current_page () == mainNB->page_num (*bpanel) || mainNB->get_current_page () == mainNB->page_num (*fpanel)){
 		    mainNB->set_current_page (mainNB->page_num (*fpanel));
+		    set_title_decorated("");
+	    }
+	    else{
+		    EditorPanel* ep = static_cast<EditorPanel*>(mainNB->get_nth_page (mainNB->get_current_page()));
+	        set_title_decorated(ep->getFileName());
+	    }
         // TODO: ask what to do: close & apply, close & apply selection, close & revert, cancel
     }
 }
@@ -435,14 +455,22 @@ void RTWindow::remEditorPanel (EditorPanel* ep) {
 bool RTWindow::selectEditorPanel(const std::string &name) {
     if (EditWindow::isMultiDisplayEnabled()) {
         EditWindow * wndEdit = EditWindow::getInstance(this);
-        if (wndEdit->selectEditorPanel(name)) return true;
+        if (wndEdit->selectEditorPanel(name)) {
+        	set_title_decorated(name);
+        	return true;
+        }
     } else {
         std::map<Glib::ustring, EditorPanel*>::iterator iep = epanels.find(name);
 
         if (iep!=epanels.end()) {
             mainNB->set_current_page (mainNB->page_num (*iep->second));
+            set_title_decorated(name);
             return true;
         }
+        else{
+        	//set_title_decorated(name);
+        	//printf("RTWindow::selectEditorPanel - plain set\n");
+        }
     }
 
     return false;
@@ -589,6 +617,7 @@ bool RTWindow::on_delete_event(GdkEventAny* event) {
     if (!options.windowMaximized) {
 		options.windowWidth = get_width();
 		options.windowHeight = get_height();
+		get_position (options.windowX,options.windowY);
     }
 
     Options::save ();
@@ -729,3 +758,18 @@ bool RTWindow::splashClosed(GdkEventAny* event) {
 	splash = NULL;
 	return true;
 }
+
+void RTWindow::set_title_decorated(Glib::ustring fname){
+	Glib::ustring subtitle;
+	if (!fname.empty()) subtitle= " - " + fname;
+	set_title(versionStr + subtitle);	
+}
+
+void RTWindow::CloseOpenEditors(){
+	std::map<Glib::ustring, EditorPanel*>::const_iterator itr;
+	itr = epanels.begin();
+	while(itr != epanels.end()) {
+		remEditorPanel((*itr).second);
+		itr = epanels.begin();
+	}
+}
