@@ -21,9 +21,7 @@
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-ShadowsHighlights::ShadowsHighlights () : Gtk::VBox(), FoldableToolPanel(this) {
-
-  set_border_width(4);
+ShadowsHighlights::ShadowsHighlights () : FoldableToolPanel(this) {
 
   enabled = Gtk::manage (new Gtk::CheckButton (M("GENERAL_ENABLED")));
   enabled->set_active (false);
