@@ -27,9 +27,7 @@ using namespace rtengine;
 using namespace rtengine::procparams;
 
 
-SharpenMicro::SharpenMicro () : Gtk::VBox(), FoldableToolPanel(this) {
-
-	set_border_width(4);
+SharpenMicro::SharpenMicro () : FoldableToolPanel(this) {
 
 	enabled = Gtk::manage (new Gtk::CheckButton (M("GENERAL_ENABLED")));
 	enabled->set_active (true);
