@@ -132,6 +132,7 @@ ThresholdSelector::ThresholdSelector(double minValue, double maxValue, double de
 
 void ThresholdSelector::initValues () {
 
+	updatePolicy = RTUP_STATIC;
 	additionalTTip = "";
 	oldLitCursor = litCursor = TS_UNDEFINED;
 	movedCursor = TS_UNDEFINED;
@@ -141,6 +142,7 @@ void ThresholdSelector::initValues () {
 	set_name("ThresholdSelector");
 	set_can_focus(false);
 	set_app_paintable(true);
+	setDirty(true);
 	updateTooltip();
 }
 
@@ -150,6 +152,8 @@ void ThresholdSelector::initValues () {
 void ThresholdSelector::setPositions (double bottom, double top) {
 
 	setPositions(bottom, top, maxValBottom, maxValTop);
+	if (updatePolicy==RTUP_DYNAMIC)
+		setDirty(true);
 }
 
 /*
@@ -165,6 +169,8 @@ void ThresholdSelector::setPositions (double bottomLeft, double topLeft, double
 	positions[TS_TOPRIGHT]    = topRight;
 
 	if (different) {
+		if (updatePolicy==RTUP_DYNAMIC)
+			setDirty(true);
 		sig_val_changed.emit();
 		updateTooltip();
 		queue_draw ();
@@ -229,7 +235,10 @@ bool ThresholdSelector::on_expose_event(GdkEventExpose* event) {
 	else {
 		// solid background
 		c = style->get_bg (state);
-		cr->set_source_rgb (c.get_red_p()*0.85, c.get_green_p()*0.85, c.get_blue_p()*0.85);
+		if (state==Gtk::STATE_INSENSITIVE)
+			cr->set_source_rgb (c.get_red_p()*0.96, c.get_green_p()*0.96, c.get_blue_p()*0.96);
+		else
+			cr->set_source_rgb (c.get_red_p()*0.85, c.get_green_p()*0.85, c.get_blue_p()*0.85);
 
 		// draw the box's background
 		cr->rectangle (hb+hwslider-0.5, double(int(float(h)*1.5f/7.f))+0.5, iw+1, double(int(float(h)*4.f/7.f)));
@@ -264,6 +273,7 @@ bool ThresholdSelector::on_expose_event(GdkEventExpose* event) {
 
 	}
 	else {
+		if (!separatedSliders) {
 		double yStart = initalEq1 ? double(int(float(h)*1.5f/7.f))+1.5 : double(int(float(h)*5.5f/7.f))-0.5;
 		double yEnd   = initalEq1 ? double(int(float(h)*5.5f/7.f))-0.5 : double(int(float(h)*1.5f/7.f))+1.5;
 		ThreshCursorId p[4];
@@ -284,6 +294,7 @@ bool ThresholdSelector::on_expose_event(GdkEventExpose* event) {
 				cr->line_to (hb+hwslider+iw+0.5, yStart);
 		}
 	}
+	}
 	if (is_sensitive() && bgGradient.size()>1) {
 		// draw surrounding curve
 		c = style->get_bg (state);
@@ -298,7 +309,7 @@ bool ThresholdSelector::on_expose_event(GdkEventExpose* event) {
 	}
 	else {
 		c = style->get_bg (Gtk::STATE_INSENSITIVE);
-		cr->set_source_rgb (c.get_red_p()*0.7, c.get_green_p()*0.7, c.get_blue_p()*0.7);
+		cr->set_source_rgb (c.get_red_p()*0.85, c.get_green_p()*0.85, c.get_blue_p()*0.85);
 	}
 	cr->set_line_width (1.5);
 	cr->stroke ();
@@ -306,8 +317,11 @@ bool ThresholdSelector::on_expose_event(GdkEventExpose* event) {
 	// draw the box's borders
 	cr->set_line_width (1.);
 	cr->rectangle (hb+hwslider-0.5, double(int(float(h)*1.5f/7.f))+0.5, iw+1, double(int(float(h)*4.f/7.f)));
-    c = style->get_bg (state);
-    cr->set_source_rgb (c.get_red_p()*0.7, c.get_green_p()*0.7, c.get_blue_p()*0.7);
+	c = style->get_bg (state);
+	if (state==Gtk::STATE_INSENSITIVE)
+		cr->set_source_rgb (c.get_red_p()*0.85, c.get_green_p()*0.85, c.get_blue_p()*0.85);
+	else
+		cr->set_source_rgb (c.get_red_p()*0.7, c.get_green_p()*0.7, c.get_blue_p()*0.7);
 	cr->stroke ();
 
 	// draw sliders
@@ -349,8 +363,11 @@ bool ThresholdSelector::on_expose_event(GdkEventExpose* event) {
 			c = style->get_bg (is_sensitive() ? Gtk::STATE_ACTIVE : Gtk::STATE_INSENSITIVE);
 			cr->set_source_rgb (c.get_red_p(), c.get_green_p(), c.get_blue_p());
 			cr->fill_preserve ();
-		    c = style->get_bg (state);
-		    cr->set_source_rgb (c.get_red_p()*0.7, c.get_green_p()*0.7, c.get_blue_p()*0.7);
+			c = style->get_bg (state);
+			if (state==Gtk::STATE_INSENSITIVE)
+				cr->set_source_rgb (c.get_red_p()*0.85, c.get_green_p()*0.85, c.get_blue_p()*0.85);
+			else
+				cr->set_source_rgb (c.get_red_p()*0.7, c.get_green_p()*0.7, c.get_blue_p()*0.7);
 			cr->stroke ();
 		}
 	}
@@ -435,6 +452,10 @@ bool ThresholdSelector::on_motion_notify_event (GdkEventMotion* event) {
 		// set the new reference value for the next move
 		tmpX = event->x;
 
+		// ask to redraw the background
+		if (updatePolicy==RTUP_DYNAMIC)
+			setDirty(true);
+
 		// update the tooltip
 		updateTooltip();
 
@@ -588,11 +609,15 @@ void ThresholdSelector::reset () {
 	positions[1] = defPos[1];
 	positions[2] = defPos[2];
 	positions[3] = defPos[3];
+
+	if (updatePolicy==RTUP_DYNAMIC)
+		setDirty(true);
+
 	updateTooltip();
 	queue_draw ();
 }
 
-inline double ThresholdSelector::to01(ThreshCursorId cursorId) {
+double ThresholdSelector::to01(ThreshCursorId cursorId) {
 
 	double rVal;
 	if (cursorId==TS_BOTTOMLEFT || cursorId==TS_BOTTOMRIGHT)
@@ -604,15 +629,15 @@ inline double ThresholdSelector::to01(ThreshCursorId cursorId) {
 	return rVal;
 }
 
-inline void ThresholdSelector::setBgCurveProvider (ThresholdCurveProvider* provider) {
+void ThresholdSelector::setBgCurveProvider (ThresholdCurveProvider* provider) {
 	bgCurveProvider = provider;
 }
 
-inline void ThresholdSelector::setSeparatedSliders(bool separated) {
+void ThresholdSelector::setSeparatedSliders(bool separated) {
 	separatedSliders = separated;
 }
 
-inline bool ThresholdSelector::getSeparatedSliders() {
+bool ThresholdSelector::getSeparatedSliders() {
 	return separatedSliders;
 }
 
