@@ -69,9 +69,12 @@ public:
 		inactive_waiting_(false)
 	{
 		int threadCount=1;
+#if !(defined( WIN32 ) && defined( __x86_64__ ))
+		// See Issue 2431 for explanation
 		#ifdef _OPENMP
-		threadCount=omp_get_num_procs();  
+			threadCount=omp_get_num_procs();
 		#endif
+#endif
 		
 		threadPool_=new Glib::ThreadPool(threadCount,0);
 	}
