@@ -21,14 +21,12 @@
 #include <sigc++/class_slot.h>
 #include <iomanip>
 #include "ppversion.h"
+#include "edit.h"
 
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-ToneCurve::ToneCurve () : Gtk::VBox(), FoldableToolPanel(this) {
-
-  set_border_width(4);
-  set_spacing(4);
+ToneCurve::ToneCurve () : FoldableToolPanel(this) {
 
   CurveListener::setMulti(true);
 
@@ -132,6 +130,7 @@ ToneCurve::ToneCurve () : Gtk::VBox(), FoldableToolPanel(this) {
   curveEditorG->setCurveListener (this);
 
   shape = static_cast<DiagonalCurveEditor*>(curveEditorG->addCurve(CT_Diagonal, "", toneCurveMode));
+  shape->setEditID(EUID_ToneCurve1, BT_IMAGEFLOAT);
   shape->setBottomBarBgGradient(bottomMilestones);
   shape->setLeftBarBgGradient(bottomMilestones);
 
@@ -156,6 +155,7 @@ ToneCurve::ToneCurve () : Gtk::VBox(), FoldableToolPanel(this) {
   curveEditorG2->setCurveListener (this);
 
   shape2 = static_cast<DiagonalCurveEditor*>(curveEditorG2->addCurve(CT_Diagonal, "", toneCurveMode2));
+  shape2->setEditID(EUID_ToneCurve2, BT_IMAGEFLOAT);
   shape2->setBottomBarBgGradient(bottomMilestones);
   shape2->setLeftBarBgGradient(bottomMilestones);
 
@@ -267,6 +267,11 @@ void ToneCurve::autoOpenCurve  () {
     shape2->openIfNonlinear();
 }
 
+void ToneCurve::setEditProvider  (EditDataProvider *provider) {
+    shape->setEditProvider(provider);
+    shape2->setEditProvider(provider);
+}
+
 void ToneCurve::write (ProcParams* pp, ParamsEdited* pedited) {
 
     pp->toneCurve.autoexp = autolevels->get_active();
@@ -599,6 +604,8 @@ void ToneCurve::waitForAutoExp () {
     saturation->setEnabled (false);
     curveEditorG->set_sensitive (false);
     toneCurveMode->set_sensitive (false);
+    curveEditorG2->set_sensitive (false);
+    toneCurveMode2->set_sensitive (false);
     hrenabled->set_sensitive(false);
     method->set_sensitive(false);
 }
@@ -633,6 +640,8 @@ void ToneCurve::enableAll () {
     saturation->setEnabled (true);
     curveEditorG->set_sensitive (true);
     toneCurveMode->set_sensitive (true);
+    curveEditorG2->set_sensitive (true);
+    toneCurveMode2->set_sensitive (true);
     hrenabled->set_sensitive(true);
     method->set_sensitive(true);
 }
@@ -682,8 +691,10 @@ void ToneCurve::setBatchMode (bool batchMode) {
     saturation->showEditedCB ();
 
     toneCurveMode->append_text (M("GENERAL_UNCHANGED"));
+    toneCurveMode2->append_text (M("GENERAL_UNCHANGED"));
 
     curveEditorG->setBatchMode (batchMode);
+    curveEditorG2->setBatchMode (batchMode);
 }
 
 void ToneCurve::setAdjusterBehavior (bool expadd, bool hlcompadd, bool hlcompthreshadd, bool bradd, bool blackadd, bool shcompadd, bool contradd, bool satadd) {
@@ -710,7 +721,7 @@ void ToneCurve::trimValues (rtengine::procparams::ProcParams* pp) {
     saturation->trimValue(pp->toneCurve.saturation);
 }
 
-void ToneCurve::updateCurveBackgroundHistogram (LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve, LUTu & histCLurve, LUTu & histLLCurve, LUTu & histLCAM, LUTu & histCCAM, LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma) {
+void ToneCurve::updateCurveBackgroundHistogram (LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve, /*LUTu & histCLurve, LUTu & histLLCurve,*/ LUTu & histLCAM, LUTu & histCCAM, LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma) {
 
     shape->updateBackgroundHistogram (histToneCurve);
 }
