@@ -27,10 +27,19 @@
 #include "mycurve.h"
 #include "guiutils.h"
 
-class ToneCurve : public Gtk::VBox, public AdjusterListener, public FoldableToolPanel, public rtengine::AutoExpListener, public CurveListener {
+class ToneCurve : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel, public rtengine::AutoExpListener,public CurveListener {
 
   protected:
+    // from HLRecovery
+    Gtk::CheckButton*   hrenabled;
+    MyComboBoxText*     method;
+    sigc::connection    methconn;
+    sigc::connection    enaconn;
+    bool                lasthrEnabled;
+  
     Gtk::HBox* abox;
+    Gtk::HBox* hlrbox;
+
     Gtk::ToggleButton* autolevels;
     MySpinButton* sclip;
     Gtk::Button* neutral;
@@ -45,7 +54,6 @@ class ToneCurve : public Gtk::VBox, public AdjusterListener, public FoldableTool
     MyComboBoxText* toneCurveMode;
     MyComboBoxText* toneCurveMode2;
 
-
     bool clipDirty, lastAuto;
     sigc::connection autoconn, neutralconn, tcmodeconn, tcmode2conn;
     CurveEditorGroup* curveEditorG;
@@ -60,7 +68,8 @@ class ToneCurve : public Gtk::VBox, public AdjusterListener, public FoldableTool
     int nextBlack;
     int nextHlcompr;
     int nextHlcomprthresh;
-  
+    bool nextHLRecons;
+
   public:
 
     ToneCurve ();
@@ -73,6 +82,7 @@ class ToneCurve : public Gtk::VBox, public AdjusterListener, public FoldableTool
     void setAdjusterBehavior (bool expadd, bool hlcompadd, bool hlcompthreshadd, bool bradd, bool blackadd, bool shcompadd, bool contradd, bool satadd);
     void trimValues          (rtengine::procparams::ProcParams* pp);
     void autoOpenCurve       ();
+    void setEditProvider     (EditDataProvider *provider);
 
 
     void adjusterChanged (Adjuster* a, double newval);
@@ -81,7 +91,7 @@ class ToneCurve : public Gtk::VBox, public AdjusterListener, public FoldableTool
     void clip_changed ();
     bool clip_changed_ ();
     void waitForAutoExp ();
-    void autoExpChanged (double expcomp, int bright, int contr, int black, int hlcompr, int hlcomprthresh);
+    void autoExpChanged (double expcomp, int bright, int contr, int black, int hlcompr, int hlcomprthresh, bool hlrecons);
     bool autoExpComputed_ ();
     void enableAll ();
     void curveChanged (CurveEditor* ce);
@@ -91,7 +101,12 @@ class ToneCurve : public Gtk::VBox, public AdjusterListener, public FoldableTool
     bool curveMode2Changed_ ();
     void expandCurve (bool isExpanded);
     bool isCurveExpanded ();
-    void updateCurveBackgroundHistogram (LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve, LUTu & histLCAM, LUTu & histCCAM, LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma);
+    void updateCurveBackgroundHistogram (LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve,/* LUTu & histCLurve, LUTu & histLLCurve,*/ LUTu & histLCAM, LUTu & histCCAM, LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma);
+ 
+    void setRaw (bool raw);
+
+    void hrenabledChanged ();
+    void methodChanged ();
 };
 
 #endif
