@@ -33,11 +33,11 @@ using namespace rtengine::procparams;
 
 ToolPanelCoordinator::ToolPanelCoordinator () : ipc(NULL)  {
 
-    exposurePanel   = Gtk::manage (new Gtk::VBox ());
-    detailsPanel    = Gtk::manage (new Gtk::VBox ());
-    colorPanel      = Gtk::manage (new Gtk::VBox ());
-    transformPanel  = Gtk::manage (new Gtk::VBox ());
-    rawPanel        = Gtk::manage (new Gtk::VBox ());
+    exposurePanel   = Gtk::manage (new ToolVBox ());
+    detailsPanel    = Gtk::manage (new ToolVBox ());
+    colorPanel      = Gtk::manage (new ToolVBox ());
+    transformPanel  = Gtk::manage (new ToolVBox ());
+    rawPanel        = Gtk::manage (new ToolVBox ());
 
     coarse              = Gtk::manage (new CoarsePanel ());
     toneCurve           = Gtk::manage (new ToneCurve ());
@@ -45,12 +45,13 @@ ToolPanelCoordinator::ToolPanelCoordinator () : ipc(NULL)  {
     impulsedenoise      = Gtk::manage (new ImpulseDenoise ());
     defringe            = Gtk::manage (new Defringe ());
     dirpyrdenoise       = Gtk::manage (new DirPyrDenoise ());
-    edgePreservingDecompositionUI = Gtk::manage (new EdgePreservingDecompositionUI ());
+    epd                 = Gtk::manage (new EdgePreservingDecompositionUI ());
     sharpening          = Gtk::manage (new Sharpening ());
     sharpenEdge         = Gtk::manage (new SharpenEdge ());
     sharpenMicro        = Gtk::manage (new SharpenMicro ());
     lcurve              = Gtk::manage (new LCurve ());
     rgbcurves           = Gtk::manage (new RGBCurves ());
+    colortoning         = Gtk::manage (new ColorToning ());
     lensgeom            = Gtk::manage (new LensGeometry ());
     lensProf            = Gtk::manage (new LensProfilePanel ());
     distortion          = Gtk::manage (new Distortion ());
@@ -72,50 +73,75 @@ ToolPanelCoordinator::ToolPanelCoordinator () : ipc(NULL)  {
     iptcpanel           = Gtk::manage (new IPTCPanel ());
     dirpyrequalizer     = Gtk::manage (new DirPyrEqualizer ());
     hsvequalizer        = Gtk::manage (new HSVEqualizer ());
-    rawprocess          = Gtk::manage (new RawProcess ());
+    filmSimulation      = Gtk::manage (new FilmSimulation ());
+    sensorbayer         = Gtk::manage (new SensorBayer ());
+    sensorxtrans        = Gtk::manage (new SensorXTrans ());
+    bayerprocess        = Gtk::manage (new BayerProcess ());
+    xtransprocess       = Gtk::manage (new XTransProcess ());
+    bayerpreprocess     = Gtk::manage (new BayerPreProcess ());
     preprocess          = Gtk::manage (new PreProcess ());
     darkframe           = Gtk::manage (new DarkFrame ());
     flatfield           = Gtk::manage (new FlatField ());
     rawcacorrection     = Gtk::manage (new RAWCACorr ());
     rawexposure         = Gtk::manage (new RAWExposure ());
+    bayerrawexposure    = Gtk::manage (new BayerRAWExposure ());
+    xtransrawexposure   = Gtk::manage (new XTransRAWExposure ());
 
-    addPanel (colorPanel, whitebalance,             M("TP_WBALANCE_LABEL"));                toolPanels.push_back (whitebalance);
-    addPanel (exposurePanel, toneCurve,             M("TP_EXPOSURE_LABEL"));                toolPanels.push_back (toneCurve);
-    addPanel (colorPanel, vibrance,                 M("TP_VIBRANCE_LABEL"));                toolPanels.push_back (vibrance);
-    addPanel (colorPanel, chmixer,                  M("TP_CHMIXER_LABEL"));                 toolPanels.push_back (chmixer);
-    addPanel (colorPanel, blackwhite,               M("TP_BWMIX_LABEL"));                   toolPanels.push_back (blackwhite);
-    addPanel (exposurePanel, shadowshighlights,     M("TP_SHADOWSHLIGHTS_LABEL"));          toolPanels.push_back (shadowshighlights);
-    addPanel (detailsPanel, sharpening,             M("TP_SHARPENING_LABEL"), true);        toolPanels.push_back (sharpening);
-    addPanel (detailsPanel, sharpenEdge,            M("TP_SHARPENEDGE_LABEL"), true);       toolPanels.push_back (sharpenEdge);
-    addPanel (detailsPanel, sharpenMicro,           M("TP_SHARPENMICRO_LABEL"), true);      toolPanels.push_back (sharpenMicro);
-    addPanel (colorPanel, hsvequalizer,             M("TP_HSVEQUALIZER_LABEL"));            toolPanels.push_back (hsvequalizer);
-    addPanel (colorPanel, rgbcurves,                M("TP_RGBCURVES_LABEL"));               toolPanels.push_back (rgbcurves);
-    addPanel (exposurePanel, edgePreservingDecompositionUI,      M("TP_EPD_LABEL"));        toolPanels.push_back (edgePreservingDecompositionUI);
-    addPanel (exposurePanel, pcvignette,            M("TP_PCVIGNETTE_LABEL"));              toolPanels.push_back (pcvignette);
-    addPanel (exposurePanel, gradient,              M("TP_GRADIENT_LABEL"));                toolPanels.push_back (gradient);
-    addPanel (exposurePanel, lcurve,                M("TP_LABCURVE_LABEL"));                toolPanels.push_back (lcurve);
-//  addPanel (exposurePanel, edgePreservingDecompositionUI,      M("TP_EPD_LABEL"));        toolPanels.push_back (edgePreservingDecompositionUI);
-    addPanel (exposurePanel, colorappearance,       M("TP_COLORAPP_LABEL"));                toolPanels.push_back (colorappearance);
-    addPanel (detailsPanel, impulsedenoise,         M("TP_IMPULSEDENOISE_LABEL"), true);    toolPanels.push_back (impulsedenoise);
-    addPanel (detailsPanel, dirpyrdenoise,          M("TP_DIRPYRDENOISE_LABEL"), true);     toolPanels.push_back (dirpyrdenoise);
-    addPanel (detailsPanel, defringe,               M("TP_DEFRINGE_LABEL"), true);          toolPanels.push_back (defringe);
-    addPanel (detailsPanel, dirpyrequalizer,        M("TP_DIRPYREQUALIZER_LABEL"), true);   toolPanels.push_back (dirpyrequalizer);
-    addPanel (transformPanel, crop,                 M("TP_CROP_LABEL"));                    toolPanels.push_back (crop);
-    addPanel (transformPanel, resize,               M("TP_RESIZE_LABEL"));                  toolPanels.push_back (resize);
-    addPanel (transformPanel, lensgeom,             M("TP_LENSGEOM_LABEL"));                toolPanels.push_back (lensgeom);
-    addPanel (lensgeom->getPackBox(), rotate,       M("TP_ROTATE_LABEL"));                  toolPanels.push_back (rotate);
-    addPanel (lensgeom->getPackBox(), perspective,  M("TP_PERSPECTIVE_LABEL"));             toolPanels.push_back (perspective);
-    addPanel (lensgeom->getPackBox(), lensProf,     M("TP_LENSPROFILE_LABEL"));             toolPanels.push_back (lensProf);
-    addPanel (lensgeom->getPackBox(), distortion,   M("TP_DISTORTION_LABEL"));              toolPanels.push_back (distortion);
-    addPanel (lensgeom->getPackBox(), cacorrection, M("TP_CACORRECTION_LABEL"));            toolPanels.push_back (cacorrection);
-    addPanel (lensgeom->getPackBox(), vignetting,   M("TP_VIGNETTING_LABEL"));              toolPanels.push_back (vignetting);
-    addPanel (colorPanel, icm,                      M("TP_ICM_LABEL"));                     toolPanels.push_back (icm);
-    addPanel (rawPanel, rawprocess,                 M("TP_RAW_LABEL"), true);               toolPanels.push_back (rawprocess);
-    addPanel (rawPanel, preprocess,                 M("TP_PREPROCESS_LABEL"), true);        toolPanels.push_back (preprocess);
-    addPanel (rawPanel, rawexposure,                M("TP_EXPOSCORR_LABEL"));               toolPanels.push_back (rawexposure);
-    addPanel (rawPanel, darkframe,                  M("TP_DARKFRAME_LABEL"));               toolPanels.push_back (darkframe);
-    addPanel (rawPanel, flatfield,                  M("TP_FLATFIELD_LABEL"));               toolPanels.push_back (flatfield);
-    addPanel (rawPanel, rawcacorrection,            M("TP_CHROMATABERR_LABEL"));            toolPanels.push_back (rawcacorrection);
+    // So Demosaic, Line noise filter, Green Equilibration, Ca-Correction (garder le nom de section identique!) and Black-Level will be moved in a "Bayer sensor" tool,
+    // and a separate Demosaic and Black Level tool will be created in an "X-Trans sensor" tool
+
+    // X-Trans demozaic methods: "3-pass (best), 1-pass (medium), fast"
+    // Mettre  jour les profils fournis pour inclure les nouvelles section Raw, notamment pour "Default High ISO"
+    // Valeurs par dfaut:
+    //     Best -> low ISO
+    //     Medium -> High ISO
+
+    addPanel (colorPanel, whitebalance,                       M("TP_WBALANCE_LABEL"));                toolPanels.push_back (whitebalance);
+    addPanel (exposurePanel, toneCurve,                       M("TP_EXPOSURE_LABEL"));                toolPanels.push_back (toneCurve);
+    addPanel (colorPanel, vibrance,                           M("TP_VIBRANCE_LABEL"));                toolPanels.push_back (vibrance);
+    addPanel (colorPanel, chmixer,                            M("TP_CHMIXER_LABEL"));                 toolPanels.push_back (chmixer);
+    addPanel (colorPanel, blackwhite,                         M("TP_BWMIX_LABEL"));                   toolPanels.push_back (blackwhite);
+    addPanel (exposurePanel, shadowshighlights,               M("TP_SHADOWSHLIGHTS_LABEL"));          toolPanels.push_back (shadowshighlights);
+    addPanel (detailsPanel, sharpening,                       M("TP_SHARPENING_LABEL"), true);        toolPanels.push_back (sharpening);
+    addPanel (detailsPanel, sharpenEdge,                      M("TP_SHARPENEDGE_LABEL"), true);       toolPanels.push_back (sharpenEdge);
+    addPanel (detailsPanel, sharpenMicro,                     M("TP_SHARPENMICRO_LABEL"), true);      toolPanels.push_back (sharpenMicro);
+    addPanel (colorPanel, hsvequalizer,                       M("TP_HSVEQUALIZER_LABEL"));            toolPanels.push_back (hsvequalizer);
+    addPanel (colorPanel, filmSimulation,                     M("TP_FILMSIMULATION_LABEL"));          toolPanels.push_back (filmSimulation);
+    addPanel (colorPanel, rgbcurves,                          M("TP_RGBCURVES_LABEL"));               toolPanels.push_back (rgbcurves);
+	addPanel (colorPanel, colortoning,						  M("TP_COLORTONING_LABEL"));             toolPanels.push_back (colortoning);
+    addPanel (exposurePanel, epd,                             M("TP_EPD_LABEL"), true);               toolPanels.push_back (epd);
+    addPanel (exposurePanel, pcvignette,                      M("TP_PCVIGNETTE_LABEL"));              toolPanels.push_back (pcvignette);
+    addPanel (exposurePanel, gradient,                        M("TP_GRADIENT_LABEL"));                toolPanels.push_back (gradient);
+    addPanel (exposurePanel, lcurve,                          M("TP_LABCURVE_LABEL"));                toolPanels.push_back (lcurve);
+    addPanel (exposurePanel, colorappearance,                 M("TP_COLORAPP_LABEL"));                toolPanels.push_back (colorappearance);
+    addPanel (detailsPanel, impulsedenoise,                   M("TP_IMPULSEDENOISE_LABEL"), true);    toolPanels.push_back (impulsedenoise);
+    addPanel (detailsPanel, dirpyrdenoise,                    M("TP_DIRPYRDENOISE_LABEL"), true);     toolPanels.push_back (dirpyrdenoise);
+    addPanel (detailsPanel, defringe,                         M("TP_DEFRINGE_LABEL"), true);          toolPanels.push_back (defringe);
+    addPanel (detailsPanel, dirpyrequalizer,                  M("TP_DIRPYREQUALIZER_LABEL"), true);   toolPanels.push_back (dirpyrequalizer);
+    addPanel (transformPanel, crop,                           M("TP_CROP_LABEL"));                    toolPanels.push_back (crop);
+    addPanel (transformPanel, resize,                         M("TP_RESIZE_LABEL"));                  toolPanels.push_back (resize);
+    addPanel (transformPanel, lensgeom,                       M("TP_LENSGEOM_LABEL"));                toolPanels.push_back (lensgeom);
+    addPanel (lensgeom->getPackBox(), rotate,                 M("TP_ROTATE_LABEL"));                  toolPanels.push_back (rotate);
+    addPanel (lensgeom->getPackBox(), perspective,            M("TP_PERSPECTIVE_LABEL"));             toolPanels.push_back (perspective);
+    addPanel (lensgeom->getPackBox(), lensProf,               M("TP_LENSPROFILE_LABEL"));             toolPanels.push_back (lensProf);
+    addPanel (lensgeom->getPackBox(), distortion,             M("TP_DISTORTION_LABEL"));              toolPanels.push_back (distortion);
+    addPanel (lensgeom->getPackBox(), cacorrection,           M("TP_CACORRECTION_LABEL"));            toolPanels.push_back (cacorrection);
+    addPanel (lensgeom->getPackBox(), vignetting,             M("TP_VIGNETTING_LABEL"));              toolPanels.push_back (vignetting);
+    addPanel (colorPanel, icm,                                M("TP_ICM_LABEL"));                     toolPanels.push_back (icm);
+    addPanel (rawPanel, sensorbayer,                          M("TP_RAW_SENSOR_BAYER_LABEL"));        toolPanels.push_back (sensorbayer);
+    addPanel (sensorbayer->getPackBox(), bayerprocess,        M("TP_RAW_LABEL"), true);               toolPanels.push_back (bayerprocess);
+    addPanel (sensorbayer->getPackBox(), bayerrawexposure,    M("TP_EXPOS_BLACKPOINT_LABEL"));        toolPanels.push_back (bayerrawexposure);
+    addPanel (sensorbayer->getPackBox(), bayerpreprocess,     M("TP_PREPROCESS_LABEL"), true);        toolPanels.push_back (bayerpreprocess);
+    addPanel (sensorbayer->getPackBox(), rawcacorrection,     M("TP_CHROMATABERR_LABEL"));            toolPanels.push_back (rawcacorrection);
+    addPanel (rawPanel, sensorxtrans,                         M("TP_RAW_SENSOR_XTRANS_LABEL"));       toolPanels.push_back (sensorxtrans);
+    addPanel (sensorxtrans->getPackBox(), xtransprocess,      M("TP_RAW_LABEL"), true);               toolPanels.push_back (xtransprocess);
+    addPanel (sensorxtrans->getPackBox(), xtransrawexposure,  M("TP_EXPOS_BLACKPOINT_LABEL"));        toolPanels.push_back (xtransrawexposure);
+    addPanel (rawPanel, rawexposure,                          M("TP_EXPOS_WHITEPOINT_LABEL"));        toolPanels.push_back (rawexposure);
+    addPanel (rawPanel, preprocess,                           M("TP_PREPROCESS_LABEL"), true);        toolPanels.push_back (preprocess);
+    addPanel (rawPanel, darkframe,                            M("TP_DARKFRAME_LABEL"));               toolPanels.push_back (darkframe);
+    addPanel (rawPanel, flatfield,                            M("TP_FLATFIELD_LABEL"));               toolPanels.push_back (flatfield);
+ 
+ 
 
     toolPanels.push_back (coarse);
     toolPanels.push_back (exifpanel);
@@ -145,24 +171,24 @@ ToolPanelCoordinator::ToolPanelCoordinator () : ipc(NULL)  {
     }
 
     exposurePanelSW->add  (*exposurePanel);
-    exposurePanel->pack_start (*Gtk::manage(new Gtk::HSeparator), Gtk::PACK_SHRINK,4);
+    exposurePanel->pack_start (*Gtk::manage(new Gtk::HSeparator), Gtk::PACK_SHRINK,0);
     exposurePanel->pack_start (*vbPanelEnd[0],Gtk::PACK_SHRINK,4);
 
     detailsPanelSW->add   (*detailsPanel);
-    detailsPanel->pack_start (*Gtk::manage(new Gtk::HSeparator), Gtk::PACK_SHRINK,4);
+    detailsPanel->pack_start (*Gtk::manage(new Gtk::HSeparator), Gtk::PACK_SHRINK,0);
     detailsPanel->pack_start (*vbPanelEnd[1],Gtk::PACK_SHRINK,4);
 
     colorPanelSW->add     (*colorPanel);
-    colorPanel->pack_start (*Gtk::manage(new Gtk::HSeparator), Gtk::PACK_SHRINK,4);
+    colorPanel->pack_start (*Gtk::manage(new Gtk::HSeparator), Gtk::PACK_SHRINK,0);
     colorPanel->pack_start (*vbPanelEnd[2],Gtk::PACK_SHRINK,4);
 
     transformPanelSW->add (*transformPanel);
-    transformPanel->pack_start (*Gtk::manage(new Gtk::HSeparator), Gtk::PACK_SHRINK,4);
+    transformPanel->pack_start (*Gtk::manage(new Gtk::HSeparator), Gtk::PACK_SHRINK,0);
     transformPanel->pack_start (*vbPanelEnd[3],Gtk::PACK_SHRINK,4);
 
     rawPanelSW->add       (*rawPanel);
-    rawPanel->pack_start (*Gtk::manage(new Gtk::HSeparator), Gtk::PACK_SHRINK,4);
-    rawPanel->pack_start (*vbPanelEnd[4],Gtk::PACK_SHRINK,4);
+    rawPanel->pack_start (*Gtk::manage(new Gtk::HSeparator), Gtk::PACK_SHRINK,0);
+    rawPanel->pack_start (*vbPanelEnd[4],Gtk::PACK_SHRINK,0);
 
     TOITypes type = options.UseIconNoText ? TOI_ICON : TOI_TEXT;
 
@@ -204,17 +230,18 @@ ToolPanelCoordinator::ToolPanelCoordinator () : ipc(NULL)  {
 
 void ToolPanelCoordinator::addPanel (Gtk::Box* where, FoldableToolPanel* panel, Glib::ustring label, bool need100Percent) {
 
-    if (where->children().size()) {
+    // no more separator!
+    /*if (where->children().size()) {
         Gtk::HSeparator *hsep = Gtk::manage (new  Gtk::HSeparator());
         where->pack_start(*hsep, Gtk::PACK_SHRINK, 0);
         hsep->show();
-    }
+    }*/
 
     panel->setParent(where);
     panel->setLabel(escapeHtmlChars(label), need100Percent);
 
-	expList.push_back (panel->exp);
-    where->pack_start(*panel->exp, false, false);
+    expList.push_back (panel->getExpander());
+    where->pack_start(*panel->getExpander(), false, false);
 }
 
 ToolPanelCoordinator::~ToolPanelCoordinator () {
@@ -254,7 +281,7 @@ void ToolPanelCoordinator::panelChanged (rtengine::ProcEvent event, const Glib::
         crop->write (params);
     }
     else if (event==rtengine::EvCTRotate) {
-        crop->rotateCrop (params->coarse.rotate);
+        crop->rotateCrop (params->coarse.rotate, params->coarse.hflip, params->coarse.vflip);
         crop->write (params);
         resize->update (params->crop.enabled, params->crop.w, params->crop.h, ipc->getFullWidth(), ipc->getFullHeight());
         resize->write (params);
@@ -301,7 +328,7 @@ void ToolPanelCoordinator::profileChange  (const PartialProfile *nparams, rtengi
         pe.set(true);
         pe.initFrom (lParams);
 
-        filterRawRefresh=pe.raw.isUnchanged() && pe.lensProf.isUnchanged();
+        filterRawRefresh = pe.raw.isUnchanged() && pe.lensProf.isUnchanged();
     }
 
     *params = *mergedParams;
@@ -363,6 +390,7 @@ void ToolPanelCoordinator::initImage (rtengine::StagedImageProcessor* ipc_, bool
         ipc->setAutoExpListener (toneCurve);
         ipc->setAutoCamListener (colorappearance);
         ipc->setAutoBWListener (blackwhite);
+        ipc->setAutoColorTonListener (colortoning);
 
         ipc->setSizeListener (crop);
         ipc->setSizeListener (resize);
@@ -492,6 +520,15 @@ rtengine::RawImage* ToolPanelCoordinator::getFF()
     }
     return NULL;
 }
+
+Glib::ustring ToolPanelCoordinator::GetCurrentImageFilePath()
+{
+	if (!ipc){
+        return "";
+    }
+    return ipc->getInitialImage()->getFileName();
+}
+
 void ToolPanelCoordinator::straightenRequested () {
 
     if (!ipc)
@@ -533,27 +570,27 @@ int ToolPanelCoordinator::getSpotWBRectSize () {
     return whitebalance->getSize ();
 }
 
-void ToolPanelCoordinator::updateCurveBackgroundHistogram (LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve, LUTu & histCLurve, LUTu & histLLCurve, LUTu & histLCAM, LUTu & histCCAM, LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma) {
-    colorappearance->updateCurveBackgroundHistogram (histToneCurve, histLCurve, histCCurve, histCLurve, histLLCurve, histLCAM,  histCCAM,histRed, histGreen, histBlue, histLuma);
-    toneCurve->updateCurveBackgroundHistogram (histToneCurve, histLCurve,histCCurve, histCLurve, histLLCurve, histLCAM,  histCCAM,histRed, histGreen, histBlue, histLuma);
-    lcurve->updateCurveBackgroundHistogram (histToneCurve, histLCurve, histCCurve, histCLurve, histLLCurve, histLCAM, histCCAM,histRed, histGreen, histBlue, histLuma); 
-	rgbcurves->updateCurveBackgroundHistogram(histToneCurve, histLCurve, histCCurve, histCLurve, histLLCurve, histLCAM, histCCAM,histRed,histGreen, histBlue, histLuma);
+void ToolPanelCoordinator::updateCurveBackgroundHistogram (LUTu & histToneCurve, LUTu & histLCurve, LUTu & histCCurve, /*LUTu & histCLurve, LUTu & histLLCurve,*/ LUTu & histLCAM, LUTu & histCCAM, LUTu & histRed, LUTu & histGreen, LUTu & histBlue, LUTu & histLuma) {
+    colorappearance->updateCurveBackgroundHistogram (histToneCurve, histLCurve, histCCurve, /*histCLurve, histLLCurve,*/ histLCAM,  histCCAM,histRed, histGreen, histBlue, histLuma);
+    toneCurve->updateCurveBackgroundHistogram (histToneCurve, histLCurve,histCCurve,/* histCLurve, histLLCurve,*/ histLCAM,  histCCAM,histRed, histGreen, histBlue, histLuma);
+    lcurve->updateCurveBackgroundHistogram (histToneCurve, histLCurve, histCCurve, /*histCLurve, histLLCurve,*/ histLCAM, histCCAM,histRed, histGreen, histBlue, histLuma); 
+	rgbcurves->updateCurveBackgroundHistogram(histToneCurve, histLCurve, histCCurve,/* histCLurve, histLLCurve, */histLCAM, histCCAM,histRed,histGreen, histBlue, histLuma);
 }
 
 void ToolPanelCoordinator::foldAllButOne (Gtk::Box* parent, FoldableToolPanel* openedSection) {
 
-	FoldableToolPanel* currentTP;
-
-	for (size_t i=0; i<toolPanels.size(); i++) {
-	currentTP = static_cast<FoldableToolPanel*>(toolPanels[i]);
-        if (currentTP->getParent() == parent) {
-            // Section in the same tab, we unfold it if it's not the one that has been clicked
-            if (currentTP != openedSection) {
-                currentTP->exp->set_expanded(false);
-            }
-            else {
-                if (!currentTP->exp->get_expanded())
-                    currentTP->exp->set_expanded(true);
+    for (size_t i=0; i<toolPanels.size(); i++) {
+        if (toolPanels[i]->getParent() != NULL) {
+            ToolPanel* currentTP = toolPanels[i];
+            if (currentTP->getParent() == parent) {
+                // Section in the same tab, we unfold it if it's not the one that has been clicked
+                if (currentTP != openedSection) {
+                    currentTP->setExpanded(false);
+                }
+                else {
+                    if (!currentTP->getExpanded())
+                        currentTP->setExpanded(true);
+                }
             }
         }
     }
@@ -561,8 +598,8 @@ void ToolPanelCoordinator::foldAllButOne (Gtk::Box* parent, FoldableToolPanel* o
 
 bool ToolPanelCoordinator::handleShortcutKey (GdkEventKey* event) {
 
-    //bool ctrl = event->state & GDK_CONTROL_MASK;  temporarilly removed because unused
-    //bool shift = event->state & GDK_SHIFT_MASK;   temporarilly removed because unused
+    //bool ctrl = event->state & GDK_CONTROL_MASK;  temporarily removed because unused
+    //bool shift = event->state & GDK_SHIFT_MASK;   temporarily removed because unused
     bool alt = event->state & GDK_MOD1_MASK;
 
     if (alt){
@@ -627,16 +664,16 @@ void ToolPanelCoordinator::toolSelected (ToolMode tool) {
     GThreadLock lock; // All GUI acces from idle_add callbacks or separate thread HAVE to be protected
 	switch (tool) {
 	case TMCropSelect:
-		crop->exp->set_expanded(true);
+		crop->setExpanded(true);
 		toolPanelNotebook->set_current_page(toolPanelNotebook->page_num(*transformPanelSW));
 		break;
 	case TMSpotWB:
-		whitebalance->exp->set_expanded(true);
+		whitebalance->setExpanded(true);
 		toolPanelNotebook->set_current_page(toolPanelNotebook->page_num(*colorPanelSW));
 		break;
 	case TMStraighten:
-		lensgeom->exp->set_expanded(true);
-		rotate->exp->set_expanded(true);
+		lensgeom->setExpanded(true);
+		rotate->setExpanded(true);
 		toolPanelNotebook->set_current_page(toolPanelNotebook->page_num(*transformPanelSW));
 		break;
 	default:
@@ -644,7 +681,19 @@ void ToolPanelCoordinator::toolSelected (ToolMode tool) {
 	}
 }
 
+void ToolPanelCoordinator::editModeSwitchedOff () {
+	if (editDataProvider) {
+		editDataProvider->switchOffEditMode();
+	}
+}
+
 void ToolPanelCoordinator::dirSelected (const Glib::ustring& dirname, const Glib::ustring& openfile) {
 
     flatfield->setShortcutPath(dirname);
 }
+
+void ToolPanelCoordinator::setEditProvider(EditDataProvider *provider) {
+	editDataProvider = provider;
+	for (size_t i=0; i<toolPanels.size(); i++)
+		toolPanels.at(i)->setEditProvider(provider);
+}
