@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -26,29 +26,37 @@
 #include "wbprovider.h"
 #include "../rtengine/procparams.h"
 
-class SpotWBListener {
+class SpotWBListener
+{
 
-    public: 
-        virtual void spotWBRequested (int size) {}
+public:
+    virtual void spotWBRequested (int size) {}
 };
 
-class WhiteBalance : public Gtk::VBox, public AdjusterListener, public FoldableToolPanel {
+class WhiteBalance : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel
+{
 
     enum WB_LabelType {
         WBLT_GUI,
         WBLT_PP
     };
 
-  protected:
-    class MethodColumns : public Gtk::TreeModel::ColumnRecord {
-      public:
+protected:
+    class MethodColumns : public Gtk::TreeModel::ColumnRecord
+    {
+    public:
         Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > colIcon;
         Gtk::TreeModelColumn<Glib::ustring> colLabel;
         Gtk::TreeModelColumn<int> colId;
-        MethodColumns() { add(colIcon); add(colLabel); add(colId); }
+        MethodColumns()
+        {
+            add(colIcon);
+            add(colLabel);
+            add(colId);
+        }
     };
 
-    static Glib::RefPtr<Gdk::Pixbuf> wbPixbufs[rtengine::procparams::WBT_CUSTOM+1];
+    static Glib::RefPtr<Gdk::Pixbuf> wbPixbufs[rtengine::procparams::WBT_CUSTOM + 1];
     Glib::RefPtr<Gtk::TreeStore> refTreeModel;
     MethodColumns methodColumns;
     MyComboBox* method;
@@ -76,30 +84,36 @@ class WhiteBalance : public Gtk::VBox, public AdjusterListener, public FoldableT
     int _setActiveMethod   (Glib::ustring &label, Gtk::TreeModel::Children &children);
 
     Gtk::TreeModel::Row            getActiveMethod ();
-    int                            findWBEntryId   (Glib::ustring label, enum WB_LabelType lblType=WBLT_GUI);
-    rtengine::procparams::WBEntry* findWBEntry     (Glib::ustring label, enum WB_LabelType lblType=WBLT_GUI);
+    int                            findWBEntryId   (Glib::ustring label, enum WB_LabelType lblType = WBLT_GUI);
+    rtengine::procparams::WBEntry* findWBEntry     (Glib::ustring label, enum WB_LabelType lblType = WBLT_GUI);
 
-  public:
+public:
 
     WhiteBalance ();
     ~WhiteBalance () {};
 
     static void init    ();
     static void cleanup ();
-    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited=NULL); 
-    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited=NULL);
-    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
+    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited = NULL);
+    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited = NULL);
+    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited = NULL);
     void setBatchMode   (bool batchMode);
-    
+
     void optChanged ();
     void spotPressed ();
     void spotSizeChanged ();
     void adjusterChanged (Adjuster* a, double newval);
-    int  getSize (); 
-    void setWBProvider (WBProvider* p) { wbp = p; }
-    void setSpotWBListener (SpotWBListener* l) { wblistener = l; }
+    int  getSize ();
+    void setWBProvider (WBProvider* p)
+    {
+        wbp = p;
+    }
+    void setSpotWBListener (SpotWBListener* l)
+    {
+        wblistener = l;
+    }
     void setWB (int temp, double green);
-    
+
     void setAdjusterBehavior (bool tempadd, bool greenadd, bool equaladd);
     void trimValues          (rtengine::procparams::ProcParams* pp);
 };
